# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/nativeact/v1/nativeact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/nativeact/v1/nativeact.proto\x12\x19\x62ilibili.app.nativeact.v1\x1a\x19google/protobuf/any.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"I\n\x04\x41rea\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x0c\n\x04ukey\x18\x05 \x01(\t\"?\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\"d\n\x0f\x43\x61rouselImgCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12:\n\x06images\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgItem\"\x90\x01\n\x0f\x43\x61rouselImgItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\x03\x12\r\n\x05width\x18\x04 \x01(\x03\x12\x32\n\x07top_tab\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\x12\x0e\n\x06height\x18\x06 \x01(\x03\"z\n\x10\x43\x61rouselWordCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12\x13\n\x0bscroll_type\x18\x02 \x01(\x03\x12:\n\x05words\x18\x03 \x03(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordItem\"#\n\x10\x43\x61rouselWordItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x91\x06\n\x05\x43olor\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x13\n\x0btitle_color\x18\x02 \x01(\t\x12\x16\n\x0etop_font_color\x18\x03 \x01(\t\x12\x19\n\x11\x62ottom_font_color\x18\x04 \x01(\t\x12\x12\n\nfont_color\x18\x05 \x01(\t\x12\x1d\n\x15text_title_font_color\x18\x06 \x01(\t\x12\x17\n\x0findicator_color\x18\x07 \x01(\t\x12\x15\n\rcard_bg_color\x18\x08 \x01(\t\x12\x1d\n\x15\x63\x61rd_title_font_color\x18\t \x01(\t\x12\x1b\n\x13\x63\x61rd_title_bg_color\x18\n \x01(\t\x12\x1c\n\x14view_more_font_color\x18\x0b \x01(\t\x12\x1a\n\x12view_more_bg_color\x18\x0c \x01(\t\x12\x16\n\x0etimeline_color\x18\r \x01(\t\x12\x17\n\x0frcmd_font_color\x18\x0e \x01(\t\x12\x1b\n\x13subtitle_font_color\x18\x0f \x01(\t\x12\x1b\n\x13selected_font_color\x18\x10 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x11 \x01(\t\x12\x1d\n\x15unselected_font_color\x18\x12 \x01(\t\x12\x1b\n\x13unselected_bg_color\x18\x13 \x01(\t\x12\x1e\n\x16nt_selected_font_color\x18\x14 \x01(\t\x12\x1c\n\x14nt_selected_bg_color\x18\x15 \x01(\t\x12 \n\x18nt_unselected_font_color\x18\x16 \x01(\t\x12\x1e\n\x16nt_unselected_bg_color\x18\x17 \x01(\t\x12\x1a\n\x12progress_bar_color\x18\x18 \x01(\t\x12\x16\n\x0epanel_bg_color\x18\x19 \x01(\t\x12\x1a\n\x12panel_select_color\x18\x1a \x01(\t\x12\x1f\n\x17panel_select_font_color\x18\x1b \x01(\t\x12\"\n\x1apanel_nt_select_font_color\x18\x1c \x01(\t\"m\n\x12\x44ynamicActMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"D\n\x0b\x44ynamicCard\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"j\n\x0f\x44ynamicMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\x84\x01\n\rDynamicParams\x12)\n\x0b\x66\x65\x65\x64_offset\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x12\n\nlast_group\x18\x03 \x01(\x03\x12\x11\n\tmodule_id\x18\x04 \x01(\x03\x12\x11\n\tsort_type\x18\x05 \x01(\x03\"\xf7\x01\n\nDynamicReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.DynamicParams\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\x07 \x01(\x03\"@\n\x0b\x44ynamicResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"1\n\x0c\x45\x64itorParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\"\xfa\x03\n\x13\x45\x64itorRecommendCard\x12\x10\n\x08top_icon\x18\x01 \x01(\t\x12\x13\n\x0btop_content\x18\x02 \x01(\t\x12\x13\n\x0b\x62ottom_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x62ottom_content\x18\x04 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x11\n\tposition1\x18\x08 \x01(\t\x12\x11\n\tposition2\x18\t \x01(\t\x12\x11\n\tposition3\x18\n \x01(\t\x12\x11\n\tposition4\x18\x0b \x01(\t\x12\x11\n\tposition5\x18\x0c \x01(\t\x12/\n\x05share\x18\r \x01(\x0b\x32 .bilibili.app.nativeact.v1.Share\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x0f \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x33\n\x07setting\x18\x10 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12\x13\n\x0bmiddle_icon\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"q\n\tEditorReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.EditorParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"?\n\nEditorResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"[\n\x0f\x46ollowOgvParams\x12\x35\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32%.bilibili.app.nativeact.v1.ActionType\x12\x11\n\tseason_id\x18\x02 \x01(\x05\"^\n\x0c\x46ollowOgvReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32*.bilibili.app.nativeact.v1.FollowOgvParams\"%\n\x0c\x46ollowOgvRly\x12\x15\n\rfollow_params\x18\x01 \x01(\t\"X\n\x08GameCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\"\xd7\x01\n\nHeaderCard\x12\x12\n\nuser_image\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x17\n\x0fsponsor_content\x18\x03 \x01(\t\x12\x18\n\x10high_light_image\x18\x04 \x01(\t\x12\x17\n\x0flow_light_image\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08view_num\x18\x07 \x01(\t\x12\x13\n\x0b\x64iscuss_num\x18\x08 \x01(\t\x12\x15\n\ris_subscribed\x18\t \x01(\x08\x12\x0b\n\x03mid\x18\n \x01(\x03\">\n\x08IconCard\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.nativeact.v1.IconItem\"5\n\x08IconItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x1f\n\x0eImageTitleCard\x12\r\n\x05image\x18\x01 \x01(\t\"\xde\x02\n\x08IndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\r \x01(\x03\x12\x10\n\x08tab_from\x18\x0e \x01(\t\"\xbc\x01\n\x0eInlineIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\"T\n\x0cLayerDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x07\x64ynamic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"R\n\x08LiveCard\x12\x10\n\x08has_live\x18\x01 \x01(\x05\x12\x34\n\x07\x63ontent\x18\x02 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveItem\"\xf9\x02\n\x08LiveItem\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x13\n\x0blive_status\x18\x03 \x01(\x03\x12\x11\n\troom_type\x18\x04 \x01(\x03\x12\x11\n\tplay_type\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x63over\x18\x07 \x01(\t\x12\x0e\n\x06online\x18\x08 \x01(\x03\x12\x0f\n\x07\x61rea_id\x18\t \x01(\x03\x12\x11\n\tarea_name\x18\n \x01(\t\x12\x16\n\x0eparent_area_id\x18\x0b \x01(\x03\x12\x18\n\x10parent_area_name\x18\x0c \x01(\t\x12\x18\n\x10live_screen_type\x18\r \x01(\x03\x12\x15\n\rlast_end_time\x18\x0e \x01(\x03\x12\x0c\n\x04link\x18\x0f \x01(\t\x12\x0f\n\x07live_id\x18\x10 \x01(\x03\x12@\n\x0cwatched_show\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.LiveWatchedShow\"{\n\x0fLiveWatchedShow\x12\x0e\n\x06switch\x18\x01 \x01(\x08\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x12\n\ntext_small\x18\x03 \x01(\t\x12\x12\n\ntext_large\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x15\n\ricon_location\x18\x06 \x01(\t\"\xba\x01\n\nMessageBox\x12\x11\n\talert_msg\x18\x01 \x01(\t\x12\x1b\n\x13\x63onfirm_button_text\x18\x02 \x01(\t\x12\x1a\n\x12\x63\x61ncel_button_text\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfirm_msg\x18\x04 \x01(\t\x12\x12\n\ncancel_msg\x18\x05 \x01(\t\x12\x37\n\x04type\x18\x06 \x01(\x0e\x32).bilibili.app.nativeact.v1.MessageBoxType\"\xb1\x02\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\x12\x36\n\x0cmodule_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12:\n\x0emodule_setting\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12;\n\x0cmodule_items\x18\x05 \x03(\x0b\x32%.bilibili.app.nativeact.v1.ModuleItem\x12\x16\n\x0esubpage_params\x18\x06 \x01(\t\x12\x13\n\x0bmodule_ukey\x18\x07 \x01(\t\x12\x10\n\x08has_more\x18\x08 \x01(\x08\x12\x0f\n\x07is_feed\x18\t \x01(\x08\"\x9c \n\nModuleItem\x12G\n\tcard_type\x18\x01 \x01(\x0e\x32\x34.bilibili.app.nativeact.v1.ModuleItem.CardDetailCase\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\t\x12O\n\x15\x65\x64itor_recommend_card\x18\n \x01(\x0b\x32..bilibili.app.nativeact.v1.EditorRecommendCardH\x00\x12J\n\x12participation_card\x18\x0b \x01(\x0b\x32,.bilibili.app.nativeact.v1.ParticipationCardH\x00\x12<\n\x0bheader_card\x18\x0c \x01(\x0b\x32%.bilibili.app.nativeact.v1.HeaderCardH\x00\x12>\n\x0c\x64ynamic_card\x18\r \x01(\x0b\x32&.bilibili.app.nativeact.v1.DynamicCardH\x00\x12\x38\n\ttext_card\x18\x0e \x01(\x0b\x32#.bilibili.app.nativeact.v1.TextCardH\x00\x12\x43\n\x0ftext_title_card\x18\x0f \x01(\x0b\x32(.bilibili.app.nativeact.v1.TextTitleCardH\x00\x12\x45\n\x10image_title_card\x18\x10 \x01(\x0b\x32).bilibili.app.nativeact.v1.ImageTitleCardH\x00\x12G\n\x11\x64ynamic_more_card\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.DynamicMoreCardH\x00\x12N\n\x15\x64ynamic_act_more_card\x18\x12 \x01(\x0b\x32-.bilibili.app.nativeact.v1.DynamicActMoreCardH\x00\x12\x38\n\tlive_card\x18\x13 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveCardH\x00\x12G\n\x11\x63\x61rousel_img_card\x18\x14 \x01(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgCardH\x00\x12I\n\x12\x63\x61rousel_word_card\x18\x15 \x01(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordCardH\x00\x12@\n\rresource_card\x18\x16 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ResourceCardH\x00\x12I\n\x12resource_more_card\x18\x17 \x01(\x0b\x32+.bilibili.app.nativeact.v1.ResourceMoreCardH\x00\x12\x38\n\tgame_card\x18\x18 \x01(\x0b\x32#.bilibili.app.nativeact.v1.GameCardH\x00\x12:\n\nvideo_card\x18\x19 \x01(\x0b\x32$.bilibili.app.nativeact.v1.VideoCardH\x00\x12\x43\n\x0fvideo_more_card\x18\x1a \x01(\x0b\x32(.bilibili.app.nativeact.v1.VideoMoreCardH\x00\x12=\n\x0erecommend_card\x18\x1b \x01(\x0b\x32#.bilibili.app.nativeact.v1.RcmdCardH\x00\x12N\n\x17recommend_vertical_card\x18\x1c \x01(\x0b\x32+.bilibili.app.nativeact.v1.RcmdVerticalCardH\x00\x12\x46\n\x10relativeact_card\x18\x1d \x01(\x0b\x32*.bilibili.app.nativeact.v1.RelativeactCardH\x00\x12U\n\x18relativeact_capsule_card\x18\x1e \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.RelativeactCapsuleCardH\x00\x12\x42\n\x0estatement_card\x18\x1f \x01(\x0b\x32(.bilibili.app.nativeact.v1.StatementCardH\x00\x12\x38\n\ticon_card\x18  \x01(\x0b\x32#.bilibili.app.nativeact.v1.IconCardH\x00\x12\x38\n\tvote_card\x18! \x01(\x0b\x32#.bilibili.app.nativeact.v1.VoteCardH\x00\x12>\n\x0creserve_card\x18\" \x01(\x0b\x32&.bilibili.app.nativeact.v1.ReserveCardH\x00\x12I\n\x12timeline_head_card\x18# \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineHeadCardH\x00\x12T\n\x18timeline_event_text_card\x18$ \x01(\x0b\x32\x30.bilibili.app.nativeact.v1.TimelineEventTextCardH\x00\x12V\n\x19timeline_event_image_card\x18% \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.TimelineEventImageCardH\x00\x12^\n\x1dtimeline_event_imagetext_card\x18& \x01(\x0b\x32\x35.bilibili.app.nativeact.v1.TimelineEventImagetextCardH\x00\x12\\\n\x1ctimeline_event_resource_card\x18\' \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineEventResourceCardH\x00\x12I\n\x12timeline_more_card\x18( \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineMoreCardH\x00\x12M\n\x14timeline_unfold_card\x18) \x01(\x0b\x32-.bilibili.app.nativeact.v1.TimelineUnfoldCardH\x00\x12=\n\x0cogv_one_card\x18* \x01(\x0b\x32%.bilibili.app.nativeact.v1.OgvOneCardH\x00\x12\x41\n\x0eogv_three_card\x18+ \x01(\x0b\x32\'.bilibili.app.nativeact.v1.OgvThreeCardH\x00\x12?\n\rogv_more_card\x18, \x01(\x0b\x32&.bilibili.app.nativeact.v1.OgvMoreCardH\x00\x12\x44\n\x0fnavigation_card\x18- \x01(\x0b\x32).bilibili.app.nativeact.v1.NavigationCardH\x00\x12:\n\nreply_card\x18. \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReplyCardH\x00\x12\x36\n\x08tab_card\x18/ \x01(\x0b\x32\".bilibili.app.nativeact.v1.TabCardH\x00\x12@\n\rnewact_header\x18\x30 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.NewactHeaderH\x00\x12>\n\x0cnewact_award\x18\x31 \x01(\x0b\x32&.bilibili.app.nativeact.v1.NewactAwardH\x00\x12\x46\n\x10newact_statement\x18\x32 \x01(\x0b\x32*.bilibili.app.nativeact.v1.NewactStatementH\x00\x12@\n\rprogress_card\x18\x33 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ProgressCardH\x00\x12<\n\x0bselect_card\x18\x34 \x01(\x0b\x32%.bilibili.app.nativeact.v1.SelectCardH\x00\"\xd6\x07\n\x0e\x43\x61rdDetailCase\x12\x16\n\x12\x43\x41RDDETAIL_NOT_SET\x10\x00\x12\x19\n\x15\x45\x44ITOR_RECOMMEND_CARD\x10\n\x12\x16\n\x12PARTICIPATION_CARD\x10\x0b\x12\x0f\n\x0bHEADER_CARD\x10\x0c\x12\x10\n\x0c\x44YNAMIC_CARD\x10\r\x12\r\n\tTEXT_CARD\x10\x0e\x12\x13\n\x0fTEXT_TITLE_CARD\x10\x0f\x12\x14\n\x10IMAGE_TITLE_CARD\x10\x10\x12\x15\n\x11\x44YNAMIC_MORE_CARD\x10\x11\x12\x19\n\x15\x44YNAMIC_ACT_MORE_CARD\x10\x12\x12\r\n\tLIVE_CARD\x10\x13\x12\x15\n\x11\x43\x41ROUSEL_IMG_CARD\x10\x14\x12\x16\n\x12\x43\x41ROUSEL_WORD_CARD\x10\x15\x12\x11\n\rRESOURCE_CARD\x10\x16\x12\x16\n\x12RESOURCE_MORE_CARD\x10\x17\x12\r\n\tGAME_CARD\x10\x18\x12\x0e\n\nVIDEO_CARD\x10\x19\x12\x13\n\x0fVIDEO_MORE_CARD\x10\x1a\x12\x12\n\x0eRECOMMEND_CARD\x10\x1b\x12\x1b\n\x17RECOMMEND_VERTICAL_CARD\x10\x1c\x12\x14\n\x10RELATIVEACT_CARD\x10\x1d\x12\x1c\n\x18RELATIVEACT_CAPSULE_CARD\x10\x1e\x12\x12\n\x0eSTATEMENT_CARD\x10\x1f\x12\r\n\tICON_CARD\x10 \x12\r\n\tVOTE_CARD\x10!\x12\x10\n\x0cRESERVE_CARD\x10\"\x12\x16\n\x12TIMELINE_HEAD_CARD\x10#\x12\x1c\n\x18TIMELINE_EVENT_TEXT_CARD\x10$\x12\x1d\n\x19TIMELINE_EVENT_IMAGE_CARD\x10%\x12!\n\x1dTIMELINE_EVENT_IMAGETEXT_CARD\x10&\x12 \n\x1cTIMELINE_EVENT_RESOURCE_CARD\x10\'\x12\x16\n\x12TIMELINE_MORE_CARD\x10(\x12\x18\n\x14TIMELINE_UNFOLD_CARD\x10)\x12\x10\n\x0cOGV_ONE_CARD\x10*\x12\x12\n\x0eOGV_THREE_CARD\x10+\x12\x11\n\rOGV_MORE_CARD\x10,\x12\x13\n\x0fNAVIGATION_CARD\x10-\x12\x0e\n\nREPLY_CARD\x10.\x12\x0c\n\x08TAB_CARD\x10/\x12\x16\n\x12NEWACT_HEADER_CARD\x10\x30\x12\x15\n\x11NEWACT_AWARD_CARD\x10\x31\x12\x19\n\x15NEWACT_STATEMENT_CARD\x10\x32\x12\x11\n\rPROGRESS_CARD\x10\x33\x12\x0f\n\x0bSELECT_CARD\x10\x34\x42\r\n\x0b\x63\x61rd_detail\"J\n\x0eNavigationCard\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32).bilibili.app.nativeact.v1.NavigationItem\"2\n\x0eNavigationItem\x12\x11\n\tmodule_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\"W\n\x0bNewactAward\x12\r\n\x05title\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.NewactAwardItem\"1\n\x0fNewactAwardItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"3\n\rNewactFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x02 \x01(\t\"\xd2\x01\n\x0cNewactHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x15\n\rsponsor_title\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x11\n\tuser_name\x18\x06 \x01(\t\x12\x11\n\tuser_face\x18\x07 \x01(\t\x12\x10\n\x08user_url\x18\x08 \x01(\t\x12:\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32(.bilibili.app.nativeact.v1.NewactFeature\"5\n\x13NewactStatementItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"_\n\x0fNewactStatement\x12\r\n\x05title\x18\x01 \x01(\t\x12=\n\x05items\x18\x02 \x03(\x0b\x32..bilibili.app.nativeact.v1.NewactStatementItem\"G\n\x0cOfficialInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\"\x95\x01\n\x0fOgvFollowButton\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\x12\x13\n\x0b\x66ollow_text\x18\x02 \x01(\t\x12\x13\n\x0b\x66ollow_icon\x18\x03 \x01(\t\x12\x15\n\runfollow_text\x18\x04 \x01(\t\x12\x15\n\runfollow_icon\x18\x05 \x01(\t\x12\x15\n\rfollow_params\x18\x06 \x01(\t\"M\n\x0bOgvMoreCard\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x19\n\x11supernatant_title\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t\"\x94\x03\n\nOgvOneCard\x12\x11\n\tposition1\x18\x01 \x01(\t\x12\x11\n\tposition2\x18\x02 \x01(\t\x12\x11\n\tposition3\x18\x03 \x01(\t\x12\x19\n\x11\x63over_right_text1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_right_text2\x18\x05 \x01(\t\x12\x14\n\x0crcmd_content\x18\x06 \x01(\t\x12\x11\n\trcmd_icon\x18\x07 \x01(\t\x12\x41\n\rfollow_button\x18\x08 \x01(\x0b\x32*.bilibili.app.nativeact.v1.OgvFollowButton\x12\r\n\x05image\x18\r \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\r\n\x05title\x18\x0f \x01(\t\x12\x38\n\nreport_dic\x18\x10 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x0b\n\x03url\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"M\n\x14OgvSupernatantParams\x12\x12\n\nlast_index\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\"\x81\x01\n\x11OgvSupernatantReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12?\n\x06params\x18\x02 \x01(\x0b\x32/.bilibili.app.nativeact.v1.OgvSupernatantParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"[\n\x12OgvSupernatantResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x12\n\nlast_index\x18\x02 \x01(\x03\"\xaa\x02\n\x0cOgvThreeCard\x12\x18\n\x10\x63over_left_text1\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x41\n\rfollow_button\x18\x03 \x01(\x0b\x32*.bilibili.app.nativeact.v1.OgvFollowButton\x12\r\n\x05image\x18\x04 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x05 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\r\n\x05title\x18\x06 \x01(\t\x12\x38\n\nreport_dic\x18\x07 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x15\n\rresource_type\x18\t \x01(\t\"\x91\x04\n\x08PageResp\x12\x11\n\tis_online\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_app_dark_theme\x18\x02 \x01(\x08\x12\x34\n\npage_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12\x38\n\npage_share\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\x12\x36\n\x0bpage_header\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x38\n\rparticipation\x18\x06 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x36\n\x0bmodule_list\x18\x07 \x03(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x17\n\x0fis_dynamic_feed\x18\x08 \x01(\x08\x12>\n\rlayer_dynamic\x18\t \x01(\x0b\x32\'.bilibili.app.nativeact.v1.LayerDynamic\x12\x16\n\x0eis_editor_feed\x18\n \x01(\x08\x12\x14\n\x0csponsor_type\x18\x0b \x01(\x03\x12\x32\n\x07top_tab\x18\x0c \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\"\xc5\x01\n\tPageShare\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x12\n\ninside_uri\x18\x05 \x01(\t\x12\x13\n\x0boutside_uri\x18\x06 \x01(\t\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x0b\n\x03sid\x18\x08 \x01(\t\x12\x16\n\x0espace_page_url\x18\t \x01(\t\x12 \n\x18space_exclusive_page_url\x18\n \x01(\t\"{\n\x11ParticipationCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0eselected_image\x18\x02 \x01(\t\x12?\n\x05items\x18\x03 \x03(\x0b\x32\x30.bilibili.app.nativeact.v1.ParticipationCardItem\"P\n\x15ParticipationCardItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"@\n\x0fPlayerDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x08\"\xae\x02\n\x0cProgressCard\x12\x37\n\x05style\x18\x01 \x01(\x0e\x32(.bilibili.app.nativeact.v1.ProgressStyle\x12:\n\tslot_type\x18\x02 \x01(\x0e\x32\'.bilibili.app.nativeact.v1.ProgressSlot\x12\x38\n\x08\x62\x61r_type\x18\x03 \x01(\x0e\x32&.bilibili.app.nativeact.v1.ProgressBar\x12\x15\n\rtexture_image\x18\x04 \x01(\t\x12\x0b\n\x03num\x18\x05 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x06 \x01(\t\x12\x36\n\x05nodes\x18\x07 \x03(\x0b\x32\'.bilibili.app.nativeact.v1.ProgressNode\"]\n\rProgressEvent\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.bilibili.app.nativeact.v1.ProgressEventItem\"x\n\x11ProgressEventItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03num\x18\x03 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x04 \x01(\t\x12\x0f\n\x07web_key\x18\x05 \x01(\t\x12\x11\n\tdimension\x18\x06 \x01(\x03\">\n\x0cProgressNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x03 \x01(\t\"\x1e\n\x0bProgressReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\"F\n\x0bProgressRly\x12\x37\n\x05\x65vent\x18\x01 \x01(\x0b\x32(.bilibili.app.nativeact.v1.ProgressEvent\"\xa4\x02\n\x08RcmdCard\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0bis_followed\x18\x06 \x01(\x08\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.OfficialInfo\x12/\n\x03vip\x18\x08 \x01(\x0b\x32\".bilibili.app.nativeact.v1.VipInfo\x12\x11\n\trank_icon\x18\t \x01(\t\x12>\n\rredirect_type\x18\n \x01(\x0e\x32\'.bilibili.app.nativeact.v1.RedirectType\"F\n\x10RcmdVerticalCard\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.nativeact.v1.RcmdCard\"i\n\x16RelativeactCapsuleCard\x12\r\n\x05title\x18\x01 \x01(\t\x12@\n\x05items\x18\x02 \x03(\x0b\x32\x31.bilibili.app.nativeact.v1.RelativeactCapsuleItem\"E\n\x16RelativeactCapsuleItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"J\n\x0fRelativeactCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"+\n\tReplyCard\x12\x10\n\x08reply_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"\xa9\x01\n\tReportDic\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\t\x12\x13\n\x0bseason_type\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x10\n\x08sub_type\x18\x05 \x01(\x05\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x12\n\nis_preview\x18\x07 \x01(\x05\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x61uthor_name\x18\t \x01(\t\"\x84\x02\n\rReserveButton\x12\x34\n\x04goto\x18\x01 \x01(\x0e\x32&.bilibili.app.nativeact.v1.ReserveGoto\x12:\n\x0bmessage_box\x18\x02 \x01(\x0b\x32%.bilibili.app.nativeact.v1.MessageBox\x12\x16\n\x0ereserve_params\x18\x03 \x01(\t\x12\x10\n\x08has_done\x18\x04 \x01(\x08\x12\x11\n\tdone_text\x18\x05 \x01(\t\x12\x13\n\x0bundone_text\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x14\n\x0cis_highlight\x18\x08 \x01(\x08\x12\x0b\n\x03url\x18\t \x01(\t\"\xe3\x01\n\x0bReserveCard\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x0b\n\x03num\x18\x08 \x01(\x03\x12\x10\n\x08subtitle\x18\t \x01(\t\x12\x38\n\x06\x62utton\x18\n \x01(\x0b\x32(.bilibili.app.nativeact.v1.ReserveButton\x12\x18\n\x10hide_reserve_num\x18\x0b \x01(\x08\",\n\rReserveParams\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0b\n\x03sid\x18\x02 \x01(\x03\"Z\n\nReserveReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.ReserveParams\"$\n\nReserveRly\x12\x16\n\x0ereserve_params\x18\x01 \x01(\t\"\xc7\x02\n\x0cResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12/\n\x05\x62\x61\x64ge\x18\t \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"k\n\x10ResourceMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\\\n\x0eResourceParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"u\n\x0bResourceReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32).bilibili.app.nativeact.v1.ResourceParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"A\n\x0cResourceResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"W\n\nSelectCard\x12\x13\n\x0b\x63urrent_tab\x18\x01 \x01(\x03\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SelectItem\"f\n\nSelectItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x38\n\npage_share\x18\x03 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\"\xf3\x02\n\x07Setting\x12\x1b\n\x13\x64isplay_more_button\x18\x01 \x01(\x08\x12\x15\n\rdisplay_title\x18\x02 \x01(\x08\x12\x15\n\rauto_carousel\x18\x03 \x01(\x08\x12\x1a\n\x12top_tab_follow_img\x18\x04 \x01(\x08\x12\x19\n\x11top_tab_fade_away\x18\x05 \x01(\x08\x12\x11\n\tauto_play\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isplay_unfold_button\x18\x07 \x01(\x08\x12\x13\n\x0b\x64isplay_num\x18\x08 \x01(\x08\x12\x18\n\x10\x64isplay_view_num\x18\t \x01(\x08\x12\x1d\n\x15\x64isplay_subscribe_btn\x18\n \x01(\x08\x12\x13\n\x0bunfold_rest\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isplay_progress_num\x18\x0c \x01(\x08\x12\x18\n\x10\x64isplay_node_num\x18\r \x01(\x08\x12\x19\n\x11\x64isplay_node_desc\x18\x0e \x01(\x08\"U\n\x05Share\x12\x15\n\rdisplay_later\x18\x01 \x01(\x08\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x12\n\nshare_type\x18\x04 \x01(\x03\"9\n\tSizeImage\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05width\x18\x03 \x01(\x03\" \n\rStatementCard\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"a\n\x0bSubpageData\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\x12\x33\n\x04tabs\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SubpageTab\"*\n\nSubpageTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"\xbd\x01\n\x07TabCard\x12\x13\n\x0b\x63urrent_tab\x18\x01 \x01(\x03\x12\x32\n\x05style\x18\x02 \x01(\x0e\x32#.bilibili.app.nativeact.v1.TabStyle\x12\x31\n\x05items\x18\x03 \x03(\x0b\x32\".bilibili.app.nativeact.v1.TabItem\x12\x36\n\x08\x62g_image\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\"\xd2\x01\n\x0bTabIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x17\n\x0fprimary_page_id\x18\x05 \x01(\x03\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x15\n\ris_cold_start\x18\x07 \x01(\x08\"\xdb\x01\n\x07TabItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rdisable_click\x18\x03 \x01(\x08\x12\x1b\n\x13\x64isable_click_toast\x18\x04 \x01(\t\x12<\n\x0eselected_image\x18\x05 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12>\n\x10unselected_image\x18\x06 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\"\x18\n\x08TextCard\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1e\n\rTextTitleCard\x12\r\n\x05title\x18\x01 \x01(\t\"i\n\x16TimelineEventImageCard\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"j\n\x1aTimelineEventImagetextCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\"\xf8\x01\n\x19TimelineEventResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tposition1\x18\x04 \x01(\t\x12\x11\n\tposition2\x18\x05 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x07 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x08 \x01(\t\"V\n\x15TimelineEventTextCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"!\n\x10TimelineHeadCard\x12\r\n\x05stage\x18\x01 \x01(\t\"R\n\x10TimelineMoreCard\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x19\n\x11supernatant_title\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t\"R\n\x19TimelineSupernatantParams\x12\x12\n\nlast_index\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\"\x8b\x01\n\x16TimelineSupernatantReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x44\n\x06params\x18\x02 \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineSupernatantParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"`\n\x17TimelineSupernatantResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x12\n\nlast_index\x18\x02 \x01(\x03\"\xce\x04\n\x12TimelineUnfoldCard\x12\x13\n\x0bunfold_text\x18\x01 \x01(\t\x12\x11\n\tfold_text\x18\x02 \x01(\t\x12\x41\n\x05\x63\x61rds\x18\x03 \x03(\x0b\x32\x32.bilibili.app.nativeact.v1.TimelineUnfoldCard.Card\x1a\xcc\x03\n\x04\x43\x61rd\x12I\n\x12timeline_head_card\x18\x01 \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineHeadCardH\x00\x12T\n\x18timeline_event_text_card\x18\x02 \x01(\x0b\x32\x30.bilibili.app.nativeact.v1.TimelineEventTextCardH\x00\x12V\n\x19timeline_event_image_card\x18\x03 \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.TimelineEventImageCardH\x00\x12^\n\x1dtimeline_event_imagetext_card\x18\x04 \x01(\x0b\x32\x35.bilibili.app.nativeact.v1.TimelineEventImagetextCardH\x00\x12\\\n\x1ctimeline_event_resource_card\x18\x05 \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineEventResourceCardH\x00\x42\r\n\x0b\x63\x61rd_detail\"\xb8\x02\n\rTopicIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\"\x9f\x01\n\x06TopTab\x12\x11\n\tbg_image1\x18\x01 \x01(\t\x12\x11\n\tbg_image2\x18\x02 \x01(\t\x12\x15\n\rtab_top_color\x18\x03 \x01(\t\x12\x18\n\x10tab_middle_color\x18\x04 \x01(\t\x12\x18\n\x10tab_bottom_color\x18\x05 \x01(\t\x12\x12\n\nfont_color\x18\x06 \x01(\t\x12\x10\n\x08\x62\x61r_type\x18\x07 \x01(\x03\"\x87\x03\n\tVideoCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x03 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x36\n\x06rights\x18\x08 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoRights\x12=\n\tdimension\x18\t \x01(\x0b\x32*.bilibili.app.nativeact.v1.PlayerDimension\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"h\n\rVideoMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"Y\n\x0bVideoParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"o\n\x08VideoReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\">\n\tVideoResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"F\n\x0bVideoRights\x12\x0f\n\x07ugc_pay\x18\x01 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x02 \x01(\x08\x12\x0e\n\x06is_pgc\x18\x03 \x01(\x08\"\xf5\x01\n\x07VipInfo\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x14\n\x0cvip_pay_type\x18\x04 \x01(\x05\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x32\n\x05label\x18\x06 \x01(\x0b\x32#.bilibili.app.nativeact.v1.VipLabel\x12\x18\n\x10\x61vatar_subscript\x18\x07 \x01(\x05\x12\x16\n\x0enickname_color\x18\x08 \x01(\t\x12\x0c\n\x04role\x18\t \x01(\x03\x12\x1c\n\x14\x61vatar_subscript_url\x18\n \x01(\t\"\x89\x01\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x13\n\x0blabel_theme\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x10\n\x08\x62g_style\x18\x06 \x01(\x05\x12\x10\n\x08\x62g_color\x18\x07 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x08 \x01(\t\"\xe1\x01\n\nVoteButton\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12\x12\n\ndone_image\x18\x02 \x01(\t\x12\x14\n\x0cundone_image\x18\x03 \x01(\t\x12\x11\n\thas_voted\x18\x04 \x01(\x08\x12:\n\x0bmessage_box\x18\x05 \x01(\x0b\x32%.bilibili.app.nativeact.v1.MessageBox\x12\x13\n\x0bvote_params\x18\x06 \x01(\t\x12\x16\n\x0esource_item_id\x18\x07 \x01(\x03\"\xff\x01\n\x08VoteCard\x12\x36\n\x08\x62g_image\x18\x01 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12\x12\n\noption_num\x18\x02 \x01(\x03\x12\x36\n\x07\x62uttons\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.VoteButton\x12\x34\n\x08left_num\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.VoteNum\x12\x39\n\x08progress\x18\x05 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.VoteProgress\"E\n\x07VoteNum\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12\x0b\n\x03num\x18\x02 \x01(\x03\"\\\n\nVoteParams\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0b\n\x03sid\x18\x02 \x01(\x03\x12\x0b\n\x03gid\x18\x03 \x01(\x03\x12\x16\n\x0esource_item_id\x18\x04 \x01(\x03\x12\x0c\n\x04type\x18\x05 \x01(\t\"\x8b\x02\n\x0cVoteProgress\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12;\n\x05style\x18\x02 \x01(\x0e\x32,.bilibili.app.nativeact.v1.VoteProgressStyle\x12G\n\x05items\x18\x03 \x03(\x0b\x32\x38.bilibili.app.nativeact.v1.VoteProgress.VoteProgressItem\x1a\x46\n\x10VoteProgressItem\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x16\n\x0esource_item_id\x18\x03 \x01(\x03\"T\n\x07VoteReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.bilibili.app.nativeact.v1.VoteParams\"G\n\x08VoteResp\x12\x13\n\x0bvote_params\x18\x01 \x01(\t\x12\x10\n\x08left_num\x18\x02 \x01(\x03\x12\x14\n\x0c\x63\x61n_vote_num\x18\x03 \x01(\x03*+\n\nActionType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x06\n\x02\x44o\x10\x01\x12\x08\n\x04Undo\x10\x02*\'\n\x0eMessageBoxType\x12\n\n\x06\x44ialog\x10\x00\x12\t\n\x05Toast\x10\x01*>\n\x0bProgressBar\x12\x0f\n\x0bPBarDefault\x10\x00\x12\r\n\tPBarColor\x10\x01\x12\x0f\n\x0bPBarTexture\x10\x02*A\n\x0cProgressSlot\x12\x10\n\x0cPSlotDefault\x10\x00\x12\x10\n\x0cPSlotOutline\x10\x01\x12\r\n\tPSlotFill\x10\x02*X\n\rProgressStyle\x12\x11\n\rPStyleDefault\x10\x00\x12\x0f\n\x0bPStyleRound\x10\x01\x12\x13\n\x0fPStyleRectangle\x10\x02\x12\x0e\n\nPStyleNode\x10\x03*A\n\x0cRedirectType\x12\x11\n\rRtTypeDefault\x10\x00\x12\x0f\n\x0bRtTypeSpace\x10\x01\x12\r\n\tRtTypeUri\x10\x02*4\n\x0bReserveGoto\x12\x0b\n\x07Reserve\x10\x00\x12\x0c\n\x08Redirect\x10\x01\x12\n\n\x06Unable\x10\x02*E\n\x08TabStyle\x12\x13\n\x0fTabStyleDefault\x10\x00\x12\x11\n\rTabStyleColor\x10\x01\x12\x11\n\rTabStyleImage\x10\x02*M\n\x11VoteProgressStyle\x12\x12\n\x0eVPStyleDefault\x10\x00\x12\x11\n\rVPStyleCircle\x10\x01\x12\x11\n\rVPStyleSquare\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.nativeact.v1.nativeact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIONTYPE']._serialized_start=21410
  _globals['_ACTIONTYPE']._serialized_end=21453
  _globals['_MESSAGEBOXTYPE']._serialized_start=21455
  _globals['_MESSAGEBOXTYPE']._serialized_end=21494
  _globals['_PROGRESSBAR']._serialized_start=21496
  _globals['_PROGRESSBAR']._serialized_end=21558
  _globals['_PROGRESSSLOT']._serialized_start=21560
  _globals['_PROGRESSSLOT']._serialized_end=21625
  _globals['_PROGRESSSTYLE']._serialized_start=21627
  _globals['_PROGRESSSTYLE']._serialized_end=21715
  _globals['_REDIRECTTYPE']._serialized_start=21717
  _globals['_REDIRECTTYPE']._serialized_end=21782
  _globals['_RESERVEGOTO']._serialized_start=21784
  _globals['_RESERVEGOTO']._serialized_end=21836
  _globals['_TABSTYLE']._serialized_start=21838
  _globals['_TABSTYLE']._serialized_end=21907
  _globals['_VOTEPROGRESSSTYLE']._serialized_start=21909
  _globals['_VOTEPROGRESSSTYLE']._serialized_end=21986
  _globals['_AREA']._serialized_start=188
  _globals['_AREA']._serialized_end=261
  _globals['_BADGE']._serialized_start=263
  _globals['_BADGE']._serialized_end=326
  _globals['_CAROUSELIMGCARD']._serialized_start=328
  _globals['_CAROUSELIMGCARD']._serialized_end=428
  _globals['_CAROUSELIMGITEM']._serialized_start=431
  _globals['_CAROUSELIMGITEM']._serialized_end=575
  _globals['_CAROUSELWORDCARD']._serialized_start=577
  _globals['_CAROUSELWORDCARD']._serialized_end=699
  _globals['_CAROUSELWORDITEM']._serialized_start=701
  _globals['_CAROUSELWORDITEM']._serialized_end=736
  _globals['_COLOR']._serialized_start=739
  _globals['_COLOR']._serialized_end=1524
  _globals['_DYNAMICACTMORECARD']._serialized_start=1526
  _globals['_DYNAMICACTMORECARD']._serialized_end=1635
  _globals['_DYNAMICCARD']._serialized_start=1637
  _globals['_DYNAMICCARD']._serialized_end=1705
  _globals['_DYNAMICMORECARD']._serialized_start=1707
  _globals['_DYNAMICMORECARD']._serialized_end=1813
  _globals['_DYNAMICPARAMS']._serialized_start=1816
  _globals['_DYNAMICPARAMS']._serialized_end=1948
  _globals['_DYNAMICREQ']._serialized_start=1951
  _globals['_DYNAMICREQ']._serialized_end=2198
  _globals['_DYNAMICRESP']._serialized_start=2200
  _globals['_DYNAMICRESP']._serialized_end=2264
  _globals['_EDITORPARAMS']._serialized_start=2266
  _globals['_EDITORPARAMS']._serialized_end=2315
  _globals['_EDITORRECOMMENDCARD']._serialized_start=2318
  _globals['_EDITORRECOMMENDCARD']._serialized_end=2824
  _globals['_EDITORREQ']._serialized_start=2826
  _globals['_EDITORREQ']._serialized_end=2939
  _globals['_EDITORRESP']._serialized_start=2941
  _globals['_EDITORRESP']._serialized_end=3004
  _globals['_FOLLOWOGVPARAMS']._serialized_start=3006
  _globals['_FOLLOWOGVPARAMS']._serialized_end=3097
  _globals['_FOLLOWOGVREQ']._serialized_start=3099
  _globals['_FOLLOWOGVREQ']._serialized_end=3193
  _globals['_FOLLOWOGVRLY']._serialized_start=3195
  _globals['_FOLLOWOGVRLY']._serialized_end=3232
  _globals['_GAMECARD']._serialized_start=3234
  _globals['_GAMECARD']._serialized_end=3322
  _globals['_HEADERCARD']._serialized_start=3325
  _globals['_HEADERCARD']._serialized_end=3540
  _globals['_ICONCARD']._serialized_start=3542
  _globals['_ICONCARD']._serialized_end=3604
  _globals['_ICONITEM']._serialized_start=3606
  _globals['_ICONITEM']._serialized_end=3659
  _globals['_IMAGETITLECARD']._serialized_start=3661
  _globals['_IMAGETITLECARD']._serialized_end=3692
  _globals['_INDEXREQ']._serialized_start=3695
  _globals['_INDEXREQ']._serialized_end=4045
  _globals['_INLINEINDEXREQ']._serialized_start=4048
  _globals['_INLINEINDEXREQ']._serialized_end=4236
  _globals['_LAYERDYNAMIC']._serialized_start=4238
  _globals['_LAYERDYNAMIC']._serialized_end=4322
  _globals['_LIVECARD']._serialized_start=4324
  _globals['_LIVECARD']._serialized_end=4406
  _globals['_LIVEITEM']._serialized_start=4409
  _globals['_LIVEITEM']._serialized_end=4786
  _globals['_LIVEWATCHEDSHOW']._serialized_start=4788
  _globals['_LIVEWATCHEDSHOW']._serialized_end=4911
  _globals['_MESSAGEBOX']._serialized_start=4914
  _globals['_MESSAGEBOX']._serialized_end=5100
  _globals['_MODULE']._serialized_start=5103
  _globals['_MODULE']._serialized_end=5408
  _globals['_MODULEITEM']._serialized_start=5411
  _globals['_MODULEITEM']._serialized_end=9535
  _globals['_MODULEITEM_CARDDETAILCASE']._serialized_start=8538
  _globals['_MODULEITEM_CARDDETAILCASE']._serialized_end=9520
  _globals['_NAVIGATIONCARD']._serialized_start=9537
  _globals['_NAVIGATIONCARD']._serialized_end=9611
  _globals['_NAVIGATIONITEM']._serialized_start=9613
  _globals['_NAVIGATIONITEM']._serialized_end=9663
  _globals['_NEWACTAWARD']._serialized_start=9665
  _globals['_NEWACTAWARD']._serialized_end=9752
  _globals['_NEWACTAWARDITEM']._serialized_start=9754
  _globals['_NEWACTAWARDITEM']._serialized_end=9803
  _globals['_NEWACTFEATURE']._serialized_start=9805
  _globals['_NEWACTFEATURE']._serialized_end=9856
  _globals['_NEWACTHEADER']._serialized_start=9859
  _globals['_NEWACTHEADER']._serialized_end=10069
  _globals['_NEWACTSTATEMENTITEM']._serialized_start=10071
  _globals['_NEWACTSTATEMENTITEM']._serialized_end=10124
  _globals['_NEWACTSTATEMENT']._serialized_start=10126
  _globals['_NEWACTSTATEMENT']._serialized_end=10221
  _globals['_OFFICIALINFO']._serialized_start=10223
  _globals['_OFFICIALINFO']._serialized_end=10294
  _globals['_OGVFOLLOWBUTTON']._serialized_start=10297
  _globals['_OGVFOLLOWBUTTON']._serialized_end=10446
  _globals['_OGVMORECARD']._serialized_start=10448
  _globals['_OGVMORECARD']._serialized_end=10525
  _globals['_OGVONECARD']._serialized_start=10528
  _globals['_OGVONECARD']._serialized_end=10932
  _globals['_OGVSUPERNATANTPARAMS']._serialized_start=10934
  _globals['_OGVSUPERNATANTPARAMS']._serialized_end=11011
  _globals['_OGVSUPERNATANTREQ']._serialized_start=11014
  _globals['_OGVSUPERNATANTREQ']._serialized_end=11143
  _globals['_OGVSUPERNATANTRESP']._serialized_start=11145
  _globals['_OGVSUPERNATANTRESP']._serialized_end=11236
  _globals['_OGVTHREECARD']._serialized_start=11239
  _globals['_OGVTHREECARD']._serialized_end=11537
  _globals['_PAGERESP']._serialized_start=11540
  _globals['_PAGERESP']._serialized_end=12069
  _globals['_PAGESHARE']._serialized_start=12072
  _globals['_PAGESHARE']._serialized_end=12269
  _globals['_PARTICIPATIONCARD']._serialized_start=12271
  _globals['_PARTICIPATIONCARD']._serialized_end=12394
  _globals['_PARTICIPATIONCARDITEM']._serialized_start=12396
  _globals['_PARTICIPATIONCARDITEM']._serialized_end=12476
  _globals['_PLAYERDIMENSION']._serialized_start=12478
  _globals['_PLAYERDIMENSION']._serialized_end=12542
  _globals['_PROGRESSCARD']._serialized_start=12545
  _globals['_PROGRESSCARD']._serialized_end=12847
  _globals['_PROGRESSEVENT']._serialized_start=12849
  _globals['_PROGRESSEVENT']._serialized_end=12942
  _globals['_PROGRESSEVENTITEM']._serialized_start=12944
  _globals['_PROGRESSEVENTITEM']._serialized_end=13064
  _globals['_PROGRESSNODE']._serialized_start=13066
  _globals['_PROGRESSNODE']._serialized_end=13128
  _globals['_PROGRESSREQ']._serialized_start=13130
  _globals['_PROGRESSREQ']._serialized_end=13160
  _globals['_PROGRESSRLY']._serialized_start=13162
  _globals['_PROGRESSRLY']._serialized_end=13232
  _globals['_RCMDCARD']._serialized_start=13235
  _globals['_RCMDCARD']._serialized_end=13527
  _globals['_RCMDVERTICALCARD']._serialized_start=13529
  _globals['_RCMDVERTICALCARD']._serialized_end=13599
  _globals['_RELATIVEACTCAPSULECARD']._serialized_start=13601
  _globals['_RELATIVEACTCAPSULECARD']._serialized_end=13706
  _globals['_RELATIVEACTCAPSULEITEM']._serialized_start=13708
  _globals['_RELATIVEACTCAPSULEITEM']._serialized_end=13777
  _globals['_RELATIVEACTCARD']._serialized_start=13779
  _globals['_RELATIVEACTCARD']._serialized_end=13853
  _globals['_REPLYCARD']._serialized_start=13855
  _globals['_REPLYCARD']._serialized_end=13898
  _globals['_REPORTDIC']._serialized_start=13901
  _globals['_REPORTDIC']._serialized_end=14070
  _globals['_RESERVEBUTTON']._serialized_start=14073
  _globals['_RESERVEBUTTON']._serialized_end=14333
  _globals['_RESERVECARD']._serialized_start=14336
  _globals['_RESERVECARD']._serialized_end=14563
  _globals['_RESERVEPARAMS']._serialized_start=14565
  _globals['_RESERVEPARAMS']._serialized_end=14609
  _globals['_RESERVEREQ']._serialized_start=14611
  _globals['_RESERVEREQ']._serialized_end=14701
  _globals['_RESERVERLY']._serialized_start=14703
  _globals['_RESERVERLY']._serialized_end=14739
  _globals['_RESOURCECARD']._serialized_start=14742
  _globals['_RESOURCECARD']._serialized_end=15069
  _globals['_RESOURCEMORECARD']._serialized_start=15071
  _globals['_RESOURCEMORECARD']._serialized_end=15178
  _globals['_RESOURCEPARAMS']._serialized_start=15180
  _globals['_RESOURCEPARAMS']._serialized_end=15272
  _globals['_RESOURCEREQ']._serialized_start=15274
  _globals['_RESOURCEREQ']._serialized_end=15391
  _globals['_RESOURCERESP']._serialized_start=15393
  _globals['_RESOURCERESP']._serialized_end=15458
  _globals['_SELECTCARD']._serialized_start=15460
  _globals['_SELECTCARD']._serialized_end=15547
  _globals['_SELECTITEM']._serialized_start=15549
  _globals['_SELECTITEM']._serialized_end=15651
  _globals['_SETTING']._serialized_start=15654
  _globals['_SETTING']._serialized_end=16025
  _globals['_SHARE']._serialized_start=16027
  _globals['_SHARE']._serialized_end=16112
  _globals['_SIZEIMAGE']._serialized_start=16114
  _globals['_SIZEIMAGE']._serialized_end=16171
  _globals['_STATEMENTCARD']._serialized_start=16173
  _globals['_STATEMENTCARD']._serialized_end=16205
  _globals['_SUBPAGEDATA']._serialized_start=16207
  _globals['_SUBPAGEDATA']._serialized_end=16304
  _globals['_SUBPAGETAB']._serialized_start=16306
  _globals['_SUBPAGETAB']._serialized_end=16348
  _globals['_TABCARD']._serialized_start=16351
  _globals['_TABCARD']._serialized_end=16540
  _globals['_TABINDEXREQ']._serialized_start=16543
  _globals['_TABINDEXREQ']._serialized_end=16753
  _globals['_TABITEM']._serialized_start=16756
  _globals['_TABITEM']._serialized_end=16975
  _globals['_TEXTCARD']._serialized_start=16977
  _globals['_TEXTCARD']._serialized_end=17001
  _globals['_TEXTTITLECARD']._serialized_start=17003
  _globals['_TEXTTITLECARD']._serialized_end=17033
  _globals['_TIMELINEEVENTIMAGECARD']._serialized_start=17035
  _globals['_TIMELINEEVENTIMAGECARD']._serialized_end=17140
  _globals['_TIMELINEEVENTIMAGETEXTCARD']._serialized_start=17142
  _globals['_TIMELINEEVENTIMAGETEXTCARD']._serialized_end=17248
  _globals['_TIMELINEEVENTRESOURCECARD']._serialized_start=17251
  _globals['_TIMELINEEVENTRESOURCECARD']._serialized_end=17499
  _globals['_TIMELINEEVENTTEXTCARD']._serialized_start=17501
  _globals['_TIMELINEEVENTTEXTCARD']._serialized_end=17587
  _globals['_TIMELINEHEADCARD']._serialized_start=17589
  _globals['_TIMELINEHEADCARD']._serialized_end=17622
  _globals['_TIMELINEMORECARD']._serialized_start=17624
  _globals['_TIMELINEMORECARD']._serialized_end=17706
  _globals['_TIMELINESUPERNATANTPARAMS']._serialized_start=17708
  _globals['_TIMELINESUPERNATANTPARAMS']._serialized_end=17790
  _globals['_TIMELINESUPERNATANTREQ']._serialized_start=17793
  _globals['_TIMELINESUPERNATANTREQ']._serialized_end=17932
  _globals['_TIMELINESUPERNATANTRESP']._serialized_start=17934
  _globals['_TIMELINESUPERNATANTRESP']._serialized_end=18030
  _globals['_TIMELINEUNFOLDCARD']._serialized_start=18033
  _globals['_TIMELINEUNFOLDCARD']._serialized_end=18623
  _globals['_TIMELINEUNFOLDCARD_CARD']._serialized_start=18163
  _globals['_TIMELINEUNFOLDCARD_CARD']._serialized_end=18623
  _globals['_TOPICINDEXREQ']._serialized_start=18626
  _globals['_TOPICINDEXREQ']._serialized_end=18938
  _globals['_TOPTAB']._serialized_start=18941
  _globals['_TOPTAB']._serialized_end=19100
  _globals['_VIDEOCARD']._serialized_start=19103
  _globals['_VIDEOCARD']._serialized_end=19494
  _globals['_VIDEOMORECARD']._serialized_start=19496
  _globals['_VIDEOMORECARD']._serialized_end=19600
  _globals['_VIDEOPARAMS']._serialized_start=19602
  _globals['_VIDEOPARAMS']._serialized_end=19691
  _globals['_VIDEOREQ']._serialized_start=19693
  _globals['_VIDEOREQ']._serialized_end=19804
  _globals['_VIDEORESP']._serialized_start=19806
  _globals['_VIDEORESP']._serialized_end=19868
  _globals['_VIDEORIGHTS']._serialized_start=19870
  _globals['_VIDEORIGHTS']._serialized_end=19940
  _globals['_VIPINFO']._serialized_start=19943
  _globals['_VIPINFO']._serialized_end=20188
  _globals['_VIPLABEL']._serialized_start=20191
  _globals['_VIPLABEL']._serialized_end=20328
  _globals['_VOTEBUTTON']._serialized_start=20331
  _globals['_VOTEBUTTON']._serialized_end=20556
  _globals['_VOTECARD']._serialized_start=20559
  _globals['_VOTECARD']._serialized_end=20814
  _globals['_VOTENUM']._serialized_start=20816
  _globals['_VOTENUM']._serialized_end=20885
  _globals['_VOTEPARAMS']._serialized_start=20887
  _globals['_VOTEPARAMS']._serialized_end=20979
  _globals['_VOTEPROGRESS']._serialized_start=20982
  _globals['_VOTEPROGRESS']._serialized_end=21249
  _globals['_VOTEPROGRESS_VOTEPROGRESSITEM']._serialized_start=21179
  _globals['_VOTEPROGRESS_VOTEPROGRESSITEM']._serialized_end=21249
  _globals['_VOTEREQ']._serialized_start=21251
  _globals['_VOTEREQ']._serialized_end=21335
  _globals['_VOTERESP']._serialized_start=21337
  _globals['_VOTERESP']._serialized_end=21408
# @@protoc_insertion_point(module_scope)
