"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.im.type.im_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ENUM_FOLD:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ENUM_FOLDEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_FOLD.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FOLD_NO: _ENUM_FOLD.ValueType  # 0
    """"""
    FOLD_YES: _ENUM_FOLD.ValueType  # 1
    """"""
    FOLD_UNKNOWN: _ENUM_FOLD.ValueType  # 2
    """"""

class ENUM_FOLD(_ENUM_FOLD, metaclass=_ENUM_FOLDEnumTypeWrapper):
    """"""

FOLD_NO: ENUM_FOLD.ValueType  # 0
""""""
FOLD_YES: ENUM_FOLD.ValueType  # 1
""""""
FOLD_UNKNOWN: ENUM_FOLD.ValueType  # 2
""""""
global___ENUM_FOLD = ENUM_FOLD

class _ENUM_UNREAD_TYPE:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ENUM_UNREAD_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_UNREAD_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNREAD_TYPE_ALL: _ENUM_UNREAD_TYPE.ValueType  # 0
    """"""
    UNREAD_TYPE_FOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 1
    """"""
    UNREAD_TYPE_UNFOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 2
    """"""
    UNREAD_TYPE_DUSTBIN: _ENUM_UNREAD_TYPE.ValueType  # 3
    """"""

class ENUM_UNREAD_TYPE(_ENUM_UNREAD_TYPE, metaclass=_ENUM_UNREAD_TYPEEnumTypeWrapper):
    """"""

UNREAD_TYPE_ALL: ENUM_UNREAD_TYPE.ValueType  # 0
""""""
UNREAD_TYPE_FOLLOW: ENUM_UNREAD_TYPE.ValueType  # 1
""""""
UNREAD_TYPE_UNFOLLOW: ENUM_UNREAD_TYPE.ValueType  # 2
""""""
UNREAD_TYPE_DUSTBIN: ENUM_UNREAD_TYPE.ValueType  # 3
""""""
global___ENUM_UNREAD_TYPE = ENUM_UNREAD_TYPE

class _SESSION_TYPE:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SESSION_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SESSION_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _SESSION_TYPE.ValueType  # 0
    """"""
    UN_FOLD_SESSION: _SESSION_TYPE.ValueType  # 1
    """"""
    UN_FOLLOW_SINGLE_SESSION: _SESSION_TYPE.ValueType  # 2
    """"""
    MY_GROUP_SESSION: _SESSION_TYPE.ValueType  # 3
    """"""
    ALL_SESSION: _SESSION_TYPE.ValueType  # 4
    """"""
    DUSTBIN_SESSION: _SESSION_TYPE.ValueType  # 5
    """"""

class SESSION_TYPE(_SESSION_TYPE, metaclass=_SESSION_TYPEEnumTypeWrapper):
    """"""

UNKNOWN: SESSION_TYPE.ValueType  # 0
""""""
UN_FOLD_SESSION: SESSION_TYPE.ValueType  # 1
""""""
UN_FOLLOW_SINGLE_SESSION: SESSION_TYPE.ValueType  # 2
""""""
MY_GROUP_SESSION: SESSION_TYPE.ValueType  # 3
""""""
ALL_SESSION: SESSION_TYPE.ValueType  # 4
""""""
DUSTBIN_SESSION: SESSION_TYPE.ValueType  # 5
""""""
global___SESSION_TYPE = SESSION_TYPE

@typing_extensions.final
class DummyReq(google.protobuf.message.Message):
    """空请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDL_FIELD_NUMBER: builtins.int
    idl: builtins.int
    """"""
    def __init__(
        self,
        *,
        idl: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idl", b"idl"]) -> None: ...

global___DummyReq = DummyReq

@typing_extensions.final
class DummyRsp(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DummyRsp = DummyRsp

@typing_extensions.final
class EmotionInfo(google.protobuf.message.Message):
    """表情资源信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    GIF_URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """表情"""
    url: builtins.str
    """表情url"""
    size: builtins.int
    """表情大小
    0:未知 1:min 2:max
    """
    gif_url: builtins.str
    """gif url"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
        size: builtins.int = ...,
        gif_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gif_url", b"gif_url", "size", b"size", "text", b"text", "url", b"url"]) -> None: ...

global___EmotionInfo = EmotionInfo

@typing_extensions.final
class MsgDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_KEY_FIELD_NUMBER: builtins.int
    SEQNO_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""
    seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        msg_key: builtins.int = ...,
        seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_key", b"msg_key", "seqno", b"seqno"]) -> None: ...

global___MsgDetail = MsgDetail

@typing_extensions.final
class MsgFeedUnreadRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UnreadEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UNREAD_FIELD_NUMBER: builtins.int
    @property
    def unread(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        unread: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread", b"unread"]) -> None: ...

global___MsgFeedUnreadRsp = MsgFeedUnreadRsp

@typing_extensions.final
class ReqAckAssisMsg(google.protobuf.message.Message):
    """更新应援团小助手消息已拉取进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACK_SEQNO_FIELD_NUMBER: builtins.int
    ack_seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        ack_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno", b"ack_seqno"]) -> None: ...

global___ReqAckAssisMsg = ReqAckAssisMsg

@typing_extensions.final
class ReqAckSessions(google.protobuf.message.Message):
    """拉取已读消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    end_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "end_ts", b"end_ts", "size", b"size"]) -> None: ...

global___ReqAckSessions = ReqAckSessions

@typing_extensions.final
class ReqBatRmSess(google.protobuf.message.Message):
    """批量删除会话-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqBatRmSess = ReqBatRmSess

@typing_extensions.final
class ReqCloseClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqCloseClearUnreadUI = ReqCloseClearUnreadUI

@typing_extensions.final
class ReqGetMsg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    MSG_DETAIL_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    @property
    def msg_detail(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgDetail]:
        """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        msg_detail: collections.abc.Iterable[global___MsgDetail] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_detail", b"msg_detail", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqGetMsg = ReqGetMsg

@typing_extensions.final
class ReqGetSessions(google.protobuf.message.Message):
    """拉取会话记录列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UNFOLLOW_FOLD_FIELD_NUMBER: builtins.int
    GROUP_FOLD_FIELD_NUMBER: builtins.int
    SORT_RULE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    end_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    session_type: builtins.int
    """"""
    unfollow_fold: builtins.int
    """"""
    group_fold: builtins.int
    """"""
    sort_rule: builtins.int
    """"""
    teenager_mode: builtins.int
    """青少年模式"""
    lessons_mode: builtins.int
    """课堂模式"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
        session_type: builtins.int = ...,
        unfollow_fold: builtins.int = ...,
        group_fold: builtins.int = ...,
        sort_rule: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "end_ts", b"end_ts", "group_fold", b"group_fold", "lessons_mode", b"lessons_mode", "session_type", b"session_type", "size", b"size", "sort_rule", b"sort_rule", "teenager_mode", b"teenager_mode", "unfollow_fold", b"unfollow_fold"]) -> None: ...

global___ReqGetSessions = ReqGetSessions

@typing_extensions.final
class ReqGetSpecificSessions(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
    def __init__(
        self,
        *,
        talker_sessions: collections.abc.Iterable[global___SimpleSession] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions", b"talker_sessions"]) -> None: ...

global___ReqGetSpecificSessions = ReqGetSpecificSessions

@typing_extensions.final
class ReqGroupAssisMsg(google.protobuf.message.Message):
    """应援团消息助手-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        client_seqno: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno", b"client_seqno", "size", b"size"]) -> None: ...

global___ReqGroupAssisMsg = ReqGroupAssisMsg

@typing_extensions.final
class ReqLiveInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    talker_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqLiveInfo = ReqLiveInfo

@typing_extensions.final
class ReqNewSessions(google.protobuf.message.Message):
    """拉取新消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    teenager_mode: builtins.int
    """"""
    lessons_mode: builtins.int
    """课堂模式"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        size: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "lessons_mode", b"lessons_mode", "size", b"size", "teenager_mode", b"teenager_mode"]) -> None: ...

global___ReqNewSessions = ReqNewSessions

@typing_extensions.final
class ReqRelationSync(google.protobuf.message.Message):
    """同步关系-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    client_relation_oplog_seqno: builtins.int
    """客户端当前seqno"""
    def __init__(
        self,
        *,
        client_relation_oplog_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_relation_oplog_seqno", b"client_relation_oplog_seqno"]) -> None: ...

global___ReqRelationSync = ReqRelationSync

@typing_extensions.final
class ReqRemoveSession(google.protobuf.message.Message):
    """删除会话记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqRemoveSession = ReqRemoveSession

@typing_extensions.final
class ReqSendMsg(google.protobuf.message.Message):
    """发送消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    COOKIE2_FIELD_NUMBER: builtins.int
    ERROR_CODE_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> bilireq.grpc.protos.bilibili.im.type.im_pb2.Msg:
        """消息内容"""
    cookie: builtins.str
    """"""
    cookie2: builtins.str
    """"""
    error_code: builtins.int
    """"""
    dev_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        msg: bilireq.grpc.protos.bilibili.im.type.im_pb2.Msg | None = ...,
        cookie: builtins.str = ...,
        cookie2: builtins.str = ...,
        error_code: builtins.int = ...,
        dev_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg", b"msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie", b"cookie", "cookie2", b"cookie2", "dev_id", b"dev_id", "error_code", b"error_code", "msg", b"msg"]) -> None: ...

global___ReqSendMsg = ReqSendMsg

@typing_extensions.final
class ReqSessionDetail(google.protobuf.message.Message):
    """拉取会话详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    uid: builtins.int
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        uid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqSessionDetail = ReqSessionDetail

@typing_extensions.final
class ReqSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESS_IDS_FIELD_NUMBER: builtins.int
    @property
    def sess_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReqSessionDetail]:
        """会话详情请求列表"""
    def __init__(
        self,
        *,
        sess_ids: collections.abc.Iterable[global___ReqSessionDetail] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_ids", b"sess_ids"]) -> None: ...

global___ReqSessionDetails = ReqSessionDetails

@typing_extensions.final
class ReqSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    END_SEQNO_FIELD_NUMBER: builtins.int
    BEGIN_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    end_seqno: builtins.int
    """"""
    begin_seqno: builtins.int
    """"""
    size: builtins.int
    """"""
    order: builtins.int
    """"""
    dev_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        end_seqno: builtins.int = ...,
        begin_seqno: builtins.int = ...,
        size: builtins.int = ...,
        order: builtins.int = ...,
        dev_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_seqno", b"begin_seqno", "dev_id", b"dev_id", "end_seqno", b"end_seqno", "order", b"order", "session_type", b"session_type", "size", b"size", "talker_id", b"talker_id"]) -> None: ...

global___ReqSessionMsg = ReqSessionMsg

@typing_extensions.final
class ReqSetTop(google.protobuf.message.Message):
    """置顶聊天-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    OP_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    op_type: builtins.int
    """
    0:置顶 1:取消置顶
    """
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        op_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["op_type", b"op_type", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqSetTop = ReqSetTop

@typing_extensions.final
class ReqShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    size: builtins.int
    """分页大小 最大20"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size", b"size"]) -> None: ...

global___ReqShareList = ReqShareList

@typing_extensions.final
class ReqShowClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        show_dustbin: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "unread_type", b"unread_type"]) -> None: ...

global___ReqShowClearUnreadUI = ReqShowClearUnreadUI

@typing_extensions.final
class ReqSingleUnread(google.protobuf.message.Message):
    """未读私信数-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    uid: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "uid", b"uid", "unread_type", b"unread_type"]) -> None: ...

global___ReqSingleUnread = ReqSingleUnread

@typing_extensions.final
class ReqSpecificSingleUnread(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
    def __init__(
        self,
        *,
        talker_sessions: collections.abc.Iterable[global___SimpleSession] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions", b"talker_sessions"]) -> None: ...

global___ReqSpecificSingleUnread = ReqSpecificSingleUnread

@typing_extensions.final
class ReqSyncAck(google.protobuf.message.Message):
    """确认同步进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        client_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno", b"client_seqno"]) -> None: ...

global___ReqSyncAck = ReqSyncAck

@typing_extensions.final
class ReqTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    SINGLEUNREAD_ON_FIELD_NUMBER: builtins.int
    MSGFEED_ON_FIELD_NUMBER: builtins.int
    SYSUP_ON_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    uid: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    singleunread_on: builtins.int
    """"""
    msgfeed_on: builtins.int
    """"""
    sysup_on: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
        singleunread_on: builtins.int = ...,
        msgfeed_on: builtins.int = ...,
        sysup_on: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msgfeed_on", b"msgfeed_on", "show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "singleunread_on", b"singleunread_on", "sysup_on", b"sysup_on", "uid", b"uid", "unread_type", b"unread_type"]) -> None: ...

global___ReqTotalUnread = ReqTotalUnread

@typing_extensions.final
class ReqUpdateAck(google.protobuf.message.Message):
    """更新已读进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    ACK_SEQNO_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""
    session_type: builtins.int
    """会话类型"""
    ack_seqno: builtins.int
    """已读的最大seqno"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        ack_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno", b"ack_seqno", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqUpdateAck = ReqUpdateAck

@typing_extensions.final
class ReqUpdateIntercept(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    talker_id: builtins.int
    """"""
    status: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqUpdateIntercept = ReqUpdateIntercept

@typing_extensions.final
class ReqUpdateTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqUpdateTotalUnread = ReqUpdateTotalUnread

@typing_extensions.final
class RspCloseClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspCloseClearUnreadUI = RspCloseClearUnreadUI

@typing_extensions.final
class RspGetMsg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
    def __init__(
        self,
        *,
        msg: collections.abc.Iterable[bilibili.im.type.im_pb2.Msg] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg"]) -> None: ...

global___RspGetMsg = RspGetMsg

@typing_extensions.final
class RspLiveInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "live_status", b"live_status"]) -> None: ...

global___RspLiveInfo = RspLiveInfo

@typing_extensions.final
class RspMyGroupUnread(google.protobuf.message.Message):
    """我创建的应援团未读数-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_COUNT_FIELD_NUMBER: builtins.int
    unread_count: builtins.int
    """未读消息数"""
    def __init__(
        self,
        *,
        unread_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread_count", b"unread_count"]) -> None: ...

global___RspMyGroupUnread = RspMyGroupUnread

@typing_extensions.final
class RspRelationSync(google.protobuf.message.Message):
    """同步关系-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_FIELD_NUMBER: builtins.int
    RELATION_LOGS_FIELD_NUMBER: builtins.int
    FRIEND_LIST_FIELD_NUMBER: builtins.int
    SERVER_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    GROUP_LIST_FIELD_NUMBER: builtins.int
    full: builtins.int
    """"""
    @property
    def relation_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.RelationLog]:
        """增量日志"""
    @property
    def friend_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.FriendRelation]:
        """全量列表"""
    server_relation_oplog_seqno: builtins.int
    """服务器端最大的relation seqno"""
    @property
    def group_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.GroupRelation]:
        """全量列表"""
    def __init__(
        self,
        *,
        full: builtins.int = ...,
        relation_logs: collections.abc.Iterable[bilibili.im.type.im_pb2.RelationLog] | None = ...,
        friend_list: collections.abc.Iterable[bilibili.im.type.im_pb2.FriendRelation] | None = ...,
        server_relation_oplog_seqno: builtins.int = ...,
        group_list: collections.abc.Iterable[bilibili.im.type.im_pb2.GroupRelation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["friend_list", b"friend_list", "full", b"full", "group_list", b"group_list", "relation_logs", b"relation_logs", "server_relation_oplog_seqno", b"server_relation_oplog_seqno"]) -> None: ...

global___RspRelationSync = RspRelationSync

@typing_extensions.final
class RspSendMsg(google.protobuf.message.Message):
    """发送消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_KEY_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    MSG_CONTENT_FIELD_NUMBER: builtins.int
    KEY_HIT_INFOS_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""
    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
    msg_content: builtins.str
    """"""
    @property
    def key_hit_infos(self) -> bilireq.grpc.protos.bilibili.im.type.im_pb2.KeyHitInfos:
        """"""
    def __init__(
        self,
        *,
        msg_key: builtins.int = ...,
        e_infos: collections.abc.Iterable[global___EmotionInfo] | None = ...,
        msg_content: builtins.str = ...,
        key_hit_infos: bilireq.grpc.protos.bilibili.im.type.im_pb2.KeyHitInfos | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_hit_infos", b"key_hit_infos"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos", b"e_infos", "key_hit_infos", b"key_hit_infos", "msg_content", b"msg_content", "msg_key", b"msg_key"]) -> None: ...

global___RspSendMsg = RspSendMsg

@typing_extensions.final
class RspSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESS_INFOS_FIELD_NUMBER: builtins.int
    @property
    def sess_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """会话详情列表"""
    def __init__(
        self,
        *,
        sess_infos: collections.abc.Iterable[bilibili.im.type.im_pb2.SessionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_infos", b"sess_infos"]) -> None: ...

global___RspSessionDetails = RspSessionDetails

@typing_extensions.final
class RspSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    MIN_SEQNO_FIELD_NUMBER: builtins.int
    MAX_SEQNO_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
    has_more: builtins.int
    """"""
    min_seqno: builtins.int
    """"""
    max_seqno: builtins.int
    """"""
    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[bilibili.im.type.im_pb2.Msg] | None = ...,
        has_more: builtins.int = ...,
        min_seqno: builtins.int = ...,
        max_seqno: builtins.int = ...,
        e_infos: collections.abc.Iterable[global___EmotionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos", b"e_infos", "has_more", b"has_more", "max_seqno", b"max_seqno", "messages", b"messages", "min_seqno", b"min_seqno"]) -> None: ...

global___RspSessionMsg = RspSessionMsg

@typing_extensions.final
class RspSessions(google.protobuf.message.Message):
    """拉取消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SystemMsgEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SESSION_LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    ANTI_DISTURB_CLEANING_FIELD_NUMBER: builtins.int
    IS_ADDRESS_LIST_EMPTY_FIELD_NUMBER: builtins.int
    SYSTEM_MSG_FIELD_NUMBER: builtins.int
    SHOW_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """"""
    has_more: builtins.int
    """"""
    anti_disturb_cleaning: builtins.bool
    """标记反垃圾会话是否在清理中"""
    is_address_list_empty: builtins.int
    """当session_list为空时，会返回该字段用于判断通讯录是否为空，1表示空，0表示非空"""
    @property
    def system_msg(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
    show_level: builtins.bool
    """"""
    def __init__(
        self,
        *,
        session_list: collections.abc.Iterable[bilibili.im.type.im_pb2.SessionInfo] | None = ...,
        has_more: builtins.int = ...,
        anti_disturb_cleaning: builtins.bool = ...,
        is_address_list_empty: builtins.int = ...,
        system_msg: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        show_level: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_disturb_cleaning", b"anti_disturb_cleaning", "has_more", b"has_more", "is_address_list_empty", b"is_address_list_empty", "session_list", b"session_list", "show_level", b"show_level", "system_msg", b"system_msg"]) -> None: ...

global___RspSessions = RspSessions

@typing_extensions.final
class RspShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_LIST_FIELD_NUMBER: builtins.int
    ISADDRESSLISTEMPTY_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareSessionInfo]:
        """最近会话列表"""
    IsAddressListEmpty: builtins.int
    """"""
    def __init__(
        self,
        *,
        session_list: collections.abc.Iterable[global___ShareSessionInfo] | None = ...,
        IsAddressListEmpty: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["IsAddressListEmpty", b"IsAddressListEmpty", "session_list", b"session_list"]) -> None: ...

global___RspShareList = RspShareList

@typing_extensions.final
class RspShowClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    display: builtins.bool
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        display: builtins.bool = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display", b"display", "text", b"text"]) -> None: ...

global___RspShowClearUnreadUI = RspShowClearUnreadUI

@typing_extensions.final
class RspSingleUnread(google.protobuf.message.Message):
    """未读私信数-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    BIZ_MSG_UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    BIZ_MSG_FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """未关注用户私信数"""
    follow_unread: builtins.int
    """已关注用户私信数"""
    unfollow_push_msg: builtins.int
    """未关注人列表是否有新业务通知"""
    dustbin_push_msg: builtins.int
    """"""
    dustbin_unread: builtins.int
    """"""
    biz_msg_unfollow_unread: builtins.int
    """"""
    biz_msg_follow_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
        biz_msg_unfollow_unread: builtins.int = ...,
        biz_msg_follow_unread: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_msg_follow_unread", b"biz_msg_follow_unread", "biz_msg_unfollow_unread", b"biz_msg_unfollow_unread", "dustbin_push_msg", b"dustbin_push_msg", "dustbin_unread", b"dustbin_unread", "follow_unread", b"follow_unread", "unfollow_push_msg", b"unfollow_push_msg", "unfollow_unread", b"unfollow_unread"]) -> None: ...

global___RspSingleUnread = RspSingleUnread

@typing_extensions.final
class RspSpecificSingleUnread(google.protobuf.message.Message):
    """-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TalkerUnreadCntEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TALKERUNREADCNT_FIELD_NUMBER: builtins.int
    ALLUNREADCNT_FIELD_NUMBER: builtins.int
    @property
    def talkerUnreadCnt(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """key -> 用户uid, value ->未读数"""
    allUnreadCnt: builtins.int
    """总未读数"""
    def __init__(
        self,
        *,
        talkerUnreadCnt: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        allUnreadCnt: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allUnreadCnt", b"allUnreadCnt", "talkerUnreadCnt", b"talkerUnreadCnt"]) -> None: ...

global___RspSpecificSingleUnread = RspSpecificSingleUnread

@typing_extensions.final
class RspSyncAck(google.protobuf.message.Message):
    """确认同步进度-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspSyncAck = RspSyncAck

@typing_extensions.final
class RspTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_SINGLE_UNREAD_FIELD_NUMBER: builtins.int
    MSG_FEED_UNREAD_FIELD_NUMBER: builtins.int
    SYS_MSG_INTERFACE_LAST_MSG_FIELD_NUMBER: builtins.int
    TOTAL_UNREAD_FIELD_NUMBER: builtins.int
    @property
    def session_single_unread(self) -> global___SessionSingleUnreadRsp:
        """"""
    @property
    def msg_feed_unread(self) -> global___MsgFeedUnreadRsp:
        """"""
    @property
    def sys_msg_interface_last_msg(self) -> global___SysMsgInterfaceLastMsgRsp:
        """"""
    total_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        session_single_unread: global___SessionSingleUnreadRsp | None = ...,
        msg_feed_unread: global___MsgFeedUnreadRsp | None = ...,
        sys_msg_interface_last_msg: global___SysMsgInterfaceLastMsgRsp | None = ...,
        total_unread: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg_feed_unread", b"msg_feed_unread", "session_single_unread", b"session_single_unread", "sys_msg_interface_last_msg", b"sys_msg_interface_last_msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_feed_unread", b"msg_feed_unread", "session_single_unread", b"session_single_unread", "sys_msg_interface_last_msg", b"sys_msg_interface_last_msg", "total_unread", b"total_unread"]) -> None: ...

global___RspTotalUnread = RspTotalUnread

@typing_extensions.final
class RspUpdateTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspUpdateTotalUnread = RspUpdateTotalUnread

@typing_extensions.final
class SessionSingleUnreadRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """"""
    follow_unread: builtins.int
    """"""
    unfollow_push_msg: builtins.int
    """"""
    dustbin_push_msg: builtins.int
    """"""
    dustbin_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dustbin_push_msg", b"dustbin_push_msg", "dustbin_unread", b"dustbin_unread", "follow_unread", b"follow_unread", "unfollow_push_msg", b"unfollow_push_msg", "unfollow_unread", b"unfollow_unread"]) -> None: ...

global___SessionSingleUnreadRsp = SessionSingleUnreadRsp

@typing_extensions.final
class ShareSessionInfo(google.protobuf.message.Message):
    """会话信息，用于私信分享"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    TALKER_UNAME_FIELD_NUMBER: builtins.int
    TALKER_ICON_FIELD_NUMBER: builtins.int
    OFFICIAL_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    talker_uname: builtins.str
    """"""
    talker_icon: builtins.str
    """"""
    official_type: builtins.int
    """认证信息
    -1: 无认证 0:个人认证 1:机构认证
    """
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        talker_uname: builtins.str = ...,
        talker_icon: builtins.str = ...,
        official_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["official_type", b"official_type", "talker_icon", b"talker_icon", "talker_id", b"talker_id", "talker_uname", b"talker_uname"]) -> None: ...

global___ShareSessionInfo = ShareSessionInfo

@typing_extensions.final
class SimpleSession(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""
    session_type: builtins.int
    """会话类型"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___SimpleSession = SimpleSession

@typing_extensions.final
class SysMsgInterfaceLastMsgRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    unread: builtins.int
    """"""
    title: builtins.str
    """"""
    time: builtins.str
    """"""
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread: builtins.int = ...,
        title: builtins.str = ...,
        time: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "time", b"time", "title", b"title", "unread", b"unread"]) -> None: ...

global___SysMsgInterfaceLastMsgRsp = SysMsgInterfaceLastMsgRsp
