# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/card/v1/card.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import single_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_single__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/app/card/v1/card.proto\x12\x14\x62ilibili.app.card.v1\x1a!bilibili/app/card/v1/single.proto\"\xc2\x05\n\x04\x43\x61rd\x12<\n\x0esmall_cover_v5\x18\x01 \x01(\x0b\x32\".bilibili.app.card.v1.SmallCoverV5H\x00\x12<\n\x0elarge_cover_v1\x18\x02 \x01(\x0b\x32\".bilibili.app.card.v1.LargeCoverV1H\x00\x12\x41\n\x11three_item_all_v2\x18\x03 \x01(\x0b\x32$.bilibili.app.card.v1.ThreeItemAllV2H\x00\x12:\n\rthree_item_v1\x18\x04 \x01(\x0b\x32!.bilibili.app.card.v1.ThreeItemV1H\x00\x12\x33\n\thot_topic\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.card.v1.HotTopicH\x00\x12;\n\x0fthree_item_h_v5\x18\x06 \x01(\x0b\x32 .bilibili.app.card.v1.DynamicHotH\x00\x12>\n\x0fmiddle_cover_v3\x18\x07 \x01(\x0b\x32#.bilibili.app.card.v1.MiddleCoverV3H\x00\x12<\n\x0elarge_cover_v4\x18\x08 \x01(\x0b\x32\".bilibili.app.card.v1.LargeCoverV4H\x00\x12H\n\x14popular_top_entrance\x18\t \x01(\x0b\x32(.bilibili.app.card.v1.PopularTopEntranceH\x00\x12:\n\rrcmd_one_item\x18\n \x01(\x0b\x32!.bilibili.app.card.v1.RcmdOneItemH\x00\x12\x41\n\x11small_cover_v5_ad\x18\x0b \x01(\x0b\x32$.bilibili.app.card.v1.SmallCoverV5AdH\x00\x42\x06\n\x04itemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.card.v1.card_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CARD']._serialized_start=93
  _globals['_CARD']._serialized_end=799
# @@protoc_insertion_point(module_scope)
