# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/web/space/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/web/space/v1/space.proto\x12\x15\x62ilibili.web.space.v1\"\t\n\x07NoReply\"\xb8\x01\n\rOfficialReply\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x0c\n\x04rcmd\x18\x06 \x01(\t\x12\x0f\n\x07ios_url\x18\x07 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x08 \x01(\t\x12\x0e\n\x06\x62utton\x18\t \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\n \x01(\t\x12\r\n\x05mtime\x18\x0b \x01(\x03\"\x1e\n\x0fOfficialRequest\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"[\n\tPhotoMall\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03img\x18\x03 \x01(\t\x12\x11\n\tnight_img\x18\x04 \x01(\t\x12\x14\n\x0cis_activated\x18\x05 \x01(\x03\"D\n\x12PhotoMallListReply\x12.\n\x04list\x18\x01 \x03(\x0b\x32 .bilibili.web.space.v1.PhotoMall\"@\n\x10PhotoMallListReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06\x64\x65vice\x18\x03 \x01(\t\"\x81\x01\n\x0cPrivacyReply\x12\x41\n\x07privacy\x18\x01 \x03(\x0b\x32\x30.bilibili.web.space.v1.PrivacyReply.PrivacyEntry\x1a.\n\x0cPrivacyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x1d\n\x0ePrivacyRequest\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"I\n\x0eSetTopPhotoReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03i_d\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\"\xe5\x02\n\x11SpaceSettingReply\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x03\x12\x11\n\tfav_video\x18\x02 \x01(\x03\x12\x13\n\x0b\x63oins_video\x18\x03 \x01(\x03\x12\x13\n\x0blikes_video\x18\x04 \x01(\x03\x12\x0f\n\x07\x62\x61ngumi\x18\x05 \x01(\x03\x12\x13\n\x0bplayed_game\x18\x06 \x01(\x03\x12\x0e\n\x06groups\x18\x07 \x01(\x03\x12\r\n\x05\x63omic\x18\x08 \x01(\x03\x12\x0c\n\x04\x62_bq\x18\t \x01(\x03\x12\x10\n\x08\x64ress_up\x18\n \x01(\x03\x12\x19\n\x11\x64isable_following\x18\x0b \x01(\x03\x12\x15\n\rlive_playback\x18\x0c \x01(\x03\x12\x19\n\x11\x63lose_space_medal\x18\r \x01(\x03\x12\x19\n\x11only_show_wearing\x18\x0e \x01(\x03\x12\x1b\n\x13\x64isable_show_school\x18\x0f \x01(\x03\x12\x18\n\x10\x64isable_show_nft\x18\x10 \x01(\x03\"\x1e\n\x0fSpaceSettingReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"?\n\x08TopPhoto\x12\x0f\n\x07img_url\x18\x01 \x01(\t\x12\x15\n\rnight_img_url\x18\x02 \x01(\t\x12\x0b\n\x03sid\x18\x03 \x01(\x03\"5\n\x0bTopPhotoArc\x12\x0c\n\x04show\x18\x01 \x01(\x08\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03pic\x18\x03 \x01(\t\"#\n\x14TopPhotoArcCancelReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"~\n\rTopPhotoReply\x12\x32\n\ttop_photo\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.space.v1.TopPhoto\x12\x39\n\rtop_photo_arc\x18\x02 \x01(\x0b\x32\".bilibili.web.space.v1.TopPhotoArc\"]\n\x0bTopPhotoReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\x12\x11\n\tlogin_mid\x18\x05 \x01(\x03\"R\n\x10UpActivityTabReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05state\x18\x02 \x01(\x05\x12\x10\n\x08tab_cont\x18\x03 \x01(\x03\x12\x10\n\x08tab_name\x18\x04 \x01(\t\"$\n\x11UpActivityTabResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x16\n\x14UpRcmdBlackListReply\"\x89\x01\n\x0cUserTabReply\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x10\n\x08tab_name\x18\x03 \x01(\t\x12\x11\n\ttab_order\x18\x04 \x01(\x05\x12\x10\n\x08tab_cont\x18\x05 \x01(\x03\x12\x12\n\nis_default\x18\x06 \x01(\x05\x12\x0f\n\x07h5_link\x18\x07 \x01(\t\"6\n\nUserTabReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"#\n\x11WhitelistAddReply\x12\x0e\n\x06\x61\x64\x64_ok\x18\x01 \x01(\x08\"<\n\x0fWhitelistAddReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03\"\"\n\x0eWhitelistReply\x12\x10\n\x08is_white\x18\x01 \x01(\x08\"\x1b\n\x0cWhitelistReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"!\n\x10WhitelistUpReply\x12\r\n\x05up_ok\x18\x01 \x01(\x08\"I\n\x17WhitelistValidTimeReply\x12\x10\n\x08is_white\x18\x01 \x01(\x08\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03*1\n\x0cTopPhotoType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PIC\x10\x01\x12\x0b\n\x07\x41RCHIVE\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.web.space.v1.space_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVACYREPLY_PRIVACYENTRY._options = None
  _PRIVACYREPLY_PRIVACYENTRY._serialized_options = b'8\001'
  _globals['_TOPPHOTOTYPE']._serialized_start=2145
  _globals['_TOPPHOTOTYPE']._serialized_end=2194
  _globals['_NOREPLY']._serialized_start=60
  _globals['_NOREPLY']._serialized_end=69
  _globals['_OFFICIALREPLY']._serialized_start=72
  _globals['_OFFICIALREPLY']._serialized_end=256
  _globals['_OFFICIALREQUEST']._serialized_start=258
  _globals['_OFFICIALREQUEST']._serialized_end=288
  _globals['_PHOTOMALL']._serialized_start=290
  _globals['_PHOTOMALL']._serialized_end=381
  _globals['_PHOTOMALLLISTREPLY']._serialized_start=383
  _globals['_PHOTOMALLLISTREPLY']._serialized_end=451
  _globals['_PHOTOMALLLISTREQ']._serialized_start=453
  _globals['_PHOTOMALLLISTREQ']._serialized_end=517
  _globals['_PRIVACYREPLY']._serialized_start=520
  _globals['_PRIVACYREPLY']._serialized_end=649
  _globals['_PRIVACYREPLY_PRIVACYENTRY']._serialized_start=603
  _globals['_PRIVACYREPLY_PRIVACYENTRY']._serialized_end=649
  _globals['_PRIVACYREQUEST']._serialized_start=651
  _globals['_PRIVACYREQUEST']._serialized_end=680
  _globals['_SETTOPPHOTOREQ']._serialized_start=682
  _globals['_SETTOPPHOTOREQ']._serialized_end=755
  _globals['_SPACESETTINGREPLY']._serialized_start=758
  _globals['_SPACESETTINGREPLY']._serialized_end=1115
  _globals['_SPACESETTINGREQ']._serialized_start=1117
  _globals['_SPACESETTINGREQ']._serialized_end=1147
  _globals['_TOPPHOTO']._serialized_start=1149
  _globals['_TOPPHOTO']._serialized_end=1212
  _globals['_TOPPHOTOARC']._serialized_start=1214
  _globals['_TOPPHOTOARC']._serialized_end=1267
  _globals['_TOPPHOTOARCCANCELREQ']._serialized_start=1269
  _globals['_TOPPHOTOARCCANCELREQ']._serialized_end=1304
  _globals['_TOPPHOTOREPLY']._serialized_start=1306
  _globals['_TOPPHOTOREPLY']._serialized_end=1432
  _globals['_TOPPHOTOREQ']._serialized_start=1434
  _globals['_TOPPHOTOREQ']._serialized_end=1527
  _globals['_UPACTIVITYTABREQ']._serialized_start=1529
  _globals['_UPACTIVITYTABREQ']._serialized_end=1611
  _globals['_UPACTIVITYTABRESP']._serialized_start=1613
  _globals['_UPACTIVITYTABRESP']._serialized_end=1649
  _globals['_UPRCMDBLACKLISTREPLY']._serialized_start=1651
  _globals['_UPRCMDBLACKLISTREPLY']._serialized_end=1673
  _globals['_USERTABREPLY']._serialized_start=1676
  _globals['_USERTABREPLY']._serialized_end=1813
  _globals['_USERTABREQ']._serialized_start=1815
  _globals['_USERTABREQ']._serialized_end=1869
  _globals['_WHITELISTADDREPLY']._serialized_start=1871
  _globals['_WHITELISTADDREPLY']._serialized_end=1906
  _globals['_WHITELISTADDREQ']._serialized_start=1908
  _globals['_WHITELISTADDREQ']._serialized_end=1968
  _globals['_WHITELISTREPLY']._serialized_start=1970
  _globals['_WHITELISTREPLY']._serialized_end=2004
  _globals['_WHITELISTREQ']._serialized_start=2006
  _globals['_WHITELISTREQ']._serialized_end=2033
  _globals['_WHITELISTUPREPLY']._serialized_start=2035
  _globals['_WHITELISTUPREPLY']._serialized_end=2068
  _globals['_WHITELISTVALIDTIMEREPLY']._serialized_start=2070
  _globals['_WHITELISTVALIDTIMEREPLY']._serialized_end=2143
# @@protoc_insertion_point(module_scope)
