"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ErrorRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    error: builtins.int
    """"""
    time: builtins.int
    """"""
    delay: builtins.int
    """"""
    def __init__(
        self,
        *,
        error: builtins.int = ...,
        time: builtins.int = ...,
        delay: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay", b"delay", "error", b"error", "time", b"time"]) -> None: ...

global___ErrorRequest = ErrorRequest

@typing_extensions.final
class ErrorResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "time", b"time"]) -> None: ...

global___ErrorResponse = ErrorResponse

@typing_extensions.final
class PingRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["time", b"time"]) -> None: ...

global___PingRequest = PingRequest

@typing_extensions.final
class PingResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "time", b"time"]) -> None: ...

global___PingResponse = PingResponse

@typing_extensions.final
class SayRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___SayRequest = SayRequest

@typing_extensions.final
class SayResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    content: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        content: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "host", b"host", "time", b"time"]) -> None: ...

global___SayResponse = SayResponse
