# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/interfaces/v1/history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/app/interfaces/v1/history.proto\x12\x19\x62ilibili.app.interface.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"\x98\x01\n\x0b\x43\x61rdArticle\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x18\n\x10\x64isplayAttention\x18\x04 \x01(\x08\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\x35\n\x08relation\x18\x06 \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\"`\n\nCardCheese\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\x03\"\xa3\x01\n\x08\x43\x61rdLive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x0e\n\x06ststus\x18\x05 \x01(\x05\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x35\n\x08relation\x18\x07 \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\"l\n\x07\x43\x61rdOGV\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\x03\"\xbd\x02\n\x07\x43\x61rdUGC\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x0c\n\x04page\x18\x08 \x01(\x05\x12\x10\n\x08subtitle\x18\t \x01(\t\x12\x35\n\x08relation\x18\n \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\x12\x0c\n\x04\x62vid\x18\x0b \x01(\t\x12\x0e\n\x06videos\x18\x0c \x01(\x03\x12\x12\n\nshort_link\x18\r \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x0e \x01(\t\x12\x0c\n\x04view\x18\x0f \x01(\x03\x12\r\n\x05state\x18\x10 \x01(\x03\"\x1c\n\x08\x43learReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\"$\n\x06\x43ursor\x12\x0b\n\x03max\x18\x01 \x01(\x03\x12\r\n\x05maxTp\x18\x02 \x01(\x05\"\xeb\x03\n\nCursorItem\x12\x36\n\x08\x63\x61rd_ugc\x18\x01 \x01(\x0b\x32\".bilibili.app.interface.v1.CardUGCH\x00\x12\x36\n\x08\x63\x61rd_ogv\x18\x02 \x01(\x0b\x32\".bilibili.app.interface.v1.CardOGVH\x00\x12>\n\x0c\x63\x61rd_article\x18\x03 \x01(\x0b\x32&.bilibili.app.interface.v1.CardArticleH\x00\x12\x38\n\tcard_live\x18\x04 \x01(\x0b\x32#.bilibili.app.interface.v1.CardLiveH\x00\x12<\n\x0b\x63\x61rd_cheese\x18\x05 \x01(\x0b\x32%.bilibili.app.interface.v1.CardCheeseH\x00\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x0e\n\x06viewAt\x18\x08 \x01(\x03\x12\x0b\n\x03kid\x18\t \x01(\x03\x12\x0b\n\x03oid\x18\n \x01(\x03\x12\x10\n\x08\x62usiness\x18\x0b \x01(\t\x12\n\n\x02tp\x18\x0c \x01(\x05\x12\x31\n\x02\x64t\x18\r \x01(\x0b\x32%.bilibili.app.interface.v1.DeviceType\x12\x11\n\thas_share\x18\x0e \x01(\x08\x42\x0b\n\tcard_item\"\xba\x01\n\x0b\x43ursorReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x31\n\x03tab\x18\x02 \x03(\x0b\x32$.bilibili.app.interface.v1.CursorTab\x12\x31\n\x06\x63ursor\x18\x03 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x0f\n\x07hasMore\x18\x04 \x01(\x08\"\xdd\x01\n\tCursorReq\x12\x31\n\x06\x63ursor\x18\x01 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"J\n\tCursorTab\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06router\x18\x03 \x01(\t\x12\r\n\x05\x66ocus\x18\x04 \x01(\x08\"\x9d\x01\n\rCursorV2Reply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x31\n\x06\x63ursor\x18\x02 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x12\n\nempty_link\x18\x04 \x01(\t\"\xf1\x01\n\x0b\x43ursorV2Req\x12\x31\n\x06\x63ursor\x18\x01 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08is_local\x18\x05 \x01(\x08\"A\n\tDeleteReq\x12\x34\n\x08his_info\x18\x01 \x01(\x0b\x32\".bilibili.app.interface.v1.HisInfo\"G\n\nDeviceType\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.bilibili.app.interface.v1.DT\x12\x0c\n\x04icon\x18\x02 \x01(\t\"(\n\x07HisInfo\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0b\n\x03kid\x18\x02 \x01(\x03\"D\n\x0fHistoryTabReply\x12\x31\n\x03tab\x18\x01 \x03(\x0b\x32$.bilibili.app.interface.v1.CursorTab\"l\n\rHistoryTabReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x38\n\x06source\x18\x02 \x01(\x0e\x32(.bilibili.app.interface.v1.HistorySource\x12\x0f\n\x07keyword\x18\x03 \x01(\t\"v\n\x12LatestHistoryReply\x12\x34\n\x05items\x18\x01 \x01(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\r\n\x05scene\x18\x02 \x01(\t\x12\r\n\x05rtime\x18\x03 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x04 \x01(\t\"l\n\x10LatestHistoryReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x02 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\"\t\n\x07NoReply\"!\n\x04Page\x12\n\n\x02pn\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"a\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x11\n\tforceHost\x18\x04 \x01(\x03\x12\r\n\x05\x66ourk\x18\x05 \x01(\x03\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\"\x83\x01\n\x0bSearchReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x0f\n\x07hasMore\x18\x02 \x01(\x08\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.interface.v1.Page\":\n\tSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\n\n\x02pn\x18\x02 \x01(\x03\x12\x10\n\x08\x62usiness\x18\x03 \x01(\t*S\n\x02\x44T\x12\x0b\n\x07Unknown\x10\x00\x12\t\n\x05Phone\x10\x01\x12\x07\n\x03Pad\x10\x02\x12\x06\n\x02PC\x10\x03\x12\x06\n\x02TV\x10\x04\x12\x07\n\x03\x43\x61r\x10\x05\x12\x07\n\x03Iot\x10\x06\x12\n\n\x06\x41ndPad\x10\x07*6\n\rHistorySource\x12\x11\n\rhistory_VALUE\x10\x00\x12\x12\n\x0eshopping_VALUE\x10\x01\x32\x8e\x05\n\x07History\x12\x62\n\nHistoryTab\x12(.bilibili.app.interface.v1.HistoryTabReq\x1a*.bilibili.app.interface.v1.HistoryTabReply\x12V\n\x06\x43ursor\x12$.bilibili.app.interface.v1.CursorReq\x1a&.bilibili.app.interface.v1.CursorReply\x12\\\n\x08\x43ursorV2\x12&.bilibili.app.interface.v1.CursorV2Req\x1a(.bilibili.app.interface.v1.CursorV2Reply\x12R\n\x06\x44\x65lete\x12$.bilibili.app.interface.v1.DeleteReq\x1a\".bilibili.app.interface.v1.NoReply\x12V\n\x06Search\x12$.bilibili.app.interface.v1.SearchReq\x1a&.bilibili.app.interface.v1.SearchReply\x12P\n\x05\x43lear\x12#.bilibili.app.interface.v1.ClearReq\x1a\".bilibili.app.interface.v1.NoReply\x12k\n\rLatestHistory\x12+.bilibili.app.interface.v1.LatestHistoryReq\x1a-.bilibili.app.interface.v1.LatestHistoryReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.interfaces.v1.history_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DT']._serialized_start=3424
  _globals['_DT']._serialized_end=3507
  _globals['_HISTORYSOURCE']._serialized_start=3509
  _globals['_HISTORYSOURCE']._serialized_end=3563
  _globals['_CARDARTICLE']._serialized_start=122
  _globals['_CARDARTICLE']._serialized_end=274
  _globals['_CARDCHEESE']._serialized_start=276
  _globals['_CARDCHEESE']._serialized_end=372
  _globals['_CARDLIVE']._serialized_start=375
  _globals['_CARDLIVE']._serialized_end=538
  _globals['_CARDOGV']._serialized_start=540
  _globals['_CARDOGV']._serialized_end=648
  _globals['_CARDUGC']._serialized_start=651
  _globals['_CARDUGC']._serialized_end=968
  _globals['_CLEARREQ']._serialized_start=970
  _globals['_CLEARREQ']._serialized_end=998
  _globals['_CURSOR']._serialized_start=1000
  _globals['_CURSOR']._serialized_end=1036
  _globals['_CURSORITEM']._serialized_start=1039
  _globals['_CURSORITEM']._serialized_end=1530
  _globals['_CURSORREPLY']._serialized_start=1533
  _globals['_CURSORREPLY']._serialized_end=1719
  _globals['_CURSORREQ']._serialized_start=1722
  _globals['_CURSORREQ']._serialized_end=1943
  _globals['_CURSORTAB']._serialized_start=1945
  _globals['_CURSORTAB']._serialized_end=2019
  _globals['_CURSORV2REPLY']._serialized_start=2022
  _globals['_CURSORV2REPLY']._serialized_end=2179
  _globals['_CURSORV2REQ']._serialized_start=2182
  _globals['_CURSORV2REQ']._serialized_end=2423
  _globals['_DELETEREQ']._serialized_start=2425
  _globals['_DELETEREQ']._serialized_end=2490
  _globals['_DEVICETYPE']._serialized_start=2492
  _globals['_DEVICETYPE']._serialized_end=2563
  _globals['_HISINFO']._serialized_start=2565
  _globals['_HISINFO']._serialized_end=2605
  _globals['_HISTORYTABREPLY']._serialized_start=2607
  _globals['_HISTORYTABREPLY']._serialized_end=2675
  _globals['_HISTORYTABREQ']._serialized_start=2677
  _globals['_HISTORYTABREQ']._serialized_end=2785
  _globals['_LATESTHISTORYREPLY']._serialized_start=2787
  _globals['_LATESTHISTORYREPLY']._serialized_end=2905
  _globals['_LATESTHISTORYREQ']._serialized_start=2907
  _globals['_LATESTHISTORYREQ']._serialized_end=3015
  _globals['_NOREPLY']._serialized_start=3017
  _globals['_NOREPLY']._serialized_end=3026
  _globals['_PAGE']._serialized_start=3028
  _globals['_PAGE']._serialized_end=3061
  _globals['_PLAYERPRELOADPARAMS']._serialized_start=3063
  _globals['_PLAYERPRELOADPARAMS']._serialized_end=3160
  _globals['_RELATION']._serialized_start=3162
  _globals['_RELATION']._serialized_end=3228
  _globals['_SEARCHREPLY']._serialized_start=3231
  _globals['_SEARCHREPLY']._serialized_end=3362
  _globals['_SEARCHREQ']._serialized_start=3364
  _globals['_SEARCHREQ']._serialized_end=3422
  _globals['_HISTORY']._serialized_start=3566
  _globals['_HISTORY']._serialized_end=4220
# @@protoc_insertion_point(module_scope)
