# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/api/probe/v1/probe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/api/probe/v1/probe.proto\x12\x15\x62ilibili.api.probe.v1\"E\n\tCodeReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03id1\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\x03\x12\x11\n\tmessage_s\x18\x04 \x01(\t\"\x17\n\x07\x43odeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\x19\n\x0b\x43reateTopic\x12\n\n\x02id\x18\x01 \x01(\x03\"\x19\n\tCreatTask\x12\x0c\n\x04task\x18\x01 \x01(\t\"J\n\x14\x44ynamicMessageUpdate\x12\x32\n\x04\x62ody\x18\x01 \x01(\x0b\x32$.bilibili.api.probe.v1.SimpleMessage\"\xc8\x04\n\x08\x45mbedded\x12\x10\n\x08\x62ool_val\x18\x01 \x01(\x08\x12\x11\n\tint32_val\x18\x02 \x01(\x05\x12\x11\n\tint64_val\x18\x03 \x01(\x03\x12\x11\n\tfloat_val\x18\x04 \x01(\x02\x12\x12\n\ndouble_val\x18\x05 \x01(\x01\x12\x12\n\nstring_val\x18\x06 \x01(\t\x12\x19\n\x11repeated_bool_val\x18\x07 \x03(\x08\x12\x1a\n\x12repeated_int32_val\x18\x08 \x03(\x05\x12\x1a\n\x12repeated_int64_val\x18\t \x03(\x03\x12\x1a\n\x12repeated_float_val\x18\n \x03(\x02\x12\x1b\n\x13repeated_double_val\x18\x0b \x03(\x01\x12\x1b\n\x13repeated_string_val\x18\x0c \x03(\t\x12I\n\x0emap_string_val\x18\r \x03(\x0b\x32\x31.bilibili.api.probe.v1.Embedded.MapStringValEntry\x12G\n\rmap_error_val\x18\x0e \x03(\x0b\x32\x30.bilibili.api.probe.v1.Embedded.MapErrorValEntry\x1a\x33\n\x11MapStringValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aW\n\x10MapErrorValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.bilibili.api.probe.v1.ErrorMessage:\x02\x38\x01\"=\n\x0c\x45rrorMessage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\nProbeReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"&\n\x08ProbeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05\x62uvid\x18\x02 \x01(\t\"H\n\x10ProbeStreamReply\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"/\n\x0eProbeStreamReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"#\n\rProbeSubReply\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\"\x1c\n\x0bProbeSubReq\x12\r\n\x05\x62uvid\x18\x01 \x01(\t\"w\n\rSimpleMessage\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0c\n\x04\x63\x61te\x18\x04 \x01(\x05\x12\x31\n\x08\x65mbedded\x18\x05 \x01(\x0b\x32\x1f.bilibili.api.probe.v1.Embedded\"3\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x03 \x01(\x08*o\n\x08\x43\x61tegory\x12\x18\n\x14\x43\x41TEGORY_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43\x41TEGORY_ONE\x10\x01\x12\x10\n\x0c\x43\x41TEGORY_TWO\x10\x02\x12\x12\n\x0e\x43\x41TEGORY_THREE\x10\x03\x12\x11\n\rCATEGORY_FOUR\x10\x04*A\n\x0b\x45rrorReason\x12\x15\n\x11PROBE_UNSPECIFIED\x10\x00\x12\x1b\n\x17PROBE_CATEGORY_NOTFOUND\x10\x01\x32\xd7\x02\n\x05Probe\x12L\n\x08TestCode\x12\x1e.bilibili.api.probe.v1.CodeReq\x1a .bilibili.api.probe.v1.CodeReply\x12M\n\x07TestReq\x12\x1f.bilibili.api.probe.v1.ProbeReq\x1a!.bilibili.api.probe.v1.ProbeReply\x12\\\n\nTestStream\x12%.bilibili.api.probe.v1.ProbeStreamReq\x1a\'.bilibili.api.probe.v1.ProbeStreamReply\x12S\n\x07TestSub\x12\".bilibili.api.probe.v1.ProbeSubReq\x1a$.bilibili.api.probe.v1.ProbeSubReply2\xd2\x03\n\x0cProbeService\x12R\n\x04\x45\x63ho\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12V\n\x08\x45\x63hoBody\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12X\n\nEchoDelete\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12U\n\tEchoError\x12#.bilibili.api.probe.v1.ErrorMessage\x1a#.bilibili.api.probe.v1.ErrorMessage\x12\x65\n\tEchoPatch\x12+.bilibili.api.probe.v1.DynamicMessageUpdate\x1a+.bilibili.api.probe.v1.DynamicMessageUpdateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.api.probe.v1.probe_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._serialized_options = b'8\001'
  _EMBEDDED_MAPERRORVALENTRY._options = None
  _EMBEDDED_MAPERRORVALENTRY._serialized_options = b'8\001'
  _globals['_CATEGORY']._serialized_start=1390
  _globals['_CATEGORY']._serialized_end=1501
  _globals['_ERRORREASON']._serialized_start=1503
  _globals['_ERRORREASON']._serialized_end=1568
  _globals['_CODEREPLY']._serialized_start=60
  _globals['_CODEREPLY']._serialized_end=129
  _globals['_CODEREQ']._serialized_start=131
  _globals['_CODEREQ']._serialized_end=154
  _globals['_CREATETOPIC']._serialized_start=156
  _globals['_CREATETOPIC']._serialized_end=181
  _globals['_CREATTASK']._serialized_start=183
  _globals['_CREATTASK']._serialized_end=208
  _globals['_DYNAMICMESSAGEUPDATE']._serialized_start=210
  _globals['_DYNAMICMESSAGEUPDATE']._serialized_end=284
  _globals['_EMBEDDED']._serialized_start=287
  _globals['_EMBEDDED']._serialized_end=871
  _globals['_EMBEDDED_MAPSTRINGVALENTRY']._serialized_start=731
  _globals['_EMBEDDED_MAPSTRINGVALENTRY']._serialized_end=782
  _globals['_EMBEDDED_MAPERRORVALENTRY']._serialized_start=784
  _globals['_EMBEDDED_MAPERRORVALENTRY']._serialized_end=871
  _globals['_ERRORMESSAGE']._serialized_start=873
  _globals['_ERRORMESSAGE']._serialized_end=934
  _globals['_PROBEREPLY']._serialized_start=936
  _globals['_PROBEREPLY']._serialized_end=984
  _globals['_PROBEREQ']._serialized_start=986
  _globals['_PROBEREQ']._serialized_end=1024
  _globals['_PROBESTREAMREPLY']._serialized_start=1026
  _globals['_PROBESTREAMREPLY']._serialized_end=1098
  _globals['_PROBESTREAMREQ']._serialized_start=1100
  _globals['_PROBESTREAMREQ']._serialized_end=1147
  _globals['_PROBESUBREPLY']._serialized_start=1149
  _globals['_PROBESUBREPLY']._serialized_end=1184
  _globals['_PROBESUBREQ']._serialized_start=1186
  _globals['_PROBESUBREQ']._serialized_end=1214
  _globals['_SIMPLEMESSAGE']._serialized_start=1216
  _globals['_SIMPLEMESSAGE']._serialized_end=1335
  _globals['_TASK']._serialized_start=1337
  _globals['_TASK']._serialized_end=1388
  _globals['_PROBE']._serialized_start=1571
  _globals['_PROBE']._serialized_end=1914
  _globals['_PROBESERVICE']._serialized_start=1917
  _globals['_PROBESERVICE']._serialized_end=2383
# @@protoc_insertion_point(module_scope)
