# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/v2/campus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.pagination import pagination_pb2 as bilibili_dot_pagination_dot_pagination__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.common import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_common_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/app/dynamic/v2/campus.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a$bilibili/pagination/pagination.proto\x1a)bilibili/app/dynamic/common/dynamic.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"\xac\x01\n\x13\x43\x61mpusWaterFlowItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12:\n\x08wh_ratio\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.common.ItemWHRatio\x12>\n\x0citem_default\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.WFItemDefaultH\x00\x42\x06\n\x04item\"\xb2\x01\n\x10WaterFlowRcmdReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x38\n\x04\x66rom\x18\x04 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusRcmdReqFrom\"\x8a\x01\n\x11WaterFlowRcmdResp\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.CampusWaterFlowItem\x12\x38\n\x06offset\x18\x02 \x01(\x0b\x32(.bilibili.pagination.FeedPaginationReply\"\xc0\x03\n\rWFItemDefault\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x41\n\rbottom_left_1\x18\x03 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x41\n\rbottom_left_2\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x42\n\x0e\x62ottom_right_1\x18\x05 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x38\n\x0brcmd_reason\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdReason\x12L\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32\x37.bilibili.app.dynamic.v2.WFItemDefault.AnnotationsEntry\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32p\n\x06\x43\x61mpus\x12\x66\n\rWaterFlowRcmd\x12).bilibili.app.dynamic.v2.WaterFlowRcmdReq\x1a*.bilibili.app.dynamic.v2.WaterFlowRcmdRespb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v2.campus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WFITEMDEFAULT_ANNOTATIONSENTRY._options = None
  _WFITEMDEFAULT_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _globals['_CAMPUSWATERFLOWITEM']._serialized_start=236
  _globals['_CAMPUSWATERFLOWITEM']._serialized_end=408
  _globals['_WATERFLOWRCMDREQ']._serialized_start=411
  _globals['_WATERFLOWRCMDREQ']._serialized_end=589
  _globals['_WATERFLOWRCMDRESP']._serialized_start=592
  _globals['_WATERFLOWRCMDRESP']._serialized_end=730
  _globals['_WFITEMDEFAULT']._serialized_start=733
  _globals['_WFITEMDEFAULT']._serialized_end=1181
  _globals['_WFITEMDEFAULT_ANNOTATIONSENTRY']._serialized_start=1131
  _globals['_WFITEMDEFAULT_ANNOTATIONSENTRY']._serialized_end=1181
  _globals['_CAMPUS']._serialized_start=1183
  _globals['_CAMPUS']._serialized_end=1295
# @@protoc_insertion_point(module_scope)
