# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/archive/v1/archive.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/archive/v1/archive.proto\x12\x17\x62ilibili.app.archive.v1\"\xad\x06\n\x03\x41rc\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06videos\x18\x02 \x01(\x03\x12\x0f\n\x07type_id\x18\x03 \x01(\x05\x12\x11\n\ttype_name\x18\x04 \x01(\t\x12\x11\n\tcopyright\x18\x05 \x01(\x05\x12\x0b\n\x03pic\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07pubdate\x18\x08 \x01(\x03\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x05\x12\x11\n\tattribute\x18\r \x01(\x05\x12\x0b\n\x03tag\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x10\n\x08\x64uration\x18\x10 \x01(\x03\x12\x12\n\nmission_id\x18\x11 \x01(\x03\x12\x10\n\x08order_id\x18\x12 \x01(\x03\x12\x14\n\x0credirect_url\x18\x13 \x01(\t\x12\x0f\n\x07\x66orward\x18\x14 \x01(\x03\x12/\n\x06rights\x18\x15 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Rights\x12/\n\x06\x61uthor\x18\x16 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x17 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x15\n\rreport_result\x18\x18 \x01(\t\x12\x0f\n\x07\x64ynamic\x18\x19 \x01(\t\x12\x11\n\tfirst_cid\x18\x1a \x01(\x03\x12\x35\n\tdimension\x18\x1b \x01(\x0b\x32\".bilibili.app.archive.v1.Dimension\x12\x36\n\nstaff_info\x18\x1c \x03(\x0b\x32\".bilibili.app.archive.v1.StaffInfo\x12\x11\n\tseason_id\x18\x1d \x01(\x03\x12\x14\n\x0c\x61ttribute_v2\x18\x1e \x01(\x03\x12:\n\x0cseason_theme\x18\x1f \x01(\x0b\x32$.bilibili.app.archive.v1.SeasonTheme\x12\x15\n\rshort_link_v2\x18( \x01(\t\x12\x12\n\nup_from_v2\x18) \x01(\x05\x12\x13\n\x0b\x66irst_frame\x18* \x01(\t\"1\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"\xc7\x01\n\x04Page\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0c\n\x04part\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03vid\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x07 \x01(\t\x12\x0f\n\x07webLink\x18\x08 \x01(\t\x12\x35\n\tdimension\x18\t \x01(\x0b\x32\".bilibili.app.archive.v1.Dimension\x12\x13\n\x0b\x66irst_frame\x18\n \x01(\t\"\x85\x02\n\x06Rights\x12\n\n\x02\x62p\x18\x01 \x01(\x05\x12\x0c\n\x04\x65lec\x18\x02 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x03 \x01(\x05\x12\r\n\x05movie\x18\x04 \x01(\x05\x12\x0b\n\x03pay\x18\x05 \x01(\x05\x12\x0b\n\x03hd5\x18\x06 \x01(\x05\x12\x12\n\nno_reprint\x18\x07 \x01(\x05\x12\x10\n\x08\x61utoplay\x18\x08 \x01(\x05\x12\x0f\n\x07ugc_pay\x18\t \x01(\x05\x12\x16\n\x0eis_cooperation\x18\n \x01(\x05\x12\x17\n\x0fugc_pay_preview\x18\x0b \x01(\x05\x12\x15\n\rno_background\x18\x0c \x01(\x05\x12\x0f\n\x07\x61rc_pay\x18\r \x01(\x05\x12\x16\n\x0epay_free_watch\x18\x0e \x01(\x05\"N\n\x0bSeasonTheme\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\":\n\tStaffInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tattribute\x18\x03 \x01(\x03\"\xae\x01\n\x04Stat\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\x12\x0f\n\x07\x64islike\x18\x0b \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.archive.v1.archive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ARC']._serialized_start=67
  _globals['_ARC']._serialized_end=880
  _globals['_AUTHOR']._serialized_start=882
  _globals['_AUTHOR']._serialized_end=931
  _globals['_DIMENSION']._serialized_start=933
  _globals['_DIMENSION']._serialized_end=991
  _globals['_PAGE']._serialized_start=994
  _globals['_PAGE']._serialized_end=1193
  _globals['_RIGHTS']._serialized_start=1196
  _globals['_RIGHTS']._serialized_end=1457
  _globals['_SEASONTHEME']._serialized_start=1459
  _globals['_SEASONTHEME']._serialized_end=1537
  _globals['_STAFFINFO']._serialized_start=1539
  _globals['_STAFFINFO']._serialized_end=1597
  _globals['_STAT']._serialized_start=1600
  _globals['_STAT']._serialized_end=1774
# @@protoc_insertion_point(module_scope)
