# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilibili.im.interfaces.inner_interface.v1 import api_pb2 as bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2


class InnerInterfaceStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateListInn = channel.unary_unary(
                '/bilibili.im.interface.inner.interface.v1.InnerInterface/UpdateListInn',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.FromString,
                )


class InnerInterfaceServicer(object):
    """
    """

    def UpdateListInn(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InnerInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateListInn': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateListInn,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.im.interface.inner.interface.v1.InnerInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InnerInterface(object):
    """
    """

    @staticmethod
    def UpdateListInn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interface.inner.interface.v1.InnerInterface/UpdateListInn',
            bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
