"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Locale(google.protobuf.message.Message):
    """区域标识
    gRPC头部:x-bili-locale-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    C_LOCALE_FIELD_NUMBER: builtins.int
    S_LOCALE_FIELD_NUMBER: builtins.int
    SIM_CODE_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    @property
    def c_locale(self) -> global___LocaleIds:
        """App设置的locale"""
    @property
    def s_locale(self) -> global___LocaleIds:
        """系统默认的locale"""
    sim_code: builtins.str
    """sim卡的国家码+运营商码"""
    timezone: builtins.str
    """时区"""
    def __init__(
        self,
        *,
        c_locale: global___LocaleIds | None = ...,
        s_locale: global___LocaleIds | None = ...,
        sim_code: builtins.str = ...,
        timezone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["c_locale", b"c_locale", "s_locale", b"s_locale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["c_locale", b"c_locale", "s_locale", b"s_locale", "sim_code", b"sim_code", "timezone", b"timezone"]) -> None: ...

global___Locale = Locale

@typing_extensions.final
class LocaleIds(google.protobuf.message.Message):
    """Defined by https://developer.apple.com/library/archive/documentation/MacOSX/Conceptual/BPInternational/LanguageandLocaleIDs/LanguageandLocaleIDs.html"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    language: builtins.str
    """A language designator is a code that represents a language."""
    script: builtins.str
    """Writing systems."""
    region: builtins.str
    """A region designator is a code that represents a country or an area."""
    def __init__(
        self,
        *,
        language: builtins.str = ...,
        script: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "region", b"region", "script", b"script"]) -> None: ...

global___LocaleIds = LocaleIds
