# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/experimental.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/app/distribution/setting/experimental.proto\x12.bilibili.app.distribution.setting.experimental\x1a/bilibili/app/distribution/v1/distribution.proto\"F\n\rDynamicSelect\x12\x35\n\x04\x66old\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"u\n\x03\x45xp\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x38\n\x06\x62ucket\x18\x02 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int32Value\"\x90\x01\n\x12\x45xperimentalConfig\x12\x37\n\x04\x66lag\x18\x01 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x41\n\x04\x65xps\x18\x02 \x03(\x0b\x32\x33.bilibili.app.distribution.setting.experimental.Exp\"\xb5\x01\n\x11MultipleTusConfig\x12I\n\x08top_left\x18\x01 \x01(\x0b\x32\x37.bilibili.app.distribution.setting.experimental.TopLeft\x12U\n\x0e\x64ynamic_select\x18\x02 \x01(\x0b\x32=.bilibili.app.distribution.setting.experimental.DynamicSelect\"\x96\x07\n\x07TopLeft\x12\x36\n\x03url\x18\x01 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12I\n\x16story_foreground_image\x18\x02 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12I\n\x16story_background_image\x18\x03 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12J\n\x17listen_foreground_image\x18\x04 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12J\n\x17listen_background_image\x18\x05 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12M\n\x1aios_story_foreground_image\x18\x06 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12M\n\x1aios_story_background_image\x18\x07 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12N\n\x1bios_listen_foreground_image\x18\x08 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12N\n\x1bios_listen_background_image\x18\t \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x37\n\x04goto\x18\n \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x39\n\x06url_v2\x18\x0b \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x39\n\x07goto_v2\x18\x0c \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x38\n\x05\x62\x61\x64ge\x18\r \x01(\x0b\x32).bilibili.app.distribution.v1.StringValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.experimental_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DYNAMICSELECT']._serialized_start=153
  _globals['_DYNAMICSELECT']._serialized_end=223
  _globals['_EXP']._serialized_start=225
  _globals['_EXP']._serialized_end=342
  _globals['_EXPERIMENTALCONFIG']._serialized_start=345
  _globals['_EXPERIMENTALCONFIG']._serialized_end=489
  _globals['_MULTIPLETUSCONFIG']._serialized_start=492
  _globals['_MULTIPLETUSCONFIG']._serialized_end=673
  _globals['_TOPLEFT']._serialized_start=676
  _globals['_TOPLEFT']._serialized_end=1594
# @@protoc_insertion_point(module_scope)
