"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetActProgressReq(google.protobuf.message.Message):
    """获取Native页进度数据-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGEID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    pageID: builtins.int
    """Native页id"""
    mid: builtins.int
    """用户mid"""
    def __init__(
        self,
        *,
        pageID: builtins.int = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "pageID", b"pageID"]) -> None: ...

global___GetActProgressReq = GetActProgressReq

@typing_extensions.final
class GetActProgressReply(google.protobuf.message.Message):
    """获取Native页进度数据-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2.NativePageEvent:
        """进度数据"""
    def __init__(
        self,
        *,
        event: bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2.NativePageEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event"]) -> None: ...

global___GetActProgressReply = GetActProgressReply
