"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CommentDoubleClickConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERACTION_FIELD_NUMBER: builtins.int
    ANIMATION_SCALE_FIELD_NUMBER: builtins.int
    @property
    def interaction(self) -> global___Interaction:
        """"""
    animation_scale: builtins.float
    """"""
    def __init__(
        self,
        *,
        interaction: global___Interaction | None = ...,
        animation_scale: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interaction", b"interaction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation_scale", b"animation_scale", "interaction", b"interaction"]) -> None: ...

global___CommentDoubleClickConfig = CommentDoubleClickConfig

@typing_extensions.final
class GyroConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GYROSCOPE_FIELD_NUMBER: builtins.int
    @property
    def gyroscope(self) -> global___NFTImageV2:
        """"""
    def __init__(
        self,
        *,
        gyroscope: global___NFTImageV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> None: ...

global___GyroConfig = GyroConfig

@typing_extensions.final
class GyroscopeContentV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_URL_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    PHYSICAL_ORIENTATION_FIELD_NUMBER: builtins.int
    file_url: builtins.str
    """"""
    scale: builtins.float
    """"""
    @property
    def physical_orientation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhysicalOrientationV2]:
        """"""
    def __init__(
        self,
        *,
        file_url: builtins.str = ...,
        scale: builtins.float = ...,
        physical_orientation: collections.abc.Iterable[global___PhysicalOrientationV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_url", b"file_url", "physical_orientation", b"physical_orientation", "scale", b"scale"]) -> None: ...

global___GyroscopeContentV2 = GyroscopeContentV2

@typing_extensions.final
class GyroscopeEntityV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_TYPE_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    display_type: builtins.str
    """"""
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GyroscopeContentV2]:
        """"""
    def __init__(
        self,
        *,
        display_type: builtins.str = ...,
        contents: collections.abc.Iterable[global___GyroscopeContentV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents", b"contents", "display_type", b"display_type"]) -> None: ...

global___GyroscopeEntityV2 = GyroscopeEntityV2

@typing_extensions.final
class Interaction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NFT_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ITYPE_FIELD_NUMBER: builtins.int
    METADATA_URL_FIELD_NUMBER: builtins.int
    nft_id: builtins.str
    """"""
    enabled: builtins.bool
    """"""
    itype: builtins.str
    """"""
    metadata_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        nft_id: builtins.str = ...,
        enabled: builtins.bool = ...,
        itype: builtins.str = ...,
        metadata_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "itype", b"itype", "metadata_url", b"metadata_url", "nft_id", b"nft_id"]) -> None: ...

global___Interaction = Interaction

@typing_extensions.final
class LiveAnimeConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVE_FIELD_NUMBER: builtins.int
    is_live: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_live: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_live", b"is_live"]) -> None: ...

global___LiveAnimeConfig = LiveAnimeConfig

@typing_extensions.final
class LiveAnimeItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    START_RATIO_FIELD_NUMBER: builtins.int
    END_RATIO_FIELD_NUMBER: builtins.int
    START_STROKE_FIELD_NUMBER: builtins.int
    START_OPACITY_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ColorConfig:
        """"""
    start_ratio: builtins.float
    """"""
    end_ratio: builtins.float
    """"""
    start_stroke: builtins.float
    """"""
    start_opacity: builtins.float
    """"""
    phase: builtins.int
    """"""
    def __init__(
        self,
        *,
        color: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ColorConfig | None = ...,
        start_ratio: builtins.float = ...,
        end_ratio: builtins.float = ...,
        start_stroke: builtins.float = ...,
        start_opacity: builtins.float = ...,
        phase: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "end_ratio", b"end_ratio", "phase", b"phase", "start_opacity", b"start_opacity", "start_ratio", b"start_ratio", "start_stroke", b"start_stroke"]) -> None: ...

global___LiveAnimeItem = LiveAnimeItem

@typing_extensions.final
class NFTImageV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GYROSCOPE_FIELD_NUMBER: builtins.int
    @property
    def gyroscope(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GyroscopeEntityV2]:
        """"""
    def __init__(
        self,
        *,
        gyroscope: collections.abc.Iterable[global___GyroscopeEntityV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> None: ...

global___NFTImageV2 = NFTImageV2

@typing_extensions.final
class PhysicalOrientationAnimation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BEZIER_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    bezier: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        bezier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bezier", b"bezier", "type", b"type"]) -> None: ...

global___PhysicalOrientationAnimation = PhysicalOrientationAnimation

@typing_extensions.final
class PhysicalOrientationV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ANIMATIONS_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    @property
    def animations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhysicalOrientationAnimation]:
        """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        animations: collections.abc.Iterable[global___PhysicalOrientationAnimation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["animations", b"animations", "type", b"type"]) -> None: ...

global___PhysicalOrientationV2 = PhysicalOrientationV2
