"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetUserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_URL_FIELD_NUMBER: builtins.int
    EXTRA_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def type_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def extra_context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        type_url: collections.abc.Iterable[builtins.str] | None = ...,
        extra_context: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra_context", b"extra_context", "type_url", b"type_url"]) -> None: ...

global___GetUserPreferenceReq = GetUserPreferenceReq

@typing_extensions.final
class GetUserPreferenceReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """对应 GetUserPreferenceReq 的请求的类型"""
    def __init__(
        self,
        *,
        value: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___GetUserPreferenceReply = GetUserPreferenceReply

@typing_extensions.final
class SetUserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PREFERENCE_FIELD_NUMBER: builtins.int
    EXTRA_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def preference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """"""
    @property
    def extra_context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        preference: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        extra_context: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra_context", b"extra_context", "preference", b"preference"]) -> None: ...

global___SetUserPreferenceReq = SetUserPreferenceReq

@typing_extensions.final
class SetUserPreferenceReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetUserPreferenceReply = SetUserPreferenceReply

@typing_extensions.final
class UserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserPreferenceReq = UserPreferenceReq

@typing_extensions.final
class UserPreferenceReply(google.protobuf.message.Message):
    """云控配置下发"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERENCE_FIELD_NUMBER: builtins.int
    @property
    def preference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """具体解码需要根据实际请求 type_url 来判断"""
    def __init__(
        self,
        *,
        preference: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["preference", b"preference"]) -> None: ...

global___UserPreferenceReply = UserPreferenceReply

@typing_extensions.final
class BoolValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.bool
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.bool
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.bool = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___BoolValue = BoolValue

@typing_extensions.final
class BytesValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.bytes
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.bytes
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.bytes = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.bytes = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___BytesValue = BytesValue

@typing_extensions.final
class DoubleValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.float
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.float
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.float = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.float = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___DoubleValue = DoubleValue

@typing_extensions.final
class FloatValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.float
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.float
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.float = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.float = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___FloatValue = FloatValue

@typing_extensions.final
class Int32Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___Int32Value = Int32Value

@typing_extensions.final
class Int64Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___Int64Value = Int64Value

@typing_extensions.final
class StringValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.str
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.str
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.str = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___StringValue = StringValue

@typing_extensions.final
class UInt32Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___UInt32Value = UInt32Value

@typing_extensions.final
class UInt64Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___UInt64Value = UInt64Value
