"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetTicketRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bytes
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTEXT_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bytes]:
        """包含: 
        + x-fingerprint(包含手机各类信息, 使用 datacenter.hakase.protobuf.AndroidDeviceInfo 生成)
        + x-exbadbasket(?)
        """
    key_id: builtins.str
    """暂时固定为 ec01"""
    sign: builtins.bytes
    """"""
    token: builtins.str
    """暂时留空"""
    def __init__(
        self,
        *,
        context: collections.abc.Mapping[builtins.str, builtins.bytes] | None = ...,
        key_id: builtins.str = ...,
        sign: builtins.bytes = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "key_id", b"key_id", "sign", b"sign", "token", b"token"]) -> None: ...

global___GetTicketRequest = GetTicketRequest

@typing_extensions.final
class GetTicketResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Context(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        V_VOUCHER_FIELD_NUMBER: builtins.int
        v_voucher: builtins.str
        """"""
        def __init__(
            self,
            *,
            v_voucher: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["v_voucher", b"v_voucher"]) -> None: ...

    TICKET_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    ticket: builtins.str
    """x-bili-ticket"""
    created_at: builtins.int
    """有效期起"""
    ttl: builtins.int
    """有效期"""
    @property
    def context(self) -> global___GetTicketResponse.Context:
        """"""
    def __init__(
        self,
        *,
        ticket: builtins.str = ...,
        created_at: builtins.int = ...,
        ttl: builtins.int = ...,
        context: global___GetTicketResponse.Context | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "created_at", b"created_at", "ticket", b"ticket", "ttl", b"ttl"]) -> None: ...

global___GetTicketResponse = GetTicketResponse
