# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/common/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/dynamic/common/dynamic.proto\x12\x1b\x62ilibili.app.dynamic.common\";\n\x0bItemWHRatio\x12\r\n\x05ratio\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05*Y\n\x07WHRatio\x12\x11\n\rW_H_RATIO_1_1\x10\x00\x12\x12\n\x0eW_H_RATIO_16_9\x10\x01\x12\x11\n\rW_H_RATIO_3_4\x10\x02\x12\x14\n\x10W_H_RATIO_CUSTOM\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.common.dynamic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WHRATIO']._serialized_start=135
  _globals['_WHRATIO']._serialized_end=224
  _globals['_ITEMWHRATIO']._serialized_start=74
  _globals['_ITEMWHRATIO']._serialized_end=133
# @@protoc_insertion_point(module_scope)
