# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.main.community.reply.v1 import reply_pb2 as bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2


class ReplyStub(object):
    """评论区
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MainList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/MainList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.FromString,
                )
        self.DetailList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/DetailList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.FromString,
                )
        self.DialogList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/DialogList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.FromString,
                )
        self.PreviewList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/PreviewList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.FromString,
                )
        self.SearchItemPreHook = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SearchItemPreHook',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.FromString,
                )
        self.SearchItem = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SearchItem',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.FromString,
                )
        self.AtSearch = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/AtSearch',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.FromString,
                )
        self.ReplyInfo = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/ReplyInfo',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.FromString,
                )
        self.UserCallback = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/UserCallback',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.FromString,
                )
        self.ShareRepliesInfo = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/ShareRepliesInfo',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.FromString,
                )
        self.SuggestEmotes = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SuggestEmotes',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.FromString,
                )


class ReplyServicer(object):
    """评论区
    """

    def MainList(self, request, context):
        """主评论列表接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetailList(self, request, context):
        """二级评论明细接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DialogList(self, request, context):
        """对话评论树接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewList(self, request, context):
        """评论预览接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchItemPreHook(self, request, context):
        """评论搜索item前置发布接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchItem(self, request, context):
        """评论搜索插入项目接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AtSearch(self, request, context):
        """评论at用户搜索接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplyInfo(self, request, context):
        """查询单条评论接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserCallback(self, request, context):
        """用户回调上报接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShareRepliesInfo(self, request, context):
        """评论分享材料接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuggestEmotes(self, request, context):
        """评论表情推荐列表接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReplyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MainList': grpc.unary_unary_rpc_method_handler(
                    servicer.MainList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.SerializeToString,
            ),
            'DetailList': grpc.unary_unary_rpc_method_handler(
                    servicer.DetailList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.SerializeToString,
            ),
            'DialogList': grpc.unary_unary_rpc_method_handler(
                    servicer.DialogList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.SerializeToString,
            ),
            'PreviewList': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.SerializeToString,
            ),
            'SearchItemPreHook': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchItemPreHook,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.SerializeToString,
            ),
            'SearchItem': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchItem,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.SerializeToString,
            ),
            'AtSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.AtSearch,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.SerializeToString,
            ),
            'ReplyInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplyInfo,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.SerializeToString,
            ),
            'UserCallback': grpc.unary_unary_rpc_method_handler(
                    servicer.UserCallback,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.SerializeToString,
            ),
            'ShareRepliesInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ShareRepliesInfo,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.SerializeToString,
            ),
            'SuggestEmotes': grpc.unary_unary_rpc_method_handler(
                    servicer.SuggestEmotes,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.main.community.reply.v1.Reply', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Reply(object):
    """评论区
    """

    @staticmethod
    def MainList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/MainList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetailList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/DetailList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DialogList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/DialogList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/PreviewList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchItemPreHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SearchItemPreHook',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SearchItem',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AtSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/AtSearch',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReplyInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/ReplyInfo',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserCallback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/UserCallback',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShareRepliesInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/ShareRepliesInfo',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuggestEmotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SuggestEmotes',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
