"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNKNOWN: _PlayState.ValueType  # 0
    """"""
    PREPARING: _PlayState.ValueType  # 1
    """"""
    PREPARED: _PlayState.ValueType  # 2
    """"""
    PLAYING: _PlayState.ValueType  # 3
    """"""
    PAUSED: _PlayState.ValueType  # 4
    """"""
    STOPPED: _PlayState.ValueType  # 5
    """"""
    FAILED: _PlayState.ValueType  # 6
    """"""

class PlayState(_PlayState, metaclass=_PlayStateEnumTypeWrapper):
    """"""

STATE_UNKNOWN: PlayState.ValueType  # 0
""""""
PREPARING: PlayState.ValueType  # 1
""""""
PREPARED: PlayState.ValueType  # 2
""""""
PLAYING: PlayState.ValueType  # 3
""""""
PAUSED: PlayState.ValueType  # 4
""""""
STOPPED: PlayState.ValueType  # 5
""""""
FAILED: PlayState.ValueType  # 6
""""""
global___PlayState = PlayState

class _Stage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Stage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STAGE_UNKNOWN: _Stage.ValueType  # 0
    """"""
    START: _Stage.ValueType  # 1
    """"""
    END: _Stage.ValueType  # 2
    """"""
    SAMPLE: _Stage.ValueType  # 3
    """"""

class Stage(_Stage, metaclass=_StageEnumTypeWrapper):
    """"""

STAGE_UNKNOWN: Stage.ValueType  # 0
""""""
START: Stage.ValueType  # 1
""""""
END: Stage.ValueType  # 2
""""""
SAMPLE: Stage.ValueType  # 3
""""""
global___Stage = Stage

@typing_extensions.final
class AccountInfo(google.protobuf.message.Message):
    """账户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___AccountInfo = AccountInfo

@typing_extensions.final
class AppInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_PAGE_CLASS_FIELD_NUMBER: builtins.int
    FTIME_FIELD_NUMBER: builtins.int
    DID_FIELD_NUMBER: builtins.int
    top_page_class: builtins.str
    """"""
    ftime: builtins.int
    """客户端首次启动时的毫秒时间戳"""
    did: builtins.str
    """"""
    def __init__(
        self,
        *,
        top_page_class: builtins.str = ...,
        ftime: builtins.int = ...,
        did: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["did", b"did", "ftime", b"ftime", "top_page_class", b"top_page_class"]) -> None: ...

global___AppInfo = AppInfo

@typing_extensions.final
class Extra(google.protobuf.message.Message):
    """心跳补充信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    REFER_FIELD_NUMBER: builtins.int
    session: builtins.str
    """"""
    refer: builtins.str
    """"""
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        refer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["refer", b"refer", "session", b"session"]) -> None: ...

global___Extra = Extra

@typing_extensions.final
class HeartBeatReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartBeatReply = HeartBeatReply

@typing_extensions.final
class HeartBeatReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_V2_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    STREAM_TIMEOUT_FIELD_NUMBER: builtins.int
    BATCH_FREQUENCY_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    VIDEO_META_FIELD_NUMBER: builtins.int
    APP_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_INFO_FIELD_NUMBER: builtins.int
    PRE_PROCESS_RESULT_FIELD_NUMBER: builtins.int
    PLAYER_STATUS_FIELD_NUMBER: builtins.int
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    session_v2: builtins.str
    """"""
    stage: global___Stage.ValueType
    """"""
    stream_timeout: builtins.int
    """流加载失败timeout"""
    batch_frequency: builtins.int
    """"""
    frequency: builtins.float
    """"""
    @property
    def video_meta(self) -> global___VideoMeta:
        """"""
    @property
    def app_info(self) -> global___AppInfo:
        """"""
    @property
    def account_info(self) -> global___AccountInfo:
        """"""
    @property
    def pre_process_result(self) -> global___PreProcessResult:
        """"""
    @property
    def player_status(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayerStatus]:
        """"""
    @property
    def video_info(self) -> global___VideoInfo:
        """"""
    def __init__(
        self,
        *,
        session_v2: builtins.str = ...,
        stage: global___Stage.ValueType = ...,
        stream_timeout: builtins.int = ...,
        batch_frequency: builtins.int = ...,
        frequency: builtins.float = ...,
        video_meta: global___VideoMeta | None = ...,
        app_info: global___AppInfo | None = ...,
        account_info: global___AccountInfo | None = ...,
        pre_process_result: global___PreProcessResult | None = ...,
        player_status: collections.abc.Iterable[global___PlayerStatus] | None = ...,
        video_info: global___VideoInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_info", b"account_info", "app_info", b"app_info", "pre_process_result", b"pre_process_result", "video_info", b"video_info", "video_meta", b"video_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_info", b"account_info", "app_info", b"app_info", "batch_frequency", b"batch_frequency", "frequency", b"frequency", "player_status", b"player_status", "pre_process_result", b"pre_process_result", "session_v2", b"session_v2", "stage", b"stage", "stream_timeout", b"stream_timeout", "video_info", b"video_info", "video_meta", b"video_meta"]) -> None: ...

global___HeartBeatReq = HeartBeatReq

@typing_extensions.final
class PlayerStatus(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYBACK_RATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    PLAY_STATE_FIELD_NUMBER: builtins.int
    IS_BUFFERING_FIELD_NUMBER: builtins.int
    playback_rate: builtins.float
    """"""
    progress: builtins.int
    """"""
    play_state: global___PlayState.ValueType
    """"""
    is_buffering: builtins.bool
    """"""
    def __init__(
        self,
        *,
        playback_rate: builtins.float = ...,
        progress: builtins.int = ...,
        play_state: global___PlayState.ValueType = ...,
        is_buffering: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_buffering", b"is_buffering", "play_state", b"play_state", "playback_rate", b"playback_rate", "progress", b"progress"]) -> None: ...

global___PlayerStatus = PlayerStatus

@typing_extensions.final
class PreProcessResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VT_FIELD_NUMBER: builtins.int
    vt: builtins.int
    """"""
    def __init__(
        self,
        *,
        vt: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vt", b"vt"]) -> None: ...

global___PreProcessResult = PreProcessResult

@typing_extensions.final
class VideoInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_DURATION_FIELD_NUMBER: builtins.int
    cid_duration: builtins.int
    """"""
    def __init__(
        self,
        *,
        cid_duration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid_duration", b"cid_duration"]) -> None: ...

global___VideoInfo = VideoInfo

@typing_extensions.final
class VideoMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid"]) -> None: ...

global___VideoMeta = VideoMeta
