# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/v1/distribution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/distribution/v1/distribution.proto\x12\x1c\x62ilibili.app.distribution.v1\x1a\x19google/protobuf/any.proto\"\xba\x01\n\x14GetUserPreferenceReq\x12\x10\n\x08type_url\x18\x01 \x03(\t\x12[\n\rextra_context\x18\x02 \x03(\x0b\x32\x44.bilibili.app.distribution.v1.GetUserPreferenceReq.ExtraContextEntry\x1a\x33\n\x11\x45xtraContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x16GetUserPreferenceReply\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\xd2\x01\n\x14SetUserPreferenceReq\x12(\n\npreference\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12[\n\rextra_context\x18\x02 \x03(\x0b\x32\x44.bilibili.app.distribution.v1.SetUserPreferenceReq.ExtraContextEntry\x1a\x33\n\x11\x45xtraContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16SetUserPreferenceReply\"\x13\n\x11UserPreferenceReq\"?\n\x13UserPreferenceReply\x12(\n\npreference\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"U\n\tBoolValue\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nBytesValue\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x0c\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0b\x44oubleValue\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x01\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nFloatValue\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x02\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nInt32Value\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x05\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x03\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bStringValue\x12\r\n\x05value\x18\x01 \x01(\t\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\t\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bUInt32Value\x12\r\n\x05value\x18\x01 \x01(\r\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\r\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bUInt64Value\x12\r\n\x05value\x18\x01 \x01(\x04\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x04\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t2\x82\x03\n\x0c\x44istribution\x12}\n\x11GetUserPreference\x12\x32.bilibili.app.distribution.v1.GetUserPreferenceReq\x1a\x34.bilibili.app.distribution.v1.GetUserPreferenceReply\x12}\n\x11SetUserPreference\x12\x32.bilibili.app.distribution.v1.SetUserPreferenceReq\x1a\x34.bilibili.app.distribution.v1.SetUserPreferenceReply\x12t\n\x0eUserPreference\x12/.bilibili.app.distribution.v1.UserPreferenceReq\x1a\x31.bilibili.app.distribution.v1.UserPreferenceReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.v1.distribution_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._options = None
  _GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._serialized_options = b'8\001'
  _SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._options = None
  _SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._serialized_options = b'8\001'
  _globals['_GETUSERPREFERENCEREQ']._serialized_start=109
  _globals['_GETUSERPREFERENCEREQ']._serialized_end=295
  _globals['_GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_start=244
  _globals['_GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_end=295
  _globals['_GETUSERPREFERENCEREPLY']._serialized_start=297
  _globals['_GETUSERPREFERENCEREPLY']._serialized_end=358
  _globals['_SETUSERPREFERENCEREQ']._serialized_start=361
  _globals['_SETUSERPREFERENCEREQ']._serialized_end=571
  _globals['_SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_start=244
  _globals['_SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_end=295
  _globals['_SETUSERPREFERENCEREPLY']._serialized_start=573
  _globals['_SETUSERPREFERENCEREPLY']._serialized_end=597
  _globals['_USERPREFERENCEREQ']._serialized_start=599
  _globals['_USERPREFERENCEREQ']._serialized_end=618
  _globals['_USERPREFERENCEREPLY']._serialized_start=620
  _globals['_USERPREFERENCEREPLY']._serialized_end=683
  _globals['_BOOLVALUE']._serialized_start=685
  _globals['_BOOLVALUE']._serialized_end=770
  _globals['_BYTESVALUE']._serialized_start=772
  _globals['_BYTESVALUE']._serialized_end=858
  _globals['_DOUBLEVALUE']._serialized_start=860
  _globals['_DOUBLEVALUE']._serialized_end=947
  _globals['_FLOATVALUE']._serialized_start=949
  _globals['_FLOATVALUE']._serialized_end=1035
  _globals['_INT32VALUE']._serialized_start=1037
  _globals['_INT32VALUE']._serialized_end=1123
  _globals['_INT64VALUE']._serialized_start=1125
  _globals['_INT64VALUE']._serialized_end=1211
  _globals['_STRINGVALUE']._serialized_start=1213
  _globals['_STRINGVALUE']._serialized_end=1300
  _globals['_UINT32VALUE']._serialized_start=1302
  _globals['_UINT32VALUE']._serialized_end=1389
  _globals['_UINT64VALUE']._serialized_start=1391
  _globals['_UINT64VALUE']._serialized_end=1478
  _globals['_DISTRIBUTION']._serialized_start=1481
  _globals['_DISTRIBUTION']._serialized_end=1867
# @@protoc_insertion_point(module_scope)
