"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ButType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ButTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ButType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BUT_INVALID: _ButType.ValueType  # 0
    """"""
    BUT_REDIRECT: _ButType.ValueType  # 1
    """"""
    BUT_LIKE: _ButType.ValueType  # 2
    """"""

class ButType(_ButType, metaclass=_ButTypeEnumTypeWrapper):
    """"""

BUT_INVALID: ButType.ValueType  # 0
""""""
BUT_REDIRECT: ButType.ValueType  # 1
""""""
BUT_LIKE: ButType.ValueType  # 2
""""""
global___ButType = ButType

class _TabType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TabTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TAB_INVALID: _TabType.ValueType  # 0
    """"""
    TAB_OGV_DETAIL: _TabType.ValueType  # 6
    """"""
    TAB_OGV_REPLY: _TabType.ValueType  # 7
    """"""
    TAB_FEED_BID: _TabType.ValueType  # 8
    """"""
    TAB_FEED_SMALL: _TabType.ValueType  # 9
    """"""

class TabType(_TabType, metaclass=_TabTypeEnumTypeWrapper):
    """"""

TAB_INVALID: TabType.ValueType  # 0
""""""
TAB_OGV_DETAIL: TabType.ValueType  # 6
""""""
TAB_OGV_REPLY: TabType.ValueType  # 7
""""""
TAB_FEED_BID: TabType.ValueType  # 8
""""""
TAB_FEED_SMALL: TabType.ValueType  # 9
""""""
global___TabType = TabType

@typing_extensions.final
class BigItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    USER_CARD_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover_image_uri: builtins.str
    """"""
    uri: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    @property
    def user_card(self) -> global___UserCard:
        """"""
    @property
    def like_button(self) -> global___LikeButton:
        """"""
    param: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover_image_uri: builtins.str = ...,
        uri: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        user_card: global___UserCard | None = ...,
        like_button: global___LikeButton | None = ...,
        param: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["like_button", b"like_button", "user_card", b"user_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_image_uri", b"cover_image_uri", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_right_text", b"cover_right_text", "like_button", b"like_button", "param", b"param", "title", b"title", "uri", b"uri", "user_card", b"user_card"]) -> None: ...

global___BigItem = BigItem

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    BUT_TYPE_FIELD_NUMBER: builtins.int
    FOLLOW_STATE_FIELD_NUMBER: builtins.int
    HAS_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    link: builtins.str
    """"""
    id: builtins.str
    """"""
    icon: builtins.int
    """"""
    but_type: global___ButType.ValueType
    """"""
    follow_state: builtins.int
    """"""
    has_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        link: builtins.str = ...,
        id: builtins.str = ...,
        icon: builtins.int = ...,
        but_type: global___ButType.ValueType = ...,
        follow_state: builtins.int = ...,
        has_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["but_type", b"but_type", "follow_state", b"follow_state", "has_title", b"has_title", "icon", b"icon", "id", b"id", "link", b"link", "title", b"title"]) -> None: ...

global___Button = Button

@typing_extensions.final
class Cast(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERSON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def person(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MediaPerson]:
        """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        person: collections.abc.Iterable[global___MediaPerson] | None = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["person", b"person", "title", b"title"]) -> None: ...

global___Cast = Cast

@typing_extensions.final
class ChannelInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SUBSCRIBED_FIELD_NUMBER: builtins.int
    channel_id: builtins.int
    """"""
    subscribed: builtins.bool
    """"""
    def __init__(
        self,
        *,
        channel_id: builtins.int = ...,
        subscribed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id", b"channel_id", "subscribed", b"subscribed"]) -> None: ...

global___ChannelInfo = ChannelInfo

@typing_extensions.final
class LikeButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    LIKE_RESOURCE_FIELD_NUMBER: builtins.int
    DIS_LIKE_RESOURCE_FIELD_NUMBER: builtins.int
    LIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    DIS_LIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    count: builtins.int
    """"""
    show_count: builtins.bool
    """"""
    event: builtins.str
    """"""
    selected: builtins.int
    """"""
    event_v2: builtins.str
    """"""
    @property
    def like_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def dis_like_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def like_night_resource(self) -> global___LikeButtonResource:
        """"""
    @property
    def dis_like_night_resource(self) -> global___LikeButtonResource:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        count: builtins.int = ...,
        show_count: builtins.bool = ...,
        event: builtins.str = ...,
        selected: builtins.int = ...,
        event_v2: builtins.str = ...,
        like_resource: global___LikeButtonResource | None = ...,
        dis_like_resource: global___LikeButtonResource | None = ...,
        like_night_resource: global___LikeButtonResource | None = ...,
        dis_like_night_resource: global___LikeButtonResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dis_like_night_resource", b"dis_like_night_resource", "dis_like_resource", b"dis_like_resource", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "count", b"count", "dis_like_night_resource", b"dis_like_night_resource", "dis_like_resource", b"dis_like_resource", "event", b"event", "event_v2", b"event_v2", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource", "selected", b"selected", "show_count", b"show_count"]) -> None: ...

global___LikeButton = LikeButton

@typing_extensions.final
class LikeButtonResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "url", b"url"]) -> None: ...

global___LikeButtonResource = LikeButtonResource

@typing_extensions.final
class LikeCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    like: builtins.int
    """"""
    is_follow: builtins.bool
    """"""
    def __init__(
        self,
        *,
        like: builtins.int = ...,
        is_follow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "like", b"like"]) -> None: ...

global___LikeCard = LikeCard

@typing_extensions.final
class MediaCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    CUR_TITLE_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUT_FIRST_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    cur_title: builtins.str
    """"""
    style: builtins.str
    """"""
    label: builtins.str
    """"""
    @property
    def but_first(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        cur_title: builtins.str = ...,
        style: builtins.str = ...,
        label: builtins.str = ...,
        but_first: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["but_first", b"but_first"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["but_first", b"but_first", "cover", b"cover", "cur_title", b"cur_title", "label", b"label", "style", b"style"]) -> None: ...

global___MediaCard = MediaCard

@typing_extensions.final
class MediaDetailReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAST_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    OVERVIEW_FIELD_NUMBER: builtins.int
    @property
    def cast(self) -> global___Cast:
        """"""
    @property
    def staff(self) -> global___Staff:
        """"""
    @property
    def overview(self) -> global___Overview:
        """"""
    def __init__(
        self,
        *,
        cast: global___Cast | None = ...,
        staff: global___Staff | None = ...,
        overview: global___Overview | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cast", b"cast", "overview", b"overview", "staff", b"staff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cast", b"cast", "overview", b"overview", "staff", b"staff"]) -> None: ...

global___MediaDetailReply = MediaDetailReply

@typing_extensions.final
class MediaDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type"]) -> None: ...

global___MediaDetailReq = MediaDetailReq

@typing_extensions.final
class MediaFollowReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MediaFollowReply = MediaFollowReply

@typing_extensions.final
class MediaFollowReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "type", b"type"]) -> None: ...

global___MediaFollowReq = MediaFollowReq

@typing_extensions.final
class MediaPerson(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REAL_NAME_FIELD_NUMBER: builtins.int
    SQUARE_URL_FIELD_NUMBER: builtins.int
    CHARACTER_FIELD_NUMBER: builtins.int
    PERSON_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    real_name: builtins.str
    """"""
    square_url: builtins.str
    """"""
    character: builtins.str
    """"""
    person_id: builtins.int
    """"""
    type: builtins.str
    """"""
    def __init__(
        self,
        *,
        real_name: builtins.str = ...,
        square_url: builtins.str = ...,
        character: builtins.str = ...,
        person_id: builtins.int = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["character", b"character", "person_id", b"person_id", "real_name", b"real_name", "square_url", b"square_url", "type", b"type"]) -> None: ...

global___MediaPerson = MediaPerson

@typing_extensions.final
class MediaRelationReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SmallItem]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        list: collections.abc.Iterable[global___SmallItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___MediaRelationReply = MediaRelationReply

@typing_extensions.final
class MediaRelationReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    feed_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    ps: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        feed_id: builtins.int = ...,
        offset: builtins.str = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "feed_id", b"feed_id", "offset", b"offset", "ps", b"ps"]) -> None: ...

global___MediaRelationReq = MediaRelationReq

@typing_extensions.final
class MediaTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_CARD_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_INDEX_FIELD_NUMBER: builtins.int
    CHANNEL_INFO_FIELD_NUMBER: builtins.int
    @property
    def media_card(self) -> global___MediaCard:
        """"""
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShowTab]:
        """"""
    default_tab_index: builtins.int
    """"""
    @property
    def channel_info(self) -> global___ChannelInfo:
        """"""
    def __init__(
        self,
        *,
        media_card: global___MediaCard | None = ...,
        tab: collections.abc.Iterable[global___ShowTab] | None = ...,
        default_tab_index: builtins.int = ...,
        channel_info: global___ChannelInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "media_card", b"media_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "default_tab_index", b"default_tab_index", "media_card", b"media_card", "tab", b"tab"]) -> None: ...

global___MediaTabReply = MediaTabReply

@typing_extensions.final
class MediaTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ArgsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    source: builtins.str
    """"""
    spmid: builtins.str
    """"""
    @property
    def args(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        source: builtins.str = ...,
        spmid: builtins.str = ...,
        args: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "biz_id", b"biz_id", "biz_type", b"biz_type", "source", b"source", "spmid", b"spmid"]) -> None: ...

global___MediaTabReq = MediaTabReq

@typing_extensions.final
class MediaVideoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BigItem]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        list: collections.abc.Iterable[global___BigItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___MediaVideoReply = MediaVideoReply

@typing_extensions.final
class MediaVideoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FEED_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    biz_id: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    feed_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    ps: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        feed_id: builtins.int = ...,
        offset: builtins.str = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "feed_id", b"feed_id", "offset", b"offset", "ps", b"ps"]) -> None: ...

global___MediaVideoReq = MediaVideoReq

@typing_extensions.final
class Overview(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "title", b"title"]) -> None: ...

global___Overview = Overview

@typing_extensions.final
class ShowTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    tab_type: global___TabType.ValueType
    """"""
    title: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: global___TabType.ValueType = ...,
        title: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tab_type", b"tab_type", "title", b"title", "url", b"url"]) -> None: ...

global___ShowTab = ShowTab

@typing_extensions.final
class SmallItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover_image_uri: builtins.str
    """"""
    uri: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    param: builtins.int
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover_image_uri: builtins.str = ...,
        uri: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        param: builtins.int = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_image_uri", b"cover_image_uri", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_right_text", b"cover_right_text", "mid", b"mid", "param", b"param", "title", b"title", "uri", b"uri"]) -> None: ...

global___SmallItem = SmallItem

@typing_extensions.final
class Staff(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "title", b"title"]) -> None: ...

global___Staff = Staff

@typing_extensions.final
class UserCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_NAME_FIELD_NUMBER: builtins.int
    USER_FACE_FIELD_NUMBER: builtins.int
    USER_URL_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    user_name: builtins.str
    """"""
    user_face: builtins.str
    """"""
    user_url: builtins.str
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        user_name: builtins.str = ...,
        user_face: builtins.str = ...,
        user_url: builtins.str = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "user_face", b"user_face", "user_name", b"user_name", "user_url", b"user_url"]) -> None: ...

global___UserCard = UserCard
