"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayLimitCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayLimitCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayLimitCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PLC_UNKNOWN: _PlayLimitCode.ValueType  # 0
    PLC_NOTPAYED: _PlayLimitCode.ValueType  # 1

class PlayLimitCode(_PlayLimitCode, metaclass=_PlayLimitCodeEnumTypeWrapper): ...

PLC_UNKNOWN: PlayLimitCode.ValueType  # 0
PLC_NOTPAYED: PlayLimitCode.ValueType  # 1
global___PlayLimitCode = PlayLimitCode

@typing_extensions.final
class ButtonStyle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    text_color: builtins.str
    bg_color: builtins.str
    jump_link: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_color: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "jump_link", b"jump_link", "text", b"text", "text_color", b"text_color"]) -> None: ...

global___ButtonStyle = ButtonStyle

@typing_extensions.final
class PlayLimit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    SUB_MESSAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    code: global___PlayLimitCode.ValueType
    message: builtins.str
    sub_message: builtins.str
    @property
    def button(self) -> global___ButtonStyle: ...
    def __init__(
        self,
        *,
        code: global___PlayLimitCode.ValueType = ...,
        message: builtins.str = ...,
        sub_message: builtins.str = ...,
        button: global___ButtonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "code", b"code", "message", b"message", "sub_message", b"sub_message"]) -> None: ...

global___PlayLimit = PlayLimit

@typing_extensions.final
class UGCAnyModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def play_limit(self) -> global___PlayLimit: ...
    def __init__(
        self,
        *,
        play_limit: global___PlayLimit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_limit", b"play_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_limit", b"play_limit"]) -> None: ...

global___UGCAnyModel = UGCAnyModel
