syntax = "proto3";

package bilibili.render;

import "google/protobuf/any.proto";

// 
message Render {
    // 
    int64 code = 1;
    // 
    string message = 2;
    // 
    string ttl = 3;
    // 
    google.protobuf.Any data = 4;
}