# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pgc/gateway/player/v2/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/pgc/gateway/player/v2/playurl.proto\x12\x1e\x62ilibili.pgc.gateway.player.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x01\n\tAnimation\x12`\n\x15qn_svga_animation_map\x18\x01 \x03(\x0b\x32\x41.bilibili.pgc.gateway.player.v2.Animation.QnSvgaAnimationMapEntry\x1a\x39\n\x17QnSvgaAnimationMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x12\x41udioMaterialProto\x12\x10\n\x08\x61udio_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\x12\x11\n\tperson_id\x18\x04 \x01(\x04\x12\x13\n\x0bperson_name\x18\x05 \x01(\t\x12\x15\n\rperson_avatar\x18\x06 \x01(\t\x12\x37\n\x05\x61udio\x18\x07 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\"\xae\x01\n\tBadgeInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\x12\x12\n\ntext_color\x18\x04 \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x05 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12\x0b\n\x03img\x18\x06 \x01(\t\"V\n\rBottomDisplay\x12\x37\n\x05title\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x0c\n\x04icon\x18\x02 \x01(\t\"\xdd\x05\n\nButtonInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x0c\n\x04link\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_type\x18\x07 \x01(\t\x12=\n\nbadge_info\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.BadgeInfo\x12\x36\n\x06report\x18\t \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x1f\n\x17left_strikethrough_text\x18\n \x01(\t\x12\x42\n\x10simple_text_info\x18\x0b \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x17\n\x0fsimple_bg_color\x18\x0c \x01(\t\x12\x1d\n\x15simple_bg_color_night\x18\r \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x0e \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12^\n\x13order_report_params\x18\x0f \x03(\x0b\x32\x41.bilibili.pgc.gateway.player.v2.ButtonInfo.OrderReportParamsEntry\x12=\n\ntask_param\x18\x10 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.TaskParam\x12\x0f\n\x07pc_link\x18\x11 \x01(\t\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x08\x43\x61stTips\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xcb\x01\n\x08\x43lipInfo\x12\x13\n\x0bmaterial_no\x18\x01 \x01(\x03\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12;\n\tclip_type\x18\x04 \x01(\x0e\x32(.bilibili.pgc.gateway.player.v2.ClipType\x12\x12\n\ntoast_text\x18\x05 \x01(\t\x12=\n\nmulti_view\x18\x06 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.MultiView\"/\n\x10\x43ontinuePlayInfo\x12\x1b\n\x13\x63ontinue_play_ep_id\x18\x01 \x01(\x03\"\x8e\x02\n\x06\x43oupon\x12\x14\n\x0c\x63oupon_token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\r\n\x05value\x18\x03 \x01(\t\x12\x10\n\x08use_desc\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\x17\n\x0fpay_button_text\x18\x07 \x01(\t\x12$\n\x1cpay_button_text_line_through\x18\x08 \x01(\t\x12\x13\n\x0breal_amount\x18\t \x01(\t\x12/\n\x0b\x65xpire_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05otype\x18\x0b \x01(\x03\x12\x0e\n\x06\x61mount\x18\x0c \x01(\t\"\x81\x01\n\nCouponInfo\x12:\n\x05toast\x18\x01 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.CouponToast\x12\x37\n\x07pop_win\x18\x02 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PopWin\";\n\x0e\x43ouponTextInfo\x12\x18\n\x10positive_preview\x18\x01 \x01(\t\x12\x0f\n\x07section\x18\x02 \x01(\t\"\x8c\x01\n\x0b\x43ouponToast\x12\x41\n\ttext_info\x18\x01 \x01(\x0b\x32..bilibili.pgc.gateway.player.v2.CouponTextInfo\x12:\n\x06\x62utton\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\"\xa6\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\x12\x15\n\rwidevine_pssh\x18\t \x01(\t\"\xe0\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x10\n\x08\x61udio_id\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\x12\x15\n\rwidevine_pssh\x18\x0c \x01(\t\"*\n\x0b\x44\x61taControl\x12\x1b\n\x13need_watch_progress\x18\x01 \x01(\x08\"\xc8\x05\n\x06\x44ialog\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nstyle_type\x18\x04 \x01(\t\x12<\n\x06\x63onfig\x18\x05 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.DialogConfig\x12\x37\n\x05title\x18\x06 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12:\n\x08subtitle\x18\x07 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x38\n\x05image\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.ImageInfo\x12:\n\x06\x62utton\x18\t \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12?\n\x0b\x62ottom_desc\x18\n \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x36\n\x06report\x18\x0b \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x16\n\x0e\x63ount_down_sec\x18\x0c \x01(\x05\x12\x43\n\x11right_bottom_desc\x18\r \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x45\n\x0e\x62ottom_display\x18\x0e \x03(\x0b\x32-.bilibili.pgc.gateway.player.v2.BottomDisplay\x12;\n\tplay_list\x18\x0f \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.PlayList\"\xb3\x01\n\x0c\x44ialogConfig\x12\x15\n\ris_show_cover\x18\x01 \x01(\x08\x12\x1d\n\x15is_orientation_enable\x18\x02 \x01(\x08\x12\x1f\n\x17is_nested_scroll_enable\x18\x03 \x01(\x08\x12\"\n\x1ais_force_halfscreen_enable\x18\x04 \x01(\x08\x12(\n is_background_translucent_enable\x18\x05 \x01(\x08\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0e\n\x06rotate\x18\x03 \x01(\x05\"\xab\x01\n\tDolbyItem\x12<\n\x04type\x18\x01 \x01(\x0e\x32..bilibili.pgc.gateway.player.v2.DolbyItem.Type\x12\x37\n\x05\x61udio\x18\x02 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"O\n\x07\x45ndPage\x12\x36\n\x06\x64ialog\x18\x01 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog\x12\x0c\n\x04hide\x18\x02 \x01(\x08\">\n\rEpInlineVideo\x12\x13\n\x0bmaterial_no\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\xc6\x01\n\x18\x45pisodeAdvertisementInfo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x1d\n\x15\x66ollow_video_bnt_flag\x18\x04 \x01(\x05\x12\x18\n\x10next_video_title\x18\x05 \x01(\t\x12\x17\n\x0fnext_video_link\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x05\x12\x0e\n\x06\x66ollow\x18\t \x01(\x05\"\xfe\x01\n\x0b\x45pisodeInfo\x12\r\n\x05\x65p_id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x11\n\tep_status\x18\x04 \x01(\x03\x12?\n\x0bseason_info\x18\x05 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.SeasonInfo\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12@\n\x0binteraction\x18\x08 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.Interaction\x12\x12\n\nlong_title\x18\t \x01(\t\"&\n\nEpPreVideo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\"\xa8\x02\n\x10\x45pPublicityVideo\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.bilibili.pgc.gateway.player.v2.EpPublicityVideo.Type\x12\x42\n\x0c\x65p_pre_video\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.EpPreVideoH\x00\x12H\n\x0f\x65p_inline_video\x18\x03 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.EpInlineVideoH\x00\"9\n\x04Type\x12\x10\n\x0c\x44\x41TA_NOT_SET\x10\x00\x12\x10\n\x0c\x45P_PRE_VIDEO\x10\x02\x12\r\n\tEP_INLINE\x10\x03\x42\x06\n\x04\x64\x61ta\"=\n\x05\x45vent\x12\x34\n\x05shake\x18\x01 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Shake\"\x88\x01\n\x0b\x46reyaConfig\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x12\n\nissued_cnt\x18\x03 \x01(\x05\x12\x16\n\x0eis_always_show\x18\x04 \x01(\x08\x12\x15\n\rscreen_number\x18\x05 \x01(\x05\x12\x1a\n\x12\x66ull_screen_number\x18\x06 \x01(\x05\"7\n\rGradientColor\x12\x13\n\x0bstart_color\x18\x01 \x01(\t\x12\x11\n\tend_color\x18\x02 \x01(\t\"\xab\x03\n\x17HighDefinitionTrialInfo\x12\x12\n\ntrial_able\x18\x01 \x01(\x08\x12\x17\n\x0fremaining_times\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x13\n\x0btime_length\x18\x04 \x01(\x05\x12:\n\x0bstart_toast\x18\x05 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x38\n\tend_toast\x18\x06 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x36\n\x06report\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12H\n\x14quality_open_tip_btn\x18\x08 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12G\n\x13no_longer_trial_btn\x18\t \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\":\n\x0bHistoryNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\x18\n\tImageInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8c\x01\n\x0bInteraction\x12\x41\n\x0chistory_node\x18\x01 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.HistoryNode\x12\x15\n\rgraph_version\x18\x02 \x01(\x03\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x16\n\x0eis_interaction\x18\x04 \x01(\x08\"N\n\tMultiView\x12\x17\n\x0f\x62utton_material\x18\x01 \x01(\t\x12\r\n\x05\x65p_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0c\n\x04\x61vid\x18\x04 \x01(\x03\"\xee\x04\n\x06PayTip\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x11\n\tshow_type\x18\x05 \x01(\x05\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x14\n\x0c\x62g_day_color\x18\x07 \x01(\t\x12\x16\n\x0e\x62g_night_color\x18\x08 \x01(\t\x12\x15\n\rbg_line_color\x18\t \x01(\t\x12\x1b\n\x13\x62g_night_line_color\x18\n \x01(\t\x12\x12\n\ntext_color\x18\x0b \x01(\t\x12\x18\n\x10text_night_color\x18\x0c \x01(\t\x12\x17\n\x0fview_start_time\x18\r \x01(\x03\x12:\n\x06\x62utton\x18\x0e \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x15\n\rurl_open_type\x18\x0f \x01(\x05\x12\x36\n\x06report\x18\x10 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x13\n\x0b\x61ngle_style\x18\x11 \x01(\x05\x12\x13\n\x0breport_type\x18\x12 \x01(\x05\x12Z\n\x13order_report_params\x18\x13 \x03(\x0b\x32=.bilibili.pgc.gateway.player.v2.PayTip.OrderReportParamsEntry\x12\x18\n\x10giant_screen_img\x18\x14 \x01(\t\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x07\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x17 \x01(\x08\x12\x15\n\rshake_disable\x18\x18 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1b\n\x13\x66reya_enter_disable\x18\x1b \x01(\x08\x12\x15\n\rdolby_disable\x18\x1c \x01(\x08\x12\x1a\n\x12\x66reya_full_disable\x18\x1d \x01(\x08\x12 \n\x18skip_oped_switch_disable\x18\x1e \x01(\x08\x12\x1d\n\x15record_screen_disable\x18\x1f \x01(\x08\x12\x1e\n\x16\x63olor_optimize_disable\x18  \x01(\x08\x12\x17\n\x0f\x64ubbing_disable\x18! \x01(\x08\"\xb2\x01\n\x12PlayAbilityExtConf\x12\x1c\n\x14\x61llow_close_subtitle\x18\x01 \x01(\x08\x12\x41\n\x0c\x66reya_config\x18\x02 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.FreyaConfig\x12;\n\tcast_tips\x18\x03 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.CastTips\"\xbc\x01\n\x0fPlayDubbingInfo\x12L\n\x10\x62\x61\x63kground_audio\x18\x01 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.AudioMaterialProto\x12G\n\x0frole_audio_list\x18\x02 \x03(\x0b\x32..bilibili.pgc.gateway.player.v2.RoleAudioProto\x12\x12\n\nguide_text\x18\x03 \x01(\t\"Y\n\x0bPlayExtInfo\x12J\n\x11play_dubbing_info\x18\x01 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v2.PlayDubbingInfo\"\x88\x01\n\x08PlayList\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04link\x18\x04 \x01(\t\x12=\n\nbadge_info\x18\x05 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.BadgeInfo\"\x94\t\n\x14PlayViewBusinessInfo\x12\x12\n\nis_preview\x18\x01 \x01(\x08\x12\n\n\x02\x62p\x18\x02 \x01(\x08\x12\x14\n\x0cmarlin_token\x18\x03 \x01(\t\x12\x1c\n\x14playback_speed_color\x18\x04 \x01(\t\x12L\n\x12\x63ontinue_play_info\x18\x05 \x01(\x0b\x32\x30.bilibili.pgc.gateway.player.v2.ContinuePlayInfo\x12;\n\tclip_info\x18\x06 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.ClipInfo\x12?\n\x0binline_type\x18\x07 \x01(\x0e\x32*.bilibili.pgc.gateway.player.v2.InlineType\x12\x19\n\x11\x65p_whole_duration\x18\x08 \x01(\x05\x12<\n\tdimension\x18\t \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.Dimension\x12`\n\x0fquality_ext_map\x18\n \x03(\x0b\x32G.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo.QualityExtMapEntry\x12Q\n\x07\x65xp_map\x18\x0b \x03(\x0b\x32@.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo.ExpMapEntry\x12\x42\n\rdrm_tech_type\x18\x0c \x01(\x0e\x32+.bilibili.pgc.gateway.player.v2.DrmTechType\x12\x19\n\x11limit_action_type\x18\r \x01(\x05\x12\x0e\n\x06is_drm\x18\x0e \x01(\x08\x12?\n\x0brecord_info\x18\x0f \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.RecordInfo\x12\x12\n\nvip_status\x18\x10 \x01(\x05\x12\x13\n\x0bis_live_pre\x18\x11 \x01(\x08\x12\x41\n\x0c\x65pisode_info\x18\x12 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.EpisodeInfo\x12\\\n\x1a\x65pisode_advertisement_info\x18\x13 \x01(\x0b\x32\x38.bilibili.pgc.gateway.player.v2.EpisodeAdvertisementInfo\x12?\n\x0buser_status\x18\x14 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.UserStatus\x1a\x64\n\x12QualityExtMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12=\n\x05value\x18\x02 \x01(\x0b\x32..bilibili.pgc.gateway.player.v2.QualityExtInfo:\x02\x38\x01\x1a-\n\x0b\x45xpMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\xdc\x03\n\rPlayViewReply\x12=\n\nvideo_info\x18\x01 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.VideoInfo\x12\x42\n\tplay_conf\x18\x02 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v2.PlayAbilityConf\x12\x46\n\x08\x62usiness\x18\x03 \x01(\x0b\x32\x34.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Event\x12;\n\tview_info\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.ViewInfo\x12I\n\rplay_ext_conf\x18\x06 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.PlayAbilityExtConf\x12\x42\n\rplay_ext_info\x18\x07 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.PlayExtInfo\"\xd2\x04\n\x0bPlayViewReq\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12\x43\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32(.bilibili.pgc.gateway.player.v2.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x0f\n\x07room_id\x18\x0e \x01(\x03\x12\x19\n\x11is_need_view_info\x18\x0f \x01(\x08\x12\x43\n\rscene_control\x18\x10 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.SceneControl\x12\x41\n\x0cinline_scene\x18\x11 \x01(\x0e\x32+.bilibili.pgc.gateway.player.v2.InlineScene\x12\x13\n\x0bmaterial_no\x18\x12 \x01(\x03\x12\x16\n\x0esecurity_level\x18\x13 \x01(\x05\x12\x11\n\tseason_id\x18\x14 \x01(\x03\x12\x41\n\x0c\x64\x61ta_control\x18\x15 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.DataControl\"\xfb\x02\n\x06PopWin\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x06\x63oupon\x18\x02 \x03(\x0b\x32&.bilibili.pgc.gateway.player.v2.Coupon\x12:\n\x06\x62utton\x18\x03 \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x13\n\x0b\x62ottom_text\x18\x04 \x01(\t\x12;\n\tpop_title\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12:\n\x08subtitle\x18\x06 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12?\n\x0b\x62ottom_desc\x18\x07 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\r\n\x05\x63over\x18\x08 \x01(\t\x12\x10\n\x08pop_type\x18\t \x01(\t\"\xdc\x03\n\tPromptBar\x12\x37\n\x05title\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12;\n\tsub_title\x18\x02 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x16\n\x0esub_title_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62g_image\x18\x04 \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x05 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12:\n\x06\x62utton\x18\x06 \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x36\n\x06report\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x1b\n\x13\x66ull_screen_ip_icon\x18\x08 \x01(\t\x12T\n\x1d\x66ull_screen_bg_gradient_color\x18\t \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\"\'\n\x0eQualityExtInfo\x12\x15\n\rtrial_support\x18\x01 \x01(\x08\"1\n\nRecordInfo\x12\x0e\n\x06record\x18\x01 \x01(\t\x12\x13\n\x0brecord_icon\x18\x02 \x01(\t\"H\n\x06Report\x12\x15\n\rshow_event_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63lick_event_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xtends\x18\x03 \x01(\t\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"\x1b\n\x06Rights\x12\x11\n\tcan_watch\x18\x01 \x01(\x05\"\x9a\x01\n\x0eRoleAudioProto\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x11\n\trole_name\x18\x02 \x01(\t\x12\x13\n\x0brole_avatar\x18\x03 \x01(\t\x12O\n\x13\x61udio_material_list\x18\x04 \x03(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.AudioMaterialProto\"u\n\x0cSceneControl\x12\x14\n\x0c\x66\x61v_playlist\x18\x01 \x01(\x08\x12\x14\n\x0csmall_window\x18\x02 \x01(\x08\x12\x0b\n\x03pip\x18\x03 \x01(\x08\x12\x15\n\rwas_he_inline\x18\x04 \x01(\x08\x12\x15\n\ris_need_trial\x18\x05 \x01(\x08\"\x8a\x01\n\x06Scheme\x12\x46\n\x0b\x61\x63tion_type\x18\x01 \x01(\x0e\x32\x31.bilibili.pgc.gateway.player.v2.Scheme.ActionType\x12\r\n\x05toast\x18\x02 \x01(\t\")\n\nActionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nSHOW_TOAST\x10\x01\"\xaf\x01\n\nSeasonInfo\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\x13\n\x0bseason_type\x18\x02 \x01(\x05\x12\x15\n\rseason_status\x18\x03 \x01(\x05\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x36\n\x06rights\x18\x06 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Rights\x12\x0c\n\x04mode\x18\x07 \x01(\x05\"L\n\x0cSegmentVideo\x12<\n\x07segment\x18\x01 \x03(\x0b\x32+.bilibili.pgc.gateway.player.v2.ResponseUrl\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xd5\x01\n\x06Stream\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.StreamInfo\x12?\n\ndash_video\x18\x02 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.DashVideoH\x00\x12\x45\n\rsegment_video\x18\x03 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\xfc\x02\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x65rr_code\x18\x04 \x01(\x05\x12:\n\x05limit\x18\x05 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\x12\x36\n\x06scheme\x18\x0e \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Scheme\x12\x13\n\x0bsupport_drm\x18\x0f \x01(\x08\x12\x10\n\x08subtitle\x18\x10 \x01(\t\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\"D\n\tTaskParam\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\x03\x12\x0f\n\x07tips_id\x18\x03 \x01(\x03\"F\n\x08TextInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\"\x83\x03\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12:\n\x06\x62utton\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x17\n\x0fshow_style_type\x18\x03 \x01(\x05\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12<\n\ntoast_text\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x36\n\x06report\x18\x06 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12Y\n\x13order_report_params\x18\x07 \x03(\x0b\x32<.bilibili.pgc.gateway.player.v2.Toast.OrderReportParamsEntry\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\nUserStatus\x12\x11\n\tpay_check\x18\x01 \x01(\x08\x12\x0f\n\x07sponsor\x18\x02 \x01(\x08\x12\x45\n\x0ewatch_progress\x18\x03 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.WatchProgress\x12I\n\x12\x61id_watch_progress\x18\x04 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.WatchProgress\"\x8c\x02\n\tVideoInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12;\n\x0bstream_list\x18\x05 \x03(\x0b\x32&.bilibili.pgc.gateway.player.v2.Stream\x12<\n\ndash_audio\x18\x06 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\x12\x38\n\x05\x64olby\x18\x07 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.DolbyItem\"\xb0\x08\n\x08ViewInfo\x12\x36\n\x06\x64ialog\x18\x01 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog\x12\x34\n\x05toast\x18\x02 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12?\n\x0b\x63oupon_info\x18\x03 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.CouponInfo\x12\x1b\n\x13\x64\x65mand_no_pay_epids\x18\x04 \x03(\x03\x12\x39\n\x08\x65nd_page\x18\x05 \x01(\x0b\x32\'.bilibili.pgc.gateway.player.v2.EndPage\x12K\n\nexp_config\x18\x06 \x03(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.ViewInfo.ExpConfigEntry\x12\x37\n\x07pop_win\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PopWin\x12G\n\x14try_watch_prompt_bar\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.PromptBar\x12\x37\n\x07pay_tip\x18\t \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PayTip\x12[\n\x1ahigh_definition_trial_info\x18\n \x01(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.HighDefinitionTrialInfo\x12K\n\next_dialog\x18\x0b \x03(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.ViewInfo.ExtDialogEntry\x12<\n\tanimation\x18\x0c \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.Animation\x12I\n\text_toast\x18\r \x03(\x0b\x32\x36.bilibili.pgc.gateway.player.v2.ViewInfo.ExtToastEntry\x1a\x30\n\x0e\x45xpConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1aX\n\x0e\x45xtDialogEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog:\x02\x38\x01\x1aV\n\rExtToastEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast:\x02\x38\x01\"\xf3\x01\n\rWatchProgress\x12\x12\n\nlast_ep_id\x18\x01 \x01(\x05\x12\x15\n\rlast_ep_index\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\x03 \x01(\x03\x12\x15\n\rlast_play_cid\x18\x04 \x01(\x03\x12\x34\n\x05toast\x18\x05 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x41\n\x12toast_without_time\x18\x06 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x15\n\rlast_play_aid\x18\x07 \x01(\x03*|\n\x08\x43lipType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x10\n\x0c\x43LIP_TYPE_OP\x10\x01\x12\x10\n\x0c\x43LIP_TYPE_ED\x10\x02\x12\x10\n\x0c\x43LIP_TYPE_HE\x10\x03\x12\x18\n\x14\x43LIP_TYPE_MULTI_VIEW\x10\x04\x12\x10\n\x0c\x43LIP_TYPE_AD\x10\x05*0\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02*B\n\x0b\x44rmTechType\x12\x07\n\x03NON\x10\x00\x12\r\n\tFAIR_PLAY\x10\x01\x12\r\n\tWIDE_VINE\x10\x02\x12\x0c\n\x08\x42ILI_DRM\x10\x03*+\n\x14\x45pPublicityVideoType\x12\x07\n\x03PRE\x10\x00\x12\n\n\x06INLINE\x10\x01*<\n\x0bInlineScene\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nRELATED_EP\x10\x01\x12\x06\n\x02HE\x10\x02\x12\x08\n\x04SKIP\x10\x03*R\n\nInlineType\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x0e\n\nTYPE_WHOLE\x10\x01\x12\x10\n\x0cTYPE_HE_CLIP\x10\x02\x12\x10\n\x0cTYPE_PREVIEW\x10\x03*N\n\x0fLimitActionType\x12\x0f\n\x0bLAT_UNKNOWN\x10\x00\x12\x15\n\x11SHOW_LIMIT_DIALOG\x10\x01\x12\x13\n\x0fSKIP_CURRENT_EP\x10\x02*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*L\n\rSecurityLevel\x12\x11\n\rLEVEL_UNKNOWN\x10\x00\x12\x0c\n\x08LEVEL_L1\x10\x01\x12\x0c\n\x08LEVEL_L2\x10\x02\x12\x0c\n\x08LEVEL_L3\x10\x03\x32\xde\x01\n\x07PlayURL\x12\x66\n\x08PlayView\x12+.bilibili.pgc.gateway.player.v2.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v2.PlayViewReply\x12k\n\rPlayViewComic\x12+.bilibili.pgc.gateway.player.v2.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v2.PlayViewReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pgc.gateway.player.v2.playurl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANIMATION_QNSVGAANIMATIONMAPENTRY._options = None
  _ANIMATION_QNSVGAANIMATIONMAPENTRY._serialized_options = b'8\001'
  _BUTTONINFO_ORDERREPORTPARAMSENTRY._options = None
  _BUTTONINFO_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _PAYTIP_ORDERREPORTPARAMSENTRY._options = None
  _PAYTIP_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY._options = None
  _PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY._serialized_options = b'8\001'
  _PLAYVIEWBUSINESSINFO_EXPMAPENTRY._options = None
  _PLAYVIEWBUSINESSINFO_EXPMAPENTRY._serialized_options = b'8\001'
  _TOAST_ORDERREPORTPARAMSENTRY._options = None
  _TOAST_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXPCONFIGENTRY._options = None
  _VIEWINFO_EXPCONFIGENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXTDIALOGENTRY._options = None
  _VIEWINFO_EXTDIALOGENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXTTOASTENTRY._options = None
  _VIEWINFO_EXTTOASTENTRY._serialized_options = b'8\001'
  _globals['_CLIPTYPE']._serialized_start=15113
  _globals['_CLIPTYPE']._serialized_end=15237
  _globals['_CODETYPE']._serialized_start=15239
  _globals['_CODETYPE']._serialized_end=15287
  _globals['_DRMTECHTYPE']._serialized_start=15289
  _globals['_DRMTECHTYPE']._serialized_end=15355
  _globals['_EPPUBLICITYVIDEOTYPE']._serialized_start=15357
  _globals['_EPPUBLICITYVIDEOTYPE']._serialized_end=15400
  _globals['_INLINESCENE']._serialized_start=15402
  _globals['_INLINESCENE']._serialized_end=15462
  _globals['_INLINETYPE']._serialized_start=15464
  _globals['_INLINETYPE']._serialized_end=15546
  _globals['_LIMITACTIONTYPE']._serialized_start=15548
  _globals['_LIMITACTIONTYPE']._serialized_end=15626
  _globals['_PLAYERR']._serialized_start=15628
  _globals['_PLAYERR']._serialized_end=15677
  _globals['_SECURITYLEVEL']._serialized_start=15679
  _globals['_SECURITYLEVEL']._serialized_end=15755
  _globals['_ANIMATION']._serialized_start=114
  _globals['_ANIMATION']._serialized_end=282
  _globals['_ANIMATION_QNSVGAANIMATIONMAPENTRY']._serialized_start=225
  _globals['_ANIMATION_QNSVGAANIMATIONMAPENTRY']._serialized_end=282
  _globals['_AUDIOMATERIALPROTO']._serialized_start=285
  _globals['_AUDIOMATERIALPROTO']._serialized_end=475
  _globals['_BADGEINFO']._serialized_start=478
  _globals['_BADGEINFO']._serialized_end=652
  _globals['_BOTTOMDISPLAY']._serialized_start=654
  _globals['_BOTTOMDISPLAY']._serialized_end=740
  _globals['_BUTTONINFO']._serialized_start=743
  _globals['_BUTTONINFO']._serialized_end=1476
  _globals['_BUTTONINFO_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_BUTTONINFO_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_CASTTIPS']._serialized_start=1478
  _globals['_CASTTIPS']._serialized_end=1519
  _globals['_CLIPINFO']._serialized_start=1522
  _globals['_CLIPINFO']._serialized_end=1725
  _globals['_CONTINUEPLAYINFO']._serialized_start=1727
  _globals['_CONTINUEPLAYINFO']._serialized_end=1774
  _globals['_COUPON']._serialized_start=1777
  _globals['_COUPON']._serialized_end=2047
  _globals['_COUPONINFO']._serialized_start=2050
  _globals['_COUPONINFO']._serialized_end=2179
  _globals['_COUPONTEXTINFO']._serialized_start=2181
  _globals['_COUPONTEXTINFO']._serialized_end=2240
  _globals['_COUPONTOAST']._serialized_start=2243
  _globals['_COUPONTOAST']._serialized_end=2383
  _globals['_DASHITEM']._serialized_start=2386
  _globals['_DASHITEM']._serialized_end=2552
  _globals['_DASHVIDEO']._serialized_start=2555
  _globals['_DASHVIDEO']._serialized_end=2779
  _globals['_DATACONTROL']._serialized_start=2781
  _globals['_DATACONTROL']._serialized_end=2823
  _globals['_DIALOG']._serialized_start=2826
  _globals['_DIALOG']._serialized_end=3538
  _globals['_DIALOGCONFIG']._serialized_start=3541
  _globals['_DIALOGCONFIG']._serialized_end=3720
  _globals['_DIMENSION']._serialized_start=3722
  _globals['_DIMENSION']._serialized_end=3780
  _globals['_DOLBYITEM']._serialized_start=3783
  _globals['_DOLBYITEM']._serialized_end=3954
  _globals['_DOLBYITEM_TYPE']._serialized_start=3915
  _globals['_DOLBYITEM_TYPE']._serialized_end=3954
  _globals['_ENDPAGE']._serialized_start=3956
  _globals['_ENDPAGE']._serialized_end=4035
  _globals['_EPINLINEVIDEO']._serialized_start=4037
  _globals['_EPINLINEVIDEO']._serialized_end=4099
  _globals['_EPISODEADVERTISEMENTINFO']._serialized_start=4102
  _globals['_EPISODEADVERTISEMENTINFO']._serialized_end=4300
  _globals['_EPISODEINFO']._serialized_start=4303
  _globals['_EPISODEINFO']._serialized_end=4557
  _globals['_EPPREVIDEO']._serialized_start=4559
  _globals['_EPPREVIDEO']._serialized_end=4597
  _globals['_EPPUBLICITYVIDEO']._serialized_start=4600
  _globals['_EPPUBLICITYVIDEO']._serialized_end=4896
  _globals['_EPPUBLICITYVIDEO_TYPE']._serialized_start=4831
  _globals['_EPPUBLICITYVIDEO_TYPE']._serialized_end=4888
  _globals['_EVENT']._serialized_start=4898
  _globals['_EVENT']._serialized_end=4959
  _globals['_FREYACONFIG']._serialized_start=4962
  _globals['_FREYACONFIG']._serialized_end=5098
  _globals['_GRADIENTCOLOR']._serialized_start=5100
  _globals['_GRADIENTCOLOR']._serialized_end=5155
  _globals['_HIGHDEFINITIONTRIALINFO']._serialized_start=5158
  _globals['_HIGHDEFINITIONTRIALINFO']._serialized_end=5585
  _globals['_HISTORYNODE']._serialized_start=5587
  _globals['_HISTORYNODE']._serialized_end=5645
  _globals['_IMAGEINFO']._serialized_start=5647
  _globals['_IMAGEINFO']._serialized_end=5671
  _globals['_INTERACTION']._serialized_start=5674
  _globals['_INTERACTION']._serialized_end=5814
  _globals['_MULTIVIEW']._serialized_start=5816
  _globals['_MULTIVIEW']._serialized_end=5894
  _globals['_PAYTIP']._serialized_start=5897
  _globals['_PAYTIP']._serialized_end=6519
  _globals['_PAYTIP_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_PAYTIP_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_PLAYABILITYCONF']._serialized_start=6522
  _globals['_PLAYABILITYCONF']._serialized_end=7424
  _globals['_PLAYABILITYEXTCONF']._serialized_start=7427
  _globals['_PLAYABILITYEXTCONF']._serialized_end=7605
  _globals['_PLAYDUBBINGINFO']._serialized_start=7608
  _globals['_PLAYDUBBINGINFO']._serialized_end=7796
  _globals['_PLAYEXTINFO']._serialized_start=7798
  _globals['_PLAYEXTINFO']._serialized_end=7887
  _globals['_PLAYLIST']._serialized_start=7890
  _globals['_PLAYLIST']._serialized_end=8026
  _globals['_PLAYVIEWBUSINESSINFO']._serialized_start=8029
  _globals['_PLAYVIEWBUSINESSINFO']._serialized_end=9201
  _globals['_PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY']._serialized_start=9054
  _globals['_PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY']._serialized_end=9154
  _globals['_PLAYVIEWBUSINESSINFO_EXPMAPENTRY']._serialized_start=9156
  _globals['_PLAYVIEWBUSINESSINFO_EXPMAPENTRY']._serialized_end=9201
  _globals['_PLAYVIEWREPLY']._serialized_start=9204
  _globals['_PLAYVIEWREPLY']._serialized_end=9680
  _globals['_PLAYVIEWREQ']._serialized_start=9683
  _globals['_PLAYVIEWREQ']._serialized_end=10277
  _globals['_POPWIN']._serialized_start=10280
  _globals['_POPWIN']._serialized_end=10659
  _globals['_PROMPTBAR']._serialized_start=10662
  _globals['_PROMPTBAR']._serialized_end=11138
  _globals['_QUALITYEXTINFO']._serialized_start=11140
  _globals['_QUALITYEXTINFO']._serialized_end=11179
  _globals['_RECORDINFO']._serialized_start=11181
  _globals['_RECORDINFO']._serialized_end=11230
  _globals['_REPORT']._serialized_start=11232
  _globals['_REPORT']._serialized_end=11304
  _globals['_RESPONSEURL']._serialized_start=11306
  _globals['_RESPONSEURL']._serialized_end=11410
  _globals['_RIGHTS']._serialized_start=11412
  _globals['_RIGHTS']._serialized_end=11439
  _globals['_ROLEAUDIOPROTO']._serialized_start=11442
  _globals['_ROLEAUDIOPROTO']._serialized_end=11596
  _globals['_SCENECONTROL']._serialized_start=11598
  _globals['_SCENECONTROL']._serialized_end=11715
  _globals['_SCHEME']._serialized_start=11718
  _globals['_SCHEME']._serialized_end=11856
  _globals['_SCHEME_ACTIONTYPE']._serialized_start=11815
  _globals['_SCHEME_ACTIONTYPE']._serialized_end=11856
  _globals['_SEASONINFO']._serialized_start=11859
  _globals['_SEASONINFO']._serialized_end=12034
  _globals['_SEGMENTVIDEO']._serialized_start=12036
  _globals['_SEGMENTVIDEO']._serialized_end=12112
  _globals['_SHAKE']._serialized_start=12114
  _globals['_SHAKE']._serialized_end=12135
  _globals['_STREAM']._serialized_start=12138
  _globals['_STREAM']._serialized_end=12351
  _globals['_STREAMINFO']._serialized_start=12354
  _globals['_STREAMINFO']._serialized_end=12734
  _globals['_STREAMLIMIT']._serialized_start=12736
  _globals['_STREAMLIMIT']._serialized_end=12790
  _globals['_TASKPARAM']._serialized_start=12792
  _globals['_TASKPARAM']._serialized_end=12860
  _globals['_TEXTINFO']._serialized_start=12862
  _globals['_TEXTINFO']._serialized_end=12932
  _globals['_TOAST']._serialized_start=12935
  _globals['_TOAST']._serialized_end=13322
  _globals['_TOAST_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_TOAST_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_USERSTATUS']._serialized_start=13325
  _globals['_USERSTATUS']._serialized_end=13519
  _globals['_VIDEOINFO']._serialized_start=13522
  _globals['_VIDEOINFO']._serialized_end=13790
  _globals['_VIEWINFO']._serialized_start=13793
  _globals['_VIEWINFO']._serialized_end=14865
  _globals['_VIEWINFO_EXPCONFIGENTRY']._serialized_start=14639
  _globals['_VIEWINFO_EXPCONFIGENTRY']._serialized_end=14687
  _globals['_VIEWINFO_EXTDIALOGENTRY']._serialized_start=14689
  _globals['_VIEWINFO_EXTDIALOGENTRY']._serialized_end=14777
  _globals['_VIEWINFO_EXTTOASTENTRY']._serialized_start=14779
  _globals['_VIEWINFO_EXTTOASTENTRY']._serialized_end=14865
  _globals['_WATCHPROGRESS']._serialized_start=14868
  _globals['_WATCHPROGRESS']._serialized_end=15111
  _globals['_PLAYURL']._serialized_start=15758
  _globals['_PLAYURL']._serialized_end=15980
# @@protoc_insertion_point(module_scope)
