# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/fawkes/fawkes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/metadata/fawkes/fawkes.proto\x12\x18\x62ilibili.metadata.fawkes\")\n\x0b\x46\x61wkesReply\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\n\n\x02\x66\x66\x18\x02 \x01(\t\"<\n\tFawkesReq\x12\x0e\n\x06\x61ppkey\x18\x01 \x01(\t\x12\x0b\n\x03\x65nv\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.fawkes.fawkes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FAWKESREPLY']._serialized_start=67
  _globals['_FAWKESREPLY']._serialized_end=108
  _globals['_FAWKESREQ']._serialized_start=110
  _globals['_FAWKESREQ']._serialized_end=170
# @@protoc_insertion_point(module_scope)
