"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TopicCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopicCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopicCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ILLEGAL_TYPE: _TopicCardType.ValueType  # 0
    """"""
    DYNAMIC: _TopicCardType.ValueType  # 1
    """"""
    FOLD: _TopicCardType.ValueType  # 2
    """"""
    VIDEO_SMALL_CARD: _TopicCardType.ValueType  # 3
    """"""

class TopicCardType(_TopicCardType, metaclass=_TopicCardTypeEnumTypeWrapper):
    """"""

ILLEGAL_TYPE: TopicCardType.ValueType  # 0
""""""
DYNAMIC: TopicCardType.ValueType  # 1
""""""
FOLD: TopicCardType.ValueType  # 2
""""""
VIDEO_SMALL_CARD: TopicCardType.ValueType  # 3
""""""
global___TopicCardType = TopicCardType

class _TopicDetailsExtMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopicDetailsExtModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopicDetailsExtMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODE_ILLEGAL_TYPE: _TopicDetailsExtMode.ValueType  # 0
    """"""
    STORY: _TopicDetailsExtMode.ValueType  # 1
    """"""

class TopicDetailsExtMode(_TopicDetailsExtMode, metaclass=_TopicDetailsExtModeEnumTypeWrapper):
    """"""

MODE_ILLEGAL_TYPE: TopicDetailsExtMode.ValueType  # 0
""""""
STORY: TopicDetailsExtMode.ValueType  # 1
""""""
global___TopicDetailsExtMode = TopicDetailsExtMode

@typing_extensions.final
class ButtonMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___ButtonMeta = ButtonMeta

@typing_extensions.final
class DetailsTopInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_INFO_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    STATS_DESC_FIELD_NUMBER: builtins.int
    HAS_CREATE_JURISDICTION_FIELD_NUMBER: builtins.int
    OPERATION_CONTENT_FIELD_NUMBER: builtins.int
    HEAD_IMG_URL_FIELD_NUMBER: builtins.int
    HEAD_IMG_BACKCOLOR_FIELD_NUMBER: builtins.int
    WORD_COLOR_FIELD_NUMBER: builtins.int
    MISSION_PAGE_SHOW_TYPE_FIELD_NUMBER: builtins.int
    MISSION_URL_FIELD_NUMBER: builtins.int
    MISSION_TEXT_FIELD_NUMBER: builtins.int
    TOPIC_SET_FIELD_NUMBER: builtins.int
    @property
    def topic_info(self) -> global___TopicInfo:
        """"""
    @property
    def user(self) -> global___User:
        """"""
    stats_desc: builtins.str
    """"""
    has_create_jurisdiction: builtins.bool
    """"""
    @property
    def operation_content(self) -> global___OperationContent:
        """"""
    head_img_url: builtins.str
    """"""
    head_img_backcolor: builtins.str
    """"""
    word_color: builtins.int
    """"""
    mission_page_show_type: builtins.int
    """"""
    mission_url: builtins.str
    """"""
    mission_text: builtins.str
    """"""
    @property
    def topic_set(self) -> global___TopicSet:
        """"""
    def __init__(
        self,
        *,
        topic_info: global___TopicInfo | None = ...,
        user: global___User | None = ...,
        stats_desc: builtins.str = ...,
        has_create_jurisdiction: builtins.bool = ...,
        operation_content: global___OperationContent | None = ...,
        head_img_url: builtins.str = ...,
        head_img_backcolor: builtins.str = ...,
        word_color: builtins.int = ...,
        mission_page_show_type: builtins.int = ...,
        mission_url: builtins.str = ...,
        mission_text: builtins.str = ...,
        topic_set: global___TopicSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_content", b"operation_content", "topic_info", b"topic_info", "topic_set", b"topic_set", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_create_jurisdiction", b"has_create_jurisdiction", "head_img_backcolor", b"head_img_backcolor", "head_img_url", b"head_img_url", "mission_page_show_type", b"mission_page_show_type", "mission_text", b"mission_text", "mission_url", b"mission_url", "operation_content", b"operation_content", "stats_desc", b"stats_desc", "topic_info", b"topic_info", "topic_set", b"topic_set", "user", b"user", "word_color", b"word_color"]) -> None: ...

global___DetailsTopInfo = DetailsTopInfo

@typing_extensions.final
class FoldCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SHOW_FOLD_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    CARD_SHOW_DESC_FIELD_NUMBER: builtins.int
    FOLD_DESC_FIELD_NUMBER: builtins.int
    is_show_fold: builtins.int
    """"""
    fold_count: builtins.int
    """"""
    card_show_desc: builtins.str
    """"""
    fold_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        is_show_fold: builtins.int = ...,
        fold_count: builtins.int = ...,
        card_show_desc: builtins.str = ...,
        fold_desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_show_desc", b"card_show_desc", "fold_count", b"fold_count", "fold_desc", b"fold_desc", "is_show_fold", b"is_show_fold"]) -> None: ...

global___FoldCardItem = FoldCardItem

@typing_extensions.final
class FunctionalCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPSULES_FIELD_NUMBER: builtins.int
    TRAFFIC_CARD_FIELD_NUMBER: builtins.int
    GAME_CARD_FIELD_NUMBER: builtins.int
    @property
    def capsules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCapsule]:
        """"""
    @property
    def traffic_card(self) -> global___TrafficCard:
        """"""
    @property
    def game_card(self) -> global___GameCard:
        """"""
    def __init__(
        self,
        *,
        capsules: collections.abc.Iterable[global___TopicCapsule] | None = ...,
        traffic_card: global___TrafficCard | None = ...,
        game_card: global___GameCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["game_card", b"game_card", "traffic_card", b"traffic_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capsules", b"capsules", "game_card", b"game_card", "traffic_card", b"traffic_card"]) -> None: ...

global___FunctionalCard = FunctionalCard

@typing_extensions.final
class GameCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAME_ID_FIELD_NUMBER: builtins.int
    GAME_ICON_FIELD_NUMBER: builtins.int
    GAME_NAME_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    GAME_TAGS_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    GAME_LINK_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """"""
    game_icon: builtins.str
    """"""
    game_name: builtins.str
    """"""
    score: builtins.str
    """"""
    game_tags: builtins.str
    """"""
    notice: builtins.str
    """"""
    game_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        game_id: builtins.int = ...,
        game_icon: builtins.str = ...,
        game_name: builtins.str = ...,
        score: builtins.str = ...,
        game_tags: builtins.str = ...,
        notice: builtins.str = ...,
        game_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_icon", b"game_icon", "game_id", b"game_id", "game_link", b"game_link", "game_name", b"game_name", "game_tags", b"game_tags", "notice", b"notice", "score", b"score"]) -> None: ...

global___GameCard = GameCard

@typing_extensions.final
class InlineProgressBar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_DRAG_FIELD_NUMBER: builtins.int
    ICON_DRAG_HASH_FIELD_NUMBER: builtins.int
    ICON_STOP_FIELD_NUMBER: builtins.int
    ICON_STOP_HASH_FIELD_NUMBER: builtins.int
    icon_drag: builtins.str
    """"""
    icon_drag_hash: builtins.str
    """"""
    icon_stop: builtins.str
    """"""
    icon_stop_hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_drag: builtins.str = ...,
        icon_drag_hash: builtins.str = ...,
        icon_stop: builtins.str = ...,
        icon_stop_hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_drag", b"icon_drag", "icon_drag_hash", b"icon_drag_hash", "icon_stop", b"icon_stop", "icon_stop_hash", b"icon_stop_hash"]) -> None: ...

global___InlineProgressBar = InlineProgressBar

@typing_extensions.final
class LargeCoverInline(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    RIGHT_TOP_LIVE_BADGE_FIELD_NUMBER: builtins.int
    EXTRA_URI_FIELD_NUMBER: builtins.int
    INLINE_PROGRESS_BAR_FIELD_NUMBER: builtins.int
    TOPIC_THREE_POINT_FIELD_NUMBER: builtins.int
    COVER_LEFT_DESC_FIELD_NUMBER: builtins.int
    HIDE_DANMU_SWITCH_FIELD_NUMBER: builtins.int
    DISABLE_DANMU_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    DURATION_TEXT_FIELD_NUMBER: builtins.int
    RELATION_DATA_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    @property
    def right_top_live_badge(self) -> global___RightTopLiveBadge:
        """"""
    extra_uri: builtins.str
    """"""
    @property
    def inline_progress_bar(self) -> global___InlineProgressBar:
        """"""
    @property
    def topic_three_point(self) -> global___TopicThreePoint:
        """"""
    cover_left_desc: builtins.str
    """"""
    hide_danmu_switch: builtins.bool
    """"""
    disable_danmu: builtins.bool
    """"""
    can_play: builtins.int
    """"""
    duration_text: builtins.str
    """"""
    @property
    def relation_data(self) -> global___RelationData:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        right_top_live_badge: global___RightTopLiveBadge | None = ...,
        extra_uri: builtins.str = ...,
        inline_progress_bar: global___InlineProgressBar | None = ...,
        topic_three_point: global___TopicThreePoint | None = ...,
        cover_left_desc: builtins.str = ...,
        hide_danmu_switch: builtins.bool = ...,
        disable_danmu: builtins.bool = ...,
        can_play: builtins.int = ...,
        duration_text: builtins.str = ...,
        relation_data: global___RelationData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "inline_progress_bar", b"inline_progress_bar", "relation_data", b"relation_data", "right_top_live_badge", b"right_top_live_badge", "topic_three_point", b"topic_three_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "can_play", b"can_play", "cover_left_desc", b"cover_left_desc", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "disable_danmu", b"disable_danmu", "duration_text", b"duration_text", "extra_uri", b"extra_uri", "hide_danmu_switch", b"hide_danmu_switch", "inline_progress_bar", b"inline_progress_bar", "relation_data", b"relation_data", "right_top_live_badge", b"right_top_live_badge", "topic_three_point", b"topic_three_point"]) -> None: ...

global___LargeCoverInline = LargeCoverInline

@typing_extensions.final
class LiveBadgeResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ANIMATION_URL_FIELD_NUMBER: builtins.int
    ANIMATION_URL_HASH_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_LIGHT_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ALPHA_LIGHT_FIELD_NUMBER: builtins.int
    ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    animation_url: builtins.str
    """"""
    animation_url_hash: builtins.str
    """"""
    background_color_light: builtins.str
    """"""
    background_color_night: builtins.str
    """"""
    alpha_light: builtins.int
    """"""
    alpha_night: builtins.int
    """"""
    font_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        animation_url: builtins.str = ...,
        animation_url_hash: builtins.str = ...,
        background_color_light: builtins.str = ...,
        background_color_night: builtins.str = ...,
        alpha_light: builtins.int = ...,
        alpha_night: builtins.int = ...,
        font_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alpha_light", b"alpha_light", "alpha_night", b"alpha_night", "animation_url", b"animation_url", "animation_url_hash", b"animation_url_hash", "background_color_light", b"background_color_light", "background_color_night", b"background_color_night", "font_color", b"font_color", "text", b"text"]) -> None: ...

global___LiveBadgeResource = LiveBadgeResource

@typing_extensions.final
class OperationCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LARGE_COVER_INLINE_FIELD_NUMBER: builtins.int
    @property
    def large_cover_inline(self) -> global___LargeCoverInline:
        """"""
    def __init__(
        self,
        *,
        large_cover_inline: global___LargeCoverInline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card", b"card", "large_cover_inline", b"large_cover_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card", b"card", "large_cover_inline", b"large_cover_inline"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card", b"card"]) -> typing_extensions.Literal["large_cover_inline"] | None: ...

global___OperationCard = OperationCard

@typing_extensions.final
class OperationContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_CARD_FIELD_NUMBER: builtins.int
    @property
    def operation_card(self) -> global___OperationCard:
        """"""
    def __init__(
        self,
        *,
        operation_card: global___OperationCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_card", b"operation_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation_card", b"operation_card"]) -> None: ...

global___OperationContent = OperationContent

@typing_extensions.final
class PubLayer(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TYPE_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    BUTTON_META_FIELD_NUMBER: builtins.int
    CLOSE_PUB_LAYER_ENTRY_FIELD_NUMBER: builtins.int
    show_type: builtins.int
    """"""
    jump_link: builtins.str
    """"""
    @property
    def button_meta(self) -> global___ButtonMeta:
        """"""
    close_pub_layer_entry: builtins.bool
    """"""
    def __init__(
        self,
        *,
        show_type: builtins.int = ...,
        jump_link: builtins.str = ...,
        button_meta: global___ButtonMeta | None = ...,
        close_pub_layer_entry: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button_meta", b"button_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_meta", b"button_meta", "close_pub_layer_entry", b"close_pub_layer_entry", "jump_link", b"jump_link", "show_type", b"show_type"]) -> None: ...

global___PubLayer = PubLayer

@typing_extensions.final
class RelationData(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FAV_FIELD_NUMBER: builtins.int
    IS_COIN_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    LIKE_COUNT_FIELD_NUMBER: builtins.int
    is_fav: builtins.bool
    """"""
    is_coin: builtins.bool
    """"""
    is_follow: builtins.bool
    """"""
    is_like: builtins.bool
    """"""
    like_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_fav: builtins.bool = ...,
        is_coin: builtins.bool = ...,
        is_follow: builtins.bool = ...,
        is_like: builtins.bool = ...,
        like_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_coin", b"is_coin", "is_fav", b"is_fav", "is_follow", b"is_follow", "is_like", b"is_like", "like_count", b"like_count"]) -> None: ...

global___RelationData = RelationData

@typing_extensions.final
class RightTopLiveBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    IN_LIVE_FIELD_NUMBER: builtins.int
    LIVE_STATS_DESC_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""
    @property
    def in_live(self) -> global___LiveBadgeResource:
        """"""
    live_stats_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        in_live: global___LiveBadgeResource | None = ...,
        live_stats_desc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_live", b"in_live"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["in_live", b"in_live", "live_stats_desc", b"live_stats_desc", "live_status", b"live_status"]) -> None: ...

global___RightTopLiveBadge = RightTopLiveBadge

@typing_extensions.final
class SortContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_BY_FIELD_NUMBER: builtins.int
    SORT_NAME_FIELD_NUMBER: builtins.int
    sort_by: builtins.int
    """"""
    sort_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        sort_by: builtins.int = ...,
        sort_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_by", b"sort_by", "sort_name", b"sort_name"]) -> None: ...

global___SortContent = SortContent

@typing_extensions.final
class ThreePointItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "title", b"title"]) -> None: ...

global___ThreePointItem = ThreePointItem

@typing_extensions.final
class TimeLineEvents(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TIME_DESC_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    """"""
    title: builtins.str
    """"""
    time_desc: builtins.str
    """"""
    jump_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        event_id: builtins.int = ...,
        title: builtins.str = ...,
        time_desc: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_id", b"event_id", "jump_link", b"jump_link", "time_desc", b"time_desc", "title", b"title"]) -> None: ...

global___TimeLineEvents = TimeLineEvents

@typing_extensions.final
class TimeLineResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_LINE_ID_FIELD_NUMBER: builtins.int
    TIME_LINE_TITLE_FIELD_NUMBER: builtins.int
    TIME_LINE_EVENTS_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    time_line_id: builtins.int
    """"""
    time_line_title: builtins.str
    """"""
    @property
    def time_line_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeLineEvents]:
        """"""
    has_more: builtins.bool
    """"""
    def __init__(
        self,
        *,
        time_line_id: builtins.int = ...,
        time_line_title: builtins.str = ...,
        time_line_events: collections.abc.Iterable[global___TimeLineEvents] | None = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "time_line_events", b"time_line_events", "time_line_id", b"time_line_id", "time_line_title", b"time_line_title"]) -> None: ...

global___TimeLineResource = TimeLineResource

@typing_extensions.final
class TopicActivities(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_FIELD_NUMBER: builtins.int
    ACT_LIST_TITLE_FIELD_NUMBER: builtins.int
    @property
    def activity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicActivity]:
        """"""
    act_list_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity: collections.abc.Iterable[global___TopicActivity] | None = ...,
        act_list_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_list_title", b"act_list_title", "activity", b"activity"]) -> None: ...

global___TopicActivities = TopicActivities

@typing_extensions.final
class TopicActivity(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""
    activity_name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        activity_name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "activity_name", b"activity_name", "icon_url", b"icon_url", "jump_url", b"jump_url"]) -> None: ...

global___TopicActivity = TopicActivity

@typing_extensions.final
class TopicCapsule(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_url", b"icon_url", "jump_url", b"jump_url", "name", b"name"]) -> None: ...

global___TopicCapsule = TopicCapsule

@typing_extensions.final
class TopicCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DYNAMIC_ITEM_FIELD_NUMBER: builtins.int
    FORD_CARD_ITEM_FIELD_NUMBER: builtins.int
    VIDEO_SMALL_CARD_ITEM_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    @property
    def dynamic_item(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
    @property
    def ford_card_item(self) -> global___FoldCardItem:
        """"""
    @property
    def video_small_card_item(self) -> global___VideoSmallCardItem:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        dynamic_item: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem | None = ...,
        ford_card_item: global___FoldCardItem | None = ...,
        video_small_card_item: global___VideoSmallCardItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_item", b"dynamic_item", "ford_card_item", b"ford_card_item", "video_small_card_item", b"video_small_card_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_item", b"dynamic_item", "ford_card_item", b"ford_card_item", "type", b"type", "video_small_card_item", b"video_small_card_item"]) -> None: ...

global___TopicCardItem = TopicCardItem

@typing_extensions.final
class TopicCardList(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_CARD_ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOPIC_SORT_BY_CONF_FIELD_NUMBER: builtins.int
    @property
    def topic_card_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCardItem]:
        """"""
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def topic_sort_by_conf(self) -> global___TopicSortByConf:
        """"""
    def __init__(
        self,
        *,
        topic_card_items: collections.abc.Iterable[global___TopicCardItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        topic_sort_by_conf: global___TopicSortByConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_sort_by_conf", b"topic_sort_by_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "offset", b"offset", "topic_card_items", b"topic_card_items", "topic_sort_by_conf", b"topic_sort_by_conf"]) -> None: ...

global___TopicCardList = TopicCardList

@typing_extensions.final
class TopicDetailsAllReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_TOP_INFO_FIELD_NUMBER: builtins.int
    TOPIC_ACTIVITIES_FIELD_NUMBER: builtins.int
    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FUNCTIONAL_CARD_FIELD_NUMBER: builtins.int
    PUB_LAYER_FIELD_NUMBER: builtins.int
    TIME_LINE_RESOURCE_FIELD_NUMBER: builtins.int
    TOPIC_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def details_top_info(self) -> global___DetailsTopInfo:
        """"""
    @property
    def topic_activities(self) -> global___TopicActivities:
        """"""
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
    @property
    def functional_card(self) -> global___FunctionalCard:
        """"""
    @property
    def pub_layer(self) -> global___PubLayer:
        """"""
    @property
    def time_line_resource(self) -> global___TimeLineResource:
        """"""
    @property
    def topic_server_config(self) -> global___TopicServerConfig:
        """"""
    def __init__(
        self,
        *,
        details_top_info: global___DetailsTopInfo | None = ...,
        topic_activities: global___TopicActivities | None = ...,
        topic_card_list: global___TopicCardList | None = ...,
        functional_card: global___FunctionalCard | None = ...,
        pub_layer: global___PubLayer | None = ...,
        time_line_resource: global___TimeLineResource | None = ...,
        topic_server_config: global___TopicServerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details_top_info", b"details_top_info", "functional_card", b"functional_card", "pub_layer", b"pub_layer", "time_line_resource", b"time_line_resource", "topic_activities", b"topic_activities", "topic_card_list", b"topic_card_list", "topic_server_config", b"topic_server_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["details_top_info", b"details_top_info", "functional_card", b"functional_card", "pub_layer", b"pub_layer", "time_line_resource", b"time_line_resource", "topic_activities", b"topic_activities", "topic_card_list", b"topic_card_list", "topic_server_config", b"topic_server_config"]) -> None: ...

global___TopicDetailsAllReply = TopicDetailsAllReply

@typing_extensions.final
class TopicDetailsAllReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    NEED_REFRESH_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOPIC_DETAILS_EXT_MODE_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    sort_by: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    need_refresh: builtins.int
    """"""
    source: builtins.str
    """"""
    topic_details_ext_mode: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        sort_by: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        need_refresh: builtins.int = ...,
        source: builtins.str = ...,
        topic_details_ext_mode: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_time", b"local_time", "need_refresh", b"need_refresh", "offset", b"offset", "page_size", b"page_size", "player_args", b"player_args", "sort_by", b"sort_by", "source", b"source", "topic_details_ext_mode", b"topic_details_ext_mode", "topic_id", b"topic_id"]) -> None: ...

global___TopicDetailsAllReq = TopicDetailsAllReq

@typing_extensions.final
class TopicDetailsFoldReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
    fold_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_card_list: global___TopicCardList | None = ...,
        fold_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_card_list", b"topic_card_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_count", b"fold_count", "topic_card_list", b"topic_card_list"]) -> None: ...

global___TopicDetailsFoldReply = TopicDetailsFoldReply

@typing_extensions.final
class TopicDetailsFoldReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_SORT_BY_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    from_sort_by: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        from_sort_by: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_sort_by", b"from_sort_by", "local_time", b"local_time", "offset", b"offset", "page_size", b"page_size", "player_args", b"player_args", "topic_id", b"topic_id"]) -> None: ...

global___TopicDetailsFoldReq = TopicDetailsFoldReq

@typing_extensions.final
class TopicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DISCUSS_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    DYNAMICS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    BACKCOLOR_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_SOURCE_FIELD_NUMBER: builtins.int
    SHARE_PIC_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    SHARE_URL_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATS_DESC_FIELD_NUMBER: builtins.int
    FIXED_TOPIC_ICON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    uid: builtins.int
    """"""
    view: builtins.int
    """"""
    discuss: builtins.int
    """"""
    fav: builtins.int
    """"""
    dynamics: builtins.int
    """"""
    state: builtins.int
    """"""
    jump_url: builtins.str
    """"""
    backcolor: builtins.str
    """"""
    is_fav: builtins.bool
    """"""
    description: builtins.str
    """"""
    create_source: builtins.int
    """"""
    share_pic: builtins.str
    """"""
    share: builtins.int
    """"""
    like: builtins.int
    """"""
    share_url: builtins.str
    """"""
    is_like: builtins.bool
    """"""
    type: builtins.int
    """"""
    stats_desc: builtins.str
    """"""
    fixed_topic_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        view: builtins.int = ...,
        discuss: builtins.int = ...,
        fav: builtins.int = ...,
        dynamics: builtins.int = ...,
        state: builtins.int = ...,
        jump_url: builtins.str = ...,
        backcolor: builtins.str = ...,
        is_fav: builtins.bool = ...,
        description: builtins.str = ...,
        create_source: builtins.int = ...,
        share_pic: builtins.str = ...,
        share: builtins.int = ...,
        like: builtins.int = ...,
        share_url: builtins.str = ...,
        is_like: builtins.bool = ...,
        type: builtins.int = ...,
        stats_desc: builtins.str = ...,
        fixed_topic_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backcolor", b"backcolor", "create_source", b"create_source", "description", b"description", "discuss", b"discuss", "dynamics", b"dynamics", "fav", b"fav", "fixed_topic_icon", b"fixed_topic_icon", "id", b"id", "is_fav", b"is_fav", "is_like", b"is_like", "jump_url", b"jump_url", "like", b"like", "name", b"name", "share", b"share", "share_pic", b"share_pic", "share_url", b"share_url", "state", b"state", "stats_desc", b"stats_desc", "type", b"type", "uid", b"uid", "view", b"view"]) -> None: ...

global___TopicInfo = TopicInfo

@typing_extensions.final
class TopicServerConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUB_EVENTS_INCREASE_THRESHOLD_FIELD_NUMBER: builtins.int
    PUB_EVENTS_HIDDEN_TIMEOUT_THRESHOLD_FIELD_NUMBER: builtins.int
    VERT_ONLINE_REFRESH_TIME_FIELD_NUMBER: builtins.int
    pub_events_increase_threshold: builtins.int
    """"""
    pub_events_hidden_timeout_threshold: builtins.int
    """"""
    vert_online_refresh_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        pub_events_increase_threshold: builtins.int = ...,
        pub_events_hidden_timeout_threshold: builtins.int = ...,
        vert_online_refresh_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_events_hidden_timeout_threshold", b"pub_events_hidden_timeout_threshold", "pub_events_increase_threshold", b"pub_events_increase_threshold", "vert_online_refresh_time", b"vert_online_refresh_time"]) -> None: ...

global___TopicServerConfig = TopicServerConfig

@typing_extensions.final
class TopicSet(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_ID_FIELD_NUMBER: builtins.int
    SET_NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    set_id: builtins.int
    """"""
    set_name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        set_id: builtins.int = ...,
        set_name: builtins.str = ...,
        jump_url: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "jump_url", b"jump_url", "set_id", b"set_id", "set_name", b"set_name"]) -> None: ...

global___TopicSet = TopicSet

@typing_extensions.final
class TopicSetDetailsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_SET_HEAD_INFO_FIELD_NUMBER: builtins.int
    TOPIC_INFO_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    SORT_CFG_FIELD_NUMBER: builtins.int
    @property
    def topic_set_head_info(self) -> global___TopicSetHeadInfo:
        """"""
    @property
    def topic_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicInfo]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def sort_cfg(self) -> global___TopicSetSortCfg:
        """"""
    def __init__(
        self,
        *,
        topic_set_head_info: global___TopicSetHeadInfo | None = ...,
        topic_info: collections.abc.Iterable[global___TopicInfo] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        sort_cfg: global___TopicSetSortCfg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sort_cfg", b"sort_cfg", "topic_set_head_info", b"topic_set_head_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "offset", b"offset", "sort_cfg", b"sort_cfg", "topic_info", b"topic_info", "topic_set_head_info", b"topic_set_head_info"]) -> None: ...

global___TopicSetDetailsReply = TopicSetDetailsReply

@typing_extensions.final
class TopicSetDetailsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_ID_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    set_id: builtins.int
    """"""
    sort_by: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        set_id: builtins.int = ...,
        sort_by: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset", b"offset", "page_size", b"page_size", "set_id", b"set_id", "sort_by", b"sort_by"]) -> None: ...

global___TopicSetDetailsReq = TopicSetDetailsReq

@typing_extensions.final
class TopicSetHeadInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_SET_FIELD_NUMBER: builtins.int
    TOPIC_CNT_TEXT_FIELD_NUMBER: builtins.int
    HEAD_IMG_URL_FIELD_NUMBER: builtins.int
    MISSION_URL_FIELD_NUMBER: builtins.int
    MISSION_TEXT_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    IS_FIRST_TIME_FIELD_NUMBER: builtins.int
    @property
    def topic_set(self) -> global___TopicSet:
        """"""
    topic_cnt_text: builtins.str
    """"""
    head_img_url: builtins.str
    """"""
    mission_url: builtins.str
    """"""
    mission_text: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    is_fav: builtins.bool
    """"""
    is_first_time: builtins.bool
    """"""
    def __init__(
        self,
        *,
        topic_set: global___TopicSet | None = ...,
        topic_cnt_text: builtins.str = ...,
        head_img_url: builtins.str = ...,
        mission_url: builtins.str = ...,
        mission_text: builtins.str = ...,
        icon_url: builtins.str = ...,
        is_fav: builtins.bool = ...,
        is_first_time: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_set", b"topic_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["head_img_url", b"head_img_url", "icon_url", b"icon_url", "is_fav", b"is_fav", "is_first_time", b"is_first_time", "mission_text", b"mission_text", "mission_url", b"mission_url", "topic_cnt_text", b"topic_cnt_text", "topic_set", b"topic_set"]) -> None: ...

global___TopicSetHeadInfo = TopicSetHeadInfo

@typing_extensions.final
class TopicSetSortCfg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SORT_BY_FIELD_NUMBER: builtins.int
    ALL_SORT_BY_FIELD_NUMBER: builtins.int
    default_sort_by: builtins.int
    """"""
    @property
    def all_sort_by(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortContent]:
        """"""
    def __init__(
        self,
        *,
        default_sort_by: builtins.int = ...,
        all_sort_by: collections.abc.Iterable[global___SortContent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_sort_by", b"all_sort_by", "default_sort_by", b"default_sort_by"]) -> None: ...

global___TopicSetSortCfg = TopicSetSortCfg

@typing_extensions.final
class TopicSortByConf(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SORT_BY_FIELD_NUMBER: builtins.int
    ALL_SORT_BY_FIELD_NUMBER: builtins.int
    SHOW_SORT_BY_FIELD_NUMBER: builtins.int
    default_sort_by: builtins.int
    """"""
    @property
    def all_sort_by(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortContent]:
        """"""
    show_sort_by: builtins.int
    """"""
    def __init__(
        self,
        *,
        default_sort_by: builtins.int = ...,
        all_sort_by: collections.abc.Iterable[global___SortContent] | None = ...,
        show_sort_by: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_sort_by", b"all_sort_by", "default_sort_by", b"default_sort_by", "show_sort_by", b"show_sort_by"]) -> None: ...

global___TopicSortByConf = TopicSortByConf

@typing_extensions.final
class TopicThreePoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_THREE_POINT_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def dyn_three_point_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """"""
    def __init__(
        self,
        *,
        dyn_three_point_items: collections.abc.Iterable[global___ThreePointItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_three_point_items", b"dyn_three_point_items"]) -> None: ...

global___TopicThreePoint = TopicThreePoint

@typing_extensions.final
class TrafficCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    BASE_PIC_FIELD_NUMBER: builtins.int
    BENEFIT_POINT_FIELD_NUMBER: builtins.int
    CARD_DESC_FIELD_NUMBER: builtins.int
    JUMP_TITLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    base_pic: builtins.str
    """"""
    benefit_point: builtins.str
    """"""
    card_desc: builtins.str
    """"""
    jump_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
        base_pic: builtins.str = ...,
        benefit_point: builtins.str = ...,
        card_desc: builtins.str = ...,
        jump_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_pic", b"base_pic", "benefit_point", b"benefit_point", "card_desc", b"card_desc", "icon_url", b"icon_url", "jump_title", b"jump_title", "jump_url", b"jump_url", "name", b"name"]) -> None: ...

global___TrafficCard = TrafficCard

@typing_extensions.final
class User(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_DESC_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    face: builtins.str
    """"""
    name: builtins.str
    """"""
    name_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        name_desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "name", b"name", "name_desc", b"name_desc", "uid", b"uid"]) -> None: ...

global___User = User

@typing_extensions.final
class VideoCardBase(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    title: builtins.str
    """"""
    up_name: builtins.str
    """"""
    play: builtins.int
    """"""
    jump_link: builtins.str
    """"""
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        up_name: builtins.str = ...,
        play: builtins.int = ...,
        jump_link: builtins.str = ...,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cover", b"cover", "jump_link", b"jump_link", "play", b"play", "title", b"title", "up_name", b"up_name"]) -> None: ...

global___VideoCardBase = VideoCardBase

@typing_extensions.final
class VideoSmallCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_CARD_BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_BADGE_TEXT_FIELD_NUMBER: builtins.int
    CARD_STAT_ICON1_FIELD_NUMBER: builtins.int
    CARD_STAT_TEXT1_FIELD_NUMBER: builtins.int
    CARD_STAT_ICON2_FIELD_NUMBER: builtins.int
    CARD_STAT_TEXT2_FIELD_NUMBER: builtins.int
    @property
    def video_card_base(self) -> global___VideoCardBase:
        """"""
    cover_left_badge_text: builtins.str
    """"""
    card_stat_icon1: builtins.int
    """"""
    card_stat_text1: builtins.str
    """"""
    card_stat_icon2: builtins.int
    """"""
    card_stat_text2: builtins.str
    """"""
    def __init__(
        self,
        *,
        video_card_base: global___VideoCardBase | None = ...,
        cover_left_badge_text: builtins.str = ...,
        card_stat_icon1: builtins.int = ...,
        card_stat_text1: builtins.str = ...,
        card_stat_icon2: builtins.int = ...,
        card_stat_text2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["video_card_base", b"video_card_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_stat_icon1", b"card_stat_icon1", "card_stat_icon2", b"card_stat_icon2", "card_stat_text1", b"card_stat_text1", "card_stat_text2", b"card_stat_text2", "cover_left_badge_text", b"cover_left_badge_text", "video_card_base", b"video_card_base"]) -> None: ...

global___VideoSmallCardItem = VideoSmallCardItem
