# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/playerunite/v1/playerunite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.playershared import playershared_pb2 as bilibili_dot_playershared_dot_playershared__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/app/playerunite/v1/playerunite.proto\x12\x1b\x62ilibili.app.playerunite.v1\x1a(bilibili/playershared/playershared.proto\x1a\x19google/protobuf/any.proto\"\xf0\x01\n\x10PlayViewUniteReq\x12,\n\x03vod\x18\x01 \x01(\x0b\x32\x1f.bilibili.playershared.VideoVod\x12\r\n\x05spmid\x18\x02 \x01(\t\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12V\n\rextra_content\x18\x04 \x03(\x0b\x32?.bilibili.app.playerunite.v1.PlayViewUniteReq.ExtraContentEntry\x1a\x33\n\x11\x45xtraContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x03\n\x12PlayViewUniteReply\x12\x30\n\x08vod_info\x18\x01 \x01(\x0b\x32\x1e.bilibili.playershared.VodInfo\x12\x39\n\rplay_arc_conf\x18\x02 \x01(\x0b\x32\".bilibili.playershared.PlayArcConf\x12?\n\x10play_device_conf\x18\x03 \x01(\x0b\x32%.bilibili.playershared.PlayDeviceConf\x12+\n\x05\x65vent\x18\x04 \x01(\x0b\x32\x1c.bilibili.playershared.Event\x12(\n\nsupplement\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x08play_arc\x18\x06 \x01(\x0b\x32\x1e.bilibili.playershared.PlayArc\x12\x39\n\rqn_trial_info\x18\x07 \x01(\x0b\x32\".bilibili.playershared.QnTrialInfo\x12/\n\x07history\x18\x08 \x01(\x0b\x32\x1e.bilibili.playershared.History2y\n\x06Player\x12o\n\rPlayViewUnite\x12-.bilibili.app.playerunite.v1.PlayViewUniteReq\x1a/.bilibili.app.playerunite.v1.PlayViewUniteReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playerunite.v1.playerunite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYVIEWUNITEREQ_EXTRACONTENTENTRY._options = None
  _PLAYVIEWUNITEREQ_EXTRACONTENTENTRY._serialized_options = b'8\001'
  _globals['_PLAYVIEWUNITEREQ']._serialized_start=148
  _globals['_PLAYVIEWUNITEREQ']._serialized_end=388
  _globals['_PLAYVIEWUNITEREQ_EXTRACONTENTENTRY']._serialized_start=337
  _globals['_PLAYVIEWUNITEREQ_EXTRACONTENTENTRY']._serialized_end=388
  _globals['_PLAYVIEWUNITEREPLY']._serialized_start=391
  _globals['_PLAYVIEWUNITEREPLY']._serialized_end=830
  _globals['_PLAYER']._serialized_start=832
  _globals['_PLAYER']._serialized_end=953
# @@protoc_insertion_point(module_scope)
