# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pagination/pagination.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/pagination/pagination.proto\x12\x13\x62ilibili.pagination\"G\n\x0e\x46\x65\x65\x64Pagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x12\n\nis_refresh\x18\x03 \x01(\x08\"Y\n\x13\x46\x65\x65\x64PaginationReply\x12\x13\n\x0bnext_offset\x18\x01 \x01(\t\x12\x13\n\x0bprev_offset\x18\x02 \x01(\t\x12\x18\n\x10last_read_offset\x18\x03 \x01(\t\"-\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0c\n\x04next\x18\x02 \x01(\t\"-\n\x0fPaginationReply\x12\x0c\n\x04next\x18\x01 \x01(\t\x12\x0c\n\x04prev\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pagination.pagination_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FEEDPAGINATION']._serialized_start=61
  _globals['_FEEDPAGINATION']._serialized_end=132
  _globals['_FEEDPAGINATIONREPLY']._serialized_start=134
  _globals['_FEEDPAGINATIONREPLY']._serialized_end=223
  _globals['_PAGINATION']._serialized_start=225
  _globals['_PAGINATION']._serialized_end=270
  _globals['_PAGINATIONREPLY']._serialized_start=272
  _globals['_PAGINATIONREPLY']._serialized_end=317
# @@protoc_insertion_point(module_scope)
