"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ModResourceResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATCION_FIELD_NUMBER: builtins.int
    APP_KEY_FIELD_NUMBER: builtins.int
    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    MODULE_VERSION_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    atcion: builtins.int
    """"""
    app_key: builtins.str
    """"""
    pool_name: builtins.str
    """"""
    module_name: builtins.str
    """"""
    module_version: builtins.int
    """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        atcion: builtins.int = ...,
        app_key: builtins.str = ...,
        pool_name: builtins.str = ...,
        module_name: builtins.str = ...,
        module_version: builtins.int = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_key", b"app_key", "atcion", b"atcion", "list_version", b"list_version", "module_name", b"module_name", "module_version", b"module_version", "pool_name", b"pool_name"]) -> None: ...

global___ModResourceResp = ModResourceResp
