syntax = "proto3";

package bilibili.app.distribution.setting.night;

import "bilibili/app/distribution/v1/distribution.proto";

// 
message NightSettingsConfig {
    // 
    bilibili.app.distribution.v1.BoolValue is_night_follow_system = 1;
}