# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.listener.v1 import listener_pb2 as bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ListenerStub(object):
    """听视频
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/Ping',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PlayUrl = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlayUrl',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLResp.FromString,
                )
        self.BkarcDetails = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/BkarcDetails',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsResp.FromString,
                )
        self.Playlist = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/Playlist',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistResp.FromString,
                )
        self.PlaylistAdd = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlaylistAdd',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistAddReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PlaylistDel = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlaylistDel',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistDelReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RcmdPlaylist = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/RcmdPlaylist',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistResp.FromString,
                )
        self.PlayHistory = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlayHistory',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryResp.FromString,
                )
        self.PlayHistoryAdd = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlayHistoryAdd',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryAddReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PlayHistoryDel = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlayHistoryDel',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryDelReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PlayActionReport = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PlayActionReport',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayActionReportReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.TripleLike = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/TripleLike',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeResp.FromString,
                )
        self.ThumbUp = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/ThumbUp',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpResp.FromString,
                )
        self.CoinAdd = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/CoinAdd',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddResp.FromString,
                )
        self.FavItemAdd = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavItemAdd',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddResp.FromString,
                )
        self.FavItemDel = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavItemDel',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelResp.FromString,
                )
        self.FavItemBatch = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavItemBatch',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchResp.FromString,
                )
        self.FavoredInAnyFolders = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavoredInAnyFolders',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersResp.FromString,
                )
        self.FavFolderList = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavFolderList',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListResp.FromString,
                )
        self.FavFolderDetail = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavFolderDetail',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailResp.FromString,
                )
        self.FavFolderCreate = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavFolderCreate',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateResp.FromString,
                )
        self.FavFolderDelete = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/FavFolderDelete',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteResp.FromString,
                )
        self.PickFeed = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PickFeed',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedResp.FromString,
                )
        self.PickCardDetail = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/PickCardDetail',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailResp.FromString,
                )
        self.Medialist = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/Medialist',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistResp.FromString,
                )
        self.Event = channel.unary_unary(
                '/bilibili.app.listener.v1.Listener/Event',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventResp.FromString,
                )


class ListenerServicer(object):
    """听视频
    """

    def Ping(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayUrl(self, request, context):
        """获取音频URL
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BkarcDetails(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Playlist(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlaylistAdd(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlaylistDel(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RcmdPlaylist(self, request, context):
        """推荐列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayHistory(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayHistoryAdd(self, request, context):
        """添加历史记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayHistoryDel(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayActionReport(self, request, context):
        """播放上报
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TripleLike(self, request, context):
        """三联
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ThumbUp(self, request, context):
        """点赞
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CoinAdd(self, request, context):
        """投币
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavItemAdd(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavItemDel(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavItemBatch(self, request, context):
        """批量处理收藏
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavoredInAnyFolders(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavFolderList(self, request, context):
        """用户收藏夹列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavFolderDetail(self, request, context):
        """收藏夹详细信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavFolderCreate(self, request, context):
        """创建收藏夹
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavFolderDelete(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PickFeed(self, request, context):
        """每日播单列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PickCardDetail(self, request, context):
        """每日播单详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Medialist(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Event(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ListenerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PlayUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayUrl,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLResp.SerializeToString,
            ),
            'BkarcDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.BkarcDetails,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsResp.SerializeToString,
            ),
            'Playlist': grpc.unary_unary_rpc_method_handler(
                    servicer.Playlist,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistResp.SerializeToString,
            ),
            'PlaylistAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.PlaylistAdd,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistAddReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PlaylistDel': grpc.unary_unary_rpc_method_handler(
                    servicer.PlaylistDel,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistDelReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RcmdPlaylist': grpc.unary_unary_rpc_method_handler(
                    servicer.RcmdPlaylist,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistResp.SerializeToString,
            ),
            'PlayHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayHistory,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryResp.SerializeToString,
            ),
            'PlayHistoryAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayHistoryAdd,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryAddReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PlayHistoryDel': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayHistoryDel,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryDelReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PlayActionReport': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayActionReport,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayActionReportReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'TripleLike': grpc.unary_unary_rpc_method_handler(
                    servicer.TripleLike,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeResp.SerializeToString,
            ),
            'ThumbUp': grpc.unary_unary_rpc_method_handler(
                    servicer.ThumbUp,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpResp.SerializeToString,
            ),
            'CoinAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.CoinAdd,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddResp.SerializeToString,
            ),
            'FavItemAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.FavItemAdd,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddResp.SerializeToString,
            ),
            'FavItemDel': grpc.unary_unary_rpc_method_handler(
                    servicer.FavItemDel,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelResp.SerializeToString,
            ),
            'FavItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.FavItemBatch,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchResp.SerializeToString,
            ),
            'FavoredInAnyFolders': grpc.unary_unary_rpc_method_handler(
                    servicer.FavoredInAnyFolders,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersResp.SerializeToString,
            ),
            'FavFolderList': grpc.unary_unary_rpc_method_handler(
                    servicer.FavFolderList,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListResp.SerializeToString,
            ),
            'FavFolderDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.FavFolderDetail,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailResp.SerializeToString,
            ),
            'FavFolderCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.FavFolderCreate,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateResp.SerializeToString,
            ),
            'FavFolderDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.FavFolderDelete,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteResp.SerializeToString,
            ),
            'PickFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.PickFeed,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedResp.SerializeToString,
            ),
            'PickCardDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.PickCardDetail,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailResp.SerializeToString,
            ),
            'Medialist': grpc.unary_unary_rpc_method_handler(
                    servicer.Medialist,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistResp.SerializeToString,
            ),
            'Event': grpc.unary_unary_rpc_method_handler(
                    servicer.Event,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.listener.v1.Listener', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Listener(object):
    """听视频
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/Ping',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlayUrl',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayURLResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BkarcDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/BkarcDetails',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.BKArcDetailsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Playlist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/Playlist',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlaylistAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlaylistAdd',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistAddReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlaylistDel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlaylistDel',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlaylistDelReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RcmdPlaylist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/RcmdPlaylist',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.RcmdPlaylistResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlayHistory',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayHistoryAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlayHistoryAdd',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryAddReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayHistoryDel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlayHistoryDel',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayHistoryDelReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayActionReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PlayActionReport',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PlayActionReportReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TripleLike(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/TripleLike',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.TripleLikeResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ThumbUp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/ThumbUp',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ThumbUpResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CoinAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/CoinAdd',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.CoinAddResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavItemAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavItemAdd',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemAddResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavItemDel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavItemDel',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemDelResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavItemBatch',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavItemBatchResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavoredInAnyFolders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavoredInAnyFolders',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavoredInAnyFoldersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavFolderList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavFolderList',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderListResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavFolderDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavFolderDetail',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDetailResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavFolderCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavFolderCreate',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderCreateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavFolderDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/FavFolderDelete',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavFolderDeleteResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PickFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PickFeed',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickFeedResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PickCardDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/PickCardDetail',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.PickCardDetailResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Medialist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/Medialist',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MedialistResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Event(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Listener/Event',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.EventResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class MusicStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FavTabShow = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/FavTabShow',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowResp.FromString,
                )
        self.MainFavMusicSubTabList = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/MainFavMusicSubTabList',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListResp.FromString,
                )
        self.MainFavMusicMenuList = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/MainFavMusicMenuList',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListResp.FromString,
                )
        self.MenuEdit = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/MenuEdit',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditResp.FromString,
                )
        self.MenuDelete = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/MenuDelete',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteResp.FromString,
                )
        self.MenuSubscribe = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/MenuSubscribe',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeResp.FromString,
                )
        self.Click = channel.unary_unary(
                '/bilibili.app.listener.v1.Music/Click',
                request_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickResp.FromString,
                )


class MusicServicer(object):
    """
    """

    def FavTabShow(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MainFavMusicSubTabList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MainFavMusicMenuList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MenuEdit(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MenuDelete(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MenuSubscribe(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Click(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MusicServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FavTabShow': grpc.unary_unary_rpc_method_handler(
                    servicer.FavTabShow,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowResp.SerializeToString,
            ),
            'MainFavMusicSubTabList': grpc.unary_unary_rpc_method_handler(
                    servicer.MainFavMusicSubTabList,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListResp.SerializeToString,
            ),
            'MainFavMusicMenuList': grpc.unary_unary_rpc_method_handler(
                    servicer.MainFavMusicMenuList,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListResp.SerializeToString,
            ),
            'MenuEdit': grpc.unary_unary_rpc_method_handler(
                    servicer.MenuEdit,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditResp.SerializeToString,
            ),
            'MenuDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.MenuDelete,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteResp.SerializeToString,
            ),
            'MenuSubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.MenuSubscribe,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeResp.SerializeToString,
            ),
            'Click': grpc.unary_unary_rpc_method_handler(
                    servicer.Click,
                    request_deserializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickReq.FromString,
                    response_serializer=bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.listener.v1.Music', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Music(object):
    """
    """

    @staticmethod
    def FavTabShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/FavTabShow',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.FavTabShowResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MainFavMusicSubTabList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/MainFavMusicSubTabList',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicSubTabListResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MainFavMusicMenuList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/MainFavMusicMenuList',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MainFavMusicMenuListResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MenuEdit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/MenuEdit',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuEditResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MenuDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/MenuDelete',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuDeleteResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MenuSubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/MenuSubscribe',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.MenuSubscribeResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Click(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.listener.v1.Music/Click',
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickReq.SerializeToString,
            bilibili_dot_app_dot_listener_dot_v1_dot_listener__pb2.ClickResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
