syntax = "proto3";

package bilibili.app.distribution.setting.other;

import "bilibili/app/distribution/v1/distribution.proto";

// 
message OtherSettingsConfig {
    // 
    bilibili.app.distribution.v1.Int64Value watermark_type = 1;
    // 
    bilibili.app.distribution.v1.Int64Value web_image_quality_type = 2;
    // 
    bilibili.app.distribution.v1.BoolValue enable_read_pasteboard = 3;
    // 
    bilibili.app.distribution.v1.BoolValue paste_auto_jump = 4;
    // 
    bilibili.app.distribution.v1.BoolValue mini_screen_play_when_back = 5;
    // 
    bilibili.app.distribution.v1.BoolValue enable_resume_playing = 6;
    // 
    bilibili.app.distribution.v1.BoolValue enable_wifi_auto_update = 7;
    // 
    bilibili.app.distribution.v1.BoolValue enable_guide_screenshot_share = 8;
}