"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.common.dynamic_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import bilireq.grpc.protos.bilibili.pagination.pagination_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CampusWaterFlowItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_TYPE_FIELD_NUMBER: builtins.int
    WH_RATIO_FIELD_NUMBER: builtins.int
    ITEM_DEFAULT_FIELD_NUMBER: builtins.int
    item_type: builtins.int
    """"""
    @property
    def wh_ratio(self) -> bilireq.grpc.protos.bilibili.app.dynamic.common.dynamic_pb2.ItemWHRatio:
        """"""
    @property
    def item_default(self) -> global___WFItemDefault: ...
    def __init__(
        self,
        *,
        item_type: builtins.int = ...,
        wh_ratio: bilireq.grpc.protos.bilibili.app.dynamic.common.dynamic_pb2.ItemWHRatio | None = ...,
        item_default: global___WFItemDefault | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "item_default", b"item_default", "wh_ratio", b"wh_ratio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "item_default", b"item_default", "item_type", b"item_type", "wh_ratio", b"wh_ratio"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["item_default"] | None: ...

global___CampusWaterFlowItem = CampusWaterFlowItem

@typing_extensions.final
class WaterFlowRcmdReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    page: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        page: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "from", b"from", "page", b"page", "player_args", b"player_args"]) -> None: ...

global___WaterFlowRcmdReq = WaterFlowRcmdReq

@typing_extensions.final
class WaterFlowRcmdResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusWaterFlowItem]:
        """"""
    @property
    def offset(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.FeedPaginationReply:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CampusWaterFlowItem] | None = ...,
        offset: bilireq.grpc.protos.bilibili.pagination.pagination_pb2.FeedPaginationReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["offset", b"offset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "offset", b"offset"]) -> None: ...

global___WaterFlowRcmdResp = WaterFlowRcmdResp

@typing_extensions.final
class WFItemDefault(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BOTTOM_LEFT_1_FIELD_NUMBER: builtins.int
    BOTTOM_LEFT_2_FIELD_NUMBER: builtins.int
    BOTTOM_RIGHT_1_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def bottom_left_1(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText:
        """"""
    @property
    def bottom_left_2(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText:
        """"""
    @property
    def bottom_right_1(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText:
        """"""
    uri: builtins.str
    """"""
    @property
    def rcmd_reason(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.RcmdReason:
        """"""
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        bottom_left_1: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText | None = ...,
        bottom_left_2: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText | None = ...,
        bottom_right_1: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.CoverIconWithText | None = ...,
        uri: builtins.str = ...,
        rcmd_reason: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.RcmdReason | None = ...,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_left_1", b"bottom_left_1", "bottom_left_2", b"bottom_left_2", "bottom_right_1", b"bottom_right_1", "rcmd_reason", b"rcmd_reason"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "bottom_left_1", b"bottom_left_1", "bottom_left_2", b"bottom_left_2", "bottom_right_1", b"bottom_right_1", "cover", b"cover", "rcmd_reason", b"rcmd_reason", "title", b"title", "uri", b"uri"]) -> None: ...

global___WFItemDefault = WFItemDefault
