# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dagw/component/avatar/common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2bilibili/dagw/component/avatar/common/common.proto\x12%bilibili.dagw.component.avatar.common\"\"\n\x0f\x42\x61sicRenderSpec\x12\x0f\n\x07opacity\x18\x01 \x01(\x01\"\xa9\x01\n\x0b\x43olorConfig\x12\x1a\n\x12is_dark_mode_aware\x18\x01 \x01(\x08\x12=\n\x03\x64\x61y\x18\x02 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.ColorSpec\x12?\n\x05night\x18\x03 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.ColorSpec\"\x19\n\tColorSpec\x12\x0c\n\x04\x61rgb\x18\x01 \x01(\t\"\xea\x01\n\x10LayerGeneralSpec\x12\x45\n\x08pos_spec\x18\x01 \x01(\x0b\x32\x33.bilibili.dagw.component.avatar.common.PositionSpec\x12\x42\n\tsize_spec\x18\x02 \x01(\x0b\x32/.bilibili.dagw.component.avatar.common.SizeSpec\x12K\n\x0brender_spec\x18\x03 \x01(\x0b\x32\x36.bilibili.dagw.component.avatar.common.BasicRenderSpec\"\xa6\x01\n\x0cMaskProperty\x12M\n\x0cgeneral_spec\x18\x01 \x01(\x0b\x32\x37.bilibili.dagw.component.avatar.common.LayerGeneralSpec\x12G\n\x08mask_src\x18\x02 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.common.ResourceSource\"\x94\x01\n\rNativeDrawRes\x12\x11\n\tdraw_type\x18\x01 \x01(\x05\x12\x11\n\tfill_mode\x18\x02 \x01(\x05\x12H\n\x0c\x63olor_config\x18\x03 \x01(\x0b\x32\x32.bilibili.dagw.component.avatar.common.ColorConfig\x12\x13\n\x0b\x65\x64ge_weight\x18\x04 \x01(\x01\"F\n\x0cPositionSpec\x12\x16\n\x0e\x63oordinate_pos\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_x\x18\x02 \x01(\x01\x12\x0e\n\x06\x61xis_y\x18\x03 \x01(\x01\"+\n\tRemoteRes\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tbfs_style\x18\x02 \x01(\t\"\xfc\x03\n\x0eResourceSource\x12\x10\n\x08src_type\x18\x01 \x01(\x05\x12\x13\n\x0bplaceholder\x18\x02 \x01(\x05\x12\x42\n\x06remote\x18\x03 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.common.RemoteResH\x00\x12O\n\x05local\x18\x04 \x01(\x0e\x32>.bilibili.dagw.component.avatar.common.ResourceSource.LocalResH\x00\x12\x44\n\x04\x64raw\x18\x05 \x01(\x0b\x32\x34.bilibili.dagw.component.avatar.common.NativeDrawResH\x00\"\xe0\x01\n\x08LocalRes\x12\x15\n\x11LOCAL_RES_INVALID\x10\x00\x12\x16\n\x12LOCAL_RES_ICON_VIP\x10\x01\x12\x1c\n\x18LOCAL_RES_ICON_SMALL_VIP\x10\x02\x12\"\n\x1eLOCAL_RES_ICON_PERSONAL_VERIFY\x10\x03\x12$\n LOCAL_RES_ICON_ENTERPRISE_VERIFY\x10\x04\x12\x1f\n\x1bLOCAL_RES_ICON_NFT_MAINLAND\x10\x05\x12\x1c\n\x18LOCAL_RES_DEFAULT_AVATAR\x10\x06\x42\x05\n\x03res\")\n\x08SizeSpec\x12\r\n\x05width\x18\x01 \x01(\x01\x12\x0e\n\x06height\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dagw.component.avatar.common.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICRENDERSPEC']._serialized_start=93
  _globals['_BASICRENDERSPEC']._serialized_end=127
  _globals['_COLORCONFIG']._serialized_start=130
  _globals['_COLORCONFIG']._serialized_end=299
  _globals['_COLORSPEC']._serialized_start=301
  _globals['_COLORSPEC']._serialized_end=326
  _globals['_LAYERGENERALSPEC']._serialized_start=329
  _globals['_LAYERGENERALSPEC']._serialized_end=563
  _globals['_MASKPROPERTY']._serialized_start=566
  _globals['_MASKPROPERTY']._serialized_end=732
  _globals['_NATIVEDRAWRES']._serialized_start=735
  _globals['_NATIVEDRAWRES']._serialized_end=883
  _globals['_POSITIONSPEC']._serialized_start=885
  _globals['_POSITIONSPEC']._serialized_end=955
  _globals['_REMOTERES']._serialized_start=957
  _globals['_REMOTERES']._serialized_end=1000
  _globals['_RESOURCESOURCE']._serialized_start=1003
  _globals['_RESOURCESOURCE']._serialized_end=1511
  _globals['_RESOURCESOURCE_LOCALRES']._serialized_start=1280
  _globals['_RESOURCESOURCE_LOCALRES']._serialized_end=1504
  _globals['_SIZESPEC']._serialized_start=1513
  _globals['_SIZESPEC']._serialized_end=1554
# @@protoc_insertion_point(module_scope)
