# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/topic/v1/topic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/topic/v1/topic.proto\x12\x15\x62ilibili.app.topic.v1\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a!bilibili/app/card/v1/common.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"(\n\nButtonMeta\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\"\xaf\x03\n\x0e\x44\x65tailsTopInfo\x12\x34\n\ntopic_info\x18\x01 \x01(\x0b\x32 .bilibili.app.topic.v1.TopicInfo\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.topic.v1.User\x12\x12\n\nstats_desc\x18\x03 \x01(\t\x12\x1f\n\x17has_create_jurisdiction\x18\x04 \x01(\x08\x12\x42\n\x11operation_content\x18\x05 \x01(\x0b\x32\'.bilibili.app.topic.v1.OperationContent\x12\x14\n\x0chead_img_url\x18\x06 \x01(\t\x12\x1a\n\x12head_img_backcolor\x18\x07 \x01(\t\x12\x12\n\nword_color\x18\x08 \x01(\x05\x12\x1e\n\x16mission_page_show_type\x18\t \x01(\x05\x12\x13\n\x0bmission_url\x18\n \x01(\t\x12\x14\n\x0cmission_text\x18\x0b \x01(\t\x12\x32\n\ttopic_set\x18\x0c \x01(\x0b\x32\x1f.bilibili.app.topic.v1.TopicSet\"c\n\x0c\x46oldCardItem\x12\x14\n\x0cis_show_fold\x18\x01 \x01(\x05\x12\x12\n\nfold_count\x18\x02 \x01(\x03\x12\x16\n\x0e\x63\x61rd_show_desc\x18\x03 \x01(\t\x12\x11\n\tfold_desc\x18\x04 \x01(\t\"\xb5\x01\n\x0e\x46unctionalCard\x12\x35\n\x08\x63\x61psules\x18\x01 \x03(\x0b\x32#.bilibili.app.topic.v1.TopicCapsule\x12\x38\n\x0ctraffic_card\x18\x02 \x01(\x0b\x32\".bilibili.app.topic.v1.TrafficCard\x12\x32\n\tgame_card\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.GameCard\"\x86\x01\n\x08GameCard\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\x12\x11\n\tgame_icon\x18\x02 \x01(\t\x12\x11\n\tgame_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\t\x12\x11\n\tgame_tags\x18\x05 \x01(\t\x12\x0e\n\x06notice\x18\x06 \x01(\t\x12\x11\n\tgame_link\x18\x07 \x01(\t\"i\n\x11InlineProgressBar\x12\x11\n\ticon_drag\x18\x01 \x01(\t\x12\x16\n\x0eicon_drag_hash\x18\x02 \x01(\t\x12\x11\n\ticon_stop\x18\x03 \x01(\t\x12\x16\n\x0eicon_stop_hash\x18\x04 \x01(\t\"\xb9\x04\n\x10LargeCoverInline\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x18\n\x10\x63over_left_text1\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x05 \x01(\x05\x12\x46\n\x14right_top_live_badge\x18\x06 \x01(\x0b\x32(.bilibili.app.topic.v1.RightTopLiveBadge\x12\x11\n\textra_uri\x18\x07 \x01(\t\x12\x45\n\x13inline_progress_bar\x18\x08 \x01(\x0b\x32(.bilibili.app.topic.v1.InlineProgressBar\x12\x41\n\x11topic_three_point\x18\t \x01(\x0b\x32&.bilibili.app.topic.v1.TopicThreePoint\x12\x17\n\x0f\x63over_left_desc\x18\n \x01(\t\x12\x19\n\x11hide_danmu_switch\x18\x0b \x01(\x08\x12\x15\n\rdisable_danmu\x18\x0c \x01(\x08\x12\x10\n\x08\x63\x61n_play\x18\r \x01(\x05\x12\x15\n\rduration_text\x18\x0e \x01(\t\x12:\n\rrelation_data\x18\x0f \x01(\x0b\x32#.bilibili.app.topic.v1.RelationData\"\xd2\x01\n\x11LiveBadgeResource\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\ranimation_url\x18\x02 \x01(\t\x12\x1a\n\x12\x61nimation_url_hash\x18\x03 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_light\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_night\x18\x05 \x01(\t\x12\x13\n\x0b\x61lpha_light\x18\x06 \x01(\x03\x12\x13\n\x0b\x61lpha_night\x18\x07 \x01(\x03\x12\x12\n\nfont_color\x18\x08 \x01(\t\"^\n\rOperationCard\x12\x45\n\x12large_cover_inline\x18\x01 \x01(\x0b\x32\'.bilibili.app.topic.v1.LargeCoverInlineH\x00\x42\x06\n\x04\x63\x61rd\"P\n\x10OperationContent\x12<\n\x0eoperation_card\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.OperationCard\"\x87\x01\n\x08PubLayer\x12\x11\n\tshow_type\x18\x01 \x01(\x05\x12\x11\n\tjump_link\x18\x02 \x01(\t\x12\x36\n\x0b\x62utton_meta\x18\x03 \x01(\x0b\x32!.bilibili.app.topic.v1.ButtonMeta\x12\x1d\n\x15\x63lose_pub_layer_entry\x18\x04 \x01(\x08\"g\n\x0cRelationData\x12\x0e\n\x06is_fav\x18\x01 \x01(\x08\x12\x0f\n\x07is_coin\x18\x02 \x01(\x08\x12\x11\n\tis_follow\x18\x03 \x01(\x08\x12\x0f\n\x07is_like\x18\x04 \x01(\x08\x12\x12\n\nlike_count\x18\x05 \x01(\x03\"|\n\x11RightTopLiveBadge\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x39\n\x07in_live\x18\x02 \x01(\x0b\x32(.bilibili.app.topic.v1.LiveBadgeResource\x12\x17\n\x0flive_stats_desc\x18\x03 \x01(\t\"1\n\x0bSortContent\x12\x0f\n\x07sort_by\x18\x01 \x01(\x03\x12\x11\n\tsort_name\x18\x02 \x01(\t\"1\n\x0eThreePointItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"W\n\x0eTimeLineEvents\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\ttime_desc\x18\x03 \x01(\t\x12\x11\n\tjump_link\x18\x04 \x01(\t\"\x94\x01\n\x10TimeLineResource\x12\x14\n\x0ctime_line_id\x18\x01 \x01(\x03\x12\x17\n\x0ftime_line_title\x18\x02 \x01(\t\x12?\n\x10time_line_events\x18\x03 \x03(\x0b\x32%.bilibili.app.topic.v1.TimeLineEvents\x12\x10\n\x08has_more\x18\x04 \x01(\x08\"a\n\x0fTopicActivities\x12\x36\n\x08\x61\x63tivity\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicActivity\x12\x16\n\x0e\x61\x63t_list_title\x18\x02 \x01(\t\"_\n\rTopicActivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_name\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x10\n\x08icon_url\x18\x04 \x01(\t\"@\n\x0cTopicCapsule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\"\xe0\x01\n\rTopicCardItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12:\n\x0c\x64ynamic_item\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12;\n\x0e\x66ord_card_item\x18\x03 \x01(\x0b\x32#.bilibili.app.topic.v1.FoldCardItem\x12H\n\x15video_small_card_item\x18\x04 \x01(\x0b\x32).bilibili.app.topic.v1.VideoSmallCardItem\"\xb5\x01\n\rTopicCardList\x12>\n\x10topic_card_items\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicCardItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x42\n\x12topic_sort_by_conf\x18\x04 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicSortByConf\"\xd8\x03\n\x14TopicDetailsAllReply\x12?\n\x10\x64\x65tails_top_info\x18\x01 \x01(\x0b\x32%.bilibili.app.topic.v1.DetailsTopInfo\x12@\n\x10topic_activities\x18\x02 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicActivities\x12=\n\x0ftopic_card_list\x18\x03 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12>\n\x0f\x66unctional_card\x18\x04 \x01(\x0b\x32%.bilibili.app.topic.v1.FunctionalCard\x12\x32\n\tpub_layer\x18\x05 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.PubLayer\x12\x43\n\x12time_line_resource\x18\x06 \x01(\x0b\x32\'.bilibili.app.topic.v1.TimeLineResource\x12\x45\n\x13topic_server_config\x18\x07 \x01(\x0b\x32(.bilibili.app.topic.v1.TopicServerConfig\"\xf9\x01\n\x12TopicDetailsAllReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0f\n\x07sort_by\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cneed_refresh\x18\x07 \x01(\x05\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x1e\n\x16topic_details_ext_mode\x18\t \x01(\x05\"j\n\x15TopicDetailsFoldReply\x12=\n\x0ftopic_card_list\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12\x12\n\nfold_count\x18\x02 \x01(\x03\"\xb9\x01\n\x13TopicDetailsFoldReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0c\x66rom_sort_by\x18\x06 \x01(\x03\"\xf0\x02\n\tTopicInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x0c\n\x04view\x18\x04 \x01(\x03\x12\x0f\n\x07\x64iscuss\x18\x05 \x01(\x03\x12\x0b\n\x03\x66\x61v\x18\x06 \x01(\x03\x12\x10\n\x08\x64ynamics\x18\x07 \x01(\x03\x12\r\n\x05state\x18\x08 \x01(\x05\x12\x10\n\x08jump_url\x18\t \x01(\t\x12\x11\n\tbackcolor\x18\n \x01(\t\x12\x0e\n\x06is_fav\x18\x0b \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x15\n\rcreate_source\x18\r \x01(\x05\x12\x11\n\tshare_pic\x18\x0e \x01(\t\x12\r\n\x05share\x18\x0f \x01(\x03\x12\x0c\n\x04like\x18\x10 \x01(\x03\x12\x11\n\tshare_url\x18\x11 \x01(\t\x12\x0f\n\x07is_like\x18\x12 \x01(\x08\x12\x0c\n\x04type\x18\x13 \x01(\x05\x12\x12\n\nstats_desc\x18\x14 \x01(\t\x12\x18\n\x10\x66ixed_topic_icon\x18\x15 \x01(\t\"\x89\x01\n\x11TopicServerConfig\x12%\n\x1dpub_events_increase_threshold\x18\x01 \x01(\x03\x12+\n#pub_events_hidden_timeout_threshold\x18\x02 \x01(\x03\x12 \n\x18vert_online_refresh_time\x18\x03 \x01(\x03\"L\n\x08TopicSet\x12\x0e\n\x06set_id\x18\x01 \x01(\x03\x12\x10\n\x08set_name\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\xee\x01\n\x14TopicSetDetailsReply\x12\x44\n\x13topic_set_head_info\x18\x01 \x01(\x0b\x32\'.bilibili.app.topic.v1.TopicSetHeadInfo\x12\x34\n\ntopic_info\x18\x02 \x03(\x0b\x32 .bilibili.app.topic.v1.TopicInfo\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x38\n\x08sort_cfg\x18\x05 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicSetSortCfg\"X\n\x12TopicSetDetailsReq\x12\x0e\n\x06set_id\x18\x01 \x01(\x03\x12\x0f\n\x07sort_by\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xd8\x01\n\x10TopicSetHeadInfo\x12\x32\n\ttopic_set\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.TopicSet\x12\x16\n\x0etopic_cnt_text\x18\x02 \x01(\t\x12\x14\n\x0chead_img_url\x18\x03 \x01(\t\x12\x13\n\x0bmission_url\x18\x04 \x01(\t\x12\x14\n\x0cmission_text\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x0e\n\x06is_fav\x18\x07 \x01(\x08\x12\x15\n\ris_first_time\x18\x08 \x01(\x08\"c\n\x0fTopicSetSortCfg\x12\x17\n\x0f\x64\x65\x66\x61ult_sort_by\x18\x01 \x01(\x03\x12\x37\n\x0b\x61ll_sort_by\x18\x02 \x03(\x0b\x32\".bilibili.app.topic.v1.SortContent\"y\n\x0fTopicSortByConf\x12\x17\n\x0f\x64\x65\x66\x61ult_sort_by\x18\x01 \x01(\x03\x12\x37\n\x0b\x61ll_sort_by\x18\x02 \x03(\x0b\x32\".bilibili.app.topic.v1.SortContent\x12\x14\n\x0cshow_sort_by\x18\x03 \x01(\x03\"W\n\x0fTopicThreePoint\x12\x44\n\x15\x64yn_three_point_items\x18\x01 \x03(\x0b\x32%.bilibili.app.topic.v1.ThreePointItem\"\x8f\x01\n\x0bTrafficCard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61se_pic\x18\x04 \x01(\t\x12\x15\n\rbenefit_point\x18\x05 \x01(\t\x12\x11\n\tcard_desc\x18\x06 \x01(\t\x12\x12\n\njump_title\x18\x07 \x01(\t\"B\n\x04User\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tname_desc\x18\x04 \x01(\t\"l\n\rVideoCardBase\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07up_name\x18\x03 \x01(\t\x12\x0c\n\x04play\x18\x04 \x01(\x03\x12\x11\n\tjump_link\x18\x05 \x01(\t\x12\x0b\n\x03\x61id\x18\x06 \x01(\x03\"\xd6\x01\n\x12VideoSmallCardItem\x12=\n\x0fvideo_card_base\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.VideoCardBase\x12\x1d\n\x15\x63over_left_badge_text\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61rd_stat_icon1\x18\x03 \x01(\x03\x12\x17\n\x0f\x63\x61rd_stat_text1\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x61rd_stat_icon2\x18\x05 \x01(\x03\x12\x17\n\x0f\x63\x61rd_stat_text2\x18\x06 \x01(\t*N\n\rTopicCardType\x12\x10\n\x0cILLEGAL_TYPE\x10\x00\x12\x0b\n\x07\x44YNAMIC\x10\x01\x12\x08\n\x04\x46OLD\x10\x02\x12\x14\n\x10VIDEO_SMALL_CARD\x10\x03*7\n\x13TopicDetailsExtMode\x12\x15\n\x11MODE_ILLEGAL_TYPE\x10\x00\x12\t\n\x05STORY\x10\x01\x32\xcb\x02\n\x05Topic\x12i\n\x0fTopicDetailsAll\x12).bilibili.app.topic.v1.TopicDetailsAllReq\x1a+.bilibili.app.topic.v1.TopicDetailsAllReply\x12l\n\x10TopicDetailsFold\x12*.bilibili.app.topic.v1.TopicDetailsFoldReq\x1a,.bilibili.app.topic.v1.TopicDetailsFoldReply\x12i\n\x0fTopicSetDetails\x12).bilibili.app.topic.v1.TopicSetDetailsReq\x1a+.bilibili.app.topic.v1.TopicSetDetailsReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.topic.v1.topic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICCARDTYPE']._serialized_start=6552
  _globals['_TOPICCARDTYPE']._serialized_end=6630
  _globals['_TOPICDETAILSEXTMODE']._serialized_start=6632
  _globals['_TOPICDETAILSEXTMODE']._serialized_end=6687
  _globals['_BUTTONMETA']._serialized_start=184
  _globals['_BUTTONMETA']._serialized_end=224
  _globals['_DETAILSTOPINFO']._serialized_start=227
  _globals['_DETAILSTOPINFO']._serialized_end=658
  _globals['_FOLDCARDITEM']._serialized_start=660
  _globals['_FOLDCARDITEM']._serialized_end=759
  _globals['_FUNCTIONALCARD']._serialized_start=762
  _globals['_FUNCTIONALCARD']._serialized_end=943
  _globals['_GAMECARD']._serialized_start=946
  _globals['_GAMECARD']._serialized_end=1080
  _globals['_INLINEPROGRESSBAR']._serialized_start=1082
  _globals['_INLINEPROGRESSBAR']._serialized_end=1187
  _globals['_LARGECOVERINLINE']._serialized_start=1190
  _globals['_LARGECOVERINLINE']._serialized_end=1759
  _globals['_LIVEBADGERESOURCE']._serialized_start=1762
  _globals['_LIVEBADGERESOURCE']._serialized_end=1972
  _globals['_OPERATIONCARD']._serialized_start=1974
  _globals['_OPERATIONCARD']._serialized_end=2068
  _globals['_OPERATIONCONTENT']._serialized_start=2070
  _globals['_OPERATIONCONTENT']._serialized_end=2150
  _globals['_PUBLAYER']._serialized_start=2153
  _globals['_PUBLAYER']._serialized_end=2288
  _globals['_RELATIONDATA']._serialized_start=2290
  _globals['_RELATIONDATA']._serialized_end=2393
  _globals['_RIGHTTOPLIVEBADGE']._serialized_start=2395
  _globals['_RIGHTTOPLIVEBADGE']._serialized_end=2519
  _globals['_SORTCONTENT']._serialized_start=2521
  _globals['_SORTCONTENT']._serialized_end=2570
  _globals['_THREEPOINTITEM']._serialized_start=2572
  _globals['_THREEPOINTITEM']._serialized_end=2621
  _globals['_TIMELINEEVENTS']._serialized_start=2623
  _globals['_TIMELINEEVENTS']._serialized_end=2710
  _globals['_TIMELINERESOURCE']._serialized_start=2713
  _globals['_TIMELINERESOURCE']._serialized_end=2861
  _globals['_TOPICACTIVITIES']._serialized_start=2863
  _globals['_TOPICACTIVITIES']._serialized_end=2960
  _globals['_TOPICACTIVITY']._serialized_start=2962
  _globals['_TOPICACTIVITY']._serialized_end=3057
  _globals['_TOPICCAPSULE']._serialized_start=3059
  _globals['_TOPICCAPSULE']._serialized_end=3123
  _globals['_TOPICCARDITEM']._serialized_start=3126
  _globals['_TOPICCARDITEM']._serialized_end=3350
  _globals['_TOPICCARDLIST']._serialized_start=3353
  _globals['_TOPICCARDLIST']._serialized_end=3534
  _globals['_TOPICDETAILSALLREPLY']._serialized_start=3537
  _globals['_TOPICDETAILSALLREPLY']._serialized_end=4009
  _globals['_TOPICDETAILSALLREQ']._serialized_start=4012
  _globals['_TOPICDETAILSALLREQ']._serialized_end=4261
  _globals['_TOPICDETAILSFOLDREPLY']._serialized_start=4263
  _globals['_TOPICDETAILSFOLDREPLY']._serialized_end=4369
  _globals['_TOPICDETAILSFOLDREQ']._serialized_start=4372
  _globals['_TOPICDETAILSFOLDREQ']._serialized_end=4557
  _globals['_TOPICINFO']._serialized_start=4560
  _globals['_TOPICINFO']._serialized_end=4928
  _globals['_TOPICSERVERCONFIG']._serialized_start=4931
  _globals['_TOPICSERVERCONFIG']._serialized_end=5068
  _globals['_TOPICSET']._serialized_start=5070
  _globals['_TOPICSET']._serialized_end=5146
  _globals['_TOPICSETDETAILSREPLY']._serialized_start=5149
  _globals['_TOPICSETDETAILSREPLY']._serialized_end=5387
  _globals['_TOPICSETDETAILSREQ']._serialized_start=5389
  _globals['_TOPICSETDETAILSREQ']._serialized_end=5477
  _globals['_TOPICSETHEADINFO']._serialized_start=5480
  _globals['_TOPICSETHEADINFO']._serialized_end=5696
  _globals['_TOPICSETSORTCFG']._serialized_start=5698
  _globals['_TOPICSETSORTCFG']._serialized_end=5797
  _globals['_TOPICSORTBYCONF']._serialized_start=5799
  _globals['_TOPICSORTBYCONF']._serialized_end=5920
  _globals['_TOPICTHREEPOINT']._serialized_start=5922
  _globals['_TOPICTHREEPOINT']._serialized_end=6009
  _globals['_TRAFFICCARD']._serialized_start=6012
  _globals['_TRAFFICCARD']._serialized_end=6155
  _globals['_USER']._serialized_start=6157
  _globals['_USER']._serialized_end=6223
  _globals['_VIDEOCARDBASE']._serialized_start=6225
  _globals['_VIDEOCARDBASE']._serialized_end=6333
  _globals['_VIDEOSMALLCARDITEM']._serialized_start=6336
  _globals['_VIDEOSMALLCARDITEM']._serialized_end=6550
  _globals['_TOPIC']._serialized_start=6690
  _globals['_TOPIC']._serialized_end=7021
# @@protoc_insertion_point(module_scope)
