"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DynamicSelect(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLD_FIELD_NUMBER: builtins.int
    @property
    def fold(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        fold: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fold", b"fold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold", b"fold"]) -> None: ...

global___DynamicSelect = DynamicSelect

@typing_extensions.final
class Exp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def bucket(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int32Value:
        """"""
    def __init__(
        self,
        *,
        id: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        bucket: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int32Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id"]) -> None: ...

global___Exp = Exp

@typing_extensions.final
class ExperimentalConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAG_FIELD_NUMBER: builtins.int
    EXPS_FIELD_NUMBER: builtins.int
    @property
    def flag(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def exps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exp]:
        """"""
    def __init__(
        self,
        *,
        flag: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        exps: collections.abc.Iterable[global___Exp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["flag", b"flag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exps", b"exps", "flag", b"flag"]) -> None: ...

global___ExperimentalConfig = ExperimentalConfig

@typing_extensions.final
class MultipleTusConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_LEFT_FIELD_NUMBER: builtins.int
    DYNAMIC_SELECT_FIELD_NUMBER: builtins.int
    @property
    def top_left(self) -> global___TopLeft:
        """"""
    @property
    def dynamic_select(self) -> global___DynamicSelect:
        """"""
    def __init__(
        self,
        *,
        top_left: global___TopLeft | None = ...,
        dynamic_select: global___DynamicSelect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_select", b"dynamic_select", "top_left", b"top_left"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_select", b"dynamic_select", "top_left", b"top_left"]) -> None: ...

global___MultipleTusConfig = MultipleTusConfig

@typing_extensions.final
class TopLeft(google.protobuf.message.Message):
    """APP首页头像跳转信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    STORY_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    STORY_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    LISTEN_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    LISTEN_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_STORY_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_STORY_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_LISTEN_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_LISTEN_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URL_V2_FIELD_NUMBER: builtins.int
    GOTO_V2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def story_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def story_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def listen_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def listen_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_story_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_story_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_listen_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_listen_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def goto(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def url_v2(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def goto_v2(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def badge(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    def __init__(
        self,
        *,
        url: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        story_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        story_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        listen_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        listen_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_story_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_story_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_listen_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_listen_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        goto: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        url_v2: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        goto_v2: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        badge: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "goto", b"goto", "goto_v2", b"goto_v2", "ios_listen_background_image", b"ios_listen_background_image", "ios_listen_foreground_image", b"ios_listen_foreground_image", "ios_story_background_image", b"ios_story_background_image", "ios_story_foreground_image", b"ios_story_foreground_image", "listen_background_image", b"listen_background_image", "listen_foreground_image", b"listen_foreground_image", "story_background_image", b"story_background_image", "story_foreground_image", b"story_foreground_image", "url", b"url", "url_v2", b"url_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "goto", b"goto", "goto_v2", b"goto_v2", "ios_listen_background_image", b"ios_listen_background_image", "ios_listen_foreground_image", b"ios_listen_foreground_image", "ios_story_background_image", b"ios_story_background_image", "ios_story_foreground_image", b"ios_story_foreground_image", "listen_background_image", b"listen_background_image", "listen_foreground_image", b"listen_foreground_image", "story_background_image", b"story_background_image", "story_foreground_image", b"story_foreground_image", "url", b"url", "url_v2", b"url_v2"]) -> None: ...

global___TopLeft = TopLeft
