"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PGCAnyModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    VIEW_INFO_FIELD_NUMBER: builtins.int
    PLAY_EXT_CONF_FIELD_NUMBER: builtins.int
    PLAY_EXT_INFO_FIELD_NUMBER: builtins.int
    @property
    def business(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayViewBusinessInfo: ...
    @property
    def event(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.Event: ...
    @property
    def view_info(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.ViewInfo: ...
    @property
    def play_ext_conf(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayAbilityExtConf: ...
    @property
    def play_ext_info(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayExtInfo: ...
    def __init__(
        self,
        *,
        business: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayViewBusinessInfo | None = ...,
        event: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.Event | None = ...,
        view_info: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.ViewInfo | None = ...,
        play_ext_conf: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayAbilityExtConf | None = ...,
        play_ext_info: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayExtInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "view_info", b"view_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "view_info", b"view_info"]) -> None: ...

global___PGCAnyModel = PGCAnyModel
