"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AnimateIcon(google.protobuf.message.Message):
    """动画效果"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon文件"""
    json: builtins.str
    """动效json文件"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        json: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "json", b"json"]) -> None: ...

global___AnimateIcon = AnimateIcon

@typing_extensions.final
class EntranceReply(google.protobuf.message.Message):
    """活动入口-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ANIMATE_ICON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """展示图标"""
    name: builtins.str
    """活动名称"""
    url: builtins.str
    """活动跳转链接"""
    @property
    def animate_icon(self) -> global___AnimateIcon:
        """动画效果"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        name: builtins.str = ...,
        url: builtins.str = ...,
        animate_icon: global___AnimateIcon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animate_icon", b"animate_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animate_icon", b"animate_icon", "icon", b"icon", "name", b"name", "url", b"url"]) -> None: ...

global___EntranceReply = EntranceReply

@typing_extensions.final
class EntranceReq(google.protobuf.message.Message):
    """活动入口-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EntranceReq = EntranceReq

@typing_extensions.final
class PrivacyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___PrivacyReply = PrivacyReply

@typing_extensions.final
class PrivacyReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_UID_FIELD_NUMBER: builtins.int
    activity_uid: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_uid", b"activity_uid"]) -> None: ...

global___PrivacyReq = PrivacyReq

@typing_extensions.final
class WindowReply(google.protobuf.message.Message):
    """首页弹窗-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    REPORT_DATA_FIELD_NUMBER: builtins.int
    type: builtins.int
    """弹窗类型
    0:弹窗 1:普通页面
    """
    url: builtins.str
    """跳转链接"""
    report_data: builtins.str
    """上报数据字段"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        url: builtins.str = ...,
        report_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["report_data", b"report_data", "type", b"type", "url", b"url"]) -> None: ...

global___WindowReply = WindowReply

@typing_extensions.final
class WindowReq(google.protobuf.message.Message):
    """首页弹窗-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___WindowReq = WindowReq
