syntax = "proto3";

package bilibili.app.playerunite.ugcanymodel;

message ButtonStyle {
    string text = 1;
    string text_color = 2;
    string bg_color = 3;
    string jump_link = 4;
}

enum PlayLimitCode {
    PLC_UNKNOWN = 0;
    PLC_NOTPAYED = 1;
}

message PlayLimit {
    PlayLimitCode code = 1;
    string message = 2;
    string sub_message = 3;
    ButtonStyle button = 4;
}

message UGCAnyModel {
    PlayLimit play_limit = 1;
}

