# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/search/v2/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.broadcast.message.main import search_pb2 as bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/app/search/v2/search.proto\x12\x16\x62ilibili.app.search.v2\x1a,bilibili/broadcast/message/main/search.proto\"<\n\x11\x43\x61ncelChatTaskReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x02 \x01(\t\"#\n\x13\x43\x61ncelChatTaskReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\"J\n\x10GetChatResultReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x03 \x01(\t\"\xf2\x01\n\rSearchEggInfo\x12\x10\n\x08\x65gg_type\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x15\n\ris_commercial\x18\x03 \x01(\x05\x12\x12\n\nmask_color\x18\x04 \x01(\t\x12\x19\n\x11mask_transparency\x18\x05 \x01(\x03\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0f\n\x07re_type\x18\x07 \x01(\x05\x12\x0e\n\x06re_url\x18\x08 \x01(\t\x12\x10\n\x08re_value\x18\t \x01(\t\x12\x12\n\nshow_count\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x03\x12\x0e\n\x06source\x18\x0c \x01(\x03\x12\x0b\n\x03url\x18\r \x01(\t\"I\n\x0eSearchEggInfos\x12\x37\n\x08\x65gg_info\x18\x01 \x03(\x0b\x32%.bilibili.app.search.v2.SearchEggInfo\"d\n\x0eSearchEggReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0c\n\x04seid\x18\x02 \x01(\t\x12\x36\n\x06result\x18\x03 \x01(\x0b\x32&.bilibili.app.search.v2.SearchEggInfos\"\x0e\n\x0cSearchEggReq\"7\n\x13SubmitChatTaskReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x12\n\nsession_id\x18\x02 \x01(\t\"I\n\x11SubmitChatTaskReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x10\n\x08track_id\x18\x02 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x03 \x01(\t2\x9f\x03\n\x06Search\x12h\n\x0e\x43\x61ncelChatTask\x12).bilibili.app.search.v2.CancelChatTaskReq\x1a+.bilibili.app.search.v2.CancelChatTaskReply\x12\x66\n\rGetChatResult\x12(.bilibili.app.search.v2.GetChatResultReq\x1a+.bilibili.broadcast.message.main.ChatResult\x12Y\n\tSearchEgg\x12$.bilibili.app.search.v2.SearchEggReq\x1a&.bilibili.app.search.v2.SearchEggReply\x12h\n\x0eSubmitChatTask\x12).bilibili.app.search.v2.SubmitChatTaskReq\x1a+.bilibili.app.search.v2.SubmitChatTaskReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.search.v2.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CANCELCHATTASKREQ']._serialized_start=109
  _globals['_CANCELCHATTASKREQ']._serialized_end=169
  _globals['_CANCELCHATTASKREPLY']._serialized_start=171
  _globals['_CANCELCHATTASKREPLY']._serialized_end=206
  _globals['_GETCHATRESULTREQ']._serialized_start=208
  _globals['_GETCHATRESULTREQ']._serialized_end=282
  _globals['_SEARCHEGGINFO']._serialized_start=285
  _globals['_SEARCHEGGINFO']._serialized_end=527
  _globals['_SEARCHEGGINFOS']._serialized_start=529
  _globals['_SEARCHEGGINFOS']._serialized_end=602
  _globals['_SEARCHEGGREPLY']._serialized_start=604
  _globals['_SEARCHEGGREPLY']._serialized_end=704
  _globals['_SEARCHEGGREQ']._serialized_start=706
  _globals['_SEARCHEGGREQ']._serialized_end=720
  _globals['_SUBMITCHATTASKREPLY']._serialized_start=722
  _globals['_SUBMITCHATTASKREPLY']._serialized_end=777
  _globals['_SUBMITCHATTASKREQ']._serialized_start=779
  _globals['_SUBMITCHATTASKREQ']._serialized_end=852
  _globals['_SEARCH']._serialized_start=855
  _globals['_SEARCH']._serialized_end=1270
# @@protoc_insertion_point(module_scope)
