"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class OtherSettingsConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WATERMARK_TYPE_FIELD_NUMBER: builtins.int
    WEB_IMAGE_QUALITY_TYPE_FIELD_NUMBER: builtins.int
    ENABLE_READ_PASTEBOARD_FIELD_NUMBER: builtins.int
    PASTE_AUTO_JUMP_FIELD_NUMBER: builtins.int
    MINI_SCREEN_PLAY_WHEN_BACK_FIELD_NUMBER: builtins.int
    ENABLE_RESUME_PLAYING_FIELD_NUMBER: builtins.int
    ENABLE_WIFI_AUTO_UPDATE_FIELD_NUMBER: builtins.int
    ENABLE_GUIDE_SCREENSHOT_SHARE_FIELD_NUMBER: builtins.int
    @property
    def watermark_type(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def web_image_quality_type(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def enable_read_pasteboard(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def paste_auto_jump(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def mini_screen_play_when_back(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_resume_playing(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_wifi_auto_update(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_guide_screenshot_share(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        watermark_type: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        web_image_quality_type: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        enable_read_pasteboard: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        paste_auto_jump: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        mini_screen_play_when_back: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_resume_playing: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_wifi_auto_update: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_guide_screenshot_share: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_guide_screenshot_share", b"enable_guide_screenshot_share", "enable_read_pasteboard", b"enable_read_pasteboard", "enable_resume_playing", b"enable_resume_playing", "enable_wifi_auto_update", b"enable_wifi_auto_update", "mini_screen_play_when_back", b"mini_screen_play_when_back", "paste_auto_jump", b"paste_auto_jump", "watermark_type", b"watermark_type", "web_image_quality_type", b"web_image_quality_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_guide_screenshot_share", b"enable_guide_screenshot_share", "enable_read_pasteboard", b"enable_read_pasteboard", "enable_resume_playing", b"enable_resume_playing", "enable_wifi_auto_update", b"enable_wifi_auto_update", "mini_screen_play_when_back", b"mini_screen_play_when_back", "paste_auto_jump", b"paste_auto_jump", "watermark_type", b"watermark_type", "web_image_quality_type", b"web_image_quality_type"]) -> None: ...

global___OtherSettingsConfig = OtherSettingsConfig
