# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/relation/interfaces/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/relation/interfaces/api.proto\x12\x1e\x62ilibili.relation.interface.v1\"+\n\x0b\x41tSearchReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"G\n\rAtSearchReply\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.relation.interface.v1.AtGroup\"h\n\x07\x41tGroup\x12\x12\n\ngroup_type\x18\x01 \x01(\x05\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x35\n\x05items\x18\x03 \x03(\x0b\x32&.bilibili.relation.interface.v1.AtItem\"]\n\x06\x41tItem\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x1c\n\x14official_verify_type\x18\x05 \x01(\x05\x32{\n\x11RelationInterface\x12\x66\n\x08\x41tSearch\x12+.bilibili.relation.interface.v1.AtSearchReq\x1a-.bilibili.relation.interface.v1.AtSearchReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.relation.interfaces.api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ATSEARCHREQ']._serialized_start=74
  _globals['_ATSEARCHREQ']._serialized_end=117
  _globals['_ATSEARCHREPLY']._serialized_start=119
  _globals['_ATSEARCHREPLY']._serialized_end=190
  _globals['_ATGROUP']._serialized_start=192
  _globals['_ATGROUP']._serialized_end=296
  _globals['_ATITEM']._serialized_start=298
  _globals['_ATITEM']._serialized_end=391
  _globals['_RELATIONINTERFACE']._serialized_start=393
  _globals['_RELATIONINTERFACE']._serialized_end=516
# @@protoc_insertion_point(module_scope)
