"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CheckAccountReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_NEW_FIELD_NUMBER: builtins.int
    is_new: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_new: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_new", b"is_new"]) -> None: ...

global___CheckAccountReply = CheckAccountReply

@typing_extensions.final
class CheckAccountReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    PERIODS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    periods: builtins.str
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        periods: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["periods", b"periods", "uid", b"uid"]) -> None: ...

global___CheckAccountReq = CheckAccountReq

@typing_extensions.final
class FavoriteTabItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    uri: builtins.str
    """"""
    type: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type", "uri", b"uri"]) -> None: ...

global___FavoriteTabItem = FavoriteTabItem

@typing_extensions.final
class FavoriteTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavoriteTabItem]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___FavoriteTabItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___FavoriteTabReply = FavoriteTabReply

@typing_extensions.final
class FavoriteTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FavoriteTabReq = FavoriteTabReq
