"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _WHRatio:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WHRatioEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WHRatio.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    W_H_RATIO_1_1: _WHRatio.ValueType  # 0
    W_H_RATIO_16_9: _WHRatio.ValueType  # 1
    W_H_RATIO_3_4: _WHRatio.ValueType  # 2
    W_H_RATIO_CUSTOM: _WHRatio.ValueType  # 3

class WHRatio(_WHRatio, metaclass=_WHRatioEnumTypeWrapper):
    """"""

W_H_RATIO_1_1: WHRatio.ValueType  # 0
W_H_RATIO_16_9: WHRatio.ValueType  # 1
W_H_RATIO_3_4: WHRatio.ValueType  # 2
W_H_RATIO_CUSTOM: WHRatio.ValueType  # 3
global___WHRatio = WHRatio

@typing_extensions.final
class ItemWHRatio(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RATIO_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ratio: builtins.int
    """"""
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    def __init__(
        self,
        *,
        ratio: builtins.int = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "ratio", b"ratio", "width", b"width"]) -> None: ...

global___ItemWHRatio = ItemWHRatio
