# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/other.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/app/distribution/setting/other.proto\x12\'bilibili.app.distribution.setting.other\x1a/bilibili/app/distribution/v1/distribution.proto\"\xdb\x04\n\x13OtherSettingsConfig\x12@\n\x0ewatermark_type\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12H\n\x16web_image_quality_type\x18\x02 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12G\n\x16\x65nable_read_pasteboard\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12@\n\x0fpaste_auto_jump\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12K\n\x1amini_screen_play_when_back\x18\x05 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x46\n\x15\x65nable_resume_playing\x18\x06 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12H\n\x17\x65nable_wifi_auto_update\x18\x07 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12N\n\x1d\x65nable_guide_screenshot_share\x18\x08 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.other_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OTHERSETTINGSCONFIG']._serialized_start=140
  _globals['_OTHERSETTINGSCONFIG']._serialized_end=743
# @@protoc_insertion_point(module_scope)
