"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ArcType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ArcTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ArcType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ArcType.ValueType  # 0
    """"""
    PAGES: _ArcType.ValueType  # 1
    """"""
    SERIES: _ArcType.ValueType  # 2
    """"""
    POSITIVE: _ArcType.ValueType  # 3
    """"""
    SECTION: _ArcType.ValueType  # 4
    """"""
    RELATE: _ArcType.ValueType  # 5
    """"""
    PUGV: _ArcType.ValueType  # 6
    """"""

class ArcType(_ArcType, metaclass=_ArcTypeEnumTypeWrapper):
    """ 业务类型"""

UNKNOWN: ArcType.ValueType  # 0
""""""
PAGES: ArcType.ValueType  # 1
""""""
SERIES: ArcType.ValueType  # 2
""""""
POSITIVE: ArcType.ValueType  # 3
""""""
SECTION: ArcType.ValueType  # 4
""""""
RELATE: ArcType.ValueType  # 5
""""""
PUGV: ArcType.ValueType  # 6
""""""
global___ArcType = ArcType

class _BizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BizTypeNone: _BizType.ValueType  # 0
    """"""
    BizTypeFollowVideo: _BizType.ValueType  # 1
    """"""
    BizTypeReserveActivity: _BizType.ValueType  # 2
    """"""
    BizTypeJumpLink: _BizType.ValueType  # 3
    """"""
    BizTypeFavSeason: _BizType.ValueType  # 4
    """"""
    BizTypeReserveGame: _BizType.ValueType  # 5
    """"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """"""

BizTypeNone: BizType.ValueType  # 0
""""""
BizTypeFollowVideo: BizType.ValueType  # 1
""""""
BizTypeReserveActivity: BizType.ValueType  # 2
""""""
BizTypeJumpLink: BizType.ValueType  # 3
""""""
BizTypeFavSeason: BizType.ValueType  # 4
""""""
BizTypeReserveGame: BizType.ValueType  # 5
""""""
global___BizType = BizType

class _MaterialBizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaterialBizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialBizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NONE: _MaterialBizType.ValueType  # 0
    """"""
    ACTIVITY: _MaterialBizType.ValueType  # 1
    """"""
    BGM: _MaterialBizType.ValueType  # 2
    """"""
    EFFECT: _MaterialBizType.ValueType  # 3
    """"""
    SHOOT_SAME: _MaterialBizType.ValueType  # 4
    """"""
    SHOOT_TOGETHER: _MaterialBizType.ValueType  # 5
    """"""
    ACTIVITY_ICON: _MaterialBizType.ValueType  # 6
    """"""
    NEW_BGM: _MaterialBizType.ValueType  # 7
    """"""

class MaterialBizType(_MaterialBizType, metaclass=_MaterialBizTypeEnumTypeWrapper):
    """素材类型"""

NONE: MaterialBizType.ValueType  # 0
""""""
ACTIVITY: MaterialBizType.ValueType  # 1
""""""
BGM: MaterialBizType.ValueType  # 2
""""""
EFFECT: MaterialBizType.ValueType  # 3
""""""
SHOOT_SAME: MaterialBizType.ValueType  # 4
""""""
SHOOT_TOGETHER: MaterialBizType.ValueType  # 5
""""""
ACTIVITY_ICON: MaterialBizType.ValueType  # 6
""""""
NEW_BGM: MaterialBizType.ValueType  # 7
""""""
global___MaterialBizType = MaterialBizType

class _MaterialSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaterialSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _MaterialSource.ValueType  # 0
    """"""
    BIJIAN: _MaterialSource.ValueType  # 1
    """必剪素材"""

class MaterialSource(_MaterialSource, metaclass=_MaterialSourceEnumTypeWrapper):
    """素材来源"""

DEFAULT: MaterialSource.ValueType  # 0
""""""
BIJIAN: MaterialSource.ValueType  # 1
"""必剪素材"""
global___MaterialSource = MaterialSource

class _PageCategory:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PageCategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PageCategory.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMMON_PAGE: _PageCategory.ValueType  # 0
    """"""
    ACTIVITY_PAGE: _PageCategory.ValueType  # 1
    """"""

class PageCategory(_PageCategory, metaclass=_PageCategoryEnumTypeWrapper):
    """"""

COMMON_PAGE: PageCategory.ValueType  # 0
""""""
ACTIVITY_PAGE: PageCategory.ValueType  # 1
""""""
global___PageCategory = PageCategory

class _PageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    H5: _PageType.ValueType  # 0
    """H5页面(Webview)"""
    NA: _PageType.ValueType  # 1
    """原生页面(native)"""

class PageType(_PageType, metaclass=_PageTypeEnumTypeWrapper):
    """页面类型"""

H5: PageType.ValueType  # 0
"""H5页面(Webview)"""
NA: PageType.ValueType  # 1
"""原生页面(native)"""
global___PageType = PageType

class _SelectionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SelectionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SelectionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LONGTITLE: _SelectionType.ValueType  # 0
    """"""
    SHORTTITLE: _SelectionType.ValueType  # 1
    """"""

class SelectionType(_SelectionType, metaclass=_SelectionTypeEnumTypeWrapper):
    """"""

LONGTITLE: SelectionType.ValueType  # 0
""""""
SHORTTITLE: SelectionType.ValueType  # 1
""""""
global___SelectionType = SelectionType

class _UnionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UGC: _UnionType.ValueType  # 0
    """"""
    OGV: _UnionType.ValueType  # 1
    """"""

class UnionType(_UnionType, metaclass=_UnionTypeEnumTypeWrapper):
    """"""

UGC: UnionType.ValueType  # 0
""""""
OGV: UnionType.ValueType  # 1
""""""
global___UnionType = UnionType

@typing_extensions.final
class AttentionCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TIME_FIELD_NUMBER: builtins.int
    @property
    def show_time(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShowTime]:
        """"""
    def __init__(
        self,
        *,
        show_time: collections.abc.Iterable[global___ShowTime] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_time", b"show_time"]) -> None: ...

global___AttentionCard = AttentionCard

@typing_extensions.final
class BadgeType(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    border_color: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___BadgeType = BadgeType

@typing_extensions.final
class BizFollowVideoParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___BizFollowVideoParam = BizFollowVideoParam

@typing_extensions.final
class BizJumpLinkParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___BizJumpLinkParam = BizJumpLinkParam

@typing_extensions.final
class BizReserveActivityParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""
    type: builtins.str
    """"""
    oid: builtins.int
    """"""
    reserve_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        type: builtins.str = ...,
        oid: builtins.int = ...,
        reserve_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "from", b"from", "oid", b"oid", "reserve_id", b"reserve_id", "type", b"type"]) -> None: ...

global___BizReserveActivityParam = BizReserveActivityParam

@typing_extensions.final
class BizReserveGameParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAME_ID_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        game_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_id", b"game_id"]) -> None: ...

global___BizReserveGameParam = BizReserveGameParam

@typing_extensions.final
class Chronos(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    md5: builtins.str
    """"""
    file: builtins.str
    """"""
    sign: builtins.str
    """"""
    def __init__(
        self,
        *,
        md5: builtins.str = ...,
        file: builtins.str = ...,
        sign: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "md5", b"md5", "sign", b"sign"]) -> None: ...

global___Chronos = Chronos

@typing_extensions.final
class ChronosParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    engine_version: builtins.str
    """"""
    message_protocol: builtins.str
    """"""
    service_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        engine_version: builtins.str = ...,
        message_protocol: builtins.str = ...,
        service_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["engine_version", b"engine_version", "message_protocol", b"message_protocol", "service_key", b"service_key"]) -> None: ...

global___ChronosParam = ChronosParam

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    oid: builtins.int
    """"""
    mid: builtins.int
    """"""
    command: builtins.str
    """"""
    content: builtins.str
    """"""
    progress: builtins.int
    """"""
    ctime: builtins.str
    """"""
    mtime: builtins.str
    """"""
    extra: builtins.str
    """"""
    id_str: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        id_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "id_str", b"id_str", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress"]) -> None: ...

global___CommandDm = CommandDm

@typing_extensions.final
class ContractCard(google.protobuf.message.Message):
    """视频播放时弹出的卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_PROGRESS_FIELD_NUMBER: builtins.int
    DISPLAY_ACCURACY_FIELD_NUMBER: builtins.int
    DISPLAY_DURATION_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    IS_FOLLOW_DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLLOW_DISPLAY_END_DURATION_FIELD_NUMBER: builtins.int
    IS_PLAY_DISPLAY_FIELD_NUMBER: builtins.int
    IS_INTERACT_DISPLAY_FIELD_NUMBER: builtins.int
    display_progress: builtins.float
    """在第几秒弹出"""
    display_accuracy: builtins.int
    """"""
    display_duration: builtins.int
    """弹出后停留的时间"""
    show_mode: builtins.int
    """展示方式, 暂未知对应关系"""
    page_type: builtins.int
    """页面类型, 暂未知对应关系"""
    @property
    def upper(self) -> global___UpperInfos:
        """"""
    is_follow_display: builtins.int
    """"""
    @property
    def text(self) -> global___ContractText:
        """卡片的文字说明信息"""
    follow_display_end_duration: builtins.int
    """"""
    is_play_display: builtins.int
    """"""
    is_interact_display: builtins.int
    """"""
    def __init__(
        self,
        *,
        display_progress: builtins.float = ...,
        display_accuracy: builtins.int = ...,
        display_duration: builtins.int = ...,
        show_mode: builtins.int = ...,
        page_type: builtins.int = ...,
        upper: global___UpperInfos | None = ...,
        is_follow_display: builtins.int = ...,
        text: global___ContractText | None = ...,
        follow_display_end_duration: builtins.int = ...,
        is_play_display: builtins.int = ...,
        is_interact_display: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text", "upper", b"upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_accuracy", b"display_accuracy", "display_duration", b"display_duration", "display_progress", b"display_progress", "follow_display_end_duration", b"follow_display_end_duration", "is_follow_display", b"is_follow_display", "is_interact_display", b"is_interact_display", "is_play_display", b"is_play_display", "page_type", b"page_type", "show_mode", b"show_mode", "text", b"text", "upper", b"upper"]) -> None: ...

global___ContractCard = ContractCard

@typing_extensions.final
class ContractText(google.protobuf.message.Message):
    """视频播放时弹出的卡片的文字说明信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    INLINE_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    inline_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        inline_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_title", b"inline_title", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___ContractText = ContractText

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    rotate: builtins.int
    """"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class DmResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_DMS_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    CARDS_FIELD_NUMBER: builtins.int
    @property
    def command_dms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """"""
    @property
    def attention(self) -> global___AttentionCard:
        """"""
    @property
    def cards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCard]:
        """"""
    def __init__(
        self,
        *,
        command_dms: collections.abc.Iterable[global___CommandDm] | None = ...,
        attention: global___AttentionCard | None = ...,
        cards: collections.abc.Iterable[global___OperationCard] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attention", b"attention"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "cards", b"cards", "command_dms", b"command_dms"]) -> None: ...

global___DmResource = DmResource

@typing_extensions.final
class Material(google.protobuf.message.Message):
    """素材详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    STATIC_ICON_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_PIC_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    type: global___MaterialBizType.ValueType
    """"""
    param: builtins.str
    """"""
    static_icon: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_pic: builtins.str
    """"""
    jump_type: builtins.int
    """"""
    page_type: global___PageType.ValueType
    """"""
    need_login: builtins.bool
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        url: builtins.str = ...,
        type: global___MaterialBizType.ValueType = ...,
        param: builtins.str = ...,
        static_icon: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_pic: builtins.str = ...,
        jump_type: builtins.int = ...,
        page_type: global___PageType.ValueType = ...,
        need_login: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_pic", b"bg_pic", "icon", b"icon", "jump_type", b"jump_type", "need_login", b"need_login", "page_type", b"page_type", "param", b"param", "static_icon", b"static_icon", "text", b"text", "type", b"type", "url", b"url"]) -> None: ...

global___Material = Material

@typing_extensions.final
class OperationCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    FOLLOW_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    JUMP_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    to: builtins.int
    """"""
    status: builtins.bool
    """"""
    biz_type: global___BizType.ValueType
    """"""
    @property
    def content(self) -> global___OperationCardContent:
        """"""
    @property
    def follow(self) -> global___BizFollowVideoParam:
        """"""
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """"""
    @property
    def jump(self) -> global___BizJumpLinkParam:
        """"""
    @property
    def game(self) -> global___BizReserveGameParam:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        to: builtins.int = ...,
        status: builtins.bool = ...,
        biz_type: global___BizType.ValueType = ...,
        content: global___OperationCardContent | None = ...,
        follow: global___BizFollowVideoParam | None = ...,
        reserve: global___BizReserveActivityParam | None = ...,
        jump: global___BizJumpLinkParam | None = ...,
        game: global___BizReserveGameParam | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "follow", b"follow", "game", b"game", "jump", b"jump", "reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "content", b"content", "follow", b"follow", "from", b"from", "game", b"game", "id", b"id", "jump", b"jump", "reserve", b"reserve", "status", b"status", "to", b"to"]) -> None: ...

global___OperationCard = OperationCard

@typing_extensions.final
class OperationCardContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SHOW_SELECTED_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    icon: builtins.str
    """"""
    button_title: builtins.str
    """"""
    button_selected_title: builtins.str
    """"""
    show_selected: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        icon: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        show_selected: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "icon", b"icon", "show_selected", b"show_selected", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___OperationCardContent = OperationCardContent

@typing_extensions.final
class PlayStrategy(google.protobuf.message.Message):
    """播放策略"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRATEGIES_FIELD_NUMBER: builtins.int
    RECOMMEND_SHOW_STRATEGY_FIELD_NUMBER: builtins.int
    AUTO_PLAY_TOAST_FIELD_NUMBER: builtins.int
    @property
    def strategies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    recommend_show_strategy: builtins.int
    """"""
    auto_play_toast: builtins.str
    """自动播放时的提示语"""
    def __init__(
        self,
        *,
        strategies: collections.abc.Iterable[builtins.str] | None = ...,
        recommend_show_strategy: builtins.int = ...,
        auto_play_toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_play_toast", b"auto_play_toast", "recommend_show_strategy", b"recommend_show_strategy", "strategies", b"strategies"]) -> None: ...

global___PlayStrategy = PlayStrategy

@typing_extensions.final
class PointMaterial(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    MATERIAL_SOURCE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    material_source: global___MaterialSource.ValueType
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        material_source: global___MaterialSource.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_source", b"material_source", "url", b"url"]) -> None: ...

global___PointMaterial = PointMaterial

@typing_extensions.final
class Selection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    ARC_TYPE_FIELD_NUMBER: builtins.int
    SELECTION_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SelectionItem]:
        """"""
    arc_type: global___ArcType.ValueType
    """"""
    selection_type: global___SelectionType.ValueType
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        item: collections.abc.Iterable[global___SelectionItem] | None = ...,
        arc_type: global___ArcType.ValueType = ...,
        selection_type: global___SelectionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_type", b"arc_type", "item", b"item", "selection_type", b"selection_type", "title", b"title"]) -> None: ...

global___Selection = Selection

@typing_extensions.final
class SelectionItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    BADGE_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LONG_TITLE_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    @property
    def badge_type(self) -> global___BadgeType:
        """"""
    title: builtins.str
    """"""
    long_title: builtins.str
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        badge_type: global___BadgeType | None = ...,
        title: builtins.str = ...,
        long_title: builtins.str = ...,
        dimension: global___Dimension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_type", b"badge_type", "dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "badge_type", b"badge_type", "cid", b"cid", "dimension", b"dimension", "long_title", b"long_title", "title", b"title"]) -> None: ...

global___SelectionItem = SelectionItem

@typing_extensions.final
class SelectionModule(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTION_FIELD_NUMBER: builtins.int
    SERIAL_SEASON_FIELD_NUMBER: builtins.int
    PLAY_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def selection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Selection]:
        """"""
    @property
    def serial_season(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SerialSeason]:
        """"""
    @property
    def play_strategy(self) -> global___PlayStrategy:
        """"""
    def __init__(
        self,
        *,
        selection: collections.abc.Iterable[global___Selection] | None = ...,
        serial_season: collections.abc.Iterable[global___SerialSeason] | None = ...,
        play_strategy: global___PlayStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_strategy", b"play_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_strategy", b"play_strategy", "selection", b"selection", "serial_season", b"serial_season"]) -> None: ...

global___SelectionModule = SelectionModule

@typing_extensions.final
class SerialSeason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TITLE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    season_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        season_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id", "season_title", b"season_title"]) -> None: ...

global___SerialSeason = SerialSeason

@typing_extensions.final
class ShowTime(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    POS_X_FIELD_NUMBER: builtins.int
    POS_Y_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    pos_x: builtins.float
    """"""
    pos_y: builtins.float
    """"""
    def __init__(
        self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        pos_x: builtins.float = ...,
        pos_y: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "pos_x", b"pos_x", "pos_y", b"pos_y", "start_time", b"start_time"]) -> None: ...

global___ShowTime = ShowTime

@typing_extensions.final
class UpperInfos(google.protobuf.message.Message):
    """UP主信息(可是Upper这个... 程序员英文不过关吧? )"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FANS_COUNT_FIELD_NUMBER: builtins.int
    ARC_COUNT_LAST_HALF_YEAR_FIELD_NUMBER: builtins.int
    FIRST_UP_DATES_FIELD_NUMBER: builtins.int
    TOTAL_PLAY_COUNT_FIELD_NUMBER: builtins.int
    fans_count: builtins.int
    """粉丝数"""
    arc_count_last_half_year: builtins.int
    """过去半年内的稿件数"""
    first_up_dates: builtins.int
    """"""
    total_play_count: builtins.int
    """UP稿件总播放数"""
    def __init__(
        self,
        *,
        fans_count: builtins.int = ...,
        arc_count_last_half_year: builtins.int = ...,
        first_up_dates: builtins.int = ...,
        total_play_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count_last_half_year", b"arc_count_last_half_year", "fans_count", b"fans_count", "first_up_dates", b"first_up_dates", "total_play_count", b"total_play_count"]) -> None: ...

global___UpperInfos = UpperInfos

@typing_extensions.final
class VideoGuide(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIAL_FIELD_NUMBER: builtins.int
    VIDEO_POINT_FIELD_NUMBER: builtins.int
    CONTRACT_CARD_FIELD_NUMBER: builtins.int
    @property
    def material(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Material]:
        """"""
    @property
    def video_point(self) -> global___VideoViewPoint:
        """"""
    @property
    def contract_card(self) -> global___ContractCard:
        """"""
    def __init__(
        self,
        *,
        material: collections.abc.Iterable[global___Material] | None = ...,
        video_point: global___VideoViewPoint | None = ...,
        contract_card: global___ContractCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card", "video_point", b"video_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card", "material", b"material", "video_point", b"video_point"]) -> None: ...

global___VideoGuide = VideoGuide

@typing_extensions.final
class VideoPoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LOGO_URL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    to: builtins.int
    """"""
    content: builtins.str
    """"""
    cover: builtins.str
    """"""
    logo_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        to: builtins.int = ...,
        content: builtins.str = ...,
        cover: builtins.str = ...,
        logo_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "cover", b"cover", "from", b"from", "logo_url", b"logo_url", "to", b"to", "type", b"type"]) -> None: ...

global___VideoPoint = VideoPoint

@typing_extensions.final
class VideoShot(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PV_DATA_FIELD_NUMBER: builtins.int
    IMG_X_LEN_FIELD_NUMBER: builtins.int
    IMD_X_SIZE_FIELD_NUMBER: builtins.int
    IMG_Y_LEN_FIELD_NUMBER: builtins.int
    IMG_Y_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    pv_data: builtins.str
    """"""
    img_x_len: builtins.int
    """"""
    imd_x_size: builtins.int
    """"""
    img_y_len: builtins.int
    """"""
    img_y_size: builtins.int
    """"""
    @property
    def image(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        pv_data: builtins.str = ...,
        img_x_len: builtins.int = ...,
        imd_x_size: builtins.int = ...,
        img_y_len: builtins.int = ...,
        img_y_size: builtins.int = ...,
        image: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "imd_x_size", b"imd_x_size", "img_x_len", b"img_x_len", "img_y_len", b"img_y_len", "img_y_size", b"img_y_size", "pv_data", b"pv_data"]) -> None: ...

global___VideoShot = VideoShot

@typing_extensions.final
class VideoViewPoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POINTS_FIELD_NUMBER: builtins.int
    POINT_MATERIAL_FIELD_NUMBER: builtins.int
    POINT_PERMANENT_FIELD_NUMBER: builtins.int
    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoPoint]:
        """"""
    @property
    def point_material(self) -> global___PointMaterial:
        """"""
    point_permanent: builtins.bool
    """"""
    def __init__(
        self,
        *,
        points: collections.abc.Iterable[global___VideoPoint] | None = ...,
        point_material: global___PointMaterial | None = ...,
        point_permanent: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["point_material", b"point_material"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["point_material", b"point_material", "point_permanent", b"point_permanent", "points", b"points"]) -> None: ...

global___VideoViewPoint = VideoViewPoint

@typing_extensions.final
class ViewBase(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNION_TYPE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    union_type: global___UnionType.ValueType
    """"""
    page_type: global___PageType.ValueType
    """"""
    def __init__(
        self,
        *,
        union_type: global___UnionType.ValueType = ...,
        page_type: global___PageType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_type", b"page_type", "union_type", b"union_type"]) -> None: ...

global___ViewBase = ViewBase

@typing_extensions.final
class ViewProgressReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    CHRONOS_PARAM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    @property
    def chronos_param(self) -> global___ChronosParam:
        """"""
    type: global___UnionType.ValueType
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        up_mid: builtins.int = ...,
        chronos_param: global___ChronosParam | None = ...,
        type: global___UnionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chronos_param", b"chronos_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "chronos_param", b"chronos_param", "cid", b"cid", "type", b"type", "up_mid", b"up_mid"]) -> None: ...

global___ViewProgressReq = ViewProgressReq

@typing_extensions.final
class ViewProgressReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_GUIDE_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    ARC_SHOT_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    @property
    def video_guide(self) -> global___VideoGuide:
        """"""
    @property
    def chronos(self) -> global___Chronos:
        """"""
    @property
    def arc_shot(self) -> global___VideoShot:
        """"""
    @property
    def dm(self) -> global___DmResource:
        """"""
    def __init__(
        self,
        *,
        video_guide: global___VideoGuide | None = ...,
        chronos: global___Chronos | None = ...,
        arc_shot: global___VideoShot | None = ...,
        dm: global___DmResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "chronos", b"chronos", "dm", b"dm", "video_guide", b"video_guide"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "chronos", b"chronos", "dm", b"dm", "video_guide", b"video_guide"]) -> None: ...

global___ViewProgressReply = ViewProgressReply

@typing_extensions.final
class ViewReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    EXTRA_CONTENT_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    session_id: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    track_id: builtins.str
    """"""
    @property
    def extra_content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        session_id: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        track_id: builtins.str = ...,
        extra_content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "extra_content", b"extra_content", "from", b"from", "from_spmid", b"from_spmid", "player_args", b"player_args", "session_id", b"session_id", "spmid", b"spmid", "track_id", b"track_id"]) -> None: ...

global___ViewReq = ViewReq

@typing_extensions.final
class ViewReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_BASE_FIELD_NUMBER: builtins.int
    SELECTION_MODULE_FIELD_NUMBER: builtins.int
    SUPPLEMENT_FIELD_NUMBER: builtins.int
    @property
    def view_base(self) -> global___ViewBase:
        """"""
    @property
    def selection_module(self) -> global___SelectionModule:
        """"""
    @property
    def supplement(self) -> google.protobuf.any_pb2.Any:
        """使用 pgcanymodel / ugcanymodel 进行proto any转换成对应业务码结构体"""
    def __init__(
        self,
        *,
        view_base: global___ViewBase | None = ...,
        selection_module: global___SelectionModule | None = ...,
        supplement: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["selection_module", b"selection_module", "supplement", b"supplement", "view_base", b"view_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["selection_module", b"selection_module", "supplement", b"supplement", "view_base", b"view_base"]) -> None: ...

global___ViewReply = ViewReply
