# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/card/v1/ad.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62ilibili/app/card/v1/ad.proto\x12\x14\x62ilibili.app.card.v1\"\xdd\x02\n\x06\x41\x64Info\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\x15\n\rcreative_type\x18\x02 \x01(\x05\x12\x11\n\tcard_type\x18\x03 \x01(\x05\x12?\n\x10\x63reative_content\x18\x04 \x01(\x0b\x32%.bilibili.app.card.v1.CreativeContent\x12\r\n\x05\x61\x64_cb\x18\x05 \x01(\t\x12\x10\n\x08resource\x18\x06 \x01(\x03\x12\x0e\n\x06source\x18\x07 \x01(\x05\x12\x12\n\nrequest_id\x18\x08 \x01(\t\x12\r\n\x05is_ad\x18\t \x01(\x08\x12\x0f\n\x07\x63m_mark\x18\n \x01(\x03\x12\r\n\x05index\x18\x0b \x01(\x05\x12\x11\n\tis_ad_loc\x18\x0c \x01(\x08\x12\x12\n\ncard_index\x18\r \x01(\x05\x12\x11\n\tclient_ip\x18\x0e \x01(\t\x12\r\n\x05\x65xtra\x18\x0f \x01(\x0c\x12\x16\n\x0e\x63reative_style\x18\x10 \x01(\x05\"\xd3\x01\n\x0f\x43reativeContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08video_id\x18\x03 \x01(\x03\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x11\n\timage_md5\x18\x06 \x01(\t\x12\x0f\n\x07log_url\x18\x07 \x01(\t\x12\x0f\n\x07log_md5\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x11\n\tclick_url\x18\n \x01(\t\x12\x10\n\x08show_url\x18\x0b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.card.v1.ad_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADINFO']._serialized_start=56
  _globals['_ADINFO']._serialized_end=405
  _globals['_CREATIVECONTENT']._serialized_start=408
  _globals['_CREATIVECONTENT']._serialized_end=619
# @@protoc_insertion_point(module_scope)
