"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CancelChatTaskReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    FROM_SOURCE_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """"""
    from_source: builtins.str
    """"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        from_source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_source", b"from_source", "session_id", b"session_id"]) -> None: ...

global___CancelChatTaskReq = CancelChatTaskReq

@typing_extensions.final
class CancelChatTaskReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code"]) -> None: ...

global___CancelChatTaskReply = CancelChatTaskReply

@typing_extensions.final
class GetChatResultReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    FROM_SOURCE_FIELD_NUMBER: builtins.int
    query: builtins.str
    """"""
    session_id: builtins.str
    """"""
    from_source: builtins.str
    """"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
        session_id: builtins.str = ...,
        from_source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_source", b"from_source", "query", b"query", "session_id", b"session_id"]) -> None: ...

global___GetChatResultReq = GetChatResultReq

@typing_extensions.final
class SearchEggInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EGG_TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_COMMERCIAL_FIELD_NUMBER: builtins.int
    MASK_COLOR_FIELD_NUMBER: builtins.int
    MASK_TRANSPARENCY_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    RE_TYPE_FIELD_NUMBER: builtins.int
    RE_URL_FIELD_NUMBER: builtins.int
    RE_VALUE_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    egg_type: builtins.int
    """"""
    id: builtins.int
    """"""
    is_commercial: builtins.int
    """"""
    mask_color: builtins.str
    """"""
    mask_transparency: builtins.int
    """"""
    md5: builtins.str
    """"""
    re_type: builtins.int
    """"""
    re_url: builtins.str
    """"""
    re_value: builtins.str
    """"""
    show_count: builtins.int
    """"""
    size: builtins.int
    """"""
    source: builtins.int
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        egg_type: builtins.int = ...,
        id: builtins.int = ...,
        is_commercial: builtins.int = ...,
        mask_color: builtins.str = ...,
        mask_transparency: builtins.int = ...,
        md5: builtins.str = ...,
        re_type: builtins.int = ...,
        re_url: builtins.str = ...,
        re_value: builtins.str = ...,
        show_count: builtins.int = ...,
        size: builtins.int = ...,
        source: builtins.int = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["egg_type", b"egg_type", "id", b"id", "is_commercial", b"is_commercial", "mask_color", b"mask_color", "mask_transparency", b"mask_transparency", "md5", b"md5", "re_type", b"re_type", "re_url", b"re_url", "re_value", b"re_value", "show_count", b"show_count", "size", b"size", "source", b"source", "url", b"url"]) -> None: ...

global___SearchEggInfo = SearchEggInfo

@typing_extensions.final
class SearchEggInfos(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EGG_INFO_FIELD_NUMBER: builtins.int
    @property
    def egg_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchEggInfo]:
        """"""
    def __init__(
        self,
        *,
        egg_info: collections.abc.Iterable[global___SearchEggInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["egg_info", b"egg_info"]) -> None: ...

global___SearchEggInfos = SearchEggInfos

@typing_extensions.final
class SearchEggReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    SEID_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    seid: builtins.str
    """"""
    @property
    def result(self) -> global___SearchEggInfos:
        """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        seid: builtins.str = ...,
        result: global___SearchEggInfos | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "result", b"result", "seid", b"seid"]) -> None: ...

global___SearchEggReply = SearchEggReply

@typing_extensions.final
class SearchEggReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SearchEggReq = SearchEggReq

@typing_extensions.final
class SubmitChatTaskReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    session_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "session_id", b"session_id"]) -> None: ...

global___SubmitChatTaskReply = SubmitChatTaskReply

@typing_extensions.final
class SubmitChatTaskReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    FROM_SOURCE_FIELD_NUMBER: builtins.int
    query: builtins.str
    """"""
    track_id: builtins.str
    """"""
    from_source: builtins.str
    """"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
        track_id: builtins.str = ...,
        from_source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_source", b"from_source", "query", b"query", "track_id", b"track_id"]) -> None: ...

global___SubmitChatTaskReq = SubmitChatTaskReq
