"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RcmdReason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    CORNER_MARK_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    corner_mark: builtins.int
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        corner_mark: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "corner_mark", b"corner_mark"]) -> None: ...

global___RcmdReason = RcmdReason

@typing_extensions.final
class WidgetItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    VIEW_ICON_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    view: builtins.str
    """"""
    @property
    def rcmd_reason(self) -> global___RcmdReason:
        """"""
    title: builtins.str
    """"""
    name: builtins.str
    """"""
    uri: builtins.str
    """"""
    goto: builtins.str
    """"""
    id: builtins.int
    """"""
    view_icon: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        view: builtins.str = ...,
        rcmd_reason: global___RcmdReason | None = ...,
        title: builtins.str = ...,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        goto: builtins.str = ...,
        id: builtins.int = ...,
        view_icon: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rcmd_reason", b"rcmd_reason"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "goto", b"goto", "id", b"id", "name", b"name", "rcmd_reason", b"rcmd_reason", "title", b"title", "uri", b"uri", "view", b"view", "view_icon", b"view_icon"]) -> None: ...

global___WidgetItem = WidgetItem

@typing_extensions.final
class WidgetReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WidgetItem]:
        """"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___WidgetItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___WidgetReply = WidgetReply

@typing_extensions.final
class WidgetReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_SPMID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    from_spmid: builtins.str
    """"""
    page_no: builtins.int
    """"""
    def __init__(
        self,
        *,
        from_spmid: builtins.str = ...,
        page_no: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_spmid", b"from_spmid", "page_no", b"page_no"]) -> None: ...

global___WidgetReq = WidgetReq
