# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/pegasus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/distribution/setting/pegasus.proto\x12)bilibili.app.distribution.setting.pegasus\x1a/bilibili/app/distribution/v1/distribution.proto\"H\n\rFeedModeValue\x12\x37\n\x05value\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\"\xa7\x02\n\x0fPegasusAutoPlay\x12\x38\n\x06single\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x38\n\x06\x64ouble\x18\x02 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12O\n\x1esingle_affected_by_server_side\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12O\n\x1e\x64ouble_affected_by_server_side\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\x97\x01\n\x12PegasusColumnValue\x12\x37\n\x05value\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12H\n\x17\x61\x66\x66\x65\x63ted_by_server_side\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\xfb\x01\n\x13PegasusDeviceConfig\x12M\n\x06\x63olumn\x18\x01 \x01(\x0b\x32=.bilibili.app.distribution.setting.pegasus.PegasusColumnValue\x12\x46\n\x04mode\x18\x02 \x01(\x0b\x32\x38.bilibili.app.distribution.setting.pegasus.FeedModeValue\x12M\n\tauto_play\x18\x03 \x01(\x0b\x32:.bilibili.app.distribution.setting.pegasus.PegasusAutoPlayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.pegasus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FEEDMODEVALUE']._serialized_start=143
  _globals['_FEEDMODEVALUE']._serialized_end=215
  _globals['_PEGASUSAUTOPLAY']._serialized_start=218
  _globals['_PEGASUSAUTOPLAY']._serialized_end=513
  _globals['_PEGASUSCOLUMNVALUE']._serialized_start=516
  _globals['_PEGASUSCOLUMNVALUE']._serialized_end=667
  _globals['_PEGASUSDEVICECONFIG']._serialized_start=670
  _globals['_PEGASUSDEVICECONFIG']._serialized_end=921
# @@protoc_insertion_point(module_scope)
