# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/demo/demo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/polymer/demo/demo.proto\x12\x15\x62ilibili.polymer.demo\" \n\rHelloWorldReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x1e\n\x0eHelloWorldResp\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.demo.demo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HELLOWORLDREQ']._serialized_start=59
  _globals['_HELLOWORLDREQ']._serialized_end=91
  _globals['_HELLOWORLDRESP']._serialized_start=93
  _globals['_HELLOWORLDRESP']._serialized_end=123
# @@protoc_insertion_point(module_scope)
