# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/listener/v1/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.interfaces.v1 import history_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2
from bilireq.grpc.protos.bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/listener/v1/listener.proto\x12\x18\x62ilibili.app.listener.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a(bilibili/app/interfaces/v1/history.proto\x1a%bilibili/app/playurl/v1/playurl.proto\"o\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12:\n\x08relation\x18\x04 \x01(\x0b\x32(.bilibili.app.listener.v1.FollowRelation\"\x88\x01\n\x0f\x42KArcDetailsReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x42\n\nplayerArgs\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x42KArcDetailsResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xe4\x01\n\tBKArchive\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03rid\x18\x06 \x01(\x05\x12\r\n\x05rname\x18\x07 \x01(\t\x12\x0f\n\x07publish\x18\x08 \x01(\x03\x12\x15\n\rdisplayed_oid\x18\t \x01(\t\x12\x11\n\tcopyright\x18\n \x01(\x05\x12\x35\n\x06rights\x18\x0b \x01(\x0b\x32%.bilibili.app.listener.v1.BKArcRights\"W\n\tBKArcPart\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0e\n\x06sub_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"!\n\x0b\x42KArcRights\x12\x12\n\nno_reprint\x18\x01 \x01(\x05\"\x98\x01\n\x06\x42KStat\x12\x0c\n\x04like\x18\x01 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x02 \x01(\x05\x12\x11\n\tfavourite\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\r\n\x05share\x18\x05 \x01(\x05\x12\x0c\n\x04view\x18\x06 \x01(\x05\x12\x10\n\x08has_like\x18\x07 \x01(\x08\x12\x10\n\x08has_coin\x18\x08 \x01(\x08\x12\x0f\n\x07has_fav\x18\t \x01(\x08\"\xee\x01\n\nCardModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\x05\x12=\n\rmodule_header\x18\x02 \x01(\x0b\x32$.bilibili.app.listener.v1.PkcmHeaderH\x00\x12?\n\x0emodule_archive\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.PkcmArchiveH\x00\x12\x41\n\x0bmodule_cbtn\x18\x04 \x01(\x0b\x32*.bilibili.app.listener.v1.PkcmCenterButtonH\x00\x42\x08\n\x06module\"\'\n\x08\x43lickReq\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x0b\n\tClickResp\"]\n\nCoinAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\x10\n\x08thumb_up\x18\x03 \x01(\x08\"\x1e\n\x0b\x43oinAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xdf\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\x05\x12\x11\n\tmime_type\x18\x05 \x01(\t\x12\x0e\n\x06\x63odecs\x18\x06 \x01(\t\x12?\n\x0csegment_base\x18\x0c \x01(\x0b\x32).bilibili.app.listener.v1.DashSegmentBase\x12\x0f\n\x07\x63odecid\x18\r \x01(\x05\x12\x0b\n\x03md5\x18\x0e \x01(\t\x12\x0c\n\x04size\x18\x0f \x01(\x03\">\n\x0f\x44\x61shSegmentBase\x12\x16\n\x0einitialization\x18\x01 \x01(\t\x12\x13\n\x0bindex_range\x18\x02 \x01(\t\"\xd3\x05\n\nDetailItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x30\n\x03\x61rc\x18\x02 \x01(\x0b\x32#.bilibili.app.listener.v1.BKArchive\x12\x32\n\x05parts\x18\x03 \x03(\x0b\x32#.bilibili.app.listener.v1.BKArcPart\x12/\n\x05owner\x18\x04 \x01(\x0b\x32 .bilibili.app.listener.v1.Author\x12.\n\x04stat\x18\x05 \x01(\x0b\x32 .bilibili.app.listener.v1.BKStat\x12\x11\n\tlast_part\x18\x06 \x01(\x03\x12\x10\n\x08progress\x18\x07 \x01(\x03\x12\x10\n\x08playable\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12I\n\x0bplayer_info\x18\n \x03(\x0b\x32\x34.bilibili.app.listener.v1.DetailItem.PlayerInfoEntry\x12;\n\x0f\x61ssociated_item\x18\x0b \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x16\n\x0elast_play_time\x18\x0c \x01(\x03\x12\x13\n\x0bhistory_tag\x18\r \x01(\t\x12:\n\x0b\x64\x65vice_type\x18\x0e \x01(\x0b\x32%.bilibili.app.interface.v1.DeviceType\x12<\n\x0fugc_season_info\x18\x0f \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"P\n\x08\x45ventReq\x12\x12\n\nevent_type\x18\x01 \x01(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x0b\n\tEventResp\"~\n\rEventTracking\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x02 \x01(\t\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\x12\x12\n\ntrack_json\x18\x06 \x01(\t\"\xf4\x02\n\tFavFolder\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).bilibili.app.listener.v1.FavFolderAuthor\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07\x66\x61vored\x18\n \x01(\x05\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\r\n\x05mtime\x18\x0c \x01(\x03\x12\x14\n\x0cstat_fav_cnt\x18\r \x01(\x05\x12\x16\n\x0estat_share_cnt\x18\x0e \x01(\x05\x12\x15\n\rstat_like_cnt\x18\x0f \x01(\x05\x12\x15\n\rstat_Play_cnt\x18\x10 \x01(\x05\x12\x16\n\x0estat_reply_cnt\x18\x11 \x01(\x05\x12\x11\n\tfav_state\x18\x12 \x01(\x05\"C\n\x0f\x46\x61vFolderAction\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\",\n\x0f\x46\x61vFolderAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x12\x46\x61vFolderCreateReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06public\x18\x03 \x01(\x05\x12\x13\n\x0b\x66older_type\x18\x04 \x01(\x05\"H\n\x13\x46\x61vFolderCreateResp\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x12\x46\x61vFolderDeleteReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"&\n\x13\x46\x61vFolderDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xaa\x01\n\x12\x46\x61vFolderDetailReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x66\x61v_mid\x18\x03 \x01(\x03\x12\x34\n\tlast_item\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x18\n\x10need_folder_info\x18\x06 \x01(\x08\"\xa8\x01\n\x13\x46\x61vFolderDetailResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x35\n\x04list\x18\x03 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavItemDetail\x12\x38\n\x0b\x66older_info\x18\x04 \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"Z\n\x10\x46\x61vFolderListReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"F\n\x11\x46\x61vFolderListResp\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"1\n\rFavFolderMeta\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"\x96\x01\n\x07\x46\x61vItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03\x66id\x18\x03 \x01(\x03\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05mtime\x18\x05 \x01(\x03\x12\r\n\x05\x63time\x18\x06 \x01(\x03\x12\x33\n\x02\x65t\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\rFavItemAddReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\rFavItemAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xbb\x01\n\x0f\x46\x61vItemBatchReq\x12:\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32).bilibili.app.listener.v1.FavFolderAction\x12\x32\n\x04play\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x03 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"#\n\x10\x46\x61vItemBatchResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9f\x01\n\rFavItemDelReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemDelResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8b\x02\n\rFavItemDetail\x12/\n\x04item\x18\x01 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x36\n\x05owner\x18\x02 \x01(\x0b\x32\'.bilibili.app.listener.v1.FavItemAuthor\x12\x33\n\x04stat\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.FavItemStat\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\r\n\x05parts\x18\t \x01(\x05\"*\n\x0b\x46\x61vItemStat\x12\x0c\n\x04view\x18\x01 \x01(\x05\x12\r\n\x05reply\x18\x02 \x01(\x05\"`\n\x16\x46\x61voredInAnyFoldersReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x85\x01\n\x17\x46\x61voredInAnyFoldersResp\x12\x38\n\x07\x66olders\x18\x01 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavFolderMeta\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x1c\n\rFavTabShowReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"#\n\x0e\x46\x61vTabShowResp\x12\x11\n\tshow_menu\x18\x01 \x01(\x08\" \n\x0e\x46ollowRelation\x12\x0e\n\x06status\x18\x01 \x01(\x05\"t\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x04 \x01(\t\x12\x13\n\x0bsuperscript\x18\x05 \x01(\t\";\n\x17MainFavMusicMenuListReq\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\"\x86\x01\n\x18MainFavMusicMenuListResp\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x36\n\tmenu_list\x18\x02 \x03(\x0b\x32#.bilibili.app.listener.v1.MusicMenu\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\"\x1b\n\x19MainFavMusicSubTabListReq\"\xe7\x02\n\x1aMainFavMusicSubTabListResp\x12\x33\n\x04tabs\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.MusicSubTab\x12K\n\x0f\x64\x65\x66\x61ult_tab_res\x18\x02 \x01(\x0b\x32\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp\x12^\n\x0e\x66irst_page_res\x18\x03 \x03(\x0b\x32\x46.bilibili.app.listener.v1.MainFavMusicSubTabListResp.FirstPageResEntry\x1ag\n\x11\x46irstPageResEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp:\x02\x38\x01\"\xe8\x01\n\rMedialistItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\r\n\x05parts\x18\x05 \x01(\x05\x12\x0e\n\x06up_mid\x18\x06 \x01(\x03\x12\x0f\n\x07up_name\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12\x11\n\tstat_view\x18\n \x01(\x03\x12\x12\n\nstat_reply\x18\x0b \x01(\x03\"A\n\x0cMedialistReq\x12\x11\n\tlist_type\x18\x01 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\"\xb4\x01\n\rMedialistResp\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x36\n\x05items\x18\x04 \x03(\x0b\x32\'.bilibili.app.listener.v1.MedialistItem\x12:\n\x07up_info\x18\x05 \x01(\x0b\x32).bilibili.app.listener.v1.MedialistUpInfo\"J\n\x0fMedialistUpInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0e\n\x06\x61vatar\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x1b\n\rMenuDeleteReq\x12\n\n\x02id\x18\x01 \x01(\x03\"!\n\x0eMenuDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"I\n\x0bMenuEditReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x11\n\tis_public\x18\x04 \x01(\x05\"\x1f\n\x0cMenuEditResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"5\n\x10MenuSubscribeReq\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x11\n\ttarget_id\x18\x02 \x01(\x03\"$\n\x11MenuSubscribeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8f\x02\n\tMusicMenu\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tmenu_type\x18\x02 \x01(\x05\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x38\n\x05owner\x18\x06 \x01(\x0b\x32).bilibili.app.listener.v1.MusicMenuAuthor\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x03\x12\x35\n\x04stat\x18\t \x01(\x0b\x32\'.bilibili.app.listener.v1.MusicMenuStat\x12\r\n\x05total\x18\n \x01(\x03\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\x0b\n\x03uri\x18\x0c \x01(\t\"<\n\x0fMusicMenuAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\",\n\rMusicMenuStat\x12\x0c\n\x04play\x18\x01 \x01(\x03\x12\r\n\x05reply\x18\x02 \x01(\x03\"<\n\x0bMusicSubTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08tab_type\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x03\"i\n\nPageOption\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x35\n\tlast_item\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x81\x02\n\x0bPickArchive\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12:\n\x05owner\x18\x03 \x01(\x0b\x32+.bilibili.app.listener.v1.PickArchiveAuthor\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\r\n\x05parts\x18\x06 \x01(\x05\x12\x11\n\tstat_view\x18\x07 \x01(\x05\x12\x12\n\nstat_reply\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\t\".\n\x11PickArchiveAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x08PickCard\x12\x0f\n\x07pick_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\x03\x12\x11\n\tcard_name\x18\x03 \x01(\t\x12\x35\n\x07modules\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"5\n\x11PickCardDetailReq\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\"m\n\x12PickCardDetailResp\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\x12\x35\n\x07modules\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"\x1d\n\x0bPickFeedReq\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"Q\n\x0cPickFeedResp\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x31\n\x05\x63\x61rds\x18\x02 \x03(\x0b\x32\".bilibili.app.listener.v1.PickCard\"V\n\x0bPkcmArchive\x12\x32\n\x03\x61rc\x18\x01 \x01(\x0b\x32%.bilibili.app.listener.v1.PickArchive\x12\x13\n\x0bpick_reason\x18\x02 \x01(\t\"T\n\x10PkcmCenterButton\x12\x11\n\ticon_head\x18\x01 \x01(\t\x12\x11\n\ticon_tail\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"^\n\nPkcmHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08\x62tn_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62tn_text\x18\x04 \x01(\t\x12\x0f\n\x07\x62tn_uri\x18\x05 \x01(\t\"[\n\x13PlayActionReportReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x12\n\nfrom_spmid\x18\x02 \x01(\t\"h\n\x08PlayDASH\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x17\n\x0fmin_buffer_time\x18\x02 \x01(\x02\x12\x31\n\x05\x61udio\x18\x03 \x03(\x0b\x32\".bilibili.app.listener.v1.DashItem\"}\n\x11PlayHistoryAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x12\n\nplay_style\x18\x04 \x01(\x05\"X\n\x11PlayHistoryDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"b\n\x0ePlayHistoryReq\x12\x36\n\x08page_opt\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x18\n\x10local_today_zero\x18\x02 \x01(\x03\"g\n\x0fPlayHistoryResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xee\x02\n\x08PlayInfo\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0f\n\x07qn_type\x18\x03 \x01(\x05\x12\x35\n\x08play_url\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.PlayURLH\x00\x12\x37\n\tplay_dash\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayDASHH\x00\x12\r\n\x05\x66nver\x18\x06 \x01(\x05\x12\r\n\x05\x66nval\x18\x07 \x01(\x05\x12\x0f\n\x07\x66ormats\x18\x08 \x03(\x05\x12\x15\n\rvideo_codecid\x18\t \x01(\x05\x12\x0e\n\x06length\x18\n \x01(\x03\x12\x0c\n\x04\x63ode\x18\x0b \x01(\x05\x12\x0f\n\x07message\x18\x0c \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\r \x01(\x03\x12\x33\n\x06volume\x18\x0e \x01(\x0b\x32#.bilibili.app.playurl.v1.VolumeInfoB\x06\n\x04info\"o\n\x08PlayItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0e\n\x06sub_id\x18\x04 \x03(\x03\x12\x33\n\x02\x65t\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\x0ePlaylistAddReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x0e\n\x04head\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04tail\x18\x04 \x01(\x08H\x00\x42\x05\n\x03pos\"U\n\x0ePlaylistDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"\xa2\x02\n\x0bPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x32\n\x06\x61nchor\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x36\n\x08page_opt\x18\x04 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08\x65xtra_id\x18\x06 \x01(\x03\x12\x36\n\x08sort_opt\x18\x07 \x01(\x0b\x32$.bilibili.app.listener.v1.SortOption\"\xc7\x01\n\x0cPlaylistResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x13\n\x0breach_start\x18\x02 \x01(\x08\x12\x11\n\treach_end\x18\x03 \x01(\x08\x12\x32\n\x04list\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x35\n\tlast_play\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x15\n\rlast_progress\x18\x06 \x01(\x03\">\n\x07PlayURL\x12\x33\n\x04\x64url\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.ResponseUrl\"\x83\x01\n\nPlayURLReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x43\n\x0bplayer_args\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x84\x02\n\x0bPlayURLResp\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08playable\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12I\n\nplayerInfo\x18\x04 \x03(\x0b\x32\x35.bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"\x9e\x01\n\x0fRcmdPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x14\n\x0cneed_history\x18\x03 \x01(\x08\x12\x16\n\x0eneed_top_cards\x18\x04 \x01(\x08\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x91\x01\n\x10RcmdPlaylistResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x13\n\x0bhistory_len\x18\x02 \x01(\x03\x12\x34\n\ttop_cards\x18\x03 \x03(\x0b\x32!.bilibili.app.listener.v1.TopCard\"\x86\x01\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\r\n\x05\x61head\x18\x04 \x01(\t\x12\r\n\x05vhead\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x12\n\nbackup_url\x18\x07 \x03(\t\x12\x0b\n\x03md5\x18\x08 \x01(\t\"/\n\nSortOption\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x12\n\nsort_field\x18\x02 \x01(\x05\"N\n\nThumbUpReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x1e\n\x0bThumbUpResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xe4\x02\n\x07TopCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x12\n\nplay_style\x18\x02 \x01(\x05\x12\x11\n\tcard_type\x18\x03 \x01(\x05\x12?\n\x0elisten_history\x18\x04 \x01(\x0b\x32%.bilibili.app.listener.v1.TpcdHistoryH\x00\x12=\n\nfav_folder\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.TpcdFavFolderH\x00\x12;\n\tup_recall\x18\x06 \x01(\x0b\x32&.bilibili.app.listener.v1.TpcdUpRecallH\x00\x12=\n\npick_today\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.TpcdPickTodayH\x00\x12\x0b\n\x03pos\x18\x08 \x01(\x03\x12\x12\n\ntitle_icon\x18\t \x01(\tB\x06\n\x04\x63\x61rd\"\x80\x01\n\rTpcdFavFolder\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\x12\x0b\n\x03\x66id\x18\x04 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x05 \x01(\x05\"\\\n\x0bTpcdHistory\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\"\x85\x01\n\rTpcdPickToday\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03pic\x18\x03 \x01(\t\x12\x0f\n\x07pick_id\x18\x04 \x01(\x03\x12\x14\n\x0cpick_card_id\x18\x05 \x01(\x03\"\xa2\x01\n\x0cTpcdUpRecall\x12\x0e\n\x06up_mid\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12\x16\n\x0emedialist_type\x18\x04 \x01(\x03\x12\x18\n\x10medialist_biz_id\x18\x05 \x01(\x03\x12\x32\n\x04item\x18\x06 \x01(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"A\n\rTripleLikeReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"T\n\x0eTripleLikeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08thumb_ok\x18\x02 \x01(\x08\x12\x0f\n\x07\x63oin_ok\x18\x03 \x01(\x08\x12\x0e\n\x06\x66\x61v_ok\x18\x04 \x01(\x08*\\\n\x0e\x43\x61rdModuleType\x12\x12\n\x0eModule_invalid\x10\x00\x12\x11\n\rModule_header\x10\x01\x12\x12\n\x0eModule_archive\x10\x02\x12\x0f\n\x0bModule_cbtn\x10\x03*P\n\tListOrder\x12\x0c\n\x08NO_ORDER\x10\x00\x12\x10\n\x0cORDER_NORMAL\x10\x01\x12\x11\n\rORDER_REVERSE\x10\x02\x12\x10\n\x0cORDER_RANDOM\x10\x03*O\n\rListSortField\x12\x0b\n\x07NO_SORT\x10\x00\x12\x0e\n\nSORT_CTIME\x10\x01\x12\x10\n\x0cSORT_VIEWCNT\x10\x02\x12\x0f\n\x0bSORT_FAVCNT\x10\x03*\xa6\x01\n\x0ePlaylistSource\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tMEM_SPACE\x10\x01\x12\x14\n\x10\x41UDIO_COLLECTION\x10\x02\x12\x0e\n\nAUDIO_CARD\x10\x03\x12\x12\n\x0eUSER_FAVOURITE\x10\x04\x12\x0e\n\nUP_ARCHIVE\x10\x05\x12\x0f\n\x0b\x41UDIO_CACHE\x10\x06\x12\r\n\tPICK_CARD\x10\x07\x12\x0e\n\nMEDIA_LIST\x10\x08*f\n\x0bTopCardType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x12\n\x0eLISTEN_HISTORY\x10\x01\x12\x13\n\x0f\x46\x41VORITE_FOLDER\x10\x02\x12\r\n\tUP_RECALL\x10\x03\x12\x0e\n\nPICK_TODAY\x10\x04\x32\xba\x13\n\x08Listener\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12V\n\x07PlayUrl\x12$.bilibili.app.listener.v1.PlayURLReq\x1a%.bilibili.app.listener.v1.PlayURLResp\x12\x65\n\x0c\x42karcDetails\x12).bilibili.app.listener.v1.BKArcDetailsReq\x1a*.bilibili.app.listener.v1.BKArcDetailsResp\x12Y\n\x08Playlist\x12%.bilibili.app.listener.v1.PlaylistReq\x1a&.bilibili.app.listener.v1.PlaylistResp\x12O\n\x0bPlaylistAdd\x12(.bilibili.app.listener.v1.PlaylistAddReq\x1a\x16.google.protobuf.Empty\x12O\n\x0bPlaylistDel\x12(.bilibili.app.listener.v1.PlaylistDelReq\x1a\x16.google.protobuf.Empty\x12\x65\n\x0cRcmdPlaylist\x12).bilibili.app.listener.v1.RcmdPlaylistReq\x1a*.bilibili.app.listener.v1.RcmdPlaylistResp\x12\x62\n\x0bPlayHistory\x12(.bilibili.app.listener.v1.PlayHistoryReq\x1a).bilibili.app.listener.v1.PlayHistoryResp\x12U\n\x0ePlayHistoryAdd\x12+.bilibili.app.listener.v1.PlayHistoryAddReq\x1a\x16.google.protobuf.Empty\x12U\n\x0ePlayHistoryDel\x12+.bilibili.app.listener.v1.PlayHistoryDelReq\x1a\x16.google.protobuf.Empty\x12Y\n\x10PlayActionReport\x12-.bilibili.app.listener.v1.PlayActionReportReq\x1a\x16.google.protobuf.Empty\x12_\n\nTripleLike\x12\'.bilibili.app.listener.v1.TripleLikeReq\x1a(.bilibili.app.listener.v1.TripleLikeResp\x12V\n\x07ThumbUp\x12$.bilibili.app.listener.v1.ThumbUpReq\x1a%.bilibili.app.listener.v1.ThumbUpResp\x12V\n\x07\x43oinAdd\x12$.bilibili.app.listener.v1.CoinAddReq\x1a%.bilibili.app.listener.v1.CoinAddResp\x12_\n\nFavItemAdd\x12\'.bilibili.app.listener.v1.FavItemAddReq\x1a(.bilibili.app.listener.v1.FavItemAddResp\x12_\n\nFavItemDel\x12\'.bilibili.app.listener.v1.FavItemDelReq\x1a(.bilibili.app.listener.v1.FavItemDelResp\x12\x65\n\x0c\x46\x61vItemBatch\x12).bilibili.app.listener.v1.FavItemBatchReq\x1a*.bilibili.app.listener.v1.FavItemBatchResp\x12z\n\x13\x46\x61voredInAnyFolders\x12\x30.bilibili.app.listener.v1.FavoredInAnyFoldersReq\x1a\x31.bilibili.app.listener.v1.FavoredInAnyFoldersResp\x12h\n\rFavFolderList\x12*.bilibili.app.listener.v1.FavFolderListReq\x1a+.bilibili.app.listener.v1.FavFolderListResp\x12n\n\x0f\x46\x61vFolderDetail\x12,.bilibili.app.listener.v1.FavFolderDetailReq\x1a-.bilibili.app.listener.v1.FavFolderDetailResp\x12n\n\x0f\x46\x61vFolderCreate\x12,.bilibili.app.listener.v1.FavFolderCreateReq\x1a-.bilibili.app.listener.v1.FavFolderCreateResp\x12n\n\x0f\x46\x61vFolderDelete\x12,.bilibili.app.listener.v1.FavFolderDeleteReq\x1a-.bilibili.app.listener.v1.FavFolderDeleteResp\x12Y\n\x08PickFeed\x12%.bilibili.app.listener.v1.PickFeedReq\x1a&.bilibili.app.listener.v1.PickFeedResp\x12k\n\x0ePickCardDetail\x12+.bilibili.app.listener.v1.PickCardDetailReq\x1a,.bilibili.app.listener.v1.PickCardDetailResp\x12\\\n\tMedialist\x12&.bilibili.app.listener.v1.MedialistReq\x1a\'.bilibili.app.listener.v1.MedialistResp\x12P\n\x05\x45vent\x12\".bilibili.app.listener.v1.EventReq\x1a#.bilibili.app.listener.v1.EventResp2\xe5\x05\n\x05Music\x12_\n\nFavTabShow\x12\'.bilibili.app.listener.v1.FavTabShowReq\x1a(.bilibili.app.listener.v1.FavTabShowResp\x12\x83\x01\n\x16MainFavMusicSubTabList\x12\x33.bilibili.app.listener.v1.MainFavMusicSubTabListReq\x1a\x34.bilibili.app.listener.v1.MainFavMusicSubTabListResp\x12}\n\x14MainFavMusicMenuList\x12\x31.bilibili.app.listener.v1.MainFavMusicMenuListReq\x1a\x32.bilibili.app.listener.v1.MainFavMusicMenuListResp\x12Y\n\x08MenuEdit\x12%.bilibili.app.listener.v1.MenuEditReq\x1a&.bilibili.app.listener.v1.MenuEditResp\x12_\n\nMenuDelete\x12\'.bilibili.app.listener.v1.MenuDeleteReq\x1a(.bilibili.app.listener.v1.MenuDeleteResp\x12h\n\rMenuSubscribe\x12*.bilibili.app.listener.v1.MenuSubscribeReq\x1a+.bilibili.app.listener.v1.MenuSubscribeResp\x12P\n\x05\x43lick\x12\".bilibili.app.listener.v1.ClickReq\x1a#.bilibili.app.listener.v1.ClickRespb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.listener.v1.listener_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETAILITEM_PLAYERINFOENTRY._options = None
  _DETAILITEM_PLAYERINFOENTRY._serialized_options = b'8\001'
  _MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY._options = None
  _MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY._serialized_options = b'8\001'
  _PLAYURLRESP_PLAYERINFOENTRY._options = None
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_options = b'8\001'
  _globals['_CARDMODULETYPE']._serialized_start=12512
  _globals['_CARDMODULETYPE']._serialized_end=12604
  _globals['_LISTORDER']._serialized_start=12606
  _globals['_LISTORDER']._serialized_end=12686
  _globals['_LISTSORTFIELD']._serialized_start=12688
  _globals['_LISTSORTFIELD']._serialized_end=12767
  _globals['_PLAYLISTSOURCE']._serialized_start=12770
  _globals['_PLAYLISTSOURCE']._serialized_end=12936
  _globals['_TOPCARDTYPE']._serialized_start=12938
  _globals['_TOPCARDTYPE']._serialized_end=13040
  _globals['_AUTHOR']._serialized_start=229
  _globals['_AUTHOR']._serialized_end=340
  _globals['_BKARCDETAILSREQ']._serialized_start=343
  _globals['_BKARCDETAILSREQ']._serialized_end=479
  _globals['_BKARCDETAILSRESP']._serialized_start=481
  _globals['_BKARCDETAILSRESP']._serialized_end=551
  _globals['_BKARCHIVE']._serialized_start=554
  _globals['_BKARCHIVE']._serialized_end=782
  _globals['_BKARCPART']._serialized_start=784
  _globals['_BKARCPART']._serialized_end=871
  _globals['_BKARCRIGHTS']._serialized_start=873
  _globals['_BKARCRIGHTS']._serialized_end=906
  _globals['_BKSTAT']._serialized_start=909
  _globals['_BKSTAT']._serialized_end=1061
  _globals['_CARDMODULE']._serialized_start=1064
  _globals['_CARDMODULE']._serialized_end=1302
  _globals['_CLICKREQ']._serialized_start=1304
  _globals['_CLICKREQ']._serialized_end=1343
  _globals['_CLICKRESP']._serialized_start=1345
  _globals['_CLICKRESP']._serialized_end=1356
  _globals['_COINADDREQ']._serialized_start=1358
  _globals['_COINADDREQ']._serialized_end=1451
  _globals['_COINADDRESP']._serialized_start=1453
  _globals['_COINADDRESP']._serialized_end=1483
  _globals['_DASHITEM']._serialized_start=1486
  _globals['_DASHITEM']._serialized_end=1709
  _globals['_DASHSEGMENTBASE']._serialized_start=1711
  _globals['_DASHSEGMENTBASE']._serialized_end=1773
  _globals['_DETAILITEM']._serialized_start=1776
  _globals['_DETAILITEM']._serialized_end=2499
  _globals['_DETAILITEM_PLAYERINFOENTRY']._serialized_start=2414
  _globals['_DETAILITEM_PLAYERINFOENTRY']._serialized_end=2499
  _globals['_EVENTREQ']._serialized_start=2501
  _globals['_EVENTREQ']._serialized_end=2581
  _globals['_EVENTRESP']._serialized_start=2583
  _globals['_EVENTRESP']._serialized_end=2594
  _globals['_EVENTTRACKING']._serialized_start=2596
  _globals['_EVENTTRACKING']._serialized_end=2722
  _globals['_FAVFOLDER']._serialized_start=2725
  _globals['_FAVFOLDER']._serialized_end=3097
  _globals['_FAVFOLDERACTION']._serialized_start=3099
  _globals['_FAVFOLDERACTION']._serialized_end=3166
  _globals['_FAVFOLDERAUTHOR']._serialized_start=3168
  _globals['_FAVFOLDERAUTHOR']._serialized_end=3212
  _globals['_FAVFOLDERCREATEREQ']._serialized_start=3214
  _globals['_FAVFOLDERCREATEREQ']._serialized_end=3299
  _globals['_FAVFOLDERCREATERESP']._serialized_start=3301
  _globals['_FAVFOLDERCREATERESP']._serialized_end=3373
  _globals['_FAVFOLDERDELETEREQ']._serialized_start=3375
  _globals['_FAVFOLDERDELETEREQ']._serialized_end=3429
  _globals['_FAVFOLDERDELETERESP']._serialized_start=3431
  _globals['_FAVFOLDERDELETERESP']._serialized_end=3469
  _globals['_FAVFOLDERDETAILREQ']._serialized_start=3472
  _globals['_FAVFOLDERDETAILREQ']._serialized_end=3642
  _globals['_FAVFOLDERDETAILRESP']._serialized_start=3645
  _globals['_FAVFOLDERDETAILRESP']._serialized_end=3813
  _globals['_FAVFOLDERLISTREQ']._serialized_start=3815
  _globals['_FAVFOLDERLISTREQ']._serialized_end=3905
  _globals['_FAVFOLDERLISTRESP']._serialized_start=3907
  _globals['_FAVFOLDERLISTRESP']._serialized_end=3977
  _globals['_FAVFOLDERMETA']._serialized_start=3979
  _globals['_FAVFOLDERMETA']._serialized_end=4028
  _globals['_FAVITEM']._serialized_start=4031
  _globals['_FAVITEM']._serialized_end=4181
  _globals['_FAVITEMADDREQ']._serialized_start=4184
  _globals['_FAVITEMADDREQ']._serialized_end=4343
  _globals['_FAVITEMADDRESP']._serialized_start=4345
  _globals['_FAVITEMADDRESP']._serialized_end=4378
  _globals['_FAVITEMAUTHOR']._serialized_start=4380
  _globals['_FAVITEMAUTHOR']._serialized_end=4422
  _globals['_FAVITEMBATCHREQ']._serialized_start=4425
  _globals['_FAVITEMBATCHREQ']._serialized_end=4612
  _globals['_FAVITEMBATCHRESP']._serialized_start=4614
  _globals['_FAVITEMBATCHRESP']._serialized_end=4649
  _globals['_FAVITEMDELREQ']._serialized_start=4652
  _globals['_FAVITEMDELREQ']._serialized_end=4811
  _globals['_FAVITEMDELRESP']._serialized_start=4813
  _globals['_FAVITEMDELRESP']._serialized_end=4846
  _globals['_FAVITEMDETAIL']._serialized_start=4849
  _globals['_FAVITEMDETAIL']._serialized_end=5116
  _globals['_FAVITEMSTAT']._serialized_start=5118
  _globals['_FAVITEMSTAT']._serialized_end=5160
  _globals['_FAVOREDINANYFOLDERSREQ']._serialized_start=5162
  _globals['_FAVOREDINANYFOLDERSREQ']._serialized_end=5258
  _globals['_FAVOREDINANYFOLDERSRESP']._serialized_start=5261
  _globals['_FAVOREDINANYFOLDERSRESP']._serialized_end=5394
  _globals['_FAVTABSHOWREQ']._serialized_start=5396
  _globals['_FAVTABSHOWREQ']._serialized_end=5424
  _globals['_FAVTABSHOWRESP']._serialized_start=5426
  _globals['_FAVTABSHOWRESP']._serialized_end=5461
  _globals['_FOLLOWRELATION']._serialized_start=5463
  _globals['_FOLLOWRELATION']._serialized_end=5495
  _globals['_FORMATDESCRIPTION']._serialized_start=5497
  _globals['_FORMATDESCRIPTION']._serialized_end=5613
  _globals['_MAINFAVMUSICMENULISTREQ']._serialized_start=5615
  _globals['_MAINFAVMUSICMENULISTREQ']._serialized_end=5674
  _globals['_MAINFAVMUSICMENULISTRESP']._serialized_start=5677
  _globals['_MAINFAVMUSICMENULISTRESP']._serialized_end=5811
  _globals['_MAINFAVMUSICSUBTABLISTREQ']._serialized_start=5813
  _globals['_MAINFAVMUSICSUBTABLISTREQ']._serialized_end=5840
  _globals['_MAINFAVMUSICSUBTABLISTRESP']._serialized_start=5843
  _globals['_MAINFAVMUSICSUBTABLISTRESP']._serialized_end=6202
  _globals['_MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY']._serialized_start=6099
  _globals['_MAINFAVMUSICSUBTABLISTRESP_FIRSTPAGERESENTRY']._serialized_end=6202
  _globals['_MEDIALISTITEM']._serialized_start=6205
  _globals['_MEDIALISTITEM']._serialized_end=6437
  _globals['_MEDIALISTREQ']._serialized_start=6439
  _globals['_MEDIALISTREQ']._serialized_end=6504
  _globals['_MEDIALISTRESP']._serialized_start=6507
  _globals['_MEDIALISTRESP']._serialized_end=6687
  _globals['_MEDIALISTUPINFO']._serialized_start=6689
  _globals['_MEDIALISTUPINFO']._serialized_end=6763
  _globals['_MENUDELETEREQ']._serialized_start=6765
  _globals['_MENUDELETEREQ']._serialized_end=6792
  _globals['_MENUDELETERESP']._serialized_start=6794
  _globals['_MENUDELETERESP']._serialized_end=6827
  _globals['_MENUEDITREQ']._serialized_start=6829
  _globals['_MENUEDITREQ']._serialized_end=6902
  _globals['_MENUEDITRESP']._serialized_start=6904
  _globals['_MENUEDITRESP']._serialized_end=6935
  _globals['_MENUSUBSCRIBEREQ']._serialized_start=6937
  _globals['_MENUSUBSCRIBEREQ']._serialized_end=6990
  _globals['_MENUSUBSCRIBERESP']._serialized_start=6992
  _globals['_MENUSUBSCRIBERESP']._serialized_end=7028
  _globals['_MUSICMENU']._serialized_start=7031
  _globals['_MUSICMENU']._serialized_end=7302
  _globals['_MUSICMENUAUTHOR']._serialized_start=7304
  _globals['_MUSICMENUAUTHOR']._serialized_end=7364
  _globals['_MUSICMENUSTAT']._serialized_start=7366
  _globals['_MUSICMENUSTAT']._serialized_end=7410
  _globals['_MUSICSUBTAB']._serialized_start=7412
  _globals['_MUSICSUBTAB']._serialized_end=7472
  _globals['_PAGEOPTION']._serialized_start=7474
  _globals['_PAGEOPTION']._serialized_end=7579
  _globals['_PICKARCHIVE']._serialized_start=7582
  _globals['_PICKARCHIVE']._serialized_end=7839
  _globals['_PICKARCHIVEAUTHOR']._serialized_start=7841
  _globals['_PICKARCHIVEAUTHOR']._serialized_end=7887
  _globals['_PICKCARD']._serialized_start=7889
  _globals['_PICKCARD']._serialized_end=8007
  _globals['_PICKCARDDETAILREQ']._serialized_start=8009
  _globals['_PICKCARDDETAILREQ']._serialized_end=8062
  _globals['_PICKCARDDETAILRESP']._serialized_start=8064
  _globals['_PICKCARDDETAILRESP']._serialized_end=8173
  _globals['_PICKFEEDREQ']._serialized_start=8175
  _globals['_PICKFEEDREQ']._serialized_end=8204
  _globals['_PICKFEEDRESP']._serialized_start=8206
  _globals['_PICKFEEDRESP']._serialized_end=8287
  _globals['_PKCMARCHIVE']._serialized_start=8289
  _globals['_PKCMARCHIVE']._serialized_end=8375
  _globals['_PKCMCENTERBUTTON']._serialized_start=8377
  _globals['_PKCMCENTERBUTTON']._serialized_end=8461
  _globals['_PKCMHEADER']._serialized_start=8463
  _globals['_PKCMHEADER']._serialized_end=8557
  _globals['_PLAYACTIONREPORTREQ']._serialized_start=8559
  _globals['_PLAYACTIONREPORTREQ']._serialized_end=8650
  _globals['_PLAYDASH']._serialized_start=8652
  _globals['_PLAYDASH']._serialized_end=8756
  _globals['_PLAYHISTORYADDREQ']._serialized_start=8758
  _globals['_PLAYHISTORYADDREQ']._serialized_end=8883
  _globals['_PLAYHISTORYDELREQ']._serialized_start=8885
  _globals['_PLAYHISTORYDELREQ']._serialized_end=8973
  _globals['_PLAYHISTORYREQ']._serialized_start=8975
  _globals['_PLAYHISTORYREQ']._serialized_end=9073
  _globals['_PLAYHISTORYRESP']._serialized_start=9075
  _globals['_PLAYHISTORYRESP']._serialized_end=9178
  _globals['_PLAYINFO']._serialized_start=9181
  _globals['_PLAYINFO']._serialized_end=9547
  _globals['_PLAYITEM']._serialized_start=9549
  _globals['_PLAYITEM']._serialized_end=9660
  _globals['_PLAYLISTADDREQ']._serialized_start=9663
  _globals['_PLAYLISTADDREQ']._serialized_end=9822
  _globals['_PLAYLISTDELREQ']._serialized_start=9824
  _globals['_PLAYLISTDELREQ']._serialized_end=9909
  _globals['_PLAYLISTREQ']._serialized_start=9912
  _globals['_PLAYLISTREQ']._serialized_end=10202
  _globals['_PLAYLISTRESP']._serialized_start=10205
  _globals['_PLAYLISTRESP']._serialized_end=10404
  _globals['_PLAYURL']._serialized_start=10406
  _globals['_PLAYURL']._serialized_end=10468
  _globals['_PLAYURLREQ']._serialized_start=10471
  _globals['_PLAYURLREQ']._serialized_end=10602
  _globals['_PLAYURLRESP']._serialized_start=10605
  _globals['_PLAYURLRESP']._serialized_end=10865
  _globals['_PLAYURLRESP_PLAYERINFOENTRY']._serialized_start=2414
  _globals['_PLAYURLRESP_PLAYERINFOENTRY']._serialized_end=2499
  _globals['_RCMDPLAYLISTREQ']._serialized_start=10868
  _globals['_RCMDPLAYLISTREQ']._serialized_end=11026
  _globals['_RCMDPLAYLISTRESP']._serialized_start=11029
  _globals['_RCMDPLAYLISTRESP']._serialized_end=11174
  _globals['_RESPONSEURL']._serialized_start=11177
  _globals['_RESPONSEURL']._serialized_end=11311
  _globals['_SORTOPTION']._serialized_start=11313
  _globals['_SORTOPTION']._serialized_end=11360
  _globals['_THUMBUPREQ']._serialized_start=11362
  _globals['_THUMBUPREQ']._serialized_end=11440
  _globals['_THUMBUPRESP']._serialized_start=11442
  _globals['_THUMBUPRESP']._serialized_end=11472
  _globals['_TOPCARD']._serialized_start=11475
  _globals['_TOPCARD']._serialized_end=11831
  _globals['_TPCDFAVFOLDER']._serialized_start=11834
  _globals['_TPCDFAVFOLDER']._serialized_end=11962
  _globals['_TPCDHISTORY']._serialized_start=11964
  _globals['_TPCDHISTORY']._serialized_end=12056
  _globals['_TPCDPICKTODAY']._serialized_start=12059
  _globals['_TPCDPICKTODAY']._serialized_end=12192
  _globals['_TPCDUPRECALL']._serialized_start=12195
  _globals['_TPCDUPRECALL']._serialized_end=12357
  _globals['_TRIPLELIKEREQ']._serialized_start=12359
  _globals['_TRIPLELIKEREQ']._serialized_end=12424
  _globals['_TRIPLELIKERESP']._serialized_start=12426
  _globals['_TRIPLELIKERESP']._serialized_end=12510
  _globals['_LISTENER']._serialized_start=13043
  _globals['_LISTENER']._serialized_end=15533
  _globals['_MUSIC']._serialized_start=15536
  _globals['_MUSIC']._serialized_end=16277
# @@protoc_insertion_point(module_scope)
