# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pangu/gallery/v1/gallery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/pangu/gallery/v1/gallery.proto\x12\x19\x62ilibili.pangu.gallery.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x12\n\x10\x41greePolicyReply\"]\n\x0e\x41greePolicyReq\x12:\n\x0bpolicy_type\x18\x01 \x01(\x0e\x32%.bilibili.pangu.gallery.v1.PolicyType\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x8a\x01\n\x0e\x42\x61sicInfoReply\x12\x1c\n\x14\x63ustomer_service_url\x18\x01 \x01(\t\x12\x15\n\ragreement_url\x18\x02 \x01(\t\x12\x13\n\x0bprivacy_url\x18\x03 \x01(\t\x12.\n\x05links\x18\x04 \x03(\x0b\x32\x1f.bilibili.pangu.gallery.v1.Link\"\x1b\n\x0c\x42\x61sicInfoReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"^\n\x07\x44isplay\x12\x16\n\x0e\x62g_theme_light\x18\x01 \x01(\t\x12\x16\n\x0e\x62g_theme_night\x18\x02 \x01(\t\x12\x12\n\nnft_poster\x18\x03 \x01(\t\x12\x0f\n\x07nft_raw\x18\x04 \x01(\t\"N\n\x12GetLastPolicyReply\x12\x12\n\nshort_desc\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65tail_jump\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"N\n\x10GetLastPolicyReq\x12:\n\x0bpolicy_type\x18\x01 \x01(\x0e\x32%.bilibili.pangu.gallery.v1.PolicyType\"d\n\x10GetUserInfoReply\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x12\n\navatar_url\x18\x04 \x01(\t\x12\x10\n\x08help_url\x18\x05 \x01(\t\"\x1d\n\x0eGetUserInfoReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\">\n\x04Link\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08link_url\x18\x02 \x01(\t\x12\x16\n\x0etrack_event_id\x18\x03 \x01(\t\"a\n\x11ListNFTByMidReply\x12,\n\x04nfts\x18\x01 \x03(\x0b\x32\x1e.bilibili.pangu.gallery.v1.NFT\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x08\"h\n\x0fListNFTByMidReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x62iz_type\x18\x03 \x01(\t\x12\x11\n\tanchor_id\x18\x04 \x01(\x03\x12\x11\n\tpage_size\x18\x05 \x01(\x03\"g\n\x13ListOrderByMidReply\x12\x30\n\x06orders\x18\x01 \x03(\x0b\x32 .bilibili.pangu.gallery.v1.Order\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x08\"F\n\x11ListOrderByMidReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tanchor_id\x18\x02 \x01(\x03\x12\x11\n\tpage_size\x18\x03 \x01(\x03\"\xe3\x01\n\x03NFT\x12\x0e\n\x06nft_id\x18\x01 \x01(\t\x12\x11\n\titem_name\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x0e\n\x06issuer\x18\x04 \x01(\t\x12\x33\n\x07\x64isplay\x18\x05 \x01(\x0b\x32\".bilibili.pangu.gallery.v1.Display\x12\x12\n\ndetail_url\x18\x06 \x01(\t\x12\x38\n\nnft_status\x18\x07 \x01(\x0e\x32$.bilibili.pangu.gallery.v1.NFTStatus\x12\x0f\n\x07item_id\x18\x08 \x01(\x03\"\xa0\x02\n\x05Order\x12\x11\n\titem_name\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07tx_time\x18\x04 \x01(\t\x12\x0e\n\x06issuer\x18\x05 \x01(\t\x12\x12\n\nissue_time\x18\x06 \x01(\t\x12\x10\n\x08token_id\x18\x07 \x01(\t\x12\x33\n\x07\x64isplay\x18\x08 \x01(\x0b\x32\".bilibili.pangu.gallery.v1.Display\x12\x18\n\x10\x63ontract_address\x18\t \x01(\t\x12\x11\n\thash_jump\x18\n \x01(\t\x12\x15\n\rcontract_jump\x18\x0b \x01(\t\x12\x1c\n\x14\x64isable_browser_jump\x18\x0c \x01(\x08\"5\n\x0eUserCheckReply\x12\x15\n\rpolicy_status\x18\x01 \x01(\x05\x12\x0c\n\x04gt14\x18\x02 \x01(\x05\"0\n\x0cUserCheckReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x13\n\x0bpolicy_type\x18\x02 \x01(\x05*2\n\nGT14Status\x12\x08\n\x04LT14\x10\x00\x12\x08\n\x04GE14\x10\x01\x12\x10\n\x0cUNKNOWN_GT14\x10\x02*1\n\tNFTStatus\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\t\n\x05\x44OING\x10\x02*<\n\x11PolicyAgreeStatus\x12\x0c\n\x08UNSIGNED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02*6\n\nPolicyType\x12\x12\n\x0eUNKNOWN_POLICY\x10\x00\x12\n\n\x06WALLET\x10\x01\x12\x08\n\x04SALE\x10\x02\x32\x9e\x06\n\x10GalleryInterface\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12\x62\n\x08UserInfo\x12).bilibili.pangu.gallery.v1.GetUserInfoReq\x1a+.bilibili.pangu.gallery.v1.GetUserInfoReply\x12h\n\x0cListNFTByMid\x12*.bilibili.pangu.gallery.v1.ListNFTByMidReq\x1a,.bilibili.pangu.gallery.v1.ListNFTByMidReply\x12n\n\x0eListOrderByMid\x12,.bilibili.pangu.gallery.v1.ListOrderByMidReq\x1a..bilibili.pangu.gallery.v1.ListOrderByMidReply\x12_\n\tBasicInfo\x12\'.bilibili.pangu.gallery.v1.BasicInfoReq\x1a).bilibili.pangu.gallery.v1.BasicInfoReply\x12_\n\tUserCheck\x12\'.bilibili.pangu.gallery.v1.UserCheckReq\x1a).bilibili.pangu.gallery.v1.UserCheckReply\x12\x65\n\x0b\x41greePolicy\x12).bilibili.pangu.gallery.v1.AgreePolicyReq\x1a+.bilibili.pangu.gallery.v1.AgreePolicyReply\x12k\n\rGetLastPolicy\x12+.bilibili.pangu.gallery.v1.GetLastPolicyReq\x1a-.bilibili.pangu.gallery.v1.GetLastPolicyReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pangu.gallery.v1.gallery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GT14STATUS']._serialized_start=1845
  _globals['_GT14STATUS']._serialized_end=1895
  _globals['_NFTSTATUS']._serialized_start=1897
  _globals['_NFTSTATUS']._serialized_end=1946
  _globals['_POLICYAGREESTATUS']._serialized_start=1948
  _globals['_POLICYAGREESTATUS']._serialized_end=2008
  _globals['_POLICYTYPE']._serialized_start=2010
  _globals['_POLICYTYPE']._serialized_end=2064
  _globals['_AGREEPOLICYREPLY']._serialized_start=99
  _globals['_AGREEPOLICYREPLY']._serialized_end=117
  _globals['_AGREEPOLICYREQ']._serialized_start=119
  _globals['_AGREEPOLICYREQ']._serialized_end=212
  _globals['_BASICINFOREPLY']._serialized_start=215
  _globals['_BASICINFOREPLY']._serialized_end=353
  _globals['_BASICINFOREQ']._serialized_start=355
  _globals['_BASICINFOREQ']._serialized_end=382
  _globals['_DISPLAY']._serialized_start=384
  _globals['_DISPLAY']._serialized_end=478
  _globals['_GETLASTPOLICYREPLY']._serialized_start=480
  _globals['_GETLASTPOLICYREPLY']._serialized_end=558
  _globals['_GETLASTPOLICYREQ']._serialized_start=560
  _globals['_GETLASTPOLICYREQ']._serialized_end=638
  _globals['_GETUSERINFOREPLY']._serialized_start=640
  _globals['_GETUSERINFOREPLY']._serialized_end=740
  _globals['_GETUSERINFOREQ']._serialized_start=742
  _globals['_GETUSERINFOREQ']._serialized_end=771
  _globals['_LINK']._serialized_start=773
  _globals['_LINK']._serialized_end=835
  _globals['_LISTNFTBYMIDREPLY']._serialized_start=837
  _globals['_LISTNFTBYMIDREPLY']._serialized_end=934
  _globals['_LISTNFTBYMIDREQ']._serialized_start=936
  _globals['_LISTNFTBYMIDREQ']._serialized_end=1040
  _globals['_LISTORDERBYMIDREPLY']._serialized_start=1042
  _globals['_LISTORDERBYMIDREPLY']._serialized_end=1145
  _globals['_LISTORDERBYMIDREQ']._serialized_start=1147
  _globals['_LISTORDERBYMIDREQ']._serialized_end=1217
  _globals['_NFT']._serialized_start=1220
  _globals['_NFT']._serialized_end=1447
  _globals['_ORDER']._serialized_start=1450
  _globals['_ORDER']._serialized_end=1738
  _globals['_USERCHECKREPLY']._serialized_start=1740
  _globals['_USERCHECKREPLY']._serialized_end=1793
  _globals['_USERCHECKREQ']._serialized_start=1795
  _globals['_USERCHECKREQ']._serialized_end=1843
  _globals['_GALLERYINTERFACE']._serialized_start=2067
  _globals['_GALLERYINTERFACE']._serialized_end=2865
# @@protoc_insertion_point(module_scope)
