# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/show/region/v1/region.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/app/show/region/v1/region.proto\x12\x1b\x62ilibili.app.show.region.v1\"8\n\x0cRegionConfig\x12\x13\n\x0bscenes_name\x18\x01 \x01(\t\x12\x13\n\x0bscenes_type\x18\x02 \x01(\t\"\x85\x02\n\nRegionInfo\x12\x0b\n\x03tid\x18\x01 \x01(\x05\x12\x0c\n\x04reid\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x0c\n\x04goto\x18\x05 \x01(\t\x12\r\n\x05param\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\x05\x12\x12\n\nis_bangumi\x18\t \x01(\x05\x12\x39\n\x08\x63hildren\x18\n \x03(\x0b\x32\'.bilibili.app.show.region.v1.RegionInfo\x12\x39\n\x06\x63onfig\x18\x0b \x03(\x0b\x32).bilibili.app.show.region.v1.RegionConfig\"G\n\x0bRegionReply\x12\x38\n\x07regions\x18\x01 \x03(\x0b\x32\'.bilibili.app.show.region.v1.RegionInfo\"\x19\n\tRegionReq\x12\x0c\n\x04lang\x18\x01 \x01(\t2d\n\x06Region\x12Z\n\x06Region\x12&.bilibili.app.show.region.v1.RegionReq\x1a(.bilibili.app.show.region.v1.RegionReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.region.v1.region_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGIONCONFIG']._serialized_start=73
  _globals['_REGIONCONFIG']._serialized_end=129
  _globals['_REGIONINFO']._serialized_start=132
  _globals['_REGIONINFO']._serialized_end=393
  _globals['_REGIONREPLY']._serialized_start=395
  _globals['_REGIONREPLY']._serialized_end=466
  _globals['_REGIONREQ']._serialized_start=468
  _globals['_REGIONREQ']._serialized_end=493
  _globals['_REGION']._serialized_start=495
  _globals['_REGION']._serialized_end=595
# @@protoc_insertion_point(module_scope)
