"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudPlayConfig(google.protobuf.message.Message):
    """云端保存的播放器配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_PANORAMA_FIELD_NUMBER: builtins.int
    ENABLE_DOLBY_FIELD_NUMBER: builtins.int
    ENABLE_SHAKE_FIELD_NUMBER: builtins.int
    ENABLE_BACKGROUND_FIELD_NUMBER: builtins.int
    ENABLE_LOSS_LESS_FIELD_NUMBER: builtins.int
    @property
    def enable_panorama(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用杜比全景声"""
    @property
    def enable_dolby(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用杜比音效"""
    @property
    def enable_shake(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用震动"""
    @property
    def enable_background(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用后台播放"""
    @property
    def enable_loss_less(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """启用HIRES"""
    def __init__(
        self,
        *,
        enable_panorama: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_dolby: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_shake: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_background: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_loss_less: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_background", b"enable_background", "enable_dolby", b"enable_dolby", "enable_loss_less", b"enable_loss_less", "enable_panorama", b"enable_panorama", "enable_shake", b"enable_shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_background", b"enable_background", "enable_dolby", b"enable_dolby", "enable_loss_less", b"enable_loss_less", "enable_panorama", b"enable_panorama", "enable_shake", b"enable_shake"]) -> None: ...

global___CloudPlayConfig = CloudPlayConfig

@typing_extensions.final
class PlayConfig(google.protobuf.message.Message):
    """播放器策略配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOULD_AUTO_PLAY_FIELD_NUMBER: builtins.int
    SHOULD_AUTO_FULLSCREEN_FIELD_NUMBER: builtins.int
    ENABLE_PLAYURL_HTTPS_FIELD_NUMBER: builtins.int
    ENABLE_DANMAKU_INTERACTION_FIELD_NUMBER: builtins.int
    SMALL_SCREEN_STATUS_FIELD_NUMBER: builtins.int
    PLAYER_CODEC_MODE_KEY_FIELD_NUMBER: builtins.int
    ENABLE_GRAVITY_ROTATE_SCREEN_FIELD_NUMBER: builtins.int
    ENABLE_DANMAKU_MONOSPACED_FIELD_NUMBER: builtins.int
    ENABLE_EDIT_SUBTITLE_FIELD_NUMBER: builtins.int
    ENABLE_SUBTITLE_FIELD_NUMBER: builtins.int
    COLOR_FILTER_FIELD_NUMBER: builtins.int
    SHOULD_AUTO_STORY_FIELD_NUMBER: builtins.int
    LANDSCAPE_AUTO_STORY_FIELD_NUMBER: builtins.int
    VOLUME_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def should_auto_play(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def should_auto_fullscreen(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_playurl_https(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_danmaku_interaction(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def small_screen_status(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def player_codec_mode_key(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def enable_gravity_rotate_screen(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_danmaku_monospaced(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_edit_subtitle(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_subtitle(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def color_filter(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def should_auto_story(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def landscape_auto_story(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def volume_balance(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        should_auto_play: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        should_auto_fullscreen: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_playurl_https: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_danmaku_interaction: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        small_screen_status: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        player_codec_mode_key: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        enable_gravity_rotate_screen: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_danmaku_monospaced: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_edit_subtitle: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_subtitle: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        color_filter: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        should_auto_story: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        landscape_auto_story: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        volume_balance: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color_filter", b"color_filter", "enable_danmaku_interaction", b"enable_danmaku_interaction", "enable_danmaku_monospaced", b"enable_danmaku_monospaced", "enable_edit_subtitle", b"enable_edit_subtitle", "enable_gravity_rotate_screen", b"enable_gravity_rotate_screen", "enable_playurl_https", b"enable_playurl_https", "enable_subtitle", b"enable_subtitle", "landscape_auto_story", b"landscape_auto_story", "player_codec_mode_key", b"player_codec_mode_key", "should_auto_fullscreen", b"should_auto_fullscreen", "should_auto_play", b"should_auto_play", "should_auto_story", b"should_auto_story", "small_screen_status", b"small_screen_status", "volume_balance", b"volume_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color_filter", b"color_filter", "enable_danmaku_interaction", b"enable_danmaku_interaction", "enable_danmaku_monospaced", b"enable_danmaku_monospaced", "enable_edit_subtitle", b"enable_edit_subtitle", "enable_gravity_rotate_screen", b"enable_gravity_rotate_screen", "enable_playurl_https", b"enable_playurl_https", "enable_subtitle", b"enable_subtitle", "landscape_auto_story", b"landscape_auto_story", "player_codec_mode_key", b"player_codec_mode_key", "should_auto_fullscreen", b"should_auto_fullscreen", "should_auto_play", b"should_auto_play", "should_auto_story", b"should_auto_story", "small_screen_status", b"small_screen_status", "volume_balance", b"volume_balance"]) -> None: ...

global___PlayConfig = PlayConfig

@typing_extensions.final
class SpecificPlayConfig(google.protobuf.message.Message):
    """灰度测试特殊功能？"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_SEGMENTED_SECTION_FIELD_NUMBER: builtins.int
    @property
    def enable_segmented_section(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        enable_segmented_section: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_segmented_section", b"enable_segmented_section"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_segmented_section", b"enable_segmented_section"]) -> None: ...

global___SpecificPlayConfig = SpecificPlayConfig
