# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/device/device.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/metadata/device/device.proto\x12\x18\x62ilibili.metadata.device\"\xfc\x01\n\x06\x44\x65vice\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x10\n\x08platform\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x07 \x01(\t\x12\r\n\x05\x62rand\x18\x08 \x01(\t\x12\r\n\x05model\x18\t \x01(\t\x12\r\n\x05osver\x18\n \x01(\t\x12\x10\n\x08\x66p_local\x18\x0b \x01(\t\x12\x11\n\tfp_remote\x18\x0c \x01(\t\x12\x14\n\x0cversion_name\x18\r \x01(\t\x12\n\n\x02\x66p\x18\x0e \x01(\t\x12\x0b\n\x03\x66ts\x18\x0f \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.device.device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DEVICE']._serialized_start=68
  _globals['_DEVICE']._serialized_end=320
# @@protoc_insertion_point(module_scope)
