# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/community/govern/v1/govern.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1bilibili/polymer/community/govern/v1/govern.proto\x12\x1e\x62ilibili.polymer.app.govern.v1\"Z\n\x12\x41ntiHarassmentInfo\x12\r\n\x05limit\x18\x01 \x01(\x05\x12 \n\x18\x66ollow_time_limit_second\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x03 \x01(\x03\"\xe9\x03\n\x15\x41ntiHarassmentSetting\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x12\n\nauto_limit\x18\x02 \x01(\x08\x12>\n\x02im\x18\x03 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x41\n\x05reply\x18\x04 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12>\n\x02\x64m\x18\x05 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x44\n\x08reply_me\x18\x06 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x43\n\x07like_me\x18\x07 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x41\n\x05\x61t_me\x18\x08 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x1e\n\x16\x61uto_limit_expire_time\x18\t \x01(\x03\"U\n\x1dLoadAntiHarassmentSettingsReq\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x10\n\x08recv_mid\x18\x02 \x01(\x03\x12\x10\n\x08send_mid\x18\x03 \x01(\x03\"\xa9\x01\n\x1dLoadAntiHarassmentSettingsRsp\x12\x1b\n\x13\x61nti_harassment_ret\x18\x01 \x01(\x08\x12V\n\x17\x61nti_harassment_setting\x18\x02 \x01(\x0b\x32\x35.bilibili.polymer.app.govern.v1.AntiHarassmentSetting\x12\x13\n\x0bshow_window\x18\x03 \x01(\x05\"\x97\x01\n\x1eStoreAntiHarassmentSettingsReq\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12V\n\x17\x61nti_harassment_setting\x18\x03 \x01(\x0b\x32\x35.bilibili.polymer.app.govern.v1.AntiHarassmentSetting\" \n\x1eStoreAntiHarassmentSettingsRsp*k\n\x13\x41ntiHarassmentLimit\x12\x10\n\x0c\x44\x65\x66\x61ultLimit\x10\x00\x12\x0f\n\x0b\x46ollowLimit\x10\x01\x12\x11\n\rReFollowLimit\x10\x02\x12\x10\n\x0cTwoWayFollow\x10\x03\x12\x0c\n\x08\x41llLimit\x10\x04*[\n\x07\x42izType\x12\x12\n\x0eInvalidBizType\x10\x00\x12\x06\n\x02Im\x10\x01\x12\x06\n\x02\x44m\x10\x02\x12\t\n\x05Reply\x10\x03\x12\x0b\n\x07ReplyMe\x10\x04\x12\n\n\x06LikeMe\x10\x05\x12\x08\n\x04\x41tMe\x10\x06\x32\xd4\x02\n\x15\x41ntiHarassmentService\x12\x9d\x01\n\x1bStoreAntiHarassmentSettings\x12>.bilibili.polymer.app.govern.v1.StoreAntiHarassmentSettingsReq\x1a>.bilibili.polymer.app.govern.v1.StoreAntiHarassmentSettingsRsp\x12\x9a\x01\n\x1aLoadAntiHarassmentSettings\x12=.bilibili.polymer.app.govern.v1.LoadAntiHarassmentSettingsReq\x1a=.bilibili.polymer.app.govern.v1.LoadAntiHarassmentSettingsRspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.community.govern.v1.govern_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ANTIHARASSMENTLIMIT']._serialized_start=1116
  _globals['_ANTIHARASSMENTLIMIT']._serialized_end=1223
  _globals['_BIZTYPE']._serialized_start=1225
  _globals['_BIZTYPE']._serialized_end=1316
  _globals['_ANTIHARASSMENTINFO']._serialized_start=85
  _globals['_ANTIHARASSMENTINFO']._serialized_end=175
  _globals['_ANTIHARASSMENTSETTING']._serialized_start=178
  _globals['_ANTIHARASSMENTSETTING']._serialized_end=667
  _globals['_LOADANTIHARASSMENTSETTINGSREQ']._serialized_start=669
  _globals['_LOADANTIHARASSMENTSETTINGSREQ']._serialized_end=754
  _globals['_LOADANTIHARASSMENTSETTINGSRSP']._serialized_start=757
  _globals['_LOADANTIHARASSMENTSETTINGSRSP']._serialized_end=926
  _globals['_STOREANTIHARASSMENTSETTINGSREQ']._serialized_start=929
  _globals['_STOREANTIHARASSMENTSETTINGSREQ']._serialized_end=1080
  _globals['_STOREANTIHARASSMENTSETTINGSRSP']._serialized_start=1082
  _globals['_STOREANTIHARASSMENTSETTINGSRSP']._serialized_end=1114
  _globals['_ANTIHARASSMENTSERVICE']._serialized_start=1319
  _globals['_ANTIHARASSMENTSERVICE']._serialized_end=1659
# @@protoc_insertion_point(module_scope)
