# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/contract/v1/contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+bilibili/polymer/contract/v1/contract.proto\x12\x1c\x62ilibili.polymer.contract.v1\x1a\x1bgoogle/protobuf/empty.proto\"g\n\x10\x41\x64\x64\x43ontractReply\x12\x15\n\rallow_message\x18\x01 \x01(\x08\x12\x13\n\x0b\x61llow_reply\x18\x02 \x01(\x08\x12\x12\n\ninput_text\x18\x03 \x01(\t\x12\x13\n\x0binput_title\x18\x04 \x01(\t\"\x83\x01\n\x0e\x41\x64\x64\x43ontractReq\x12\x37\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\'.bilibili.polymer.contract.v1.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\"x\n\tCommonReq\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\r\n\x05spmid\x18\x07 \x01(\t\"0\n\x0c\x43ontractCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\"\x8e\x01\n\x13\x43ontractConfigReply\x12\x19\n\x11is_follow_display\x18\x01 \x01(\x05\x12\x19\n\x11is_triple_display\x18\x02 \x01(\x05\x12\x41\n\rcontract_card\x18\x03 \x01(\x0b\x32*.bilibili.polymer.contract.v1.ContractCard\"\x86\x01\n\x11\x43ontractConfigReq\x12\x37\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\'.bilibili.polymer.contract.v1.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\x32\xc4\x02\n\x08\x43ontract\x12S\n\x0b\x41\x64\x64\x43ontract\x12,.bilibili.polymer.contract.v1.AddContractReq\x1a\x16.google.protobuf.Empty\x12m\n\rAddContractV2\x12,.bilibili.polymer.contract.v1.AddContractReq\x1a..bilibili.polymer.contract.v1.AddContractReply\x12t\n\x0e\x43ontractConfig\x12/.bilibili.polymer.contract.v1.ContractConfigReq\x1a\x31.bilibili.polymer.contract.v1.ContractConfigReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.contract.v1.contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDCONTRACTREPLY']._serialized_start=106
  _globals['_ADDCONTRACTREPLY']._serialized_end=209
  _globals['_ADDCONTRACTREQ']._serialized_start=212
  _globals['_ADDCONTRACTREQ']._serialized_end=343
  _globals['_COMMONREQ']._serialized_start=345
  _globals['_COMMONREQ']._serialized_end=465
  _globals['_CONTRACTCARD']._serialized_start=467
  _globals['_CONTRACTCARD']._serialized_end=515
  _globals['_CONTRACTCONFIGREPLY']._serialized_start=518
  _globals['_CONTRACTCONFIGREPLY']._serialized_end=660
  _globals['_CONTRACTCONFIGREQ']._serialized_start=663
  _globals['_CONTRACTCONFIGREQ']._serialized_end=797
  _globals['_CONTRACT']._serialized_start=800
  _globals['_CONTRACT']._serialized_end=1124
# @@protoc_insertion_point(module_scope)
