"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ArchiveReply(google.protobuf.message.Message):
    """-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    EPISODIC_BUTTON_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BiliSpaceVideo]:
        """"""
    count: builtins.int
    """"""
    @property
    def episodic_button(self) -> global___EpisodicButton:
        """"""
    @property
    def order(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrderConfig]:
        """"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___BiliSpaceVideo] | None = ...,
        count: builtins.int = ...,
        episodic_button: global___EpisodicButton | None = ...,
        order: collections.abc.Iterable[global___OrderConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["episodic_button", b"episodic_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "episodic_button", b"episodic_button", "item", b"item", "order", b"order"]) -> None: ...

global___ArchiveReply = ArchiveReply

@typing_extensions.final
class ArchiveReq(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VMID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    vmid: builtins.int
    """"""
    pn: builtins.int
    """"""
    ps: builtins.int
    """"""
    order: builtins.str
    """"""
    def __init__(
        self,
        *,
        vmid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        order: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order", b"order", "pn", b"pn", "ps", b"ps", "vmid", b"vmid"]) -> None: ...

global___ArchiveReq = ArchiveReq

@typing_extensions.final
class Badge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    border_color: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___Badge = Badge

@typing_extensions.final
class BiliSpaceVideo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    IS_POPULAR_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    COVER_RIGHT_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    IS_STEINS_FIELD_NUMBER: builtins.int
    IS_UGCPAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    tname: builtins.str
    """"""
    duration: builtins.int
    """"""
    cover: builtins.str
    """"""
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    danmaku: builtins.str
    """"""
    play: builtins.int
    """"""
    ctime: builtins.int
    """"""
    state: builtins.bool
    """"""
    is_popular: builtins.bool
    """"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Badge]:
        """"""
    cover_right: builtins.str
    """"""
    bvid: builtins.str
    """"""
    is_steins: builtins.bool
    """"""
    is_ugcpay: builtins.bool
    """"""
    is_cooperation: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        tname: builtins.str = ...,
        duration: builtins.int = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        danmaku: builtins.str = ...,
        play: builtins.int = ...,
        ctime: builtins.int = ...,
        state: builtins.bool = ...,
        is_popular: builtins.bool = ...,
        badges: collections.abc.Iterable[global___Badge] | None = ...,
        cover_right: builtins.str = ...,
        bvid: builtins.str = ...,
        is_steins: builtins.bool = ...,
        is_ugcpay: builtins.bool = ...,
        is_cooperation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badges", b"badges", "bvid", b"bvid", "cover", b"cover", "cover_right", b"cover_right", "ctime", b"ctime", "danmaku", b"danmaku", "duration", b"duration", "is_cooperation", b"is_cooperation", "is_popular", b"is_popular", "is_steins", b"is_steins", "is_ugcpay", b"is_ugcpay", "param", b"param", "play", b"play", "state", b"state", "title", b"title", "tname", b"tname", "uri", b"uri"]) -> None: ...

global___BiliSpaceVideo = BiliSpaceVideo

@typing_extensions.final
class EpisodicButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "uri", b"uri"]) -> None: ...

global___EpisodicButton = EpisodicButton

@typing_extensions.final
class OrderConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    value: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "value", b"value"]) -> None: ...

global___OrderConfig = OrderConfig
