"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Device(google.protobuf.message.Message):
    """设备信息
    gRPC头部:x-bili-device-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    FP_LOCAL_FIELD_NUMBER: builtins.int
    FP_REMOTE_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    FP_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    app_id: builtins.int
    """产品id
    粉 白 蓝 直播姬 HD 海外 OTT 漫画 TV野版 小视频 网易漫画 网易漫画 网易漫画HD 国际版 东南亚版
    1  2  3    4    5   6    7   8     9     10      11       12       13       14       30
    """
    build: builtins.int
    """构建id"""
    buvid: builtins.str
    """设备buvid"""
    mobi_app: builtins.str
    """包类型"""
    platform: builtins.str
    """平台类型
    ios android
    """
    device: builtins.str
    """设备类型"""
    channel: builtins.str
    """渠道"""
    brand: builtins.str
    """手机品牌"""
    model: builtins.str
    """手机型号"""
    osver: builtins.str
    """系统版本"""
    fp_local: builtins.str
    """本地设备指纹"""
    fp_remote: builtins.str
    """远程设备指纹"""
    version_name: builtins.str
    """APP版本号"""
    fp: builtins.str
    """设备指纹, 不区分本地或远程设备指纹，作为推送目标的索引"""
    fts: builtins.int
    """首次启动时的毫秒时间戳"""
    def __init__(
        self,
        *,
        app_id: builtins.int = ...,
        build: builtins.int = ...,
        buvid: builtins.str = ...,
        mobi_app: builtins.str = ...,
        platform: builtins.str = ...,
        device: builtins.str = ...,
        channel: builtins.str = ...,
        brand: builtins.str = ...,
        model: builtins.str = ...,
        osver: builtins.str = ...,
        fp_local: builtins.str = ...,
        fp_remote: builtins.str = ...,
        version_name: builtins.str = ...,
        fp: builtins.str = ...,
        fts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "brand", b"brand", "build", b"build", "buvid", b"buvid", "channel", b"channel", "device", b"device", "fp", b"fp", "fp_local", b"fp_local", "fp_remote", b"fp_remote", "fts", b"fts", "mobi_app", b"mobi_app", "model", b"model", "osver", b"osver", "platform", b"platform", "version_name", b"version_name"]) -> None: ...

global___Device = Device
