# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/parabox/parabox.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/metadata/parabox/parabox.proto\x12\x19\x62ilibili.metadata.parabox\"!\n\x03\x45xp\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x05\"4\n\x04\x45xps\x12,\n\x04\x65xps\x18\x01 \x03(\x0b\x32\x1e.bilibili.metadata.parabox.Expb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.parabox.parabox_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EXP']._serialized_start=70
  _globals['_EXP']._serialized_end=103
  _globals['_EXPS']._serialized_start=105
  _globals['_EXPS']._serialized_end=157
# @@protoc_insertion_point(module_scope)
