# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/playerunite/pgcanymodel/pgcanymodel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.pgc.gateway.player.v2 import playurl_pb2 as bilibili_dot_pgc_dot_gateway_dot_player_dot_v2_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6bilibili/app/playerunite/pgcanymodel/pgcanymodel.proto\x12$bilibili.app.playerunite.pgcanymodel\x1a,bilibili/pgc/gateway/player/v2/playurl.proto\"\xd7\x02\n\x0bPGCAnyModel\x12\x46\n\x08\x62usiness\x18\x03 \x01(\x0b\x32\x34.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Event\x12;\n\tview_info\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.ViewInfo\x12I\n\rplay_ext_conf\x18\x06 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.PlayAbilityExtConf\x12\x42\n\rplay_ext_info\x18\x07 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.PlayExtInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playerunite.pgcanymodel.pgcanymodel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PGCANYMODEL']._serialized_start=143
  _globals['_PGCANYMODEL']._serialized_end=486
# @@protoc_insertion_point(module_scope)
