# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/play.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/app/distribution/setting/play.proto\x12&bilibili.app.distribution.setting.play\x1a/bilibili/app/distribution/v1/distribution.proto\"\xd8\x02\n\x0f\x43loudPlayConfig\x12@\n\x0f\x65nable_panorama\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12=\n\x0c\x65nable_dolby\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12=\n\x0c\x65nable_shake\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x42\n\x11\x65nable_background\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x41\n\x10\x65nable_loss_less\x18\x05 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\xec\x07\n\nPlayConfig\x12\x41\n\x10should_auto_play\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12G\n\x16should_auto_fullscreen\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14\x65nable_playurl_https\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12K\n\x1a\x65nable_danmaku_interaction\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x13small_screen_status\x18\x05 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12G\n\x15player_codec_mode_key\x18\x06 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12M\n\x1c\x65nable_gravity_rotate_screen\x18\x07 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12J\n\x19\x65nable_danmaku_monospaced\x18\x08 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14\x65nable_edit_subtitle\x18\t \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12@\n\x0f\x65nable_subtitle\x18\n \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12>\n\x0c\x63olor_filter\x18\x0b \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x42\n\x11should_auto_story\x18\x0c \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14landscape_auto_story\x18\r \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12?\n\x0evolume_balance\x18\x0e \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"_\n\x12SpecificPlayConfig\x12I\n\x18\x65nable_segmented_section\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.play_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOUDPLAYCONFIG']._serialized_start=138
  _globals['_CLOUDPLAYCONFIG']._serialized_end=482
  _globals['_PLAYCONFIG']._serialized_start=485
  _globals['_PLAYCONFIG']._serialized_end=1489
  _globals['_SPECIFICPLAYCONFIG']._serialized_start=1491
  _globals['_SPECIFICPLAYCONFIG']._serialized_end=1586
# @@protoc_insertion_point(module_scope)
