"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Bubble(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAGRAPHS_FIELD_NUMBER: builtins.int
    @property
    def paragraphs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.app.dynamic.v2.dynamic_pb2.Paragraph]: ...
    def __init__(
        self,
        *,
        paragraphs: collections.abc.Iterable[bilibili.app.dynamic.v2.dynamic_pb2.Paragraph] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["paragraphs", b"paragraphs"]) -> None: ...

global___Bubble = Bubble

@typing_extensions.final
class ChatResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    REWRITE_WORD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    session_id: builtins.str
    """"""
    @property
    def bubble(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Bubble]:
        """"""
    rewrite_word: builtins.str
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        session_id: builtins.str = ...,
        bubble: collections.abc.Iterable[global___Bubble] | None = ...,
        rewrite_word: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "code", b"code", "rewrite_word", b"rewrite_word", "session_id", b"session_id", "title", b"title"]) -> None: ...

global___ChatResult = ChatResult
