# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/tv/proj.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/broadcast/message/tv/proj.proto\x12\x1d\x62ilibili.broadcast.message.tv\x1a\x1bgoogle/protobuf/empty.proto\"\x9a\x01\n\tProjReply\x12\x10\n\x08\x63md_type\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x12\n\nvideo_type\x18\x05 \x01(\x03\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x11\n\tseason_id\x18\x07 \x01(\x03\x12\x0f\n\x07seek_ts\x18\x08 \x01(\x03\x12\r\n\x05\x65xtra\x18\t \x01(\t\"<\n\x10LiveStatusNotify\x12\x0e\n\x06status\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\x1c\n\rEsportsNotify\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\"H\n\x0fPublicityNotify\x12\x14\n\x0cpublicity_id\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x03\"!\n\x0eLiveSkipNotify\x12\x0f\n\x07live_id\x18\x01 \x01(\x03\x32\xa8\x03\n\x02Tv\x12J\n\x04Proj\x12\x16.google.protobuf.Empty\x1a(.bilibili.broadcast.message.tv.ProjReply0\x01\x12W\n\nLiveStatus\x12\x16.google.protobuf.Empty\x1a/.bilibili.broadcast.message.tv.LiveStatusNotify0\x01\x12Q\n\x07\x45sports\x12\x16.google.protobuf.Empty\x1a,.bilibili.broadcast.message.tv.EsportsNotify0\x01\x12U\n\tPublicity\x12\x16.google.protobuf.Empty\x1a..bilibili.broadcast.message.tv.PublicityNotify0\x01\x12S\n\x08LiveSkip\x12\x16.google.protobuf.Empty\x1a-.bilibili.broadcast.message.tv.LiveSkipNotify0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.tv.proj_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PROJREPLY']._serialized_start=105
  _globals['_PROJREPLY']._serialized_end=259
  _globals['_LIVESTATUSNOTIFY']._serialized_start=261
  _globals['_LIVESTATUSNOTIFY']._serialized_end=321
  _globals['_ESPORTSNOTIFY']._serialized_start=323
  _globals['_ESPORTSNOTIFY']._serialized_end=351
  _globals['_PUBLICITYNOTIFY']._serialized_start=353
  _globals['_PUBLICITYNOTIFY']._serialized_end=425
  _globals['_LIVESKIPNOTIFY']._serialized_start=427
  _globals['_LIVESKIPNOTIFY']._serialized_end=460
  _globals['_TV']._serialized_start=463
  _globals['_TV']._serialized_end=887
# @@protoc_insertion_point(module_scope)
