"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DynamicButtonClickBizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynamicButtonClickBizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynamicButtonClickBizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE: _DynamicButtonClickBizType.ValueType  # 0
    """"""
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE: _DynamicButtonClickBizType.ValueType  # 1
    """"""
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP: _DynamicButtonClickBizType.ValueType  # 2
    """"""

class DynamicButtonClickBizType(_DynamicButtonClickBizType, metaclass=_DynamicButtonClickBizTypeEnumTypeWrapper):
    """"""

DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE: DynamicButtonClickBizType.ValueType  # 0
""""""
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE: DynamicButtonClickBizType.ValueType  # 1
""""""
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP: DynamicButtonClickBizType.ValueType  # 2
""""""
global___DynamicButtonClickBizType = DynamicButtonClickBizType

class _ReserveButtonMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveButtonModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveButtonMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_BUTTON_MODE_NONE: _ReserveButtonMode.ValueType  # 0
    """"""
    RESERVE_BUTTON_MODE_RESERVE: _ReserveButtonMode.ValueType  # 1
    """"""
    RESERVE_BUTTON_MODE_UP_CANCEL: _ReserveButtonMode.ValueType  # 2
    """"""

class ReserveButtonMode(_ReserveButtonMode, metaclass=_ReserveButtonModeEnumTypeWrapper):
    """"""

RESERVE_BUTTON_MODE_NONE: ReserveButtonMode.ValueType  # 0
""""""
RESERVE_BUTTON_MODE_RESERVE: ReserveButtonMode.ValueType  # 1
""""""
RESERVE_BUTTON_MODE_UP_CANCEL: ReserveButtonMode.ValueType  # 2
""""""
global___ReserveButtonMode = ReserveButtonMode

class _ReserveButtonStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveButtonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveButtonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_BUTTON_STATUS_NONE: _ReserveButtonStatus.ValueType  # 0
    """"""
    RESERVE_BUTTON_STATUS_UNCHECK: _ReserveButtonStatus.ValueType  # 1
    """"""
    RESERVE_BUTTON_STATUS_CHECK: _ReserveButtonStatus.ValueType  # 2
    """"""

class ReserveButtonStatus(_ReserveButtonStatus, metaclass=_ReserveButtonStatusEnumTypeWrapper):
    """"""

RESERVE_BUTTON_STATUS_NONE: ReserveButtonStatus.ValueType  # 0
""""""
RESERVE_BUTTON_STATUS_UNCHECK: ReserveButtonStatus.ValueType  # 1
""""""
RESERVE_BUTTON_STATUS_CHECK: ReserveButtonStatus.ValueType  # 2
""""""
global___ReserveButtonStatus = ReserveButtonStatus

@typing_extensions.final
class CreateDynReq(google.protobuf.message.Message):
    """创建动态-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    PICS_FIELD_NUMBER: builtins.int
    REPOST_SRC_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    SKETCH_TYPE_FIELD_NUMBER: builtins.int
    SKETCH_FIELD_NUMBER: builtins.int
    PROGRAM_FIELD_NUMBER: builtins.int
    DYN_TAG_FIELD_NUMBER: builtins.int
    ATTACH_CARD_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    UPLOAD_ID_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.UserCreateMeta:
        """用户创建接口meta信息"""
    @property
    def content(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent:
        """发布的内容"""
    scene: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateScene.ValueType
    """发布类型"""
    @property
    def pics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.dynamic.common.dynamic_pb2.CreatePic]:
        """图片内容"""
    @property
    def repost_src(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.DynIdentity:
        """转发源"""
    @property
    def video(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateDynVideo:
        """动态视频"""
    sketch_type: builtins.int
    """通用模板类型：2048方图 2049竖图 其他值无效"""
    @property
    def sketch(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Sketch:
        """通用模板的元内容（网页内容）"""
    @property
    def program(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Program:
        """小程序的内容"""
    @property
    def dyn_tag(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTag:
        """动态附加小卡"""
    @property
    def attach_card(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateAttachCard:
        """动态附加大卡"""
    @property
    def option(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateOption:
        """特殊的创建选项"""
    @property
    def topic(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTopic:
        """"""
    upload_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        meta: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.UserCreateMeta | None = ...,
        content: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent | None = ...,
        scene: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateScene.ValueType = ...,
        pics: collections.abc.Iterable[bilibili.dynamic.common.dynamic_pb2.CreatePic] | None = ...,
        repost_src: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.DynIdentity | None = ...,
        video: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateDynVideo | None = ...,
        sketch_type: builtins.int = ...,
        sketch: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Sketch | None = ...,
        program: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Program | None = ...,
        dyn_tag: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTag | None = ...,
        attach_card: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateAttachCard | None = ...,
        option: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateOption | None = ...,
        topic: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTopic | None = ...,
        upload_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attach_card", b"attach_card", "content", b"content", "dyn_tag", b"dyn_tag", "meta", b"meta", "option", b"option", "program", b"program", "repost_src", b"repost_src", "sketch", b"sketch", "topic", b"topic", "video", b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attach_card", b"attach_card", "content", b"content", "dyn_tag", b"dyn_tag", "meta", b"meta", "option", b"option", "pics", b"pics", "program", b"program", "repost_src", b"repost_src", "scene", b"scene", "sketch", b"sketch", "sketch_type", b"sketch_type", "topic", b"topic", "upload_id", b"upload_id", "video", b"video"]) -> None: ...

global___CreateDynReq = CreateDynReq

@typing_extensions.final
class CreateInitCheckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENE_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    REPOST_FIELD_NUMBER: builtins.int
    scene: builtins.int
    """"""
    @property
    def meta(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.MetaDataCtrl:
        """"""
    @property
    def repost(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.RepostInitCheck:
        """"""
    def __init__(
        self,
        *,
        scene: builtins.int = ...,
        meta: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.MetaDataCtrl | None = ...,
        repost: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.RepostInitCheck | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta", "repost", b"repost"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta", "repost", b"repost", "scene", b"scene"]) -> None: ...

global___CreateInitCheckReq = CreateInitCheckReq

@typing_extensions.final
class CreatePageInfosReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic_id", b"topic_id"]) -> None: ...

global___CreatePageInfosReq = CreatePageInfosReq

@typing_extensions.final
class CreatePageInfosRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def topic(self) -> global___CreatePageTopicInfo:
        """"""
    def __init__(
        self,
        *,
        topic: global___CreatePageTopicInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___CreatePageInfosRsp = CreatePageInfosRsp

@typing_extensions.final
class CreatePageTopicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic_id", b"topic_id", "topic_name", b"topic_name"]) -> None: ...

global___CreatePageTopicInfo = CreatePageTopicInfo

@typing_extensions.final
class CreatePermissionButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: global___DynamicButtonClickBizType.ValueType
    """"""
    def __init__(
        self,
        *,
        type: global___DynamicButtonClickBizType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___CreatePermissionButtonClickReq = CreatePermissionButtonClickReq

@typing_extensions.final
class CreatePermissionButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePermissionButtonClickRsp = CreatePermissionButtonClickRsp

@typing_extensions.final
class CreatePlusButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePlusButtonClickReq = CreatePlusButtonClickReq

@typing_extensions.final
class CreatePlusButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePlusButtonClickRsp = CreatePlusButtonClickRsp

@typing_extensions.final
class DynamicButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DynamicButtonClickReq = DynamicButtonClickReq

@typing_extensions.final
class DynamicButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DynamicButtonClickRsp = DynamicButtonClickRsp

@typing_extensions.final
class HotSearchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HotSearchReq = HotSearchReq

@typing_extensions.final
class HotSearchRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Item(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        WORDS_FIELD_NUMBER: builtins.int
        words: builtins.str
        """"""
        def __init__(
            self,
            *,
            words: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["words", b"words"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HotSearchRsp.Item]:
        """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___HotSearchRsp.Item] | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "version", b"version"]) -> None: ...

global___HotSearchRsp = HotSearchRsp

@typing_extensions.final
class ReserveButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    RESERVE_TOTAL_FIELD_NUMBER: builtins.int
    CUR_BTN_STATUS_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    reserve_id: builtins.int
    """"""
    reserve_total: builtins.int
    """"""
    cur_btn_status: builtins.int
    """"""
    spmid: builtins.str
    """"""
    dyn_id: builtins.int
    """"""
    dyn_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        reserve_id: builtins.int = ...,
        reserve_total: builtins.int = ...,
        cur_btn_status: builtins.int = ...,
        spmid: builtins.str = ...,
        dyn_id: builtins.int = ...,
        dyn_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur_btn_status", b"cur_btn_status", "dyn_id", b"dyn_id", "dyn_type", b"dyn_type", "reserve_id", b"reserve_id", "reserve_total", b"reserve_total", "spmid", b"spmid", "uid", b"uid"]) -> None: ...

global___ReserveButtonClickReq = ReserveButtonClickReq

@typing_extensions.final
class ReserveButtonClickResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FINAL_BTN_STATUS_FIELD_NUMBER: builtins.int
    BTN_MODE_FIELD_NUMBER: builtins.int
    RESERVE_UPDATE_FIELD_NUMBER: builtins.int
    DESC_UPDATE_FIELD_NUMBER: builtins.int
    HAS_ACTIVITY_FIELD_NUMBER: builtins.int
    ACTIVITY_URL_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    final_btn_status: global___ReserveButtonStatus.ValueType
    """"""
    btn_mode: global___ReserveButtonMode.ValueType
    """"""
    reserve_update: builtins.int
    """"""
    desc_update: builtins.str
    """"""
    has_activity: builtins.bool
    """"""
    activity_url: builtins.str
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        final_btn_status: global___ReserveButtonStatus.ValueType = ...,
        btn_mode: global___ReserveButtonMode.ValueType = ...,
        reserve_update: builtins.int = ...,
        desc_update: builtins.str = ...,
        has_activity: builtins.bool = ...,
        activity_url: builtins.str = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_url", b"activity_url", "btn_mode", b"btn_mode", "desc_update", b"desc_update", "final_btn_status", b"final_btn_status", "has_activity", b"has_activity", "reserve_update", b"reserve_update", "toast", b"toast"]) -> None: ...

global___ReserveButtonClickResp = ReserveButtonClickResp

@typing_extensions.final
class SubmitCheckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    PICS_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent:
        """"""
    @property
    def pics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.dynamic.common.dynamic_pb2.CreatePic]:
        """"""
    def __init__(
        self,
        *,
        content: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent | None = ...,
        pics: collections.abc.Iterable[bilibili.dynamic.common.dynamic_pb2.CreatePic] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "pics", b"pics"]) -> None: ...

global___SubmitCheckReq = SubmitCheckReq

@typing_extensions.final
class SubmitCheckRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SubmitCheckRsp = SubmitCheckRsp

@typing_extensions.final
class SuggestReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    s: builtins.str
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        s: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["s", b"s", "type", b"type"]) -> None: ...

global___SuggestReq = SuggestReq

@typing_extensions.final
class SuggestRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    track_id: builtins.str
    """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[builtins.str] | None = ...,
        track_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "track_id", b"track_id", "version", b"version"]) -> None: ...

global___SuggestRsp = SuggestRsp
