# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dagw/component/avatar/v1/plugin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.dagw.component.avatar.common import common_pb2 as bilibili_dot_dagw_dot_component_dot_avatar_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/dagw/component/avatar/v1/plugin.proto\x12(bilibili.dagw.component.avatar.v1.plugin\x1a\x32\x62ilibili/dagw/component/avatar/common/common.proto\"\x7f\n\x18\x43ommentDoubleClickConfig\x12J\n\x0binteraction\x18\x01 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.v1.plugin.Interaction\x12\x17\n\x0f\x61nimation_scale\x18\x02 \x01(\x01\"U\n\nGyroConfig\x12G\n\tgyroscope\x18\x01 \x01(\x0b\x32\x34.bilibili.dagw.component.avatar.v1.plugin.NFTImageV2\"\x94\x01\n\x12GyroscopeContentV2\x12\x10\n\x08\x66ile_url\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\x02\x12]\n\x14physical_orientation\x18\x03 \x03(\x0b\x32?.bilibili.dagw.component.avatar.v1.plugin.PhysicalOrientationV2\"y\n\x11GyroscopeEntityV2\x12\x14\n\x0c\x64isplay_type\x18\x01 \x01(\t\x12N\n\x08\x63ontents\x18\x02 \x03(\x0b\x32<.bilibili.dagw.component.avatar.v1.plugin.GyroscopeContentV2\"S\n\x0bInteraction\x12\x0e\n\x06nft_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\r\n\x05itype\x18\x03 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x04 \x01(\t\"\"\n\x0fLiveAnimeConfig\x12\x0f\n\x07is_live\x18\x01 \x01(\x08\"\xb6\x01\n\rLiveAnimeItem\x12\x41\n\x05\x63olor\x18\x01 \x01(\x0b\x32\x32.bilibili.dagw.component.avatar.common.ColorConfig\x12\x13\n\x0bstart_ratio\x18\x02 \x01(\x01\x12\x11\n\tend_ratio\x18\x03 \x01(\x01\x12\x14\n\x0cstart_stroke\x18\x04 \x01(\x01\x12\x15\n\rstart_opacity\x18\x05 \x01(\x01\x12\r\n\x05phase\x18\x06 \x01(\x03\"\\\n\nNFTImageV2\x12N\n\tgyroscope\x18\x01 \x03(\x0b\x32;.bilibili.dagw.component.avatar.v1.plugin.GyroscopeEntityV2\"<\n\x1cPhysicalOrientationAnimation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x62\x65zier\x18\x03 \x01(\t\"\x81\x01\n\x15PhysicalOrientationV2\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Z\n\nanimations\x18\x03 \x03(\x0b\x32\x46.bilibili.dagw.component.avatar.v1.plugin.PhysicalOrientationAnimationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dagw.component.avatar.v1.plugin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMENTDOUBLECLICKCONFIG']._serialized_start=144
  _globals['_COMMENTDOUBLECLICKCONFIG']._serialized_end=271
  _globals['_GYROCONFIG']._serialized_start=273
  _globals['_GYROCONFIG']._serialized_end=358
  _globals['_GYROSCOPECONTENTV2']._serialized_start=361
  _globals['_GYROSCOPECONTENTV2']._serialized_end=509
  _globals['_GYROSCOPEENTITYV2']._serialized_start=511
  _globals['_GYROSCOPEENTITYV2']._serialized_end=632
  _globals['_INTERACTION']._serialized_start=634
  _globals['_INTERACTION']._serialized_end=717
  _globals['_LIVEANIMECONFIG']._serialized_start=719
  _globals['_LIVEANIMECONFIG']._serialized_end=753
  _globals['_LIVEANIMEITEM']._serialized_start=756
  _globals['_LIVEANIMEITEM']._serialized_end=938
  _globals['_NFTIMAGEV2']._serialized_start=940
  _globals['_NFTIMAGEV2']._serialized_end=1032
  _globals['_PHYSICALORIENTATIONANIMATION']._serialized_start=1034
  _globals['_PHYSICALORIENTATIONANIMATION']._serialized_end=1094
  _globals['_PHYSICALORIENTATIONV2']._serialized_start=1097
  _globals['_PHYSICALORIENTATIONV2']._serialized_end=1226
# @@protoc_insertion_point(module_scope)
